"Main interface for sagemaker service Client"
from __future__ import annotations

from datetime import datetime
from typing import Any, Dict, List
from botocore.client import BaseClient
from botocore.exceptions import ClientError as Boto3ClientError
from botocore.paginate import Paginator as Boto3Paginator
from botocore.waiter import Waiter as Boto3Waiter
from mypy_boto3.type_defs import Literal, overload

# pylint: disable=import-self
import mypy_boto3_sagemaker.client as client_scope

# pylint: disable=import-self
import mypy_boto3_sagemaker.paginator as paginator_scope
from mypy_boto3_sagemaker.type_defs import (
    ClientAddTagsResponseTypeDef,
    ClientAddTagsTagsTypeDef,
    ClientAssociateTrialComponentResponseTypeDef,
    ClientCreateAlgorithmInferenceSpecificationTypeDef,
    ClientCreateAlgorithmResponseTypeDef,
    ClientCreateAlgorithmTrainingSpecificationTypeDef,
    ClientCreateAlgorithmValidationSpecificationTypeDef,
    ClientCreateAppResourceSpecTypeDef,
    ClientCreateAppResponseTypeDef,
    ClientCreateAppTagsTypeDef,
    ClientCreateAutoMlJobAutoMLJobConfigTypeDef,
    ClientCreateAutoMlJobAutoMLJobObjectiveTypeDef,
    ClientCreateAutoMlJobInputDataConfigTypeDef,
    ClientCreateAutoMlJobOutputDataConfigTypeDef,
    ClientCreateAutoMlJobResponseTypeDef,
    ClientCreateAutoMlJobTagsTypeDef,
    ClientCreateCodeRepositoryGitConfigTypeDef,
    ClientCreateCodeRepositoryResponseTypeDef,
    ClientCreateCompilationJobInputConfigTypeDef,
    ClientCreateCompilationJobOutputConfigTypeDef,
    ClientCreateCompilationJobResponseTypeDef,
    ClientCreateCompilationJobStoppingConditionTypeDef,
    ClientCreateDomainDefaultUserSettingsTypeDef,
    ClientCreateDomainResponseTypeDef,
    ClientCreateDomainTagsTypeDef,
    ClientCreateEndpointConfigDataCaptureConfigTypeDef,
    ClientCreateEndpointConfigProductionVariantsTypeDef,
    ClientCreateEndpointConfigResponseTypeDef,
    ClientCreateEndpointConfigTagsTypeDef,
    ClientCreateEndpointResponseTypeDef,
    ClientCreateEndpointTagsTypeDef,
    ClientCreateExperimentResponseTypeDef,
    ClientCreateExperimentTagsTypeDef,
    ClientCreateFlowDefinitionHumanLoopActivationConfigTypeDef,
    ClientCreateFlowDefinitionHumanLoopConfigTypeDef,
    ClientCreateFlowDefinitionOutputConfigTypeDef,
    ClientCreateFlowDefinitionResponseTypeDef,
    ClientCreateFlowDefinitionTagsTypeDef,
    ClientCreateHumanTaskUiResponseTypeDef,
    ClientCreateHumanTaskUiTagsTypeDef,
    ClientCreateHumanTaskUiUiTemplateTypeDef,
    ClientCreateHyperParameterTuningJobHyperParameterTuningJobConfigTypeDef,
    ClientCreateHyperParameterTuningJobResponseTypeDef,
    ClientCreateHyperParameterTuningJobTagsTypeDef,
    ClientCreateHyperParameterTuningJobTrainingJobDefinitionTypeDef,
    ClientCreateHyperParameterTuningJobTrainingJobDefinitionsTypeDef,
    ClientCreateHyperParameterTuningJobWarmStartConfigTypeDef,
    ClientCreateLabelingJobHumanTaskConfigTypeDef,
    ClientCreateLabelingJobInputConfigTypeDef,
    ClientCreateLabelingJobLabelingJobAlgorithmsConfigTypeDef,
    ClientCreateLabelingJobOutputConfigTypeDef,
    ClientCreateLabelingJobResponseTypeDef,
    ClientCreateLabelingJobStoppingConditionsTypeDef,
    ClientCreateLabelingJobTagsTypeDef,
    ClientCreateModelContainersTypeDef,
    ClientCreateModelPackageInferenceSpecificationTypeDef,
    ClientCreateModelPackageResponseTypeDef,
    ClientCreateModelPackageSourceAlgorithmSpecificationTypeDef,
    ClientCreateModelPackageValidationSpecificationTypeDef,
    ClientCreateModelPrimaryContainerTypeDef,
    ClientCreateModelResponseTypeDef,
    ClientCreateModelTagsTypeDef,
    ClientCreateModelVpcConfigTypeDef,
    ClientCreateMonitoringScheduleMonitoringScheduleConfigTypeDef,
    ClientCreateMonitoringScheduleResponseTypeDef,
    ClientCreateMonitoringScheduleTagsTypeDef,
    ClientCreateNotebookInstanceLifecycleConfigOnCreateTypeDef,
    ClientCreateNotebookInstanceLifecycleConfigOnStartTypeDef,
    ClientCreateNotebookInstanceLifecycleConfigResponseTypeDef,
    ClientCreateNotebookInstanceResponseTypeDef,
    ClientCreateNotebookInstanceTagsTypeDef,
    ClientCreatePresignedDomainUrlResponseTypeDef,
    ClientCreatePresignedNotebookInstanceUrlResponseTypeDef,
    ClientCreateProcessingJobAppSpecificationTypeDef,
    ClientCreateProcessingJobExperimentConfigTypeDef,
    ClientCreateProcessingJobNetworkConfigTypeDef,
    ClientCreateProcessingJobProcessingInputsTypeDef,
    ClientCreateProcessingJobProcessingOutputConfigTypeDef,
    ClientCreateProcessingJobProcessingResourcesTypeDef,
    ClientCreateProcessingJobResponseTypeDef,
    ClientCreateProcessingJobStoppingConditionTypeDef,
    ClientCreateProcessingJobTagsTypeDef,
    ClientCreateTrainingJobAlgorithmSpecificationTypeDef,
    ClientCreateTrainingJobCheckpointConfigTypeDef,
    ClientCreateTrainingJobDebugHookConfigTypeDef,
    ClientCreateTrainingJobDebugRuleConfigurationsTypeDef,
    ClientCreateTrainingJobExperimentConfigTypeDef,
    ClientCreateTrainingJobInputDataConfigTypeDef,
    ClientCreateTrainingJobOutputDataConfigTypeDef,
    ClientCreateTrainingJobResourceConfigTypeDef,
    ClientCreateTrainingJobResponseTypeDef,
    ClientCreateTrainingJobStoppingConditionTypeDef,
    ClientCreateTrainingJobTagsTypeDef,
    ClientCreateTrainingJobTensorBoardOutputConfigTypeDef,
    ClientCreateTrainingJobVpcConfigTypeDef,
    ClientCreateTransformJobDataProcessingTypeDef,
    ClientCreateTransformJobExperimentConfigTypeDef,
    ClientCreateTransformJobResponseTypeDef,
    ClientCreateTransformJobTagsTypeDef,
    ClientCreateTransformJobTransformInputTypeDef,
    ClientCreateTransformJobTransformOutputTypeDef,
    ClientCreateTransformJobTransformResourcesTypeDef,
    ClientCreateTrialComponentInputArtifactsTypeDef,
    ClientCreateTrialComponentOutputArtifactsTypeDef,
    ClientCreateTrialComponentParametersTypeDef,
    ClientCreateTrialComponentResponseTypeDef,
    ClientCreateTrialComponentStatusTypeDef,
    ClientCreateTrialComponentTagsTypeDef,
    ClientCreateTrialResponseTypeDef,
    ClientCreateTrialTagsTypeDef,
    ClientCreateUserProfileResponseTypeDef,
    ClientCreateUserProfileTagsTypeDef,
    ClientCreateUserProfileUserSettingsTypeDef,
    ClientCreateWorkteamMemberDefinitionsTypeDef,
    ClientCreateWorkteamNotificationConfigurationTypeDef,
    ClientCreateWorkteamResponseTypeDef,
    ClientCreateWorkteamTagsTypeDef,
    ClientDeleteDomainRetentionPolicyTypeDef,
    ClientDeleteExperimentResponseTypeDef,
    ClientDeleteTrialComponentResponseTypeDef,
    ClientDeleteTrialResponseTypeDef,
    ClientDeleteWorkteamResponseTypeDef,
    ClientDescribeAlgorithmResponseTypeDef,
    ClientDescribeAppResponseTypeDef,
    ClientDescribeAutoMlJobResponseTypeDef,
    ClientDescribeCodeRepositoryResponseTypeDef,
    ClientDescribeCompilationJobResponseTypeDef,
    ClientDescribeDomainResponseTypeDef,
    ClientDescribeEndpointConfigResponseTypeDef,
    ClientDescribeEndpointResponseTypeDef,
    ClientDescribeExperimentResponseTypeDef,
    ClientDescribeFlowDefinitionResponseTypeDef,
    ClientDescribeHumanTaskUiResponseTypeDef,
    ClientDescribeHyperParameterTuningJobResponseTypeDef,
    ClientDescribeLabelingJobResponseTypeDef,
    ClientDescribeModelPackageResponseTypeDef,
    ClientDescribeModelResponseTypeDef,
    ClientDescribeMonitoringScheduleResponseTypeDef,
    ClientDescribeNotebookInstanceLifecycleConfigResponseTypeDef,
    ClientDescribeNotebookInstanceResponseTypeDef,
    ClientDescribeProcessingJobResponseTypeDef,
    ClientDescribeSubscribedWorkteamResponseTypeDef,
    ClientDescribeTrainingJobResponseTypeDef,
    ClientDescribeTransformJobResponseTypeDef,
    ClientDescribeTrialComponentResponseTypeDef,
    ClientDescribeTrialResponseTypeDef,
    ClientDescribeUserProfileResponseTypeDef,
    ClientDescribeWorkteamResponseTypeDef,
    ClientDisassociateTrialComponentResponseTypeDef,
    ClientGetSearchSuggestionsResponseTypeDef,
    ClientGetSearchSuggestionsSuggestionQueryTypeDef,
    ClientListAlgorithmsResponseTypeDef,
    ClientListAppsResponseTypeDef,
    ClientListAutoMlJobsResponseTypeDef,
    ClientListCandidatesForAutoMlJobResponseTypeDef,
    ClientListCodeRepositoriesResponseTypeDef,
    ClientListCompilationJobsResponseTypeDef,
    ClientListDomainsResponseTypeDef,
    ClientListEndpointConfigsResponseTypeDef,
    ClientListEndpointsResponseTypeDef,
    ClientListExperimentsResponseTypeDef,
    ClientListFlowDefinitionsResponseTypeDef,
    ClientListHumanTaskUisResponseTypeDef,
    ClientListHyperParameterTuningJobsResponseTypeDef,
    ClientListLabelingJobsForWorkteamResponseTypeDef,
    ClientListLabelingJobsResponseTypeDef,
    ClientListModelPackagesResponseTypeDef,
    ClientListModelsResponseTypeDef,
    ClientListMonitoringExecutionsResponseTypeDef,
    ClientListMonitoringSchedulesResponseTypeDef,
    ClientListNotebookInstanceLifecycleConfigsResponseTypeDef,
    ClientListNotebookInstancesResponseTypeDef,
    ClientListProcessingJobsResponseTypeDef,
    ClientListSubscribedWorkteamsResponseTypeDef,
    ClientListTagsResponseTypeDef,
    ClientListTrainingJobsForHyperParameterTuningJobResponseTypeDef,
    ClientListTrainingJobsResponseTypeDef,
    ClientListTransformJobsResponseTypeDef,
    ClientListTrialComponentsResponseTypeDef,
    ClientListTrialsResponseTypeDef,
    ClientListUserProfilesResponseTypeDef,
    ClientListWorkteamsResponseTypeDef,
    ClientRenderUiTemplateResponseTypeDef,
    ClientRenderUiTemplateTaskTypeDef,
    ClientRenderUiTemplateUiTemplateTypeDef,
    ClientSearchResponseTypeDef,
    ClientSearchSearchExpressionTypeDef,
    ClientUpdateCodeRepositoryGitConfigTypeDef,
    ClientUpdateCodeRepositoryResponseTypeDef,
    ClientUpdateDomainDefaultUserSettingsTypeDef,
    ClientUpdateDomainResponseTypeDef,
    ClientUpdateEndpointResponseTypeDef,
    ClientUpdateEndpointWeightsAndCapacitiesDesiredWeightsAndCapacitiesTypeDef,
    ClientUpdateEndpointWeightsAndCapacitiesResponseTypeDef,
    ClientUpdateExperimentResponseTypeDef,
    ClientUpdateMonitoringScheduleMonitoringScheduleConfigTypeDef,
    ClientUpdateMonitoringScheduleResponseTypeDef,
    ClientUpdateNotebookInstanceLifecycleConfigOnCreateTypeDef,
    ClientUpdateNotebookInstanceLifecycleConfigOnStartTypeDef,
    ClientUpdateTrialComponentInputArtifactsTypeDef,
    ClientUpdateTrialComponentOutputArtifactsTypeDef,
    ClientUpdateTrialComponentParametersTypeDef,
    ClientUpdateTrialComponentResponseTypeDef,
    ClientUpdateTrialComponentStatusTypeDef,
    ClientUpdateTrialResponseTypeDef,
    ClientUpdateUserProfileResponseTypeDef,
    ClientUpdateUserProfileUserSettingsTypeDef,
    ClientUpdateWorkteamMemberDefinitionsTypeDef,
    ClientUpdateWorkteamNotificationConfigurationTypeDef,
    ClientUpdateWorkteamResponseTypeDef,
)

# pylint: disable=import-self
import mypy_boto3_sagemaker.waiter as waiter_scope


__all__ = ("Client",)


class Client(BaseClient):
    exceptions: client_scope.Exceptions

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def add_tags(
        self, ResourceArn: str, Tags: List[ClientAddTagsTagsTypeDef]
    ) -> ClientAddTagsResponseTypeDef:
        """
        Adds or overwrites one or more tags for the specified Amazon SageMaker resource. You can add
        tags to notebook instances, training jobs, hyperparameter tuning jobs, batch transform jobs,
        models, labeling jobs, work teams, endpoint configurations, and endpoints.

        Each tag consists of a key and an optional value. Tag keys must be unique per resource. For
        more information about tags, see For more information, see `AWS Tagging Strategies
        <https://aws.amazon.com/answers/account-management/aws-tagging-strategies/>`__ .

        .. note::

          Tags that you add to a hyperparameter tuning job by calling this API are also added to any
          training jobs that the hyperparameter tuning job launches after you call this API, but not
          to training jobs that the hyperparameter tuning job launched before you called this API.
          To make sure that the tags associated with a hyperparameter tuning job are also added to
          all training jobs that the hyperparameter tuning job launches, add the tags when you first
          create the tuning job by specifying them in the ``Tags`` parameter of
          CreateHyperParameterTuningJob

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/AddTags>`_

        **Request Syntax**
        ::

          response = client.add_tags(
              ResourceArn='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type ResourceArn: string
        :param ResourceArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the resource that you want to tag.

        :type Tags: list
        :param Tags: **[REQUIRED]**

          An array of ``Tag`` objects. Each tag is a key-value pair. Only the ``key`` parameter is
          required. If you don't specify a value, Amazon SageMaker sets the value to an empty
          string.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Tags': [
                    {
                        'Key': 'string',
                        'Value': 'string'
                    },
                ]
            }
          **Response Structure**

          - *(dict) --*

            - **Tags** *(list) --*

              A list of tags associated with the Amazon SageMaker resource.

              - *(dict) --*

                Describes a tag.

                - **Key** *(string) --*

                  The tag key.

                - **Value** *(string) --*

                  The tag value.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def associate_trial_component(
        self, TrialComponentName: str, TrialName: str
    ) -> ClientAssociateTrialComponentResponseTypeDef:
        """
        Associates a trial component with a trial. A trial component can be associated with multiple
        trials. To disassociate a trial component from a trial, call the  DisassociateTrialComponent
        API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/AssociateTrialComponent>`_

        **Request Syntax**
        ::

          response = client.associate_trial_component(
              TrialComponentName='string',
              TrialName='string'
          )
        :type TrialComponentName: string
        :param TrialComponentName: **[REQUIRED]**

          The name of the component to associated with the trial.

        :type TrialName: string
        :param TrialName: **[REQUIRED]**

          The name of the trial to associate with.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialComponentArn': 'string',
                'TrialArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialComponentArn** *(string) --*

              The ARN of the trial component.

            - **TrialArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def can_paginate(self, operation_name: str) -> bool:
        """
        Check if an operation can be paginated.

        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you'd normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator("create_foo")``.

        :return: ``True`` if the operation can be paginated,
            ``False`` otherwise.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_algorithm(
        self,
        AlgorithmName: str,
        TrainingSpecification: ClientCreateAlgorithmTrainingSpecificationTypeDef,
        AlgorithmDescription: str = None,
        InferenceSpecification: ClientCreateAlgorithmInferenceSpecificationTypeDef = None,
        ValidationSpecification: ClientCreateAlgorithmValidationSpecificationTypeDef = None,
        CertifyForMarketplace: bool = None,
    ) -> ClientCreateAlgorithmResponseTypeDef:
        """
        Create a machine learning algorithm that you can use in Amazon SageMaker and list in the AWS
        Marketplace.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateAlgorithm>`_

        **Request Syntax**
        ::

          response = client.create_algorithm(
              AlgorithmName='string',
              AlgorithmDescription='string',
              TrainingSpecification={
                  'TrainingImage': 'string',
                  'TrainingImageDigest': 'string',
                  'SupportedHyperParameters': [
                      {
                          'Name': 'string',
                          'Description': 'string',
                          'Type': 'Integer'|'Continuous'|'Categorical'|'FreeText',
                          'Range': {
                              'IntegerParameterRangeSpecification': {
                                  'MinValue': 'string',
                                  'MaxValue': 'string'
                              },
                              'ContinuousParameterRangeSpecification': {
                                  'MinValue': 'string',
                                  'MaxValue': 'string'
                              },
                              'CategoricalParameterRangeSpecification': {
                                  'Values': [
                                      'string',
                                  ]
                              }
                          },
                          'IsTunable': True|False,
                          'IsRequired': True|False,
                          'DefaultValue': 'string'
                      },
                  ],
                  'SupportedTrainingInstanceTypes': [
                      'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                      |'ml.m4.16xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                      |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'
                      |'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'
                      |'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'
                      |'ml.p3dn.24xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                      |'ml.c5.9xlarge'|'ml.c5.18xlarge',
                  ],
                  'SupportsDistributedTraining': True|False,
                  'MetricDefinitions': [
                      {
                          'Name': 'string',
                          'Regex': 'string'
                      },
                  ],
                  'TrainingChannels': [
                      {
                          'Name': 'string',
                          'Description': 'string',
                          'IsRequired': True|False,
                          'SupportedContentTypes': [
                              'string',
                          ],
                          'SupportedCompressionTypes': [
                              'None'|'Gzip',
                          ],
                          'SupportedInputModes': [
                              'Pipe'|'File',
                          ]
                      },
                  ],
                  'SupportedTuningJobObjectiveMetrics': [
                      {
                          'Type': 'Maximize'|'Minimize',
                          'MetricName': 'string'
                      },
                  ]
              },
              InferenceSpecification={
                  'Containers': [
                      {
                          'ContainerHostname': 'string',
                          'Image': 'string',
                          'ImageDigest': 'string',
                          'ModelDataUrl': 'string',
                          'ProductId': 'string'
                      },
                  ],
                  'SupportedTransformInstanceTypes': [
                      'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                      |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                      |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                      |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                      |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge'
                      |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.12xlarge'
                      |'ml.m5.24xlarge',
                  ],
                  'SupportedRealtimeInferenceInstanceTypes': [
                      'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'|'ml.m4.xlarge'
                      |'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'|'ml.m4.16xlarge'
                      |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.12xlarge'
                      |'ml.m5.24xlarge'|'ml.m5d.large'|'ml.m5d.xlarge'|'ml.m5d.2xlarge'
                      |'ml.m5d.4xlarge'|'ml.m5d.12xlarge'|'ml.m5d.24xlarge'|'ml.c4.large'
                      |'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'
                      |'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                      |'ml.p3.16xlarge'|'ml.c5.large'|'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                      |'ml.c5.9xlarge'|'ml.c5.18xlarge'|'ml.c5d.large'|'ml.c5d.xlarge'
                      |'ml.c5d.2xlarge'|'ml.c5d.4xlarge'|'ml.c5d.9xlarge'|'ml.c5d.18xlarge'
                      |'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'|'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                      |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'|'ml.r5.large'|'ml.r5.xlarge'
                      |'ml.r5.2xlarge'|'ml.r5.4xlarge'|'ml.r5.12xlarge'|'ml.r5.24xlarge'
                      |'ml.r5d.large'|'ml.r5d.xlarge'|'ml.r5d.2xlarge'|'ml.r5d.4xlarge'
                      |'ml.r5d.12xlarge'|'ml.r5d.24xlarge'|'ml.inf1.xlarge'|'ml.inf1.2xlarge'
                      |'ml.inf1.6xlarge'|'ml.inf1.24xlarge',
                  ],
                  'SupportedContentTypes': [
                      'string',
                  ],
                  'SupportedResponseMIMETypes': [
                      'string',
                  ]
              },
              ValidationSpecification={
                  'ValidationRole': 'string',
                  'ValidationProfiles': [
                      {
                          'ProfileName': 'string',
                          'TrainingJobDefinition': {
                              'TrainingInputMode': 'Pipe'|'File',
                              'HyperParameters': {
                                  'string': 'string'
                              },
                              'InputDataConfig': [
                                  {
                                      'ChannelName': 'string',
                                      'DataSource': {
                                          'S3DataSource': {
                                              'S3DataType':
                                              'ManifestFile'
                                              |'S3Prefix'
                                              |'AugmentedManifestFile',
                                              'S3Uri': 'string',
                                              'S3DataDistributionType':
                                              'FullyReplicated'
                                              |'ShardedByS3Key',
                                              'AttributeNames': [
                                                  'string',
                                              ]
                                          },
                                          'FileSystemDataSource': {
                                              'FileSystemId': 'string',
                                              'FileSystemAccessMode': 'rw'|'ro',
                                              'FileSystemType': 'EFS'|'FSxLustre',
                                              'DirectoryPath': 'string'
                                          }
                                      },
                                      'ContentType': 'string',
                                      'CompressionType': 'None'|'Gzip',
                                      'RecordWrapperType': 'None'|'RecordIO',
                                      'InputMode': 'Pipe'|'File',
                                      'ShuffleConfig': {
                                          'Seed': 123
                                      }
                                  },
                              ],
                              'OutputDataConfig': {
                                  'KmsKeyId': 'string',
                                  'S3OutputPath': 'string'
                              },
                              'ResourceConfig': {
                                  'InstanceType':
                                  'ml.m4.xlarge'|'ml.m4.2xlarge'
                                  |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                  |'ml.m4.16xlarge'|'ml.m5.large'
                                  |'ml.m5.xlarge'|'ml.m5.2xlarge'
                                  |'ml.m5.4xlarge'|'ml.m5.12xlarge'
                                  |'ml.m5.24xlarge'|'ml.c4.xlarge'
                                  |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                  |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                  |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                  |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                  |'ml.p3.16xlarge'|'ml.p3dn.24xlarge'
                                  |'ml.c5.xlarge'|'ml.c5.2xlarge'
                                  |'ml.c5.4xlarge'|'ml.c5.9xlarge'
                                  |'ml.c5.18xlarge',
                                  'InstanceCount': 123,
                                  'VolumeSizeInGB': 123,
                                  'VolumeKmsKeyId': 'string'
                              },
                              'StoppingCondition': {
                                  'MaxRuntimeInSeconds': 123,
                                  'MaxWaitTimeInSeconds': 123
                              }
                          },
                          'TransformJobDefinition': {
                              'MaxConcurrentTransforms': 123,
                              'MaxPayloadInMB': 123,
                              'BatchStrategy': 'MultiRecord'|'SingleRecord',
                              'Environment': {
                                  'string': 'string'
                              },
                              'TransformInput': {
                                  'DataSource': {
                                      'S3DataSource': {
                                          'S3DataType':
                                          'ManifestFile'
                                          |'S3Prefix'
                                          |'AugmentedManifestFile',
                                          'S3Uri': 'string'
                                      }
                                  },
                                  'ContentType': 'string',
                                  'CompressionType': 'None'|'Gzip',
                                  'SplitType': 'None'|'Line'|'RecordIO'|'TFRecord'
                              },
                              'TransformOutput': {
                                  'S3OutputPath': 'string',
                                  'Accept': 'string',
                                  'AssembleWith': 'None'|'Line',
                                  'KmsKeyId': 'string'
                              },
                              'TransformResources': {
                                  'InstanceType':
                                  'ml.m4.xlarge'|'ml.m4.2xlarge'
                                  |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                  |'ml.m4.16xlarge'|'ml.c4.xlarge'
                                  |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                  |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                  |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                  |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                  |'ml.p3.16xlarge'|'ml.c5.xlarge'
                                  |'ml.c5.2xlarge'|'ml.c5.4xlarge'
                                  |'ml.c5.9xlarge'|'ml.c5.18xlarge'
                                  |'ml.m5.large'|'ml.m5.xlarge'
                                  |'ml.m5.2xlarge'|'ml.m5.4xlarge'
                                  |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                                  'InstanceCount': 123,
                                  'VolumeKmsKeyId': 'string'
                              }
                          }
                      },
                  ]
              },
              CertifyForMarketplace=True|False
          )
        :type AlgorithmName: string
        :param AlgorithmName: **[REQUIRED]**

          The name of the algorithm.

        :type AlgorithmDescription: string
        :param AlgorithmDescription:

          A description of the algorithm.

        :type TrainingSpecification: dict
        :param TrainingSpecification: **[REQUIRED]**

          Specifies details about training jobs run by this algorithm, including the following:

          * The Amazon ECR path of the container and the version digest of the algorithm.

          * The hyperparameters that the algorithm supports.

          * The instance types that the algorithm supports for training.

          * Whether the algorithm supports distributed training.

          * The metrics that the algorithm emits to Amazon CloudWatch.

          * Which metrics that the algorithm emits can be used as the objective metric for
          hyperparameter tuning jobs.

          * The input channels that the algorithm supports for training data. For example, an
          algorithm might support ``train`` , ``validation`` , and ``test`` channels.

          - **TrainingImage** *(string) --* **[REQUIRED]**

            The Amazon ECR registry path of the Docker image that contains the training algorithm.

          - **TrainingImageDigest** *(string) --*

            An MD5 hash of the training algorithm that identifies the Docker image used for
            training.

          - **SupportedHyperParameters** *(list) --*

            A list of the ``HyperParameterSpecification`` objects, that define the supported
            hyperparameters. This is required if the algorithm supports automatic model tuning.>

            - *(dict) --*

              Defines a hyperparameter to be used by an algorithm.

              - **Name** *(string) --* **[REQUIRED]**

                The name of this hyperparameter. The name must be unique.

              - **Description** *(string) --*

                A brief description of the hyperparameter.

              - **Type** *(string) --* **[REQUIRED]**

                The type of this hyperparameter. The valid types are ``Integer`` , ``Continuous`` ,
                ``Categorical`` , and ``FreeText`` .

              - **Range** *(dict) --*

                The allowed range for this hyperparameter.

                - **IntegerParameterRangeSpecification** *(dict) --*

                  A ``IntegerParameterRangeSpecification`` object that defines the possible values
                  for an integer hyperparameter.

                  - **MinValue** *(string) --* **[REQUIRED]**

                    The minimum integer value allowed.

                  - **MaxValue** *(string) --* **[REQUIRED]**

                    The maximum integer value allowed.

                - **ContinuousParameterRangeSpecification** *(dict) --*

                  A ``ContinuousParameterRangeSpecification`` object that defines the possible
                  values for a continuous hyperparameter.

                  - **MinValue** *(string) --* **[REQUIRED]**

                    The minimum floating-point value allowed.

                  - **MaxValue** *(string) --* **[REQUIRED]**

                    The maximum floating-point value allowed.

                - **CategoricalParameterRangeSpecification** *(dict) --*

                  A ``CategoricalParameterRangeSpecification`` object that defines the possible
                  values for a categorical hyperparameter.

                  - **Values** *(list) --* **[REQUIRED]**

                    The allowed categories for the hyperparameter.

                    - *(string) --*

              - **IsTunable** *(boolean) --*

                Indicates whether this hyperparameter is tunable in a hyperparameter tuning job.

              - **IsRequired** *(boolean) --*

                Indicates whether this hyperparameter is required.

              - **DefaultValue** *(string) --*

                The default value for this hyperparameter. If a default value is specified, a
                hyperparameter cannot be required.

          - **SupportedTrainingInstanceTypes** *(list) --* **[REQUIRED]**

            A list of the instance types that this algorithm can use for training.

            - *(string) --*

          - **SupportsDistributedTraining** *(boolean) --*

            Indicates whether the algorithm supports distributed training. If set to false, buyers
            can't request more than one instance during training.

          - **MetricDefinitions** *(list) --*

            A list of ``MetricDefinition`` objects, which are used for parsing metrics generated by
            the algorithm.

            - *(dict) --*

              Specifies a metric that the training algorithm writes to ``stderr`` or ``stdout`` .
              Amazon SageMakerhyperparameter tuning captures all defined metrics. You specify one
              metric that a hyperparameter tuning job uses as its objective metric to choose the
              best training job.

              - **Name** *(string) --* **[REQUIRED]**

                The name of the metric.

              - **Regex** *(string) --* **[REQUIRED]**

                A regular expression that searches the output of a training job and gets the value
                of the metric. For more information about using regular expressions to define
                metrics, see `Defining Objective Metrics
                <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                .

          - **TrainingChannels** *(list) --* **[REQUIRED]**

            A list of ``ChannelSpecification`` objects, which specify the input sources to be used
            by the algorithm.

            - *(dict) --*

              Defines a named input source, called a channel, to be used by an algorithm.

              - **Name** *(string) --* **[REQUIRED]**

                The name of the channel.

              - **Description** *(string) --*

                A brief description of the channel.

              - **IsRequired** *(boolean) --*

                Indicates whether the channel is required by the algorithm.

              - **SupportedContentTypes** *(list) --* **[REQUIRED]**

                The supported MIME types for the data.

                - *(string) --*

              - **SupportedCompressionTypes** *(list) --*

                The allowed compression types, if data compression is used.

                - *(string) --*

              - **SupportedInputModes** *(list) --* **[REQUIRED]**

                The allowed input mode, either FILE or PIPE.

                In FILE mode, Amazon SageMaker copies the data from the input source onto the local
                Amazon Elastic Block Store (Amazon EBS) volumes before starting your training
                algorithm. This is the most commonly used input mode.

                In PIPE mode, Amazon SageMaker streams input data from the source directly to your
                algorithm without using the EBS volume.

                - *(string) --*

          - **SupportedTuningJobObjectiveMetrics** *(list) --*

            A list of the metrics that the algorithm emits that can be used as the objective metric
            in a hyperparameter tuning job.

            - *(dict) --*

              Defines the objective metric for a hyperparameter tuning job. Hyperparameter tuning
              uses the value of this metric to evaluate the training jobs it launches, and returns
              the training job that results in either the highest or lowest value for this metric,
              depending on the value you specify for the ``Type`` parameter.

              - **Type** *(string) --* **[REQUIRED]**

                Whether to minimize or maximize the objective metric.

              - **MetricName** *(string) --* **[REQUIRED]**

                The name of the metric to use for the objective metric.

        :type InferenceSpecification: dict
        :param InferenceSpecification:

          Specifies details about inference jobs that the algorithm runs, including the following:

          * The Amazon ECR paths of containers that contain the inference code and model artifacts.

          * The instance types that the algorithm supports for transform jobs and real-time
          endpoints used for inference.

          * The input and output content formats that the algorithm supports for inference.

          - **Containers** *(list) --* **[REQUIRED]**

            The Amazon ECR registry path of the Docker image that contains the inference code.

            - *(dict) --*

              Describes the Docker container for the model package.

              - **ContainerHostname** *(string) --*

                The DNS host name for the Docker container.

              - **Image** *(string) --* **[REQUIRED]**

                The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.

                If you are using your own custom algorithm instead of an algorithm provided by
                Amazon SageMaker, the inference code must meet Amazon SageMaker requirements. Amazon
                SageMaker supports both ``registry/repository[:tag]`` and
                ``registry/repository[@digest]`` image path formats. For more information, see
                `Using Your Own Algorithms with Amazon SageMaker
                <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

              - **ImageDigest** *(string) --*

                An MD5 hash of the training algorithm that identifies the Docker image used for
                training.

              - **ModelDataUrl** *(string) --*

                The Amazon S3 path where the model artifacts, which result from model training, are
                stored. This path must point to a single ``gzip`` compressed tar archive
                (``.tar.gz`` suffix).

              - **ProductId** *(string) --*

                The AWS Marketplace product ID of the model package.

          - **SupportedTransformInstanceTypes** *(list) --* **[REQUIRED]**

            A list of the instance types on which a transformation job can be run or on which an
            endpoint can be deployed.

            - *(string) --*

          - **SupportedRealtimeInferenceInstanceTypes** *(list) --* **[REQUIRED]**

            A list of the instance types that are used to generate inferences in real-time.

            - *(string) --*

          - **SupportedContentTypes** *(list) --* **[REQUIRED]**

            The supported MIME types for the input data.

            - *(string) --*

          - **SupportedResponseMIMETypes** *(list) --* **[REQUIRED]**

            The supported MIME types for the output data.

            - *(string) --*

        :type ValidationSpecification: dict
        :param ValidationSpecification:

          Specifies configurations for one or more training jobs and that Amazon SageMaker runs to
          test the algorithm's training code and, optionally, one or more batch transform jobs that
          Amazon SageMaker runs to test the algorithm's inference code.

          - **ValidationRole** *(string) --* **[REQUIRED]**

            The IAM roles that Amazon SageMaker uses to run the training jobs.

          - **ValidationProfiles** *(list) --* **[REQUIRED]**

            An array of ``AlgorithmValidationProfile`` objects, each of which specifies a training
            job and batch transform job that Amazon SageMaker runs to validate your algorithm.

            - *(dict) --*

              Defines a training job and a batch transform job that Amazon SageMaker runs to
              validate your algorithm.

              The data provided in the validation profile is made available to your buyers on AWS
              Marketplace.

              - **ProfileName** *(string) --* **[REQUIRED]**

                The name of the profile for the algorithm. The name must have 1 to 63 characters.
                Valid characters are a-z, A-Z, 0-9, and - (hyphen).

              - **TrainingJobDefinition** *(dict) --* **[REQUIRED]**

                The ``TrainingJobDefinition`` object that describes the training job that Amazon
                SageMaker runs to validate your algorithm.

                - **TrainingInputMode** *(string) --* **[REQUIRED]**

                  The input mode used by the algorithm for the training job. For the input modes
                  that Amazon SageMaker algorithms support, see `Algorithms
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

                  If an algorithm supports the ``File`` input mode, Amazon SageMaker downloads the
                  training data from S3 to the provisioned ML storage Volume, and mounts the
                  directory to docker volume for training container. If an algorithm supports the
                  ``Pipe`` input mode, Amazon SageMaker streams data directly from S3 to the
                  container.

                - **HyperParameters** *(dict) --*

                  The hyperparameters used for the training job.

                  - *(string) --*

                    - *(string) --*

                - **InputDataConfig** *(list) --* **[REQUIRED]**

                  An array of ``Channel`` objects, each of which specifies an input source.

                  - *(dict) --*

                    A channel is a named input source that training algorithms can consume.

                    - **ChannelName** *(string) --* **[REQUIRED]**

                      The name of the channel.

                    - **DataSource** *(dict) --* **[REQUIRED]**

                      The location of the channel data.

                      - **S3DataSource** *(dict) --*

                        The S3 location of the data source that is associated with a channel.

                        - **S3DataType** *(string) --* **[REQUIRED]**

                          If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix.
                          Amazon SageMaker uses all objects that match the specified key name prefix
                          for model training.

                          If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                          manifest file containing a list of object keys that you want Amazon
                          SageMaker to use for model training.

                          If you choose ``AugmentedManifestFile`` , S3Uri identifies an object that
                          is an augmented manifest file in JSON lines format. This file contains the
                          data you want to use for model training. ``AugmentedManifestFile`` can
                          only be used if the Channel's input mode is ``Pipe`` .

                        - **S3Uri** *(string) --* **[REQUIRED]**

                          Depending on the value specified for the ``S3DataType`` , identifies
                          either a key name prefix or a manifest. For example:

                          * A key name prefix might look like this:
                          ``s3://bucketname/exampleprefix`` .

                          * A manifest might look like this: ``s3://bucketname/example.manifest``
                          The manifest is an S3 object which is a JSON file with the following
                          format:  The preceding JSON matches the following ``s3Uris`` :   ``[
                          {"prefix": "s3://customer_bucket/some/prefix/"},``
                          ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                          ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                          matches the following ``s3Uris`` :
                          ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                          ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                          ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The
                          complete set of ``s3uris`` in this manifest is the input data for the
                          channel for this datasource. The object that each ``s3uris`` points to
                          must be readable by the IAM role that Amazon SageMaker uses to perform
                          tasks on your behalf.

                        - **S3DataDistributionType** *(string) --*

                          If you want Amazon SageMaker to replicate the entire dataset on each ML
                          compute instance that is launched for model training, specify
                          ``FullyReplicated`` .

                          If you want Amazon SageMaker to replicate a subset of data on each ML
                          compute instance that is launched for model training, specify
                          ``ShardedByS3Key`` . If there are *n* ML compute instances launched for a
                          training job, each instance gets approximately 1/*n* of the number of S3
                          objects. In this case, model training on each machine uses only the subset
                          of training data.

                          Don't choose more ML compute instances for training than available S3
                          objects. If you do, some nodes won't get any data and you will pay for
                          nodes that aren't getting any training data. This applies in both File and
                          Pipe modes. Keep this in mind when developing algorithms.

                          In distributed training, where you use multiple ML compute EC2 instances,
                          you might choose ``ShardedByS3Key`` . If the algorithm requires copying
                          training data to the ML storage volume (when ``TrainingInputMode`` is set
                          to ``File`` ), this copies 1/*n* of the number of objects.

                        - **AttributeNames** *(list) --*

                          A list of one or more attribute names to use that are found in a specified
                          augmented manifest file.

                          - *(string) --*

                      - **FileSystemDataSource** *(dict) --*

                        The file system that is associated with a channel.

                        - **FileSystemId** *(string) --* **[REQUIRED]**

                          The file system id.

                        - **FileSystemAccessMode** *(string) --* **[REQUIRED]**

                          The access mode of the mount of the directory associated with the channel.
                          A directory can be mounted either in ``ro`` (read-only) or ``rw``
                          (read-write) mode.

                        - **FileSystemType** *(string) --* **[REQUIRED]**

                          The file system type.

                        - **DirectoryPath** *(string) --* **[REQUIRED]**

                          The full path to the directory to associate with the channel.

                    - **ContentType** *(string) --*

                      The MIME type of the data.

                    - **CompressionType** *(string) --*

                      If training data is compressed, the compression type. The default value is
                      ``None`` . ``CompressionType`` is used only in Pipe input mode. In File mode,
                      leave this field unset or set it to None.

                    - **RecordWrapperType** *(string) --*

                      Specify RecordIO as the value when input data is in raw format but the
                      training algorithm requires the RecordIO format. In this case, Amazon
                      SageMaker wraps each individual S3 object in a RecordIO record. If the input
                      data is already in RecordIO format, you don't need to set this attribute. For
                      more information, see `Create a Dataset Using RecordIO
                      <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__ .

                      In File mode, leave this field unset or set it to None.

                    - **InputMode** *(string) --*

                      (Optional) The input mode to use for the data channel in a training job. If
                      you don't set a value for ``InputMode`` , Amazon SageMaker uses the value set
                      for ``TrainingInputMode`` . Use this parameter to override the
                      ``TrainingInputMode`` setting in a  AlgorithmSpecification request when you
                      have a channel that needs a different input mode from the training job's
                      general setting. To download the data from Amazon Simple Storage Service
                      (Amazon S3) to the provisioned ML storage volume, and mount the directory to a
                      Docker volume, use ``File`` input mode. To stream data directly from Amazon S3
                      to the container, choose ``Pipe`` input mode.

                      To use a model for incremental training, choose ``File`` input model.

                    - **ShuffleConfig** *(dict) --*

                      A configuration for a shuffle option for input data in a channel. If you use
                      ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key
                      prefix matches. If you use ``ManifestFile`` , the order of the S3 object
                      references in the ``ManifestFile`` is shuffled. If you use
                      ``AugmentedManifestFile`` , the order of the JSON lines in the
                      ``AugmentedManifestFile`` is shuffled. The shuffling order is determined using
                      the ``Seed`` value.

                      For Pipe input mode, shuffling is done at the start of every epoch. With large
                      datasets this ensures that the order of the training data is different for
                      each epoch, it helps reduce bias and possible overfitting. In a multi-node
                      training job when ShuffleConfig is combined with ``S3DataDistributionType`` of
                      ``ShardedByS3Key`` , the data is shuffled across nodes so that the content
                      sent to a particular node on the first epoch might be sent to a different node
                      on the second epoch.

                      - **Seed** *(integer) --* **[REQUIRED]**

                        Determines the shuffling order in ``ShuffleConfig`` value.

                - **OutputDataConfig** *(dict) --* **[REQUIRED]**

                  the path to the S3 bucket where you want to store model artifacts. Amazon
                  SageMaker creates subfolders for the artifacts.

                  - **KmsKeyId** *(string) --*

                    The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                    encrypt the model artifacts at rest using Amazon S3 server-side encryption. The
                    ``KmsKeyId`` can be any of the following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // KMS Key Alias  ``"alias/ExampleAlias"``

                    * // Amazon Resource Name (ARN) of a KMS Key Alias
                    ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                    If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                    execution role must include permissions to call ``kms:Encrypt`` . If you don't
                    provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3
                    for your role's account. Amazon SageMaker uses server-side encryption with
                    KMS-managed keys for ``OutputDataConfig`` . If you use a bucket policy with an
                    ``s3:PutObject`` permission that only allows objects with server-side
                    encryption, set the condition key of ``s3:x-amz-server-side-encryption`` to
                    ``"aws:kms"`` . For more information, see `KMS-Managed Encryption Keys
                    <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in
                    the *Amazon Simple Storage Service Developer Guide.*

                    The KMS key policy must grant permission to the IAM role that you specify in
                    your ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                    ``CreateHyperParameterTuningJob`` requests. For more information, see `Using Key
                    Policies in AWS KMS
                    <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in
                    the *AWS Key Management Service Developer Guide* .

                  - **S3OutputPath** *(string) --* **[REQUIRED]**

                    Identifies the S3 path where you want Amazon SageMaker to store the model
                    artifacts. For example, ``s3://bucket-name/key-name-prefix`` .

                - **ResourceConfig** *(dict) --* **[REQUIRED]**

                  The resources, including the ML compute instances and ML storage volumes, to use
                  for model training.

                  - **InstanceType** *(string) --* **[REQUIRED]**

                    The ML compute instance type.

                  - **InstanceCount** *(integer) --* **[REQUIRED]**

                    The number of ML compute instances to use. For distributed training, provide a
                    value greater than 1.

                  - **VolumeSizeInGB** *(integer) --* **[REQUIRED]**

                    The size of the ML storage volume that you want to provision.

                    ML storage volumes store model artifacts and incremental states. Training
                    algorithms might also use the ML storage volume for scratch space. If you want
                    to store the training data in the ML storage volume, choose ``File`` as the
                    ``TrainingInputMode`` in the algorithm specification.

                    You must specify sufficient ML storage for your scenario.

                    .. note::

                      Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage volume
                      type.

                    .. note::

                      Certain Nitro-based instances include local storage with a fixed total size,
                      dependent on the instance type. When using these instances for training,
                      Amazon SageMaker mounts the local instance storage instead of Amazon EBS gp2
                      storage. You can't request a ``VolumeSizeInGB`` greater than the total size of
                      the local instance storage.

                      For a list of instance types that support local instance storage, including
                      the total size per instance type, see `Instance Store Volumes
                      <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                      .

                  - **VolumeKmsKeyId** *(string) --*

                    The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume
                    attached to the ML compute instance(s) that run the training job.

                    .. note::

                      Certain Nitro-based instances include local storage, dependent on the instance
                      type. Local storage volumes are encrypted using a hardware module on the
                      instance. You can't request a ``VolumeKmsKeyId`` when using an instance type
                      with local storage.

                      For a list of instance types that support local instance storage, see
                      `Instance Store Volumes
                      <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                      .

                      For more information about local instance storage encryption, see `SSD
                      Instance Store Volumes
                      <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__
                      .

                    The ``VolumeKmsKeyId`` can be in any of the following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                - **StoppingCondition** *(dict) --* **[REQUIRED]**

                  Specifies a limit to how long a model training job can run. When the job reaches
                  the time limit, Amazon SageMaker ends the training job. Use this API to cap model
                  training costs.

                  To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which
                  delays job termination for 120 seconds. Algorithms can use this 120-second window
                  to save the model artifacts.

                  - **MaxRuntimeInSeconds** *(integer) --*

                    The maximum length of time, in seconds, that the training or compilation job can
                    run. If job does not complete during this time, Amazon SageMaker ends the job.
                    If value is not specified, default value is 1 day. The maximum value is 28 days.

                  - **MaxWaitTimeInSeconds** *(integer) --*

                    The maximum length of time, in seconds, how long you are willing to wait for a
                    managed spot training job to complete. It is the amount of time spent waiting
                    for Spot capacity plus the amount of time the training job runs. It must be
                    equal to or greater than ``MaxRuntimeInSeconds`` .

              - **TransformJobDefinition** *(dict) --*

                The ``TransformJobDefinition`` object that describes the transform job that Amazon
                SageMaker runs to validate your algorithm.

                - **MaxConcurrentTransforms** *(integer) --*

                  The maximum number of parallel requests that can be sent to each instance in a
                  transform job. The default value is 1.

                - **MaxPayloadInMB** *(integer) --*

                  The maximum payload size allowed, in MB. A payload is the data portion of a record
                  (without metadata).

                - **BatchStrategy** *(string) --*

                  A string that determines the number of records included in a single mini-batch.

                   ``SingleRecord`` means only one record is used per mini-batch. ``MultiRecord``
                   means a mini-batch is set to contain as many records that can fit within the
                   ``MaxPayloadInMB`` limit.

                - **Environment** *(dict) --*

                  The environment variables to set in the Docker container. We support up to 16 key
                  and values entries in the map.

                  - *(string) --*

                    - *(string) --*

                - **TransformInput** *(dict) --* **[REQUIRED]**

                  A description of the input source and the way the transform job consumes it.

                  - **DataSource** *(dict) --* **[REQUIRED]**

                    Describes the location of the channel data, which is, the S3 location of the
                    input data that the model can consume.

                    - **S3DataSource** *(dict) --* **[REQUIRED]**

                      The S3 location of the data source that is associated with a channel.

                      - **S3DataType** *(string) --* **[REQUIRED]**

                        If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                        SageMaker uses all objects with the specified key name prefix for batch
                        transform.

                        If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                        manifest file containing a list of object keys that you want Amazon
                        SageMaker to use for batch transform.

                        The following values are compatible: ``ManifestFile`` , ``S3Prefix``

                        The following value is not compatible: ``AugmentedManifestFile``

                      - **S3Uri** *(string) --* **[REQUIRED]**

                        Depending on the value specified for the ``S3DataType`` , identifies either
                        a key name prefix or a manifest. For example:

                        * A key name prefix might look like this: ``s3://bucketname/exampleprefix``
                        .

                        * A manifest might look like this: ``s3://bucketname/example.manifest``
                        The manifest is an S3 object which is a JSON file with the following format:
                        ``[ {"prefix": "s3://customer_bucket/some/prefix/"},``
                        ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                        ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                        matches the following ``s3Uris`` :
                        ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                        ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                        ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete
                        set of ``S3Uris`` in this manifest constitutes the input data for the
                        channel for this datasource. The object that each ``S3Uris`` points to must
                        be readable by the IAM role that Amazon SageMaker uses to perform tasks on
                        your behalf.

                  - **ContentType** *(string) --*

                    The multipurpose internet mail extension (MIME) type of the data. Amazon
                    SageMaker uses the MIME type with each http call to transfer data to the
                    transform job.

                  - **CompressionType** *(string) --*

                    If your transform data is compressed, specify the compression type. Amazon
                    SageMaker automatically decompresses the data for the transform job accordingly.
                    The default value is ``None`` .

                  - **SplitType** *(string) --*

                    The method to use to split the transform job's data files into smaller batches.
                    Splitting is necessary when the total size of each object is too large to fit in
                    a single request. You can also use data splitting to improve performance by
                    processing multiple concurrent mini-batches. The default value for ``SplitType``
                    is ``None`` , which indicates that input data files are not split, and request
                    payloads contain the entire contents of an input object. Set the value of this
                    parameter to ``Line`` to split records on a newline character boundary.
                    ``SplitType`` also supports a number of record-oriented binary data formats.

                    When splitting is enabled, the size of a mini-batch depends on the values of the
                    ``BatchStrategy`` and ``MaxPayloadInMB`` parameters. When the value of
                    ``BatchStrategy`` is ``MultiRecord`` , Amazon SageMaker sends the maximum number
                    of records in each request, up to the ``MaxPayloadInMB`` limit. If the value of
                    ``BatchStrategy`` is ``SingleRecord`` , Amazon SageMaker sends individual
                    records in each request.

                    .. note::

                      Some data formats represent a record as a binary payload wrapped with extra
                      padding bytes. When splitting is applied to a binary data format, padding is
                      removed if the value of ``BatchStrategy`` is set to ``SingleRecord`` . Padding
                      is not removed if the value of ``BatchStrategy`` is set to ``MultiRecord`` .

                      For more information about ``RecordIO`` , see `Create a Dataset Using RecordIO
                      <https://mxnet.apache.org/api/faq/recordio>`__ in the MXNet documentation. For
                      more information about ``TFRecord`` , see `Consuming TFRecord data
                      <https://www.tensorflow.org/guide/datasets#consuming_tfrecord_data>`__ in the
                      TensorFlow documentation.

                - **TransformOutput** *(dict) --* **[REQUIRED]**

                  Identifies the Amazon S3 location where you want Amazon SageMaker to save the
                  results from the transform job.

                  - **S3OutputPath** *(string) --* **[REQUIRED]**

                    The Amazon S3 path where you want Amazon SageMaker to store the results of the
                    transform job. For example, ``s3://bucket-name/key-name-prefix`` .

                    For every S3 object used as input for the transform job, batch transform stores
                    the transformed data with an .``out`` suffix in a corresponding subfolder in the
                    location in the output prefix. For example, for the input data stored at
                    ``s3://bucket-name/input-name-prefix/dataset01/data.csv`` , batch transform
                    stores the transformed data at
                    ``s3://bucket-name/output-name-prefix/input-name-prefix/data.csv.out`` . Batch
                    transform doesn't upload partially processed objects. For an input S3 object
                    that contains multiple records, it creates an .``out`` file only if the
                    transform job succeeds on the entire file. When the input contains multiple S3
                    objects, the batch transform job processes the listed S3 objects and uploads
                    only the output for successfully processed objects. If any object fails in the
                    transform job batch transform marks the job as failed to prompt investigation.

                  - **Accept** *(string) --*

                    The MIME type used to specify the output data. Amazon SageMaker uses the MIME
                    type with each http call to transfer data from the transform job.

                  - **AssembleWith** *(string) --*

                    Defines how to assemble the results of the transform job as a single S3 object.
                    Choose a format that is most convenient to you. To concatenate the results in
                    binary format, specify ``None`` . To add a newline character at the end of every
                    transformed record, specify ``Line`` .

                  - **KmsKeyId** *(string) --*

                    The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                    encrypt the model artifacts at rest using Amazon S3 server-side encryption. The
                    ``KmsKeyId`` can be any of the following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // KMS Key Alias  ``"alias/ExampleAlias"``

                    * // Amazon Resource Name (ARN) of a KMS Key Alias
                    ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                    If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS key for
                    Amazon S3 for your role's account. For more information, see `KMS-Managed
                    Encryption Keys
                    <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in
                    the *Amazon Simple Storage Service Developer Guide.*

                    The KMS key policy must grant permission to the IAM role that you specify in
                    your  CreateModel request. For more information, see `Using Key Policies in AWS
                    KMS <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__
                    in the *AWS Key Management Service Developer Guide* .

                - **TransformResources** *(dict) --* **[REQUIRED]**

                  Identifies the ML compute instances for the transform job.

                  - **InstanceType** *(string) --* **[REQUIRED]**

                    The ML compute instance type for the transform job. If you are using built-in
                    algorithms to transform moderately sized datasets, we recommend using
                    ml.m4.xlarge or ``ml.m5.large`` instance types.

                  - **InstanceCount** *(integer) --* **[REQUIRED]**

                    The number of ML compute instances to use in the transform job. For distributed
                    transform jobs, specify a value greater than 1. The default value is ``1`` .

                  - **VolumeKmsKeyId** *(string) --*

                    The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                    encrypt model data on the storage volume attached to the ML compute instance(s)
                    that run the batch transform job. The ``VolumeKmsKeyId`` can be any of the
                    following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

        :type CertifyForMarketplace: boolean
        :param CertifyForMarketplace:

          Whether to certify the algorithm so that it can be listed in AWS Marketplace.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AlgorithmArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **AlgorithmArn** *(string) --*

              The Amazon Resource Name (ARN) of the new algorithm.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_app(
        self,
        DomainId: str,
        UserProfileName: str,
        AppType: Literal["JupyterServer", "KernelGateway", "TensorBoard"],
        AppName: str,
        Tags: List[ClientCreateAppTagsTypeDef] = None,
        ResourceSpec: ClientCreateAppResourceSpecTypeDef = None,
    ) -> ClientCreateAppResponseTypeDef:
        """
        Creates a running App for the specified UserProfile. Supported Apps are JupyterServer and
        KernelGateway. This operation is automatically invoked by Amazon SageMaker Amazon SageMaker
        Studio (Studio) upon access to the associated Studio Domain, and when new kernel
        configurations are selected by the user. A user may have multiple Apps active
        simultaneously. Apps will automatically terminate and be deleted when stopped from within
        Studio, or when the DeleteApp API is manually called. UserProfiles are limited to 5
        concurrently running Apps at a time.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateApp>`_

        **Request Syntax**
        ::

          response = client.create_app(
              DomainId='string',
              UserProfileName='string',
              AppType='JupyterServer'|'KernelGateway'|'TensorBoard',
              AppName='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              ResourceSpec={
                  'EnvironmentArn': 'string',
                  'InstanceType':
                  'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'|'ml.t3.large'
                  |'ml.t3.xlarge'|'ml.t3.2xlarge'|'ml.m5.large'|'ml.m5.xlarge'
                  |'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                  |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'|'ml.c5.xlarge'
                  |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.12xlarge'
                  |'ml.c5.18xlarge'|'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                  |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'|'ml.g4dn.4xlarge'
                  |'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'
              }
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          The user profile name.

        :type AppType: string
        :param AppType: **[REQUIRED]**

          The type of app.

        :type AppName: string
        :param AppName: **[REQUIRED]**

          The name of the app.

        :type Tags: list
        :param Tags:

          Each tag consists of a key and an optional value. Tag keys must be unique per resource.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type ResourceSpec: dict
        :param ResourceSpec:

          The instance type and quantity.

          - **EnvironmentArn** *(string) --*

            The Amazon Resource Name (ARN) of the environment.

          - **InstanceType** *(string) --*

            The instance type.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AppArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **AppArn** *(string) --*

              The app's Amazon Resource Name (ARN).
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_auto_ml_job(
        self,
        AutoMLJobName: str,
        InputDataConfig: List[ClientCreateAutoMlJobInputDataConfigTypeDef],
        OutputDataConfig: ClientCreateAutoMlJobOutputDataConfigTypeDef,
        RoleArn: str,
        ProblemType: Literal[
            "BinaryClassification", "MulticlassClassification", "Regression"
        ] = None,
        AutoMLJobObjective: ClientCreateAutoMlJobAutoMLJobObjectiveTypeDef = None,
        AutoMLJobConfig: ClientCreateAutoMlJobAutoMLJobConfigTypeDef = None,
        GenerateCandidateDefinitionsOnly: bool = None,
        Tags: List[ClientCreateAutoMlJobTagsTypeDef] = None,
    ) -> ClientCreateAutoMlJobResponseTypeDef:
        """
        Creates an AutoPilot job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateAutoMLJob>`_

        **Request Syntax**
        ::

          response = client.create_auto_ml_job(
              AutoMLJobName='string',
              InputDataConfig=[
                  {
                      'DataSource': {
                          'S3DataSource': {
                              'S3DataType': 'ManifestFile'|'S3Prefix',
                              'S3Uri': 'string'
                          }
                      },
                      'CompressionType': 'None'|'Gzip',
                      'TargetAttributeName': 'string'
                  },
              ],
              OutputDataConfig={
                  'KmsKeyId': 'string',
                  'S3OutputPath': 'string'
              },
              ProblemType='BinaryClassification'|'MulticlassClassification'|'Regression',
              AutoMLJobObjective={
                  'MetricName': 'Accuracy'|'MSE'|'F1'|'F1macro'
              },
              AutoMLJobConfig={
                  'CompletionCriteria': {
                      'MaxCandidates': 123,
                      'MaxRuntimePerTrainingJobInSeconds': 123,
                      'MaxAutoMLJobRuntimeInSeconds': 123
                  },
                  'SecurityConfig': {
                      'VolumeKmsKeyId': 'string',
                      'EnableInterContainerTrafficEncryption': True|False,
                      'VpcConfig': {
                          'SecurityGroupIds': [
                              'string',
                          ],
                          'Subnets': [
                              'string',
                          ]
                      }
                  }
              },
              RoleArn='string',
              GenerateCandidateDefinitionsOnly=True|False,
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type AutoMLJobName: string
        :param AutoMLJobName: **[REQUIRED]**

          Identifies an AutoPilot job. Must be unique to your account and is case-insensitive.

        :type InputDataConfig: list
        :param InputDataConfig: **[REQUIRED]**

          Similar to InputDataConfig supported by Tuning. Format(s) supported: CSV.

          - *(dict) --*

            Similar to Channel. A channel is a named input source that training algorithms can
            consume. Refer to Channel for detailed descriptions.

            - **DataSource** *(dict) --* **[REQUIRED]**

              The data source.

              - **S3DataSource** *(dict) --* **[REQUIRED]**

                The Amazon S3 location of the data.

                - **S3DataType** *(string) --* **[REQUIRED]**

                  The data type.

                - **S3Uri** *(string) --* **[REQUIRED]**

                  The URL to the Amazon S3 data source.

            - **CompressionType** *(string) --*

              You can use Gzip or None. The default value is None.

            - **TargetAttributeName** *(string) --* **[REQUIRED]**

              The name of the target variable in supervised learning, a.k.a. ‘y’.

        :type OutputDataConfig: dict
        :param OutputDataConfig: **[REQUIRED]**

          Similar to OutputDataConfig supported by Tuning. Format(s) supported: CSV.

          - **KmsKeyId** *(string) --*

            The AWS KMS encryption key ID.

          - **S3OutputPath** *(string) --* **[REQUIRED]**

            The Amazon S3 output path. Must be 128 characters or less.

        :type ProblemType: string
        :param ProblemType:

          Defines the kind of preprocessing and algorithms intended for the candidates. Options
          include: BinaryClassification, MulticlassClassification, and Regression.

        :type AutoMLJobObjective: dict
        :param AutoMLJobObjective:

          Defines the job's objective. You provide a MetricName and AutoML will infer minimize or
          maximize. If this is not provided, the most commonly used ObjectiveMetric for problem type
          will be selected.

          - **MetricName** *(string) --* **[REQUIRED]**

            The name of the metric.

        :type AutoMLJobConfig: dict
        :param AutoMLJobConfig:

          Contains CompletionCriteria and SecurityConfig.

          - **CompletionCriteria** *(dict) --*

            How long a job is allowed to run, or how many candidates a job is allowed to generate.

            - **MaxCandidates** *(integer) --*

              The maximum number of times a training job is allowed to run.

            - **MaxRuntimePerTrainingJobInSeconds** *(integer) --*

              The maximum time, in seconds, a job is allowed to run.

            - **MaxAutoMLJobRuntimeInSeconds** *(integer) --*

              The maximum time, in seconds, an AutoML job is allowed to wait for a trial to
              complete. It must be equal to or greater than MaxRuntimePerTrainingJobInSeconds.

          - **SecurityConfig** *(dict) --*

            Security configuration for traffic encryption or Amazon VPC settings.

            - **VolumeKmsKeyId** *(string) --*

              The key used to encrypt stored data.

            - **EnableInterContainerTrafficEncryption** *(boolean) --*

              Whether to use traffic encryption between the container layers.

            - **VpcConfig** *(dict) --*

              VPC configuration.

              - **SecurityGroupIds** *(list) --* **[REQUIRED]**

                The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for
                the VPC that is specified in the ``Subnets`` field.

                - *(string) --*

              - **Subnets** *(list) --* **[REQUIRED]**

                The ID of the subnets in the VPC to which you want to connect your training job or
                model.

                .. note::

                  Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                  availability zones of region us-east-1. If you want to create endpoints with P3
                  instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                  zones instead.

                - *(string) --*

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          The ARN of the role that will be used to access the data.

        :type GenerateCandidateDefinitionsOnly: boolean
        :param GenerateCandidateDefinitionsOnly:

          This will generate possible candidates without training a model. A candidate is a
          combination of data preprocessors, algorithms, and algorithm parameter settings.

        :type Tags: list
        :param Tags:

          Each tag consists of a key and an optional value. Tag keys must be unique per resource.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AutoMLJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **AutoMLJobArn** *(string) --*

              When a job is created, it is assigned a unique ARN.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_code_repository(
        self, CodeRepositoryName: str, GitConfig: ClientCreateCodeRepositoryGitConfigTypeDef
    ) -> ClientCreateCodeRepositoryResponseTypeDef:
        """
        Creates a Git repository as a resource in your Amazon SageMaker account. You can associate
        the repository with notebook instances so that you can use Git source control for the
        notebooks you create. The Git repository is a resource in your Amazon SageMaker account, so
        it can be associated with more than one notebook instance, and it persists independently
        from the lifecycle of any notebook instances it is associated with.

        The repository can be hosted either in `AWS CodeCommit
        <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in any other
        Git repository.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateCodeRepository>`_

        **Request Syntax**
        ::

          response = client.create_code_repository(
              CodeRepositoryName='string',
              GitConfig={
                  'RepositoryUrl': 'string',
                  'Branch': 'string',
                  'SecretArn': 'string'
              }
          )
        :type CodeRepositoryName: string
        :param CodeRepositoryName: **[REQUIRED]**

          The name of the Git repository. The name must have 1 to 63 characters. Valid characters
          are a-z, A-Z, 0-9, and - (hyphen).

        :type GitConfig: dict
        :param GitConfig: **[REQUIRED]**

          Specifies details about the repository, including the URL where the repository is located,
          the default branch, and credentials to use to access the repository.

          - **RepositoryUrl** *(string) --* **[REQUIRED]**

            The URL where the Git repository is located.

          - **Branch** *(string) --*

            The default branch for the Git repository.

          - **SecretArn** *(string) --*

            The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the
            credentials used to access the git repository. The secret must have a staging label of
            ``AWSCURRENT`` and must be in the following format:

             ``{"username": *UserName* , "password": *Password* }``

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CodeRepositoryArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **CodeRepositoryArn** *(string) --*

              The Amazon Resource Name (ARN) of the new repository.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_compilation_job(
        self,
        CompilationJobName: str,
        RoleArn: str,
        InputConfig: ClientCreateCompilationJobInputConfigTypeDef,
        OutputConfig: ClientCreateCompilationJobOutputConfigTypeDef,
        StoppingCondition: ClientCreateCompilationJobStoppingConditionTypeDef,
    ) -> ClientCreateCompilationJobResponseTypeDef:
        """
        Starts a model compilation job. After the model has been compiled, Amazon SageMaker saves
        the resulting model artifacts to an Amazon Simple Storage Service (Amazon S3) bucket that
        you specify.

        If you choose to host your model using Amazon SageMaker hosting services, you can use the
        resulting model artifacts as part of the model. You can also use the artifacts with AWS IoT
        Greengrass. In that case, deploy them as an ML resource.

        In the request body, you provide the following:

        * A name for the compilation job

        * Information about the input model artifacts

        * The output location for the compiled model and the device (target) that the model runs on

        * ``The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker assumes to perform
        the model compilation job``

        You can also provide a ``Tag`` to track the model compilation job's resource use and costs.
        The response body contains the ``CompilationJobArn`` for the compiled job.

        To stop a model compilation job, use  StopCompilationJob . To get information about a
        particular model compilation job, use  DescribeCompilationJob . To get information about
        multiple model compilation jobs, use  ListCompilationJobs .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateCompilationJob>`_

        **Request Syntax**
        ::

          response = client.create_compilation_job(
              CompilationJobName='string',
              RoleArn='string',
              InputConfig={
                  'S3Uri': 'string',
                  'DataInputConfig': 'string',
                  'Framework': 'TENSORFLOW'|'MXNET'|'ONNX'|'PYTORCH'|'XGBOOST'
              },
              OutputConfig={
                  'S3OutputLocation': 'string',
                  'TargetDevice':
                  'lambda'|'ml_m4'|'ml_m5'|'ml_c4'|'ml_c5'|'ml_p2'|'ml_p3'|'ml_inf1'
                  |'jetson_tx1'|'jetson_tx2'|'jetson_nano'|'rasp3b'|'deeplens'|'rk3399'
                  |'rk3288'|'aisage'|'sbe_c'|'qcs605'|'qcs603'
              },
              StoppingCondition={
                  'MaxRuntimeInSeconds': 123,
                  'MaxWaitTimeInSeconds': 123
              }
          )
        :type CompilationJobName: string
        :param CompilationJobName: **[REQUIRED]**

          A name for the model compilation job. The name must be unique within the AWS Region and
          within your AWS account.

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform
          tasks on your behalf.

          During model compilation, Amazon SageMaker needs your permission to:

          * Read input data from an S3 bucket

          * Write model artifacts to an S3 bucket

          * Write logs to Amazon CloudWatch Logs

          * Publish metrics to Amazon CloudWatch

          You grant permissions for all of these tasks to an IAM role. To pass this role to Amazon
          SageMaker, the caller of this API must have the ``iam:PassRole`` permission. For more
          information, see `Amazon SageMaker Roles.
          <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-roles.html>`__

        :type InputConfig: dict
        :param InputConfig: **[REQUIRED]**

          Provides information about the location of input model artifacts, the name and shape of
          the expected data inputs, and the framework in which the model was trained.

          - **S3Uri** *(string) --* **[REQUIRED]**

            The S3 path where the model artifacts, which result from model training, are stored.
            This path must point to a single gzip compressed tar archive (.tar.gz suffix).

          - **DataInputConfig** *(string) --* **[REQUIRED]**

            Specifies the name and shape of the expected data inputs for your trained model with a
            JSON dictionary form. The data inputs are  InputConfig$Framework specific.

            * ``TensorFlow`` : You must specify the name and shape (NHWC format) of the expected
            data inputs using a dictionary format for your trained model. The dictionary formats
            required for the console and CLI are different.

              * Examples for one input:

                * If using the console, ``{"input":[1,1024,1024,3]}``

                * If using the CLI, ``{\\"input\\":[1,1024,1024,3]}``

              * Examples for two inputs:

                * If using the console, ``{"data1": [1,28,28,1], "data2":[1,28,28,1]}``

                * If using the CLI, ``{\\"data1\\": [1,28,28,1], \\"data2\\":[1,28,28,1]}``

            * ``MXNET/ONNX`` : You must specify the name and shape (NCHW format) of the expected
            data inputs in order using a dictionary format for your trained model. The dictionary
            formats required for the console and CLI are different.

              * Examples for one input:

                * If using the console, ``{"data":[1,3,1024,1024]}``

                * If using the CLI, ``{\\"data\\":[1,3,1024,1024]}``

              * Examples for two inputs:

                * If using the console, ``{"var1": [1,1,28,28], "var2":[1,1,28,28]}``

                * If using the CLI, ``{\\"var1\\": [1,1,28,28], \\"var2\\":[1,1,28,28]}``

            * ``PyTorch`` : You can either specify the name and shape (NCHW format) of expected data
            inputs in order using a dictionary format for your trained model or you can specify the
            shape only using a list format. The dictionary formats required for the console and CLI
            are different. The list formats for the console and CLI are the same.

              * Examples for one input in dictionary format:

                * If using the console, ``{"input0":[1,3,224,224]}``

                * If using the CLI, ``{\\"input0\\":[1,3,224,224]}``

              * Example for one input in list format: ``[[1,3,224,224]]``

              * Examples for two inputs in dictionary format:

                * If using the console, ``{"input0":[1,3,224,224], "input1":[1,3,224,224]}``

                * If using the CLI, ``{\\"input0\\":[1,3,224,224], \\"input1\\":[1,3,224,224]}``

              * Example for two inputs in list format: ``[[1,3,224,224], [1,3,224,224]]``

            * ``XGBOOST`` : input data name and shape are not needed.

          - **Framework** *(string) --* **[REQUIRED]**

            Identifies the framework in which the model was trained. For example: TENSORFLOW.

        :type OutputConfig: dict
        :param OutputConfig: **[REQUIRED]**

          Provides information about the output location for the compiled model and the target
          device the model runs on.

          - **S3OutputLocation** *(string) --* **[REQUIRED]**

            Identifies the S3 path where you want Amazon SageMaker to store the model artifacts. For
            example, s3://bucket-name/key-name-prefix.

          - **TargetDevice** *(string) --* **[REQUIRED]**

            Identifies the device that you want to run your model on after it has been compiled. For
            example: ml_c5.

        :type StoppingCondition: dict
        :param StoppingCondition: **[REQUIRED]**

          Specifies a limit to how long a model compilation job can run. When the job reaches the
          time limit, Amazon SageMaker ends the compilation job. Use this API to cap model training
          costs.

          - **MaxRuntimeInSeconds** *(integer) --*

            The maximum length of time, in seconds, that the training or compilation job can run. If
            job does not complete during this time, Amazon SageMaker ends the job. If value is not
            specified, default value is 1 day. The maximum value is 28 days.

          - **MaxWaitTimeInSeconds** *(integer) --*

            The maximum length of time, in seconds, how long you are willing to wait for a managed
            spot training job to complete. It is the amount of time spent waiting for Spot capacity
            plus the amount of time the training job runs. It must be equal to or greater than
            ``MaxRuntimeInSeconds`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CompilationJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **CompilationJobArn** *(string) --*

              If the action is successful, the service sends back an HTTP 200 response. Amazon
              SageMaker returns the following data in JSON format:

              * ``CompilationJobArn`` : The Amazon Resource Name (ARN) of the compiled job.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_domain(
        self,
        DomainName: str,
        AuthMode: Literal["SSO", "IAM"],
        DefaultUserSettings: ClientCreateDomainDefaultUserSettingsTypeDef,
        SubnetIds: List[str],
        VpcId: str,
        Tags: List[ClientCreateDomainTagsTypeDef] = None,
        HomeEfsFileSystemKmsKeyId: str = None,
    ) -> ClientCreateDomainResponseTypeDef:
        """
        Creates a Domain for Amazon SageMaker Amazon SageMaker Studio (Studio), which can be
        accessed by end-users in a web browser. A Domain has an associated directory, list of
        authorized users, and a variety of security, application, policies, and Amazon Virtual
        Private Cloud configurations. An AWS account is limited to one Domain, per region. Users
        within a domain can share notebook files and other artifacts with each other. When a Domain
        is created, an Amazon Elastic File System (EFS) is also created for use by all of the users
        within the Domain. Each user receives a private home directory within the EFS for notebooks,
        Git repositories, and data files.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateDomain>`_

        **Request Syntax**
        ::

          response = client.create_domain(
              DomainName='string',
              AuthMode='SSO'|'IAM',
              DefaultUserSettings={
                  'ExecutionRole': 'string',
                  'SecurityGroups': [
                      'string',
                  ],
                  'SharingSettings': {
                      'NotebookOutputOption': 'Allowed'|'Disabled',
                      'S3OutputPath': 'string',
                      'S3KmsKeyId': 'string'
                  },
                  'JupyterServerAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'KernelGatewayAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'TensorBoardAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  }
              },
              SubnetIds=[
                  'string',
              ],
              VpcId='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              HomeEfsFileSystemKmsKeyId='string'
          )
        :type DomainName: string
        :param DomainName: **[REQUIRED]**

          A name for the domain.

        :type AuthMode: string
        :param AuthMode: **[REQUIRED]**

          The mode of authentication that member use to access the domain.

        :type DefaultUserSettings: dict
        :param DefaultUserSettings: **[REQUIRED]**

          The default user settings.

          - **ExecutionRole** *(string) --*

            The execution role for the user.

          - **SecurityGroups** *(list) --*

            The security groups.

            - *(string) --*

          - **SharingSettings** *(dict) --*

            The sharing settings.

            - **NotebookOutputOption** *(string) --*

              The notebook output option.

            - **S3OutputPath** *(string) --*

              The Amazon S3 output path.

            - **S3KmsKeyId** *(string) --*

              The AWS Key Management Service encryption key ID.

          - **JupyterServerAppSettings** *(dict) --*

            The Jupyter server's app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **KernelGatewayAppSettings** *(dict) --*

            The kernel gateway app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **TensorBoardAppSettings** *(dict) --*

            The TensorBoard app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

        :type SubnetIds: list
        :param SubnetIds: **[REQUIRED]**

          Security setting to limit to a set of subnets.

          - *(string) --*

        :type VpcId: string
        :param VpcId: **[REQUIRED]**

          Security setting to limit the domain's communication to a Amazon Virtual Private Cloud.

        :type Tags: list
        :param Tags:

          Each tag consists of a key and an optional value. Tag keys must be unique per resource.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type HomeEfsFileSystemKmsKeyId: string
        :param HomeEfsFileSystemKmsKeyId:

          The AWS Key Management Service encryption key ID.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'DomainArn': 'string',
                'Url': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **DomainArn** *(string) --*

              The Amazon Resource Name (ARN) of the created domain.

            - **Url** *(string) --*

              The URL to the created domain.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_endpoint(
        self,
        EndpointName: str,
        EndpointConfigName: str,
        Tags: List[ClientCreateEndpointTagsTypeDef] = None,
    ) -> ClientCreateEndpointResponseTypeDef:
        """
        Creates an endpoint using the endpoint configuration specified in the request. Amazon
        SageMaker uses the endpoint to provision resources and deploy models. You create the
        endpoint configuration with the `CreateEndpointConfig
        <https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateEndpointConfig.html>`__ API.

        .. note::

          Use this API only for hosting models using Amazon SageMaker hosting services.

          You must not delete an ``EndpointConfig`` in use by an endpoint that is live or while the
          ``UpdateEndpoint`` or ``CreateEndpoint`` operations are being performed on the endpoint.
          To update an endpoint, you must create a new ``EndpointConfig`` .

        The endpoint name must be unique within an AWS Region in your AWS account.

        When it receives the request, Amazon SageMaker creates the endpoint, launches the resources
        (ML compute instances), and deploys the model(s) on them.

        When Amazon SageMaker receives the request, it sets the endpoint status to ``Creating`` .
        After it creates the endpoint, it sets the status to ``InService`` . Amazon SageMaker can
        then process incoming requests for inferences. To check the status of an endpoint, use the
        `DescribeEndpoint
        <https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeEndpoint.html>`__ API.

        For an example, see `Exercise 1\\: Using the K-Means Algorithm Provided by Amazon SageMaker
        <https://docs.aws.amazon.com/sagemaker/latest/dg/ex1.html>`__ .

        If any of the models hosted at this endpoint get model data from an Amazon S3 location,
        Amazon SageMaker uses AWS Security Token Service to download model artifacts from the S3
        path you provided. AWS STS is activated in your IAM user account by default. If you
        previously deactivated AWS STS for a region, you need to reactivate AWS STS for that region.
        For more information, see `Activating and Deactivating AWS STS in an AWS Region
        <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html>`__
        in the *AWS Identity and Access Management User Guide* .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateEndpoint>`_

        **Request Syntax**
        ::

          response = client.create_endpoint(
              EndpointName='string',
              EndpointConfigName='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type EndpointName: string
        :param EndpointName: **[REQUIRED]**

          The name of the endpoint. The name must be unique within an AWS Region in your AWS
          account.

        :type EndpointConfigName: string
        :param EndpointConfigName: **[REQUIRED]**

          The name of an endpoint configuration. For more information, see `CreateEndpointConfig
          <https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateEndpointConfig.html>`__ .

        :type Tags: list
        :param Tags:

          An array of key-value pairs. For more information, see `Using Cost Allocation Tags
          <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **EndpointArn** *(string) --*

              The Amazon Resource Name (ARN) of the endpoint.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_endpoint_config(
        self,
        EndpointConfigName: str,
        ProductionVariants: List[ClientCreateEndpointConfigProductionVariantsTypeDef],
        DataCaptureConfig: ClientCreateEndpointConfigDataCaptureConfigTypeDef = None,
        Tags: List[ClientCreateEndpointConfigTagsTypeDef] = None,
        KmsKeyId: str = None,
    ) -> ClientCreateEndpointConfigResponseTypeDef:
        """
        Creates an endpoint configuration that Amazon SageMaker hosting services uses to deploy
        models. In the configuration, you identify one or more models, created using the
        ``CreateModel`` API, to deploy and the resources that you want Amazon SageMaker to
        provision. Then you call the `CreateEndpoint
        <https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateEndpoint.html>`__ API.

        .. note::

          Use this API only if you want to use Amazon SageMaker hosting services to deploy models
          into production.

        In the request, you define one or more ``ProductionVariant`` s, each of which identifies a
        model. Each ``ProductionVariant`` parameter also describes the resources that you want
        Amazon SageMaker to provision. This includes the number and type of ML compute instances to
        deploy.

        If you are hosting multiple models, you also assign a ``VariantWeight`` to specify how much
        traffic you want to allocate to each model. For example, suppose that you want to host two
        models, A and B, and you assign traffic weight 2 for model A and 1 for model B. Amazon
        SageMaker distributes two-thirds of the traffic to Model A, and one-third to model B.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateEndpointConfig>`_

        **Request Syntax**
        ::

          response = client.create_endpoint_config(
              EndpointConfigName='string',
              ProductionVariants=[
                  {
                      'VariantName': 'string',
                      'ModelName': 'string',
                      'InitialInstanceCount': 123,
                      'InstanceType':
                      'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'
                      |'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                      |'ml.m4.16xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                      |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'
                      |'ml.m5d.large'|'ml.m5d.xlarge'|'ml.m5d.2xlarge'
                      |'ml.m5d.4xlarge'|'ml.m5d.12xlarge'|'ml.m5d.24xlarge'
                      |'ml.c4.large'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                      |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                      |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.large'
                      |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                      |'ml.c5.18xlarge'|'ml.c5d.large'|'ml.c5d.xlarge'
                      |'ml.c5d.2xlarge'|'ml.c5d.4xlarge'|'ml.c5d.9xlarge'
                      |'ml.c5d.18xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                      |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                      |'ml.g4dn.16xlarge'|'ml.r5.large'|'ml.r5.xlarge'|'ml.r5.2xlarge'
                      |'ml.r5.4xlarge'|'ml.r5.12xlarge'|'ml.r5.24xlarge'
                      |'ml.r5d.large'|'ml.r5d.xlarge'|'ml.r5d.2xlarge'
                      |'ml.r5d.4xlarge'|'ml.r5d.12xlarge'|'ml.r5d.24xlarge'
                      |'ml.inf1.xlarge'|'ml.inf1.2xlarge'|'ml.inf1.6xlarge'
                      |'ml.inf1.24xlarge',
                      'InitialVariantWeight': ...,
                      'AcceleratorType':
                      'ml.eia1.medium'|'ml.eia1.large'|'ml.eia1.xlarge'
                      |'ml.eia2.medium'|'ml.eia2.large'|'ml.eia2.xlarge'
                  },
              ],
              DataCaptureConfig={
                  'EnableCapture': True|False,
                  'InitialSamplingPercentage': 123,
                  'DestinationS3Uri': 'string',
                  'KmsKeyId': 'string',
                  'CaptureOptions': [
                      {
                          'CaptureMode': 'Input'|'Output'
                      },
                  ],
                  'CaptureContentTypeHeader': {
                      'CsvContentTypes': [
                          'string',
                      ],
                      'JsonContentTypes': [
                          'string',
                      ]
                  }
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              KmsKeyId='string'
          )
        :type EndpointConfigName: string
        :param EndpointConfigName: **[REQUIRED]**

          The name of the endpoint configuration. You specify this name in a `CreateEndpoint
          <https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateEndpoint.html>`__ request.

        :type ProductionVariants: list
        :param ProductionVariants: **[REQUIRED]**

          An list of ``ProductionVariant`` objects, one for each model that you want to host at this
          endpoint.

          - *(dict) --*

            Identifies a model that you want to host and the resources to deploy for hosting it. If
            you are deploying multiple models, tell Amazon SageMaker how to distribute traffic among
            the models by specifying variant weights.

            - **VariantName** *(string) --* **[REQUIRED]**

              The name of the production variant.

            - **ModelName** *(string) --* **[REQUIRED]**

              The name of the model that you want to host. This is the name that you specified when
              creating the model.

            - **InitialInstanceCount** *(integer) --* **[REQUIRED]**

              Number of instances to launch initially.

            - **InstanceType** *(string) --* **[REQUIRED]**

              The ML compute instance type.

            - **InitialVariantWeight** *(float) --*

              Determines initial traffic distribution among all of the models that you specify in
              the endpoint configuration. The traffic to a production variant is determined by the
              ratio of the ``VariantWeight`` to the sum of all ``VariantWeight`` values across all
              ProductionVariants. If unspecified, it defaults to 1.0.

            - **AcceleratorType** *(string) --*

              The size of the Elastic Inference (EI) instance to use for the production variant. EI
              instances provide on-demand GPU computing for inference. For more information, see
              `Using Elastic Inference in Amazon SageMaker
              <https://docs.aws.amazon.com/sagemaker/latest/dg/ei.html>`__ .

        :type DataCaptureConfig: dict
        :param DataCaptureConfig:

          - **EnableCapture** *(boolean) --*

          - **InitialSamplingPercentage** *(integer) --* **[REQUIRED]**

          - **DestinationS3Uri** *(string) --* **[REQUIRED]**

          - **KmsKeyId** *(string) --*

          - **CaptureOptions** *(list) --* **[REQUIRED]**

            - *(dict) --*

              - **CaptureMode** *(string) --* **[REQUIRED]**

          - **CaptureContentTypeHeader** *(dict) --*

            - **CsvContentTypes** *(list) --*

              - *(string) --*

            - **JsonContentTypes** *(list) --*

              - *(string) --*

        :type Tags: list
        :param Tags:

          A list of key-value pairs. For more information, see `Using Cost Allocation Tags
          <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type KmsKeyId: string
        :param KmsKeyId:

          The Amazon Resource Name (ARN) of a AWS Key Management Service key that Amazon SageMaker
          uses to encrypt data on the storage volume attached to the ML compute instance that hosts
          the endpoint.

          .. note::

            Certain Nitro-based instances include local storage, dependent on the instance type.
            Local storage volumes are encrypted using a hardware module on the instance. You can't
            request a ``KmsKeyId`` when using an instance type with local storage. If any of the
            models that you specify in the ``ProductionVariants`` parameter use nitro-based
            instances with local storage, do not specify a value for the ``KmsKeyId`` parameter. If
            you specify a value for ``KmsKeyId`` when using any nitro-based instances with local
            storage, the call to ``CreateEndpointConfig`` fails.

            For a list of instance types that support local instance storage, see `Instance Store
            Volumes
            <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
            .

            For more information about local instance storage encryption, see `SSD Instance Store
            Volumes <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__
            .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointConfigArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **EndpointConfigArn** *(string) --*

              The Amazon Resource Name (ARN) of the endpoint configuration.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_experiment(
        self,
        ExperimentName: str,
        DisplayName: str = None,
        Description: str = None,
        Tags: List[ClientCreateExperimentTagsTypeDef] = None,
    ) -> ClientCreateExperimentResponseTypeDef:
        """
        Creates an Amazon SageMaker *experiment* . An experiment is a collection of *trials* that
        are observed, compared and evaluated as a group. A trial is a set of steps, called *trial
        components* , that produce a machine learning model.

        The goal of an experiment is to determine the components that produce the best model.
        Multiple trials are performed, each one isolating and measuring the impact of a change to
        one or more inputs, while keeping the remaining inputs constant.

        When you use Amazon SageMaker Studio or the Amazon SageMaker Python SDK, all experiments,
        trials, and trial components are automatically tracked, logged, and indexed. When you use
        the AWS SDK for Python (Boto), you must use the logging APIs provided by the SDK.

        You can add tags to experiments, trials, trial components and then use the  Search API to
        search for the tags.

        To add a description to an experiment, specify the optional ``Description`` parameter. To
        add a description later, or to change the description, call the  UpdateExperiment API.

        To get a list of all your experiments, call the  ListExperiments API. To view an
        experiment's properties, call the  DescribeExperiment API. To get a list of all the trials
        associated with an experiment, call the  ListTrials API. To create a trial call the
        CreateTrial API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateExperiment>`_

        **Request Syntax**
        ::

          response = client.create_experiment(
              ExperimentName='string',
              DisplayName='string',
              Description='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type ExperimentName: string
        :param ExperimentName: **[REQUIRED]**

          The name of the experiment. The name must be unique in your AWS account and is not
          case-sensitive.

        :type DisplayName: string
        :param DisplayName:

          The name of the experiment as displayed. The name doesn't need to be unique. If you don't
          specify ``DisplayName`` , the value in ``ExperimentName`` is displayed.

        :type Description: string
        :param Description:

          The description of the experiment.

        :type Tags: list
        :param Tags:

          A list of tags to associate with the experiment. You can use  Search API to search on the
          tags.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExperimentArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ExperimentArn** *(string) --*

              The Amazon Resource Name (ARN) of the experiment.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_flow_definition(
        self,
        FlowDefinitionName: str,
        HumanLoopConfig: ClientCreateFlowDefinitionHumanLoopConfigTypeDef,
        OutputConfig: ClientCreateFlowDefinitionOutputConfigTypeDef,
        RoleArn: str,
        HumanLoopActivationConfig: ClientCreateFlowDefinitionHumanLoopActivationConfigTypeDef = None,
        Tags: List[ClientCreateFlowDefinitionTagsTypeDef] = None,
    ) -> ClientCreateFlowDefinitionResponseTypeDef:
        """
        Creates a flow definition.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateFlowDefinition>`_

        **Request Syntax**
        ::

          response = client.create_flow_definition(
              FlowDefinitionName='string',
              HumanLoopActivationConfig={
                  'HumanLoopRequestSource': {
                      'AwsManagedHumanLoopRequestSource':
                      'AWS/Rekognition/DetectModerationLabels/Image/V3'
                      |'AWS/Textract/AnalyzeDocument/Forms/V1'
                  },
                  'HumanLoopActivationConditionsConfig': {
                      'HumanLoopActivationConditions': 'string'
                  }
              },
              HumanLoopConfig={
                  'WorkteamArn': 'string',
                  'HumanTaskUiArn': 'string',
                  'TaskTitle': 'string',
                  'TaskDescription': 'string',
                  'TaskCount': 123,
                  'TaskAvailabilityLifetimeInSeconds': 123,
                  'TaskTimeLimitInSeconds': 123,
                  'TaskKeywords': [
                      'string',
                  ],
                  'PublicWorkforceTaskPrice': {
                      'AmountInUsd': {
                          'Dollars': 123,
                          'Cents': 123,
                          'TenthFractionsOfACent': 123
                      }
                  }
              },
              OutputConfig={
                  'S3OutputPath': 'string',
                  'KmsKeyId': 'string'
              },
              RoleArn='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type FlowDefinitionName: string
        :param FlowDefinitionName: **[REQUIRED]**

          The name of your flow definition.

        :type HumanLoopActivationConfig: dict
        :param HumanLoopActivationConfig:

          An object containing information about the events that trigger a human workflow.

          - **HumanLoopRequestSource** *(dict) --* **[REQUIRED]**

            Container for configuring the source of human task requests.

            - **AwsManagedHumanLoopRequestSource** *(string) --* **[REQUIRED]**

              Specifies whether Amazon Rekognition or Amazon Textract are used as the integration
              source. The default field settings and JSON parsing rules are different based on the
              integration source. Valid values:

          - **HumanLoopActivationConditionsConfig** *(dict) --* **[REQUIRED]**

            Container structure for defining under what conditions SageMaker creates a human loop.

            - **HumanLoopActivationConditions** *(string) --* **[REQUIRED]**

              JSON expressing use-case specific conditions declaratively. If any condition is
              matched, atomic tasks are created against the configured work team. The set of
              conditions is different for Rekognition and Textract.

        :type HumanLoopConfig: dict
        :param HumanLoopConfig: **[REQUIRED]**

          An object containing information about the tasks the human reviewers will perform.

          - **WorkteamArn** *(string) --* **[REQUIRED]**

            Amazon Resource Name (ARN) of a team of workers.

          - **HumanTaskUiArn** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of the human task user interface.

          - **TaskTitle** *(string) --* **[REQUIRED]**

            A title for the human worker task.

          - **TaskDescription** *(string) --* **[REQUIRED]**

            A description for the human worker task.

          - **TaskCount** *(integer) --* **[REQUIRED]**

            The number of human tasks.

          - **TaskAvailabilityLifetimeInSeconds** *(integer) --*

            The length of time that a task remains available for labeling by human workers.

          - **TaskTimeLimitInSeconds** *(integer) --*

            The amount of time that a worker has to complete a task.

          - **TaskKeywords** *(list) --*

            Keywords used to describe the task so that workers can discover the task.

            - *(string) --*

          - **PublicWorkforceTaskPrice** *(dict) --*

            Defines the amount of money paid to an Amazon Mechanical Turk worker for each task
            performed.

            Use one of the following prices for bounding box tasks. Prices are in US dollars and
            should be based on the complexity of the task; the longer it takes in your initial
            testing, the more you should offer.

            * 0.036

            * 0.048

            * 0.060

            * 0.072

            * 0.120

            * 0.240

            * 0.360

            * 0.480

            * 0.600

            * 0.720

            * 0.840

            * 0.960

            * 1.080

            * 1.200

            Use one of the following prices for image classification, text classification, and
            custom tasks. Prices are in US dollars.

            * 0.012

            * 0.024

            * 0.036

            * 0.048

            * 0.060

            * 0.072

            * 0.120

            * 0.240

            * 0.360

            * 0.480

            * 0.600

            * 0.720

            * 0.840

            * 0.960

            * 1.080

            * 1.200

            Use one of the following prices for semantic segmentation tasks. Prices are in US
            dollars.

            * 0.840

            * 0.960

            * 1.080

            * 1.200

            Use one of the following prices for Textract AnalyzeDocument Important Form Key Amazon
            Augmented AI review tasks. Prices are in US dollars.

            * 2.400

            * 2.280

            * 2.160

            * 2.040

            * 1.920

            * 1.800

            * 1.680

            * 1.560

            * 1.440

            * 1.320

            * 1.200

            * 1.080

            * 0.960

            * 0.840

            * 0.720

            * 0.600

            * 0.480

            * 0.360

            * 0.240

            * 0.120

            * 0.072

            * 0.060

            * 0.048

            * 0.036

            * 0.024

            * 0.012

            Use one of the following prices for Rekognition DetectModerationLabels Amazon Augmented
            AI review tasks. Prices are in US dollars.

            * 1.200

            * 1.080

            * 0.960

            * 0.840

            * 0.720

            * 0.600

            * 0.480

            * 0.360

            * 0.240

            * 0.120

            * 0.072

            * 0.060

            * 0.048

            * 0.036

            * 0.024

            * 0.012

            Use one of the following prices for Amazon Augmented AI custom human review tasks.
            Prices are in US dollars.

            * 1.200

            * 1.080

            * 0.960

            * 0.840

            * 0.720

            * 0.600

            * 0.480

            * 0.360

            * 0.240

            * 0.120

            * 0.072

            * 0.060

            * 0.048

            * 0.036

            * 0.024

            * 0.012

            - **AmountInUsd** *(dict) --*

              Defines the amount of money paid to an Amazon Mechanical Turk worker in United States
              dollars.

              - **Dollars** *(integer) --*

                The whole number of dollars in the amount.

              - **Cents** *(integer) --*

                The fractional portion, in cents, of the amount.

              - **TenthFractionsOfACent** *(integer) --*

                Fractions of a cent, in tenths.

        :type OutputConfig: dict
        :param OutputConfig: **[REQUIRED]**

          An object containing information about where the human review results will be uploaded.

          - **S3OutputPath** *(string) --* **[REQUIRED]**

            The Amazon S3 path where the object containing human output will be made available.

          - **KmsKeyId** *(string) --*

            The Amazon Key Management Service (KMS) key ID for server-side encryption.

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the role needed to call other services on your behalf.
          For example,
          ``arn:aws:iam::1234567890:role/service-role/AmazonSageMaker-ExecutionRole-20180111T151298``
          .

        :type Tags: list
        :param Tags:

          An array of key-value pairs that contain metadata to help you categorize and organize a
          flow definition. Each tag consists of a key and a value, both of which you define.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'FlowDefinitionArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **FlowDefinitionArn** *(string) --*

              The Amazon Resource Name (ARN) of the flow definition you create.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_human_task_ui(
        self,
        HumanTaskUiName: str,
        UiTemplate: ClientCreateHumanTaskUiUiTemplateTypeDef,
        Tags: List[ClientCreateHumanTaskUiTagsTypeDef] = None,
    ) -> ClientCreateHumanTaskUiResponseTypeDef:
        """
        Defines the settings you will use for the human review workflow user interface. Reviewers
        will see a three-panel interface with an instruction area, the item to review, and an input
        area.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateHumanTaskUi>`_

        **Request Syntax**
        ::

          response = client.create_human_task_ui(
              HumanTaskUiName='string',
              UiTemplate={
                  'Content': 'string'
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type HumanTaskUiName: string
        :param HumanTaskUiName: **[REQUIRED]**

          The name of the user interface you are creating.

        :type UiTemplate: dict
        :param UiTemplate: **[REQUIRED]**

          The Liquid template for the worker user interface.

          - **Content** *(string) --* **[REQUIRED]**

            The content of the Liquid template for the worker user interface.

        :type Tags: list
        :param Tags:

          An array of key-value pairs that contain metadata to help you categorize and organize a
          human review workflow user interface. Each tag consists of a key and a value, both of
          which you define.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'HumanTaskUiArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **HumanTaskUiArn** *(string) --*

              The Amazon Resource Name (ARN) of the human review workflow user interface you create.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_hyper_parameter_tuning_job(
        self,
        HyperParameterTuningJobName: str,
        HyperParameterTuningJobConfig: ClientCreateHyperParameterTuningJobHyperParameterTuningJobConfigTypeDef,
        TrainingJobDefinition: ClientCreateHyperParameterTuningJobTrainingJobDefinitionTypeDef = None,
        TrainingJobDefinitions: List[
            ClientCreateHyperParameterTuningJobTrainingJobDefinitionsTypeDef
        ] = None,
        WarmStartConfig: ClientCreateHyperParameterTuningJobWarmStartConfigTypeDef = None,
        Tags: List[ClientCreateHyperParameterTuningJobTagsTypeDef] = None,
    ) -> ClientCreateHyperParameterTuningJobResponseTypeDef:
        """
        Starts a hyperparameter tuning job. A hyperparameter tuning job finds the best version of a
        model by running many training jobs on your dataset using the algorithm you choose and
        values for hyperparameters within ranges that you specify. It then chooses the
        hyperparameter values that result in a model that performs the best, as measured by an
        objective metric that you choose.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateHyperParameterTuningJob>`_

        **Request Syntax**
        ::

          response = client.create_hyper_parameter_tuning_job(
              HyperParameterTuningJobName='string',
              HyperParameterTuningJobConfig={
                  'Strategy': 'Bayesian'|'Random',
                  'HyperParameterTuningJobObjective': {
                      'Type': 'Maximize'|'Minimize',
                      'MetricName': 'string'
                  },
                  'ResourceLimits': {
                      'MaxNumberOfTrainingJobs': 123,
                      'MaxParallelTrainingJobs': 123
                  },
                  'ParameterRanges': {
                      'IntegerParameterRanges': [
                          {
                              'Name': 'string',
                              'MinValue': 'string',
                              'MaxValue': 'string',
                              'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                          },
                      ],
                      'ContinuousParameterRanges': [
                          {
                              'Name': 'string',
                              'MinValue': 'string',
                              'MaxValue': 'string',
                              'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                          },
                      ],
                      'CategoricalParameterRanges': [
                          {
                              'Name': 'string',
                              'Values': [
                                  'string',
                              ]
                          },
                      ]
                  },
                  'TrainingJobEarlyStoppingType': 'Off'|'Auto',
                  'TuningJobCompletionCriteria': {
                      'TargetObjectiveMetricValue': ...
                  }
              },
              TrainingJobDefinition={
                  'DefinitionName': 'string',
                  'TuningObjective': {
                      'Type': 'Maximize'|'Minimize',
                      'MetricName': 'string'
                  },
                  'HyperParameterRanges': {
                      'IntegerParameterRanges': [
                          {
                              'Name': 'string',
                              'MinValue': 'string',
                              'MaxValue': 'string',
                              'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                          },
                      ],
                      'ContinuousParameterRanges': [
                          {
                              'Name': 'string',
                              'MinValue': 'string',
                              'MaxValue': 'string',
                              'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                          },
                      ],
                      'CategoricalParameterRanges': [
                          {
                              'Name': 'string',
                              'Values': [
                                  'string',
                              ]
                          },
                      ]
                  },
                  'StaticHyperParameters': {
                      'string': 'string'
                  },
                  'AlgorithmSpecification': {
                      'TrainingImage': 'string',
                      'TrainingInputMode': 'Pipe'|'File',
                      'AlgorithmName': 'string',
                      'MetricDefinitions': [
                          {
                              'Name': 'string',
                              'Regex': 'string'
                          },
                      ]
                  },
                  'RoleArn': 'string',
                  'InputDataConfig': [
                      {
                          'ChannelName': 'string',
                          'DataSource': {
                              'S3DataSource': {
                                  'S3DataType': 'ManifestFile'|'S3Prefix'|'AugmentedManifestFile',
                                  'S3Uri': 'string',
                                  'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key',
                                  'AttributeNames': [
                                      'string',
                                  ]
                              },
                              'FileSystemDataSource': {
                                  'FileSystemId': 'string',
                                  'FileSystemAccessMode': 'rw'|'ro',
                                  'FileSystemType': 'EFS'|'FSxLustre',
                                  'DirectoryPath': 'string'
                              }
                          },
                          'ContentType': 'string',
                          'CompressionType': 'None'|'Gzip',
                          'RecordWrapperType': 'None'|'RecordIO',
                          'InputMode': 'Pipe'|'File',
                          'ShuffleConfig': {
                              'Seed': 123
                          }
                      },
                  ],
                  'VpcConfig': {
                      'SecurityGroupIds': [
                          'string',
                      ],
                      'Subnets': [
                          'string',
                      ]
                  },
                  'OutputDataConfig': {
                      'KmsKeyId': 'string',
                      'S3OutputPath': 'string'
                  },
                  'ResourceConfig': {
                      'InstanceType':
                      'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                      |'ml.m4.16xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                      |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'
                      |'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'
                      |'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'
                      |'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.p3dn.24xlarge'
                      |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                      |'ml.c5.18xlarge',
                      'InstanceCount': 123,
                      'VolumeSizeInGB': 123,
                      'VolumeKmsKeyId': 'string'
                  },
                  'StoppingCondition': {
                      'MaxRuntimeInSeconds': 123,
                      'MaxWaitTimeInSeconds': 123
                  },
                  'EnableNetworkIsolation': True|False,
                  'EnableInterContainerTrafficEncryption': True|False,
                  'EnableManagedSpotTraining': True|False,
                  'CheckpointConfig': {
                      'S3Uri': 'string',
                      'LocalPath': 'string'
                  }
              },
              TrainingJobDefinitions=[
                  {
                      'DefinitionName': 'string',
                      'TuningObjective': {
                          'Type': 'Maximize'|'Minimize',
                          'MetricName': 'string'
                      },
                      'HyperParameterRanges': {
                          'IntegerParameterRanges': [
                              {
                                  'Name': 'string',
                                  'MinValue': 'string',
                                  'MaxValue': 'string',
                                  'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                              },
                          ],
                          'ContinuousParameterRanges': [
                              {
                                  'Name': 'string',
                                  'MinValue': 'string',
                                  'MaxValue': 'string',
                                  'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                              },
                          ],
                          'CategoricalParameterRanges': [
                              {
                                  'Name': 'string',
                                  'Values': [
                                      'string',
                                  ]
                              },
                          ]
                      },
                      'StaticHyperParameters': {
                          'string': 'string'
                      },
                      'AlgorithmSpecification': {
                          'TrainingImage': 'string',
                          'TrainingInputMode': 'Pipe'|'File',
                          'AlgorithmName': 'string',
                          'MetricDefinitions': [
                              {
                                  'Name': 'string',
                                  'Regex': 'string'
                              },
                          ]
                      },
                      'RoleArn': 'string',
                      'InputDataConfig': [
                          {
                              'ChannelName': 'string',
                              'DataSource': {
                                  'S3DataSource': {
                                      'S3DataType':
                                      'ManifestFile'|'S3Prefix'
                                      |'AugmentedManifestFile',
                                      'S3Uri': 'string',
                                      'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key',
                                      'AttributeNames': [
                                          'string',
                                      ]
                                  },
                                  'FileSystemDataSource': {
                                      'FileSystemId': 'string',
                                      'FileSystemAccessMode': 'rw'|'ro',
                                      'FileSystemType': 'EFS'|'FSxLustre',
                                      'DirectoryPath': 'string'
                                  }
                              },
                              'ContentType': 'string',
                              'CompressionType': 'None'|'Gzip',
                              'RecordWrapperType': 'None'|'RecordIO',
                              'InputMode': 'Pipe'|'File',
                              'ShuffleConfig': {
                                  'Seed': 123
                              }
                          },
                      ],
                      'VpcConfig': {
                          'SecurityGroupIds': [
                              'string',
                          ],
                          'Subnets': [
                              'string',
                          ]
                      },
                      'OutputDataConfig': {
                          'KmsKeyId': 'string',
                          'S3OutputPath': 'string'
                      },
                      'ResourceConfig': {
                          'InstanceType':
                          'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'
                          |'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.large'
                          |'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                          |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'
                          |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'
                          |'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                          |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'
                          |'ml.p3dn.24xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                          |'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge',
                          'InstanceCount': 123,
                          'VolumeSizeInGB': 123,
                          'VolumeKmsKeyId': 'string'
                      },
                      'StoppingCondition': {
                          'MaxRuntimeInSeconds': 123,
                          'MaxWaitTimeInSeconds': 123
                      },
                      'EnableNetworkIsolation': True|False,
                      'EnableInterContainerTrafficEncryption': True|False,
                      'EnableManagedSpotTraining': True|False,
                      'CheckpointConfig': {
                          'S3Uri': 'string',
                          'LocalPath': 'string'
                      }
                  },
              ],
              WarmStartConfig={
                  'ParentHyperParameterTuningJobs': [
                      {
                          'HyperParameterTuningJobName': 'string'
                      },
                  ],
                  'WarmStartType': 'IdenticalDataAndAlgorithm'|'TransferLearning'
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type HyperParameterTuningJobName: string
        :param HyperParameterTuningJobName: **[REQUIRED]**

          The name of the tuning job. This name is the prefix for the names of all training jobs
          that this tuning job launches. The name must be unique within the same AWS account and AWS
          Region. The name must have { } to { } characters. Valid characters are a-z, A-Z, 0-9, and
          : + = @ _ % - (hyphen). The name is not case sensitive.

        :type HyperParameterTuningJobConfig: dict
        :param HyperParameterTuningJobConfig: **[REQUIRED]**

          The  HyperParameterTuningJobConfig object that describes the tuning job, including the
          search strategy, the objective metric used to evaluate training jobs, ranges of parameters
          to search, and resource limits for the tuning job. For more information, see
          automatic-model-tuning

          - **Strategy** *(string) --* **[REQUIRED]**

            Specifies how hyperparameter tuning chooses the combinations of hyperparameter values to
            use for the training job it launches. To use the Bayesian search strategy, set this to
            ``Bayesian`` . To randomly search, set it to ``Random`` . For information about search
            strategies, see `How Hyperparameter Tuning Works
            <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html>`__
            .

          - **HyperParameterTuningJobObjective** *(dict) --*

            The  HyperParameterTuningJobObjective object that specifies the objective metric for
            this tuning job.

            - **Type** *(string) --* **[REQUIRED]**

              Whether to minimize or maximize the objective metric.

            - **MetricName** *(string) --* **[REQUIRED]**

              The name of the metric to use for the objective metric.

          - **ResourceLimits** *(dict) --* **[REQUIRED]**

            The  ResourceLimits object that specifies the maximum number of training jobs and
            parallel training jobs for this tuning job.

            - **MaxNumberOfTrainingJobs** *(integer) --* **[REQUIRED]**

              The maximum number of training jobs that a hyperparameter tuning job can launch.

            - **MaxParallelTrainingJobs** *(integer) --* **[REQUIRED]**

              The maximum number of concurrent training jobs that a hyperparameter tuning job can
              launch.

          - **ParameterRanges** *(dict) --*

            The  ParameterRanges object that specifies the ranges of hyperparameters that this
            tuning job searches.

            - **IntegerParameterRanges** *(list) --*

              The array of  IntegerParameterRange objects that specify ranges of integer
              hyperparameters that a hyperparameter tuning job searches.

              - *(dict) --*

                For a hyperparameter of the integer type, specifies the range that a hyperparameter
                tuning job searches.

                - **Name** *(string) --* **[REQUIRED]**

                  The name of the hyperparameter to search.

                - **MinValue** *(string) --* **[REQUIRED]**

                  The minimum value of the hyperparameter to search.

                - **MaxValue** *(string) --* **[REQUIRED]**

                  The maximum value of the hyperparameter to search.

                - **ScalingType** *(string) --*

                  The scale that hyperparameter tuning uses to search the hyperparameter range. For
                  information about choosing a hyperparameter scale, see `Hyperparameter Scaling
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                  . One of the following values:

                    Auto

                  Amazon SageMaker hyperparameter tuning chooses the best scale for the
                  hyperparameter.

                    Linear

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  linear scale.

                    Logarithmic

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  logarithmic scale.

                  Logarithmic scaling works only for ranges that have only values greater than 0.

            - **ContinuousParameterRanges** *(list) --*

              The array of  ContinuousParameterRange objects that specify ranges of continuous
              hyperparameters that a hyperparameter tuning job searches.

              - *(dict) --*

                A list of continuous hyperparameters to tune.

                - **Name** *(string) --* **[REQUIRED]**

                  The name of the continuous hyperparameter to tune.

                - **MinValue** *(string) --* **[REQUIRED]**

                  The minimum value for the hyperparameter. The tuning job uses floating-point
                  values between this value and ``MaxValue`` for tuning.

                - **MaxValue** *(string) --* **[REQUIRED]**

                  The maximum value for the hyperparameter. The tuning job uses floating-point
                  values between ``MinValue`` value and this value for tuning.

                - **ScalingType** *(string) --*

                  The scale that hyperparameter tuning uses to search the hyperparameter range. For
                  information about choosing a hyperparameter scale, see `Hyperparameter Scaling
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                  . One of the following values:

                    Auto

                  Amazon SageMaker hyperparameter tuning chooses the best scale for the
                  hyperparameter.

                    Linear

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  linear scale.

                    Logarithmic

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  logarithmic scale.

                  Logarithmic scaling works only for ranges that have only values greater than 0.

                    ReverseLogarithmic

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  reverse logarithmic scale.

                  Reverse logarithmic scaling works only for ranges that are entirely within the
                  range 0<=x<1.0.

            - **CategoricalParameterRanges** *(list) --*

              The array of  CategoricalParameterRange objects that specify ranges of categorical
              hyperparameters that a hyperparameter tuning job searches.

              - *(dict) --*

                A list of categorical hyperparameters to tune.

                - **Name** *(string) --* **[REQUIRED]**

                  The name of the categorical hyperparameter to tune.

                - **Values** *(list) --* **[REQUIRED]**

                  A list of the categories for the hyperparameter.

                  - *(string) --*

          - **TrainingJobEarlyStoppingType** *(string) --*

            Specifies whether to use early stopping for training jobs launched by the hyperparameter
            tuning job. This can be one of the following values (the default value is ``OFF`` ):

              OFF

            Training jobs launched by the hyperparameter tuning job do not use early stopping.

              AUTO

            Amazon SageMaker stops training jobs launched by the hyperparameter tuning job when they
            are unlikely to perform better than previously completed training jobs. For more
            information, see `Stop Training Jobs Early
            <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-early-stopping.html>`__
            .

          - **TuningJobCompletionCriteria** *(dict) --*

            The tuning job's completion criteria.

            - **TargetObjectiveMetricValue** *(float) --* **[REQUIRED]**

              The objective metric's value.

        :type TrainingJobDefinition: dict
        :param TrainingJobDefinition:

          The  HyperParameterTrainingJobDefinition object that describes the training jobs that this
          tuning job launches, including static hyperparameters, input data configuration, output
          data configuration, resource configuration, and stopping condition.

          - **DefinitionName** *(string) --*

            The job definition name.

          - **TuningObjective** *(dict) --*

            Defines the objective metric for a hyperparameter tuning job. Hyperparameter tuning uses
            the value of this metric to evaluate the training jobs it launches, and returns the
            training job that results in either the highest or lowest value for this metric,
            depending on the value you specify for the ``Type`` parameter.

            - **Type** *(string) --* **[REQUIRED]**

              Whether to minimize or maximize the objective metric.

            - **MetricName** *(string) --* **[REQUIRED]**

              The name of the metric to use for the objective metric.

          - **HyperParameterRanges** *(dict) --*

            Specifies ranges of integer, continuous, and categorical hyperparameters that a
            hyperparameter tuning job searches. The hyperparameter tuning job launches training jobs
            with hyperparameter values within these ranges to find the combination of values that
            result in the training job with the best performance as measured by the objective metric
            of the hyperparameter tuning job.

            .. note::

              You can specify a maximum of 20 hyperparameters that a hyperparameter tuning job can
              search over. Every possible value of a categorical parameter range counts against this
              limit.

            - **IntegerParameterRanges** *(list) --*

              The array of  IntegerParameterRange objects that specify ranges of integer
              hyperparameters that a hyperparameter tuning job searches.

              - *(dict) --*

                For a hyperparameter of the integer type, specifies the range that a hyperparameter
                tuning job searches.

                - **Name** *(string) --* **[REQUIRED]**

                  The name of the hyperparameter to search.

                - **MinValue** *(string) --* **[REQUIRED]**

                  The minimum value of the hyperparameter to search.

                - **MaxValue** *(string) --* **[REQUIRED]**

                  The maximum value of the hyperparameter to search.

                - **ScalingType** *(string) --*

                  The scale that hyperparameter tuning uses to search the hyperparameter range. For
                  information about choosing a hyperparameter scale, see `Hyperparameter Scaling
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                  . One of the following values:

                    Auto

                  Amazon SageMaker hyperparameter tuning chooses the best scale for the
                  hyperparameter.

                    Linear

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  linear scale.

                    Logarithmic

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  logarithmic scale.

                  Logarithmic scaling works only for ranges that have only values greater than 0.

            - **ContinuousParameterRanges** *(list) --*

              The array of  ContinuousParameterRange objects that specify ranges of continuous
              hyperparameters that a hyperparameter tuning job searches.

              - *(dict) --*

                A list of continuous hyperparameters to tune.

                - **Name** *(string) --* **[REQUIRED]**

                  The name of the continuous hyperparameter to tune.

                - **MinValue** *(string) --* **[REQUIRED]**

                  The minimum value for the hyperparameter. The tuning job uses floating-point
                  values between this value and ``MaxValue`` for tuning.

                - **MaxValue** *(string) --* **[REQUIRED]**

                  The maximum value for the hyperparameter. The tuning job uses floating-point
                  values between ``MinValue`` value and this value for tuning.

                - **ScalingType** *(string) --*

                  The scale that hyperparameter tuning uses to search the hyperparameter range. For
                  information about choosing a hyperparameter scale, see `Hyperparameter Scaling
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                  . One of the following values:

                    Auto

                  Amazon SageMaker hyperparameter tuning chooses the best scale for the
                  hyperparameter.

                    Linear

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  linear scale.

                    Logarithmic

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  logarithmic scale.

                  Logarithmic scaling works only for ranges that have only values greater than 0.

                    ReverseLogarithmic

                  Hyperparameter tuning searches the values in the hyperparameter range by using a
                  reverse logarithmic scale.

                  Reverse logarithmic scaling works only for ranges that are entirely within the
                  range 0<=x<1.0.

            - **CategoricalParameterRanges** *(list) --*

              The array of  CategoricalParameterRange objects that specify ranges of categorical
              hyperparameters that a hyperparameter tuning job searches.

              - *(dict) --*

                A list of categorical hyperparameters to tune.

                - **Name** *(string) --* **[REQUIRED]**

                  The name of the categorical hyperparameter to tune.

                - **Values** *(list) --* **[REQUIRED]**

                  A list of the categories for the hyperparameter.

                  - *(string) --*

          - **StaticHyperParameters** *(dict) --*

            Specifies the values of hyperparameters that do not change for the tuning job.

            - *(string) --*

              - *(string) --*

          - **AlgorithmSpecification** *(dict) --* **[REQUIRED]**

            The  HyperParameterAlgorithmSpecification object that specifies the resource algorithm
            to use for the training jobs that the tuning job launches.

            - **TrainingImage** *(string) --*

              The registry path of the Docker image that contains the training algorithm. For
              information about Docker registry paths for built-in algorithms, see `Algorithms
              Provided by Amazon SageMaker\\: Common Parameters
              <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
              . Amazon SageMaker supports both ``registry/repository[:tag]`` and
              ``registry/repository[@digest]`` image path formats. For more information, see `Using
              Your Own Algorithms with Amazon SageMaker
              <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

            - **TrainingInputMode** *(string) --* **[REQUIRED]**

              The input mode that the algorithm supports: File or Pipe. In File input mode, Amazon
              SageMaker downloads the training data from Amazon S3 to the storage volume that is
              attached to the training instance and mounts the directory to the Docker volume for
              the training container. In Pipe input mode, Amazon SageMaker streams data directly
              from Amazon S3 to the container.

              If you specify File mode, make sure that you provision the storage volume that is
              attached to the training instance with enough capacity to accommodate the training
              data downloaded from Amazon S3, the model artifacts, and intermediate information.

              For more information about input modes, see `Algorithms
              <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

            - **AlgorithmName** *(string) --*

              The name of the resource algorithm to use for the hyperparameter tuning job. If you
              specify a value for this parameter, do not specify a value for ``TrainingImage`` .

            - **MetricDefinitions** *(list) --*

              An array of  MetricDefinition objects that specify the metrics that the algorithm
              emits.

              - *(dict) --*

                Specifies a metric that the training algorithm writes to ``stderr`` or ``stdout`` .
                Amazon SageMakerhyperparameter tuning captures all defined metrics. You specify one
                metric that a hyperparameter tuning job uses as its objective metric to choose the
                best training job.

                - **Name** *(string) --* **[REQUIRED]**

                  The name of the metric.

                - **Regex** *(string) --* **[REQUIRED]**

                  A regular expression that searches the output of a training job and gets the value
                  of the metric. For more information about using regular expressions to define
                  metrics, see `Defining Objective Metrics
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                  .

          - **RoleArn** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of the IAM role associated with the training jobs that
            the tuning job launches.

          - **InputDataConfig** *(list) --*

            An array of  Channel objects that specify the input for the training jobs that the
            tuning job launches.

            - *(dict) --*

              A channel is a named input source that training algorithms can consume.

              - **ChannelName** *(string) --* **[REQUIRED]**

                The name of the channel.

              - **DataSource** *(dict) --* **[REQUIRED]**

                The location of the channel data.

                - **S3DataSource** *(dict) --*

                  The S3 location of the data source that is associated with a channel.

                  - **S3DataType** *(string) --* **[REQUIRED]**

                    If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                    SageMaker uses all objects that match the specified key name prefix for model
                    training.

                    If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                    manifest file containing a list of object keys that you want Amazon SageMaker to
                    use for model training.

                    If you choose ``AugmentedManifestFile`` , S3Uri identifies an object that is an
                    augmented manifest file in JSON lines format. This file contains the data you
                    want to use for model training. ``AugmentedManifestFile`` can only be used if
                    the Channel's input mode is ``Pipe`` .

                  - **S3Uri** *(string) --* **[REQUIRED]**

                    Depending on the value specified for the ``S3DataType`` , identifies either a
                    key name prefix or a manifest. For example:

                    * A key name prefix might look like this: ``s3://bucketname/exampleprefix`` .

                    * A manifest might look like this: ``s3://bucketname/example.manifest``   The
                    manifest is an S3 object which is a JSON file with the following format:  The
                    preceding JSON matches the following ``s3Uris`` :   ``[ {"prefix":
                    "s3://customer_bucket/some/prefix/"},``    ``"relative/path/to/custdata-1",``
                    ``"relative/path/custdata-2",``    ``...``    ``"relative/path/custdata-N"``
                    ``]``   The preceding JSON matches the following ``s3Uris`` :
                    ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                    ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                    ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete set
                    of ``s3uris`` in this manifest is the input data for the channel for this
                    datasource. The object that each ``s3uris`` points to must be readable by the
                    IAM role that Amazon SageMaker uses to perform tasks on your behalf.

                  - **S3DataDistributionType** *(string) --*

                    If you want Amazon SageMaker to replicate the entire dataset on each ML compute
                    instance that is launched for model training, specify ``FullyReplicated`` .

                    If you want Amazon SageMaker to replicate a subset of data on each ML compute
                    instance that is launched for model training, specify ``ShardedByS3Key`` . If
                    there are *n* ML compute instances launched for a training job, each instance
                    gets approximately 1/*n* of the number of S3 objects. In this case, model
                    training on each machine uses only the subset of training data.

                    Don't choose more ML compute instances for training than available S3 objects.
                    If you do, some nodes won't get any data and you will pay for nodes that aren't
                    getting any training data. This applies in both File and Pipe modes. Keep this
                    in mind when developing algorithms.

                    In distributed training, where you use multiple ML compute EC2 instances, you
                    might choose ``ShardedByS3Key`` . If the algorithm requires copying training
                    data to the ML storage volume (when ``TrainingInputMode`` is set to ``File`` ),
                    this copies 1/*n* of the number of objects.

                  - **AttributeNames** *(list) --*

                    A list of one or more attribute names to use that are found in a specified
                    augmented manifest file.

                    - *(string) --*

                - **FileSystemDataSource** *(dict) --*

                  The file system that is associated with a channel.

                  - **FileSystemId** *(string) --* **[REQUIRED]**

                    The file system id.

                  - **FileSystemAccessMode** *(string) --* **[REQUIRED]**

                    The access mode of the mount of the directory associated with the channel. A
                    directory can be mounted either in ``ro`` (read-only) or ``rw`` (read-write)
                    mode.

                  - **FileSystemType** *(string) --* **[REQUIRED]**

                    The file system type.

                  - **DirectoryPath** *(string) --* **[REQUIRED]**

                    The full path to the directory to associate with the channel.

              - **ContentType** *(string) --*

                The MIME type of the data.

              - **CompressionType** *(string) --*

                If training data is compressed, the compression type. The default value is ``None``
                . ``CompressionType`` is used only in Pipe input mode. In File mode, leave this
                field unset or set it to None.

              - **RecordWrapperType** *(string) --*

                Specify RecordIO as the value when input data is in raw format but the training
                algorithm requires the RecordIO format. In this case, Amazon SageMaker wraps each
                individual S3 object in a RecordIO record. If the input data is already in RecordIO
                format, you don't need to set this attribute. For more information, see `Create a
                Dataset Using RecordIO
                <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__ .

                In File mode, leave this field unset or set it to None.

              - **InputMode** *(string) --*

                (Optional) The input mode to use for the data channel in a training job. If you
                don't set a value for ``InputMode`` , Amazon SageMaker uses the value set for
                ``TrainingInputMode`` . Use this parameter to override the ``TrainingInputMode``
                setting in a  AlgorithmSpecification request when you have a channel that needs a
                different input mode from the training job's general setting. To download the data
                from Amazon Simple Storage Service (Amazon S3) to the provisioned ML storage volume,
                and mount the directory to a Docker volume, use ``File`` input mode. To stream data
                directly from Amazon S3 to the container, choose ``Pipe`` input mode.

                To use a model for incremental training, choose ``File`` input model.

              - **ShuffleConfig** *(dict) --*

                A configuration for a shuffle option for input data in a channel. If you use
                ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key prefix
                matches. If you use ``ManifestFile`` , the order of the S3 object references in the
                ``ManifestFile`` is shuffled. If you use ``AugmentedManifestFile`` , the order of
                the JSON lines in the ``AugmentedManifestFile`` is shuffled. The shuffling order is
                determined using the ``Seed`` value.

                For Pipe input mode, shuffling is done at the start of every epoch. With large
                datasets this ensures that the order of the training data is different for each
                epoch, it helps reduce bias and possible overfitting. In a multi-node training job
                when ShuffleConfig is combined with ``S3DataDistributionType`` of ``ShardedByS3Key``
                , the data is shuffled across nodes so that the content sent to a particular node on
                the first epoch might be sent to a different node on the second epoch.

                - **Seed** *(integer) --* **[REQUIRED]**

                  Determines the shuffling order in ``ShuffleConfig`` value.

          - **VpcConfig** *(dict) --*

            The  VpcConfig object that specifies the VPC that you want the training jobs that this
            hyperparameter tuning job launches to connect to. Control access to and from your
            training container by configuring the VPC. For more information, see `Protect Training
            Jobs by Using an Amazon Virtual Private Cloud
            <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

            - **SecurityGroupIds** *(list) --* **[REQUIRED]**

              The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for
              the VPC that is specified in the ``Subnets`` field.

              - *(string) --*

            - **Subnets** *(list) --* **[REQUIRED]**

              The ID of the subnets in the VPC to which you want to connect your training job or
              model.

              .. note::

                Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                availability zones of region us-east-1. If you want to create endpoints with P3
                instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                zones instead.

              - *(string) --*

          - **OutputDataConfig** *(dict) --* **[REQUIRED]**

            Specifies the path to the Amazon S3 bucket where you store model artifacts from the
            training jobs that the tuning job launches.

            - **KmsKeyId** *(string) --*

              The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the
              model artifacts at rest using Amazon S3 server-side encryption. The ``KmsKeyId`` can
              be any of the following formats:

              * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

              * // Amazon Resource Name (ARN) of a KMS Key
              ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

              * // KMS Key Alias  ``"alias/ExampleAlias"``

              * // Amazon Resource Name (ARN) of a KMS Key Alias
              ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

              If you use a KMS key ID or an alias of your master key, the Amazon SageMaker execution
              role must include permissions to call ``kms:Encrypt`` . If you don't provide a KMS key
              ID, Amazon SageMaker uses the default KMS key for Amazon S3 for your role's account.
              Amazon SageMaker uses server-side encryption with KMS-managed keys for
              ``OutputDataConfig`` . If you use a bucket policy with an ``s3:PutObject`` permission
              that only allows objects with server-side encryption, set the condition key of
              ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For more information, see
              `KMS-Managed Encryption Keys
              <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in the
              *Amazon Simple Storage Service Developer Guide.*

              The KMS key policy must grant permission to the IAM role that you specify in your
              ``CreateTrainingJob`` , ``CreateTransformJob`` , or ``CreateHyperParameterTuningJob``
              requests. For more information, see `Using Key Policies in AWS KMS
              <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the
              *AWS Key Management Service Developer Guide* .

            - **S3OutputPath** *(string) --* **[REQUIRED]**

              Identifies the S3 path where you want Amazon SageMaker to store the model artifacts.
              For example, ``s3://bucket-name/key-name-prefix`` .

          - **ResourceConfig** *(dict) --* **[REQUIRED]**

            The resources, including the compute instances and storage volumes, to use for the
            training jobs that the tuning job launches.

            Storage volumes store model artifacts and incremental states. Training algorithms might
            also use storage volumes for scratch space. If you want Amazon SageMaker to use the
            storage volume to store the training data, choose ``File`` as the ``TrainingInputMode``
            in the algorithm specification. For distributed training algorithms, specify an instance
            count greater than 1.

            - **InstanceType** *(string) --* **[REQUIRED]**

              The ML compute instance type.

            - **InstanceCount** *(integer) --* **[REQUIRED]**

              The number of ML compute instances to use. For distributed training, provide a value
              greater than 1.

            - **VolumeSizeInGB** *(integer) --* **[REQUIRED]**

              The size of the ML storage volume that you want to provision.

              ML storage volumes store model artifacts and incremental states. Training algorithms
              might also use the ML storage volume for scratch space. If you want to store the
              training data in the ML storage volume, choose ``File`` as the ``TrainingInputMode``
              in the algorithm specification.

              You must specify sufficient ML storage for your scenario.

              .. note::

                Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage volume type.

              .. note::

                Certain Nitro-based instances include local storage with a fixed total size,
                dependent on the instance type. When using these instances for training, Amazon
                SageMaker mounts the local instance storage instead of Amazon EBS gp2 storage. You
                can't request a ``VolumeSizeInGB`` greater than the total size of the local instance
                storage.

                For a list of instance types that support local instance storage, including the
                total size per instance type, see `Instance Store Volumes
                <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                .

            - **VolumeKmsKeyId** *(string) --*

              The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume
              attached to the ML compute instance(s) that run the training job.

              .. note::

                Certain Nitro-based instances include local storage, dependent on the instance type.
                Local storage volumes are encrypted using a hardware module on the instance. You
                can't request a ``VolumeKmsKeyId`` when using an instance type with local storage.

                For a list of instance types that support local instance storage, see `Instance
                Store Volumes
                <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                .

                For more information about local instance storage encryption, see `SSD Instance
                Store Volumes
                <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__ .

              The ``VolumeKmsKeyId`` can be in any of the following formats:

              * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

              * // Amazon Resource Name (ARN) of a KMS Key
              ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

          - **StoppingCondition** *(dict) --* **[REQUIRED]**

            Specifies a limit to how long a model hyperparameter training job can run. It also
            specifies how long you are willing to wait for a managed spot training job to complete.
            When the job reaches the a limit, Amazon SageMaker ends the training job. Use this API
            to cap model training costs.

            - **MaxRuntimeInSeconds** *(integer) --*

              The maximum length of time, in seconds, that the training or compilation job can run.
              If job does not complete during this time, Amazon SageMaker ends the job. If value is
              not specified, default value is 1 day. The maximum value is 28 days.

            - **MaxWaitTimeInSeconds** *(integer) --*

              The maximum length of time, in seconds, how long you are willing to wait for a managed
              spot training job to complete. It is the amount of time spent waiting for Spot
              capacity plus the amount of time the training job runs. It must be equal to or greater
              than ``MaxRuntimeInSeconds`` .

          - **EnableNetworkIsolation** *(boolean) --*

            Isolates the training container. No inbound or outbound network calls can be made,
            except for calls between peers within a training cluster for distributed training. If
            network isolation is used for training jobs that are configured to use a VPC, Amazon
            SageMaker downloads and uploads customer data and model artifacts through the specified
            VPC, but the training container does not have network access.

            .. note::

              The Semantic Segmentation built-in algorithm does not support network isolation.

          - **EnableInterContainerTrafficEncryption** *(boolean) --*

            To encrypt all communications between ML compute instances in distributed training,
            choose ``True`` . Encryption provides greater security for distributed training, but
            training might take longer. How long it takes depends on the amount of communication
            between compute instances, especially if you use a deep learning algorithm in
            distributed training.

          - **EnableManagedSpotTraining** *(boolean) --*

            A Boolean indicating whether managed spot training is enabled (``True`` ) or not
            (``False`` ).

          - **CheckpointConfig** *(dict) --*

            Contains information about the output location for managed spot training checkpoint
            data.

            - **S3Uri** *(string) --* **[REQUIRED]**

              Identifies the S3 path where you want Amazon SageMaker to store checkpoints. For
              example, ``s3://bucket-name/key-name-prefix`` .

            - **LocalPath** *(string) --*

              (Optional) The local directory where checkpoints are written. The default directory is
              ``/opt/ml/checkpoints/`` .

        :type TrainingJobDefinitions: list
        :param TrainingJobDefinitions:

          - *(dict) --*

            Defines the training jobs launched by a hyperparameter tuning job.

            - **DefinitionName** *(string) --*

              The job definition name.

            - **TuningObjective** *(dict) --*

              Defines the objective metric for a hyperparameter tuning job. Hyperparameter tuning
              uses the value of this metric to evaluate the training jobs it launches, and returns
              the training job that results in either the highest or lowest value for this metric,
              depending on the value you specify for the ``Type`` parameter.

              - **Type** *(string) --* **[REQUIRED]**

                Whether to minimize or maximize the objective metric.

              - **MetricName** *(string) --* **[REQUIRED]**

                The name of the metric to use for the objective metric.

            - **HyperParameterRanges** *(dict) --*

              Specifies ranges of integer, continuous, and categorical hyperparameters that a
              hyperparameter tuning job searches. The hyperparameter tuning job launches training
              jobs with hyperparameter values within these ranges to find the combination of values
              that result in the training job with the best performance as measured by the objective
              metric of the hyperparameter tuning job.

              .. note::

                You can specify a maximum of 20 hyperparameters that a hyperparameter tuning job can
                search over. Every possible value of a categorical parameter range counts against
                this limit.

              - **IntegerParameterRanges** *(list) --*

                The array of  IntegerParameterRange objects that specify ranges of integer
                hyperparameters that a hyperparameter tuning job searches.

                - *(dict) --*

                  For a hyperparameter of the integer type, specifies the range that a
                  hyperparameter tuning job searches.

                  - **Name** *(string) --* **[REQUIRED]**

                    The name of the hyperparameter to search.

                  - **MinValue** *(string) --* **[REQUIRED]**

                    The minimum value of the hyperparameter to search.

                  - **MaxValue** *(string) --* **[REQUIRED]**

                    The maximum value of the hyperparameter to search.

                  - **ScalingType** *(string) --*

                    The scale that hyperparameter tuning uses to search the hyperparameter range.
                    For information about choosing a hyperparameter scale, see `Hyperparameter
                    Scaling
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                    . One of the following values:

                      Auto

                    Amazon SageMaker hyperparameter tuning chooses the best scale for the
                    hyperparameter.

                      Linear

                    Hyperparameter tuning searches the values in the hyperparameter range by using a
                    linear scale.

                      Logarithmic

                    Hyperparameter tuning searches the values in the hyperparameter range by using a
                    logarithmic scale.

                    Logarithmic scaling works only for ranges that have only values greater than 0.

              - **ContinuousParameterRanges** *(list) --*

                The array of  ContinuousParameterRange objects that specify ranges of continuous
                hyperparameters that a hyperparameter tuning job searches.

                - *(dict) --*

                  A list of continuous hyperparameters to tune.

                  - **Name** *(string) --* **[REQUIRED]**

                    The name of the continuous hyperparameter to tune.

                  - **MinValue** *(string) --* **[REQUIRED]**

                    The minimum value for the hyperparameter. The tuning job uses floating-point
                    values between this value and ``MaxValue`` for tuning.

                  - **MaxValue** *(string) --* **[REQUIRED]**

                    The maximum value for the hyperparameter. The tuning job uses floating-point
                    values between ``MinValue`` value and this value for tuning.

                  - **ScalingType** *(string) --*

                    The scale that hyperparameter tuning uses to search the hyperparameter range.
                    For information about choosing a hyperparameter scale, see `Hyperparameter
                    Scaling
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                    . One of the following values:

                      Auto

                    Amazon SageMaker hyperparameter tuning chooses the best scale for the
                    hyperparameter.

                      Linear

                    Hyperparameter tuning searches the values in the hyperparameter range by using a
                    linear scale.

                      Logarithmic

                    Hyperparameter tuning searches the values in the hyperparameter range by using a
                    logarithmic scale.

                    Logarithmic scaling works only for ranges that have only values greater than 0.

                      ReverseLogarithmic

                    Hyperparameter tuning searches the values in the hyperparameter range by using a
                    reverse logarithmic scale.

                    Reverse logarithmic scaling works only for ranges that are entirely within the
                    range 0<=x<1.0.

              - **CategoricalParameterRanges** *(list) --*

                The array of  CategoricalParameterRange objects that specify ranges of categorical
                hyperparameters that a hyperparameter tuning job searches.

                - *(dict) --*

                  A list of categorical hyperparameters to tune.

                  - **Name** *(string) --* **[REQUIRED]**

                    The name of the categorical hyperparameter to tune.

                  - **Values** *(list) --* **[REQUIRED]**

                    A list of the categories for the hyperparameter.

                    - *(string) --*

            - **StaticHyperParameters** *(dict) --*

              Specifies the values of hyperparameters that do not change for the tuning job.

              - *(string) --*

                - *(string) --*

            - **AlgorithmSpecification** *(dict) --* **[REQUIRED]**

              The  HyperParameterAlgorithmSpecification object that specifies the resource algorithm
              to use for the training jobs that the tuning job launches.

              - **TrainingImage** *(string) --*

                The registry path of the Docker image that contains the training algorithm. For
                information about Docker registry paths for built-in algorithms, see `Algorithms
                Provided by Amazon SageMaker\\: Common Parameters
                <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                . Amazon SageMaker supports both ``registry/repository[:tag]`` and
                ``registry/repository[@digest]`` image path formats. For more information, see
                `Using Your Own Algorithms with Amazon SageMaker
                <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

              - **TrainingInputMode** *(string) --* **[REQUIRED]**

                The input mode that the algorithm supports: File or Pipe. In File input mode, Amazon
                SageMaker downloads the training data from Amazon S3 to the storage volume that is
                attached to the training instance and mounts the directory to the Docker volume for
                the training container. In Pipe input mode, Amazon SageMaker streams data directly
                from Amazon S3 to the container.

                If you specify File mode, make sure that you provision the storage volume that is
                attached to the training instance with enough capacity to accommodate the training
                data downloaded from Amazon S3, the model artifacts, and intermediate information.

                For more information about input modes, see `Algorithms
                <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

              - **AlgorithmName** *(string) --*

                The name of the resource algorithm to use for the hyperparameter tuning job. If you
                specify a value for this parameter, do not specify a value for ``TrainingImage`` .

              - **MetricDefinitions** *(list) --*

                An array of  MetricDefinition objects that specify the metrics that the algorithm
                emits.

                - *(dict) --*

                  Specifies a metric that the training algorithm writes to ``stderr`` or ``stdout``
                  . Amazon SageMakerhyperparameter tuning captures all defined metrics. You specify
                  one metric that a hyperparameter tuning job uses as its objective metric to choose
                  the best training job.

                  - **Name** *(string) --* **[REQUIRED]**

                    The name of the metric.

                  - **Regex** *(string) --* **[REQUIRED]**

                    A regular expression that searches the output of a training job and gets the
                    value of the metric. For more information about using regular expressions to
                    define metrics, see `Defining Objective Metrics
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                    .

            - **RoleArn** *(string) --* **[REQUIRED]**

              The Amazon Resource Name (ARN) of the IAM role associated with the training jobs that
              the tuning job launches.

            - **InputDataConfig** *(list) --*

              An array of  Channel objects that specify the input for the training jobs that the
              tuning job launches.

              - *(dict) --*

                A channel is a named input source that training algorithms can consume.

                - **ChannelName** *(string) --* **[REQUIRED]**

                  The name of the channel.

                - **DataSource** *(dict) --* **[REQUIRED]**

                  The location of the channel data.

                  - **S3DataSource** *(dict) --*

                    The S3 location of the data source that is associated with a channel.

                    - **S3DataType** *(string) --* **[REQUIRED]**

                      If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                      SageMaker uses all objects that match the specified key name prefix for model
                      training.

                      If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                      manifest file containing a list of object keys that you want Amazon SageMaker
                      to use for model training.

                      If you choose ``AugmentedManifestFile`` , S3Uri identifies an object that is
                      an augmented manifest file in JSON lines format. This file contains the data
                      you want to use for model training. ``AugmentedManifestFile`` can only be used
                      if the Channel's input mode is ``Pipe`` .

                    - **S3Uri** *(string) --* **[REQUIRED]**

                      Depending on the value specified for the ``S3DataType`` , identifies either a
                      key name prefix or a manifest. For example:

                      * A key name prefix might look like this: ``s3://bucketname/exampleprefix`` .

                      * A manifest might look like this: ``s3://bucketname/example.manifest``   The
                      manifest is an S3 object which is a JSON file with the following format:  The
                      preceding JSON matches the following ``s3Uris`` :   ``[ {"prefix":
                      "s3://customer_bucket/some/prefix/"},``    ``"relative/path/to/custdata-1",``
                      ``"relative/path/custdata-2",``    ``...``    ``"relative/path/custdata-N"``
                      ``]``   The preceding JSON matches the following ``s3Uris`` :
                      ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                      ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                      ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete
                      set of ``s3uris`` in this manifest is the input data for the channel for this
                      datasource. The object that each ``s3uris`` points to must be readable by the
                      IAM role that Amazon SageMaker uses to perform tasks on your behalf.

                    - **S3DataDistributionType** *(string) --*

                      If you want Amazon SageMaker to replicate the entire dataset on each ML
                      compute instance that is launched for model training, specify
                      ``FullyReplicated`` .

                      If you want Amazon SageMaker to replicate a subset of data on each ML compute
                      instance that is launched for model training, specify ``ShardedByS3Key`` . If
                      there are *n* ML compute instances launched for a training job, each instance
                      gets approximately 1/*n* of the number of S3 objects. In this case, model
                      training on each machine uses only the subset of training data.

                      Don't choose more ML compute instances for training than available S3 objects.
                      If you do, some nodes won't get any data and you will pay for nodes that
                      aren't getting any training data. This applies in both File and Pipe modes.
                      Keep this in mind when developing algorithms.

                      In distributed training, where you use multiple ML compute EC2 instances, you
                      might choose ``ShardedByS3Key`` . If the algorithm requires copying training
                      data to the ML storage volume (when ``TrainingInputMode`` is set to ``File``
                      ), this copies 1/*n* of the number of objects.

                    - **AttributeNames** *(list) --*

                      A list of one or more attribute names to use that are found in a specified
                      augmented manifest file.

                      - *(string) --*

                  - **FileSystemDataSource** *(dict) --*

                    The file system that is associated with a channel.

                    - **FileSystemId** *(string) --* **[REQUIRED]**

                      The file system id.

                    - **FileSystemAccessMode** *(string) --* **[REQUIRED]**

                      The access mode of the mount of the directory associated with the channel. A
                      directory can be mounted either in ``ro`` (read-only) or ``rw`` (read-write)
                      mode.

                    - **FileSystemType** *(string) --* **[REQUIRED]**

                      The file system type.

                    - **DirectoryPath** *(string) --* **[REQUIRED]**

                      The full path to the directory to associate with the channel.

                - **ContentType** *(string) --*

                  The MIME type of the data.

                - **CompressionType** *(string) --*

                  If training data is compressed, the compression type. The default value is
                  ``None`` . ``CompressionType`` is used only in Pipe input mode. In File mode,
                  leave this field unset or set it to None.

                - **RecordWrapperType** *(string) --*

                  Specify RecordIO as the value when input data is in raw format but the training
                  algorithm requires the RecordIO format. In this case, Amazon SageMaker wraps each
                  individual S3 object in a RecordIO record. If the input data is already in
                  RecordIO format, you don't need to set this attribute. For more information, see
                  `Create a Dataset Using RecordIO
                  <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__ .

                  In File mode, leave this field unset or set it to None.

                - **InputMode** *(string) --*

                  (Optional) The input mode to use for the data channel in a training job. If you
                  don't set a value for ``InputMode`` , Amazon SageMaker uses the value set for
                  ``TrainingInputMode`` . Use this parameter to override the ``TrainingInputMode``
                  setting in a  AlgorithmSpecification request when you have a channel that needs a
                  different input mode from the training job's general setting. To download the data
                  from Amazon Simple Storage Service (Amazon S3) to the provisioned ML storage
                  volume, and mount the directory to a Docker volume, use ``File`` input mode. To
                  stream data directly from Amazon S3 to the container, choose ``Pipe`` input mode.

                  To use a model for incremental training, choose ``File`` input model.

                - **ShuffleConfig** *(dict) --*

                  A configuration for a shuffle option for input data in a channel. If you use
                  ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key prefix
                  matches. If you use ``ManifestFile`` , the order of the S3 object references in
                  the ``ManifestFile`` is shuffled. If you use ``AugmentedManifestFile`` , the order
                  of the JSON lines in the ``AugmentedManifestFile`` is shuffled. The shuffling
                  order is determined using the ``Seed`` value.

                  For Pipe input mode, shuffling is done at the start of every epoch. With large
                  datasets this ensures that the order of the training data is different for each
                  epoch, it helps reduce bias and possible overfitting. In a multi-node training job
                  when ShuffleConfig is combined with ``S3DataDistributionType`` of
                  ``ShardedByS3Key`` , the data is shuffled across nodes so that the content sent to
                  a particular node on the first epoch might be sent to a different node on the
                  second epoch.

                  - **Seed** *(integer) --* **[REQUIRED]**

                    Determines the shuffling order in ``ShuffleConfig`` value.

            - **VpcConfig** *(dict) --*

              The  VpcConfig object that specifies the VPC that you want the training jobs that this
              hyperparameter tuning job launches to connect to. Control access to and from your
              training container by configuring the VPC. For more information, see `Protect Training
              Jobs by Using an Amazon Virtual Private Cloud
              <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

              - **SecurityGroupIds** *(list) --* **[REQUIRED]**

                The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for
                the VPC that is specified in the ``Subnets`` field.

                - *(string) --*

              - **Subnets** *(list) --* **[REQUIRED]**

                The ID of the subnets in the VPC to which you want to connect your training job or
                model.

                .. note::

                  Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                  availability zones of region us-east-1. If you want to create endpoints with P3
                  instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                  zones instead.

                - *(string) --*

            - **OutputDataConfig** *(dict) --* **[REQUIRED]**

              Specifies the path to the Amazon S3 bucket where you store model artifacts from the
              training jobs that the tuning job launches.

              - **KmsKeyId** *(string) --*

                The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                the model artifacts at rest using Amazon S3 server-side encryption. The ``KmsKeyId``
                can be any of the following formats:

                * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // Amazon Resource Name (ARN) of a KMS Key
                ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // KMS Key Alias  ``"alias/ExampleAlias"``

                * // Amazon Resource Name (ARN) of a KMS Key Alias
                ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                execution role must include permissions to call ``kms:Encrypt`` . If you don't
                provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3 for
                your role's account. Amazon SageMaker uses server-side encryption with KMS-managed
                keys for ``OutputDataConfig`` . If you use a bucket policy with an ``s3:PutObject``
                permission that only allows objects with server-side encryption, set the condition
                key of ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For more information,
                see `KMS-Managed Encryption Keys
                <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in the
                *Amazon Simple Storage Service Developer Guide.*

                The KMS key policy must grant permission to the IAM role that you specify in your
                ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                ``CreateHyperParameterTuningJob`` requests. For more information, see `Using Key
                Policies in AWS KMS
                <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the
                *AWS Key Management Service Developer Guide* .

              - **S3OutputPath** *(string) --* **[REQUIRED]**

                Identifies the S3 path where you want Amazon SageMaker to store the model artifacts.
                For example, ``s3://bucket-name/key-name-prefix`` .

            - **ResourceConfig** *(dict) --* **[REQUIRED]**

              The resources, including the compute instances and storage volumes, to use for the
              training jobs that the tuning job launches.

              Storage volumes store model artifacts and incremental states. Training algorithms
              might also use storage volumes for scratch space. If you want Amazon SageMaker to use
              the storage volume to store the training data, choose ``File`` as the
              ``TrainingInputMode`` in the algorithm specification. For distributed training
              algorithms, specify an instance count greater than 1.

              - **InstanceType** *(string) --* **[REQUIRED]**

                The ML compute instance type.

              - **InstanceCount** *(integer) --* **[REQUIRED]**

                The number of ML compute instances to use. For distributed training, provide a value
                greater than 1.

              - **VolumeSizeInGB** *(integer) --* **[REQUIRED]**

                The size of the ML storage volume that you want to provision.

                ML storage volumes store model artifacts and incremental states. Training algorithms
                might also use the ML storage volume for scratch space. If you want to store the
                training data in the ML storage volume, choose ``File`` as the ``TrainingInputMode``
                in the algorithm specification.

                You must specify sufficient ML storage for your scenario.

                .. note::

                  Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage volume
                  type.

                .. note::

                  Certain Nitro-based instances include local storage with a fixed total size,
                  dependent on the instance type. When using these instances for training, Amazon
                  SageMaker mounts the local instance storage instead of Amazon EBS gp2 storage. You
                  can't request a ``VolumeSizeInGB`` greater than the total size of the local
                  instance storage.

                  For a list of instance types that support local instance storage, including the
                  total size per instance type, see `Instance Store Volumes
                  <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                  .

              - **VolumeKmsKeyId** *(string) --*

                The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume
                attached to the ML compute instance(s) that run the training job.

                .. note::

                  Certain Nitro-based instances include local storage, dependent on the instance
                  type. Local storage volumes are encrypted using a hardware module on the instance.
                  You can't request a ``VolumeKmsKeyId`` when using an instance type with local
                  storage.

                  For a list of instance types that support local instance storage, see `Instance
                  Store Volumes
                  <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                  .

                  For more information about local instance storage encryption, see `SSD Instance
                  Store Volumes
                  <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__ .

                The ``VolumeKmsKeyId`` can be in any of the following formats:

                * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // Amazon Resource Name (ARN) of a KMS Key
                ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            - **StoppingCondition** *(dict) --* **[REQUIRED]**

              Specifies a limit to how long a model hyperparameter training job can run. It also
              specifies how long you are willing to wait for a managed spot training job to
              complete. When the job reaches the a limit, Amazon SageMaker ends the training job.
              Use this API to cap model training costs.

              - **MaxRuntimeInSeconds** *(integer) --*

                The maximum length of time, in seconds, that the training or compilation job can
                run. If job does not complete during this time, Amazon SageMaker ends the job. If
                value is not specified, default value is 1 day. The maximum value is 28 days.

              - **MaxWaitTimeInSeconds** *(integer) --*

                The maximum length of time, in seconds, how long you are willing to wait for a
                managed spot training job to complete. It is the amount of time spent waiting for
                Spot capacity plus the amount of time the training job runs. It must be equal to or
                greater than ``MaxRuntimeInSeconds`` .

            - **EnableNetworkIsolation** *(boolean) --*

              Isolates the training container. No inbound or outbound network calls can be made,
              except for calls between peers within a training cluster for distributed training. If
              network isolation is used for training jobs that are configured to use a VPC, Amazon
              SageMaker downloads and uploads customer data and model artifacts through the
              specified VPC, but the training container does not have network access.

              .. note::

                The Semantic Segmentation built-in algorithm does not support network isolation.

            - **EnableInterContainerTrafficEncryption** *(boolean) --*

              To encrypt all communications between ML compute instances in distributed training,
              choose ``True`` . Encryption provides greater security for distributed training, but
              training might take longer. How long it takes depends on the amount of communication
              between compute instances, especially if you use a deep learning algorithm in
              distributed training.

            - **EnableManagedSpotTraining** *(boolean) --*

              A Boolean indicating whether managed spot training is enabled (``True`` ) or not
              (``False`` ).

            - **CheckpointConfig** *(dict) --*

              Contains information about the output location for managed spot training checkpoint
              data.

              - **S3Uri** *(string) --* **[REQUIRED]**

                Identifies the S3 path where you want Amazon SageMaker to store checkpoints. For
                example, ``s3://bucket-name/key-name-prefix`` .

              - **LocalPath** *(string) --*

                (Optional) The local directory where checkpoints are written. The default directory
                is ``/opt/ml/checkpoints/`` .

        :type WarmStartConfig: dict
        :param WarmStartConfig:

          Specifies the configuration for starting the hyperparameter tuning job using one or more
          previous tuning jobs as a starting point. The results of previous tuning jobs are used to
          inform which combinations of hyperparameters to search over in the new tuning job.

          All training jobs launched by the new hyperparameter tuning job are evaluated by using the
          objective metric. If you specify ``IDENTICAL_DATA_AND_ALGORITHM`` as the ``WarmStartType``
          value for the warm start configuration, the training job that performs the best in the new
          tuning job is compared to the best training jobs from the parent tuning jobs. From these,
          the training job that performs the best as measured by the objective metric is returned as
          the overall best training job.

          .. note::

            All training jobs launched by parent hyperparameter tuning jobs and the new
            hyperparameter tuning jobs count against the limit of training jobs for the tuning job.

          - **ParentHyperParameterTuningJobs** *(list) --* **[REQUIRED]**

            An array of hyperparameter tuning jobs that are used as the starting point for the new
            hyperparameter tuning job. For more information about warm starting a hyperparameter
            tuning job, see `Using a Previous Hyperparameter Tuning Job as a Starting Point
            <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-warm-start.html>`__
            .

            Hyperparameter tuning jobs created before October 1, 2018 cannot be used as parent jobs
            for warm start tuning jobs.

            - *(dict) --*

              A previously completed or stopped hyperparameter tuning job to be used as a starting
              point for a new hyperparameter tuning job.

              - **HyperParameterTuningJobName** *(string) --*

                The name of the hyperparameter tuning job to be used as a starting point for a new
                hyperparameter tuning job.

          - **WarmStartType** *(string) --* **[REQUIRED]**

            Specifies one of the following:

              IDENTICAL_DATA_AND_ALGORITHM

            The new hyperparameter tuning job uses the same input data and training image as the
            parent tuning jobs. You can change the hyperparameter ranges to search and the maximum
            number of training jobs that the hyperparameter tuning job launches. You cannot use a
            new version of the training algorithm, unless the changes in the new version do not
            affect the algorithm itself. For example, changes that improve logging or adding support
            for a different data format are allowed. You can also change hyperparameters from
            tunable to static, and from static to tunable, but the total number of static plus
            tunable hyperparameters must remain the same as it is in all parent jobs. The objective
            metric for the new tuning job must be the same as for all parent jobs.

              TRANSFER_LEARNING

            The new hyperparameter tuning job can include input data, hyperparameter ranges, maximum
            number of concurrent training jobs, and maximum number of training jobs that are
            different than those of its parent hyperparameter tuning jobs. The training image can
            also be a different version from the version used in the parent hyperparameter tuning
            job. You can also change hyperparameters from tunable to static, and from static to
            tunable, but the total number of static plus tunable hyperparameters must remain the
            same as it is in all parent jobs. The objective metric for the new tuning job must be
            the same as for all parent jobs.

        :type Tags: list
        :param Tags:

          An array of key-value pairs. You can use tags to categorize your AWS resources in
          different ways, for example, by purpose, owner, or environment. For more information, see
          `AWS Tagging Strategies
          <https://aws.amazon.com/answers/account-management/aws-tagging-strategies/>`__ .

          Tags that you specify for the tuning job are also added to all training jobs that the
          tuning job launches.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'HyperParameterTuningJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **HyperParameterTuningJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the tuning job. Amazon SageMaker assigns an ARN to a
              hyperparameter tuning job when you create it.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_labeling_job(
        self,
        LabelingJobName: str,
        LabelAttributeName: str,
        InputConfig: ClientCreateLabelingJobInputConfigTypeDef,
        OutputConfig: ClientCreateLabelingJobOutputConfigTypeDef,
        RoleArn: str,
        HumanTaskConfig: ClientCreateLabelingJobHumanTaskConfigTypeDef,
        LabelCategoryConfigS3Uri: str = None,
        StoppingConditions: ClientCreateLabelingJobStoppingConditionsTypeDef = None,
        LabelingJobAlgorithmsConfig: ClientCreateLabelingJobLabelingJobAlgorithmsConfigTypeDef = None,
        Tags: List[ClientCreateLabelingJobTagsTypeDef] = None,
    ) -> ClientCreateLabelingJobResponseTypeDef:
        """
        Creates a job that uses workers to label the data objects in your input dataset. You can use
        the labeled data to train machine learning models.

        You can select your workforce from one of three providers:

        * A private workforce that you create. It can include employees, contractors, and outside
        experts. Use a private workforce when want the data to stay within your organization or when
        a specific set of skills is required.

        * One or more vendors that you select from the AWS Marketplace. Vendors provide expertise in
        specific areas.

        * The Amazon Mechanical Turk workforce. This is the largest workforce, but it should only be
        used for public data or data that has been stripped of any personally identifiable
        information.

        You can also use *automated data labeling* to reduce the number of data objects that need to
        be labeled by a human. Automated data labeling uses *active learning* to determine if a data
        object can be labeled by machine or if it needs to be sent to a human worker. For more
        information, see `Using Automated Data Labeling
        <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-automated-labeling.html>`__ .

        The data objects to be labeled are contained in an Amazon S3 bucket. You create a *manifest
        file* that describes the location of each object. For more information, see `Using Input and
        Output Data <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data.html>`__ .

        The output can be used as the manifest file for another labeling job or as training data for
        your machine learning models.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateLabelingJob>`_

        **Request Syntax**
        ::

          response = client.create_labeling_job(
              LabelingJobName='string',
              LabelAttributeName='string',
              InputConfig={
                  'DataSource': {
                      'S3DataSource': {
                          'ManifestS3Uri': 'string'
                      }
                  },
                  'DataAttributes': {
                      'ContentClassifiers': [
                          'FreeOfPersonallyIdentifiableInformation'|'FreeOfAdultContent',
                      ]
                  }
              },
              OutputConfig={
                  'S3OutputPath': 'string',
                  'KmsKeyId': 'string'
              },
              RoleArn='string',
              LabelCategoryConfigS3Uri='string',
              StoppingConditions={
                  'MaxHumanLabeledObjectCount': 123,
                  'MaxPercentageOfInputDatasetLabeled': 123
              },
              LabelingJobAlgorithmsConfig={
                  'LabelingJobAlgorithmSpecificationArn': 'string',
                  'InitialActiveLearningModelArn': 'string',
                  'LabelingJobResourceConfig': {
                      'VolumeKmsKeyId': 'string'
                  }
              },
              HumanTaskConfig={
                  'WorkteamArn': 'string',
                  'UiConfig': {
                      'UiTemplateS3Uri': 'string'
                  },
                  'PreHumanTaskLambdaArn': 'string',
                  'TaskKeywords': [
                      'string',
                  ],
                  'TaskTitle': 'string',
                  'TaskDescription': 'string',
                  'NumberOfHumanWorkersPerDataObject': 123,
                  'TaskTimeLimitInSeconds': 123,
                  'TaskAvailabilityLifetimeInSeconds': 123,
                  'MaxConcurrentTaskCount': 123,
                  'AnnotationConsolidationConfig': {
                      'AnnotationConsolidationLambdaArn': 'string'
                  },
                  'PublicWorkforceTaskPrice': {
                      'AmountInUsd': {
                          'Dollars': 123,
                          'Cents': 123,
                          'TenthFractionsOfACent': 123
                      }
                  }
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type LabelingJobName: string
        :param LabelingJobName: **[REQUIRED]**

          The name of the labeling job. This name is used to identify the job in a list of labeling
          jobs.

        :type LabelAttributeName: string
        :param LabelAttributeName: **[REQUIRED]**

          The attribute name to use for the label in the output manifest file. This is the key for
          the key/value pair formed with the label that a worker assigns to the object. The name
          can't end with "-metadata". If you are running a semantic segmentation labeling job, the
          attribute name must end with "-ref". If you are running any other kind of labeling job,
          the attribute name must not end with "-ref".

        :type InputConfig: dict
        :param InputConfig: **[REQUIRED]**

          Input data for the labeling job, such as the Amazon S3 location of the data objects and
          the location of the manifest file that describes the data objects.

          - **DataSource** *(dict) --* **[REQUIRED]**

            The location of the input data.

            - **S3DataSource** *(dict) --* **[REQUIRED]**

              The Amazon S3 location of the input data objects.

              - **ManifestS3Uri** *(string) --* **[REQUIRED]**

                The Amazon S3 location of the manifest file that describes the input data objects.

          - **DataAttributes** *(dict) --*

            Attributes of the data specified by the customer.

            - **ContentClassifiers** *(list) --*

              Declares that your content is free of personally identifiable information or adult
              content. Amazon SageMaker may restrict the Amazon Mechanical Turk workers that can
              view your task based on this information.

              - *(string) --*

        :type OutputConfig: dict
        :param OutputConfig: **[REQUIRED]**

          The location of the output data and the AWS Key Management Service key ID for the key used
          to encrypt the output data, if any.

          - **S3OutputPath** *(string) --* **[REQUIRED]**

            The Amazon S3 location to write output data.

          - **KmsKeyId** *(string) --*

            The AWS Key Management Service ID of the key used to encrypt the output data, if any.

            If you use a KMS key ID or an alias of your master key, the Amazon SageMaker execution
            role must include permissions to call ``kms:Encrypt`` . If you don't provide a KMS key
            ID, Amazon SageMaker uses the default KMS key for Amazon S3 for your role's account.
            Amazon SageMaker uses server-side encryption with KMS-managed keys for
            ``LabelingJobOutputConfig`` . If you use a bucket policy with an ``s3:PutObject``
            permission that only allows objects with server-side encryption, set the condition key
            of ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For more information, see
            `KMS-Managed Encryption Keys
            <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in the
            *Amazon Simple Storage Service Developer Guide.*

            The KMS key policy must grant permission to the IAM role that you specify in your
            ``CreateLabelingJob`` request. For more information, see `Using Key Policies in AWS KMS
            <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the *AWS
            Key Management Service Developer Guide* .

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          The Amazon Resource Number (ARN) that Amazon SageMaker assumes to perform tasks on your
          behalf during data labeling. You must grant this role the necessary permissions so that
          Amazon SageMaker can successfully complete data labeling.

        :type LabelCategoryConfigS3Uri: string
        :param LabelCategoryConfigS3Uri:

          The S3 URL of the file that defines the categories used to label the data objects.

          The file is a JSON structure in the following format:

           ``{``

           ``"document-version": "2018-11-28"``

           ``"labels": [``

           ``{``

           ``"label": "*label 1* "``

           ``},``

           ``{``

           ``"label": "*label 2* "``

           ``},``

           ``...``

           ``{``

           ``"label": "*label n* "``

           ``}``

           ``]``

           ``}``

        :type StoppingConditions: dict
        :param StoppingConditions:

          A set of conditions for stopping the labeling job. If any of the conditions are met, the
          job is automatically stopped. You can use these conditions to control the cost of data
          labeling.

          - **MaxHumanLabeledObjectCount** *(integer) --*

            The maximum number of objects that can be labeled by human workers.

          - **MaxPercentageOfInputDatasetLabeled** *(integer) --*

            The maximum number of input data objects that should be labeled.

        :type LabelingJobAlgorithmsConfig: dict
        :param LabelingJobAlgorithmsConfig:

          Configures the information required to perform automated data labeling.

          - **LabelingJobAlgorithmSpecificationArn** *(string) --* **[REQUIRED]**

            Specifies the Amazon Resource Name (ARN) of the algorithm used for auto-labeling. You
            must select one of the following ARNs:

            * *Image classification*    ``arn:aws:sagemaker:*region*
            :027400017018:labeling-job-algorithm-specification/image-classification``

            * *Text classification*    ``arn:aws:sagemaker:*region*
            :027400017018:labeling-job-algorithm-specification/text-classification``

            * *Object detection*    ``arn:aws:sagemaker:*region*
            :027400017018:labeling-job-algorithm-specification/object-detection``

            * *Semantic Segmentation*    ``arn:aws:sagemaker:*region*
            :027400017018:labeling-job-algorithm-specification/semantic-segmentation``

          - **InitialActiveLearningModelArn** *(string) --*

            At the end of an auto-label job Amazon SageMaker Ground Truth sends the Amazon Resource
            Nam (ARN) of the final model used for auto-labeling. You can use this model as the
            starting point for subsequent similar jobs by providing the ARN of the model here.

          - **LabelingJobResourceConfig** *(dict) --*

            Provides configuration information for a labeling job.

            - **VolumeKmsKeyId** *(string) --*

              The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
              data on the storage volume attached to the ML compute instance(s) that run the
              training job. The ``VolumeKmsKeyId`` can be any of the following formats:

              * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

              * // Amazon Resource Name (ARN) of a KMS Key
              ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

        :type HumanTaskConfig: dict
        :param HumanTaskConfig: **[REQUIRED]**

          Configures the labeling task and how it is presented to workers; including, but not
          limited to price, keywords, and batch size (task count).

          - **WorkteamArn** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of the work team assigned to complete the tasks.

          - **UiConfig** *(dict) --* **[REQUIRED]**

            Information about the user interface that workers use to complete the labeling task.

            - **UiTemplateS3Uri** *(string) --* **[REQUIRED]**

              The Amazon S3 bucket location of the UI template. For more information about the
              contents of a UI template, see `Creating Your Custom Labeling Task Template
              <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-custom-templates-step2.html>`__ .

          - **PreHumanTaskLambdaArn** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of a Lambda function that is run before a data object is
            sent to a human worker. Use this function to provide input to a custom labeling job.

            For the built-in bounding box, image classification, semantic segmentation, and text
            classification task types, Amazon SageMaker Ground Truth provides the following Lambda
            functions:

             **US East (Northern Virginia) (us-east-1):**

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-BoundingBox``

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:us-east-1:432418664414:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-AdjustmentBoundingBox``

            * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-AdjustmentSemanticSegmentation``

             **US East (Ohio) (us-east-2):**

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-BoundingBox``

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:us-east-2:266458841044:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-AdjustmentBoundingBox``

            * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-AdjustmentSemanticSegmentation``

             **US West (Oregon) (us-west-2):**

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-BoundingBox``

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:us-west-2:081040173940:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-AdjustmentBoundingBox``

            * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-AdjustmentSemanticSegmentation``

             **Canada (Central) (ca-central-1):**

            * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-BoundingBox``

            * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-AdjustmentBoundingBox``

            *
            ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-AdjustmentSemanticSegmentation``

             **EU (Ireland) (eu-west-1):**

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-BoundingBox``

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-AdjustmentBoundingBox``

            * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-AdjustmentSemanticSegmentation``

             **EU (London) (eu-west-2):**

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-BoundingBox``

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-AdjustmentBoundingBox``

            * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-AdjustmentSemanticSegmentation``

             **EU Frankfurt (eu-central-1):**

            * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-BoundingBox``

            * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-AdjustmentBoundingBox``

            *
            ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-AdjustmentSemanticSegmentation``

             **Asia Pacific (Tokyo) (ap-northeast-1):**

            * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-BoundingBox``

            * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-AdjustmentBoundingBox``

            *
            ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-AdjustmentSemanticSegmentation``

             **Asia Pacific (Seoul) (ap-northeast-2):**

            * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-BoundingBox``

            * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-AdjustmentBoundingBox``

            *
            ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-AdjustmentSemanticSegmentation``

             **Asia Pacific (Mumbai) (ap-south-1):**

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-BoundingBox``

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-AdjustmentBoundingBox``

            * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-AdjustmentSemanticSegmentation``

             **Asia Pacific (Singapore) (ap-southeast-1):**

            * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-BoundingBox``

            * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-AdjustmentBoundingBox``

            *
            ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-AdjustmentSemanticSegmentation``

             **Asia Pacific (Sydney) (ap-southeast-2):**

            * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-BoundingBox``

            * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-ImageMultiClass``

            * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-SemanticSegmentation``

            * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-TextMultiClass``

            * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-NamedEntityRecognition``

            * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-VerificationBoundingBox``

            *
            ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-VerificationSemanticSegmentation``

            * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-AdjustmentBoundingBox``

            *
            ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-AdjustmentSemanticSegmentation``

          - **TaskKeywords** *(list) --*

            Keywords used to describe the task so that workers on Amazon Mechanical Turk can
            discover the task.

            - *(string) --*

          - **TaskTitle** *(string) --* **[REQUIRED]**

            A title for the task for your human workers.

          - **TaskDescription** *(string) --* **[REQUIRED]**

            A description of the task for your human workers.

          - **NumberOfHumanWorkersPerDataObject** *(integer) --* **[REQUIRED]**

            The number of human workers that will label an object.

          - **TaskTimeLimitInSeconds** *(integer) --* **[REQUIRED]**

            The amount of time that a worker has to complete a task.

          - **TaskAvailabilityLifetimeInSeconds** *(integer) --*

            The length of time that a task remains available for labeling by human workers. **If you
            choose the Amazon Mechanical Turk workforce, the maximum is 12 hours (43200)** . For
            private and vendor workforces, the maximum is as listed.

          - **MaxConcurrentTaskCount** *(integer) --*

            Defines the maximum number of data objects that can be labeled by human workers at the
            same time. Also referred to as batch size. Each object may have more than one worker at
            one time.

          - **AnnotationConsolidationConfig** *(dict) --* **[REQUIRED]**

            Configures how labels are consolidated across human workers.

            - **AnnotationConsolidationLambdaArn** *(string) --* **[REQUIRED]**

              The Amazon Resource Name (ARN) of a Lambda function implements the logic for
              annotation consolidation.

              For the built-in bounding box, image classification, semantic segmentation, and text
              classification task types, Amazon SageMaker Ground Truth provides the following Lambda
              functions:

              * *Bounding box* - Finds the most similar boxes from different workers based on the
              Jaccard index of the boxes.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-BoundingBox``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-BoundingBox``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-BoundingBox``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-BoundingBox``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-BoundingBox``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-BoundingBox``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-BoundingBox``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-BoundingBox``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-BoundingBox``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-BoundingBox``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-BoundingBox``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-BoundingBox``

              * *Image classification* - Uses a variant of the Expectation Maximization approach to
              estimate the true class of an image based on annotations from individual workers.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClass``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClass``

              * *Semantic segmentation* - Treats each pixel in an image as a multi-class
              classification and treats pixel annotations from workers as "votes" for the correct
              label.  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-SemanticSegmentation``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-SemanticSegmentation``

              * *Text classification* - Uses a variant of the Expectation Maximization approach to
              estimate the true class of text based on annotations from individual workers.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClass``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClass``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClass``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClass``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClass``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClass``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClass``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClass``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClass``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClass``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClass``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClass``

              * *Named entity recognition* - Groups similar selections and calculates aggregate
              boundaries, resolving to most-assigned label.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-NamedEntityRecognition``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-NamedEntityRecognition``

              * *Bounding box verification* - Uses a variant of the Expectation Maximization
              approach to estimate the true class of verification judgement for bounding box labels
              based on annotations from individual workers.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationBoundingBox``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationBoundingBox``

              * *Semantic segmentation verification* - Uses a variant of the Expectation
              Maximization approach to estimate the true class of verification judgement for
              semantic segmentation labels based on annotations from individual workers.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationSemanticSegmentation``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationSemanticSegmentation``

              * *Bounding box adjustment* - Finds the most similar boxes from different workers
              based on the Jaccard index of the adjusted annotations.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentBoundingBox``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentBoundingBox``

              * *Semantic segmentation adjustment* - Treats each pixel in an image as a multi-class
              classification and treats pixel adjusted annotations from workers as "votes" for the
              correct label.
              ``arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentSemanticSegmentation``
              ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentSemanticSegmentation``

              For more information, see `Annotation Consolidation
              <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-annotation-consolidation.html>`__
              .

          - **PublicWorkforceTaskPrice** *(dict) --*

            The price that you pay for each task performed by an Amazon Mechanical Turk worker.

            - **AmountInUsd** *(dict) --*

              Defines the amount of money paid to an Amazon Mechanical Turk worker in United States
              dollars.

              - **Dollars** *(integer) --*

                The whole number of dollars in the amount.

              - **Cents** *(integer) --*

                The fractional portion, in cents, of the amount.

              - **TenthFractionsOfACent** *(integer) --*

                Fractions of a cent, in tenths.

        :type Tags: list
        :param Tags:

          An array of key/value pairs. For more information, see `Using Cost Allocation Tags
          <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'LabelingJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **LabelingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the labeling job. You use this ARN to identify the
              labeling job.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_model(
        self,
        ModelName: str,
        ExecutionRoleArn: str,
        PrimaryContainer: ClientCreateModelPrimaryContainerTypeDef = None,
        Containers: List[ClientCreateModelContainersTypeDef] = None,
        Tags: List[ClientCreateModelTagsTypeDef] = None,
        VpcConfig: ClientCreateModelVpcConfigTypeDef = None,
        EnableNetworkIsolation: bool = None,
    ) -> ClientCreateModelResponseTypeDef:
        """
        Creates a model in Amazon SageMaker. In the request, you name the model and describe a
        primary container. For the primary container, you specify the docker image containing
        inference code, artifacts (from prior training), and custom environment map that the
        inference code uses when you deploy the model for predictions.

        Use this API to create a model if you want to use Amazon SageMaker hosting services or run a
        batch transform job.

        To host your model, you create an endpoint configuration with the ``CreateEndpointConfig``
        API, and then create an endpoint with the ``CreateEndpoint`` API. Amazon SageMaker then
        deploys all of the containers that you defined for the model in the hosting environment.

        To run a batch transform using your model, you start a job with the ``CreateTransformJob``
        API. Amazon SageMaker uses your model and your dataset to get inferences which are then
        saved to a specified S3 location.

        In the ``CreateModel`` request, you must define a container with the ``PrimaryContainer``
        parameter.

        In the request, you also provide an IAM role that Amazon SageMaker can assume to access
        model artifacts and docker image for deployment on ML compute hosting instances or for batch
        transform jobs. In addition, you also use the IAM role to manage permissions the inference
        code needs. For example, if the inference code access any other AWS resources, you grant
        necessary permissions via this role.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateModel>`_

        **Request Syntax**
        ::

          response = client.create_model(
              ModelName='string',
              PrimaryContainer={
                  'ContainerHostname': 'string',
                  'Image': 'string',
                  'Mode': 'SingleModel'|'MultiModel',
                  'ModelDataUrl': 'string',
                  'Environment': {
                      'string': 'string'
                  },
                  'ModelPackageName': 'string'
              },
              Containers=[
                  {
                      'ContainerHostname': 'string',
                      'Image': 'string',
                      'Mode': 'SingleModel'|'MultiModel',
                      'ModelDataUrl': 'string',
                      'Environment': {
                          'string': 'string'
                      },
                      'ModelPackageName': 'string'
                  },
              ],
              ExecutionRoleArn='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              VpcConfig={
                  'SecurityGroupIds': [
                      'string',
                  ],
                  'Subnets': [
                      'string',
                  ]
              },
              EnableNetworkIsolation=True|False
          )
        :type ModelName: string
        :param ModelName: **[REQUIRED]**

          The name of the new model.

        :type PrimaryContainer: dict
        :param PrimaryContainer:

          The location of the primary docker image containing inference code, associated artifacts,
          and custom environment map that the inference code uses when the model is deployed for
          predictions.

          - **ContainerHostname** *(string) --*

            This parameter is ignored for models that contain only a ``PrimaryContainer`` .

            When a ``ContainerDefinition`` is part of an inference pipeline, the value of the
            parameter uniquely identifies the container for the purposes of logging and metrics. For
            information, see `Use Logs and Metrics to Monitor an Inference Pipeline
            <https://docs.aws.amazon.com/sagemaker/latest/dg/inference-pipeline-logs-metrics.html>`__
            . If you don't specify a value for this parameter for a ``ContainerDefinition`` that is
            part of an inference pipeline, a unique name is automatically assigned based on the
            position of the ``ContainerDefinition`` in the pipeline. If you specify a value for the
            ``ContainerHostName`` for any ``ContainerDefinition`` that is part of an inference
            pipeline, you must specify a value for the ``ContainerHostName`` parameter of every
            ``ContainerDefinition`` in that pipeline.

          - **Image** *(string) --*

            The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored. If
            you are using your own custom algorithm instead of an algorithm provided by Amazon
            SageMaker, the inference code must meet Amazon SageMaker requirements. Amazon SageMaker
            supports both ``registry/repository[:tag]`` and ``registry/repository[@digest]`` image
            path formats. For more information, see `Using Your Own Algorithms with Amazon SageMaker
            <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__

          - **Mode** *(string) --*

            Whether the container hosts a single model or multiple models.

          - **ModelDataUrl** *(string) --*

            The S3 path where the model artifacts, which result from model training, are stored.
            This path must point to a single gzip compressed tar archive (.tar.gz suffix). The S3
            path is required for Amazon SageMaker built-in algorithms, but not if you use your own
            algorithms. For more information on built-in algorithms, see `Common Parameters
            <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
            .

            If you provide a value for this parameter, Amazon SageMaker uses AWS Security Token
            Service to download model artifacts from the S3 path you provide. AWS STS is activated
            in your IAM user account by default. If you previously deactivated AWS STS for a region,
            you need to reactivate AWS STS for that region. For more information, see `Activating
            and Deactivating AWS STS in an AWS Region
            <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html>`__
            in the *AWS Identity and Access Management User Guide* .

            .. warning::

              If you use a built-in algorithm to create a model, Amazon SageMaker requires that you
              provide a S3 path to the model artifacts in ``ModelDataUrl`` .

          - **Environment** *(dict) --*

            The environment variables to set in the Docker container. Each key and value in the
            ``Environment`` string to string map can have length of up to 1024. We support up to 16
            entries in the map.

            - *(string) --*

              - *(string) --*

          - **ModelPackageName** *(string) --*

            The name or Amazon Resource Name (ARN) of the model package to use to create the model.

        :type Containers: list
        :param Containers:

          Specifies the containers in the inference pipeline.

          - *(dict) --*

            Describes the container, as part of model definition.

            - **ContainerHostname** *(string) --*

              This parameter is ignored for models that contain only a ``PrimaryContainer`` .

              When a ``ContainerDefinition`` is part of an inference pipeline, the value of the
              parameter uniquely identifies the container for the purposes of logging and metrics.
              For information, see `Use Logs and Metrics to Monitor an Inference Pipeline
              <https://docs.aws.amazon.com/sagemaker/latest/dg/inference-pipeline-logs-metrics.html>`__
              . If you don't specify a value for this parameter for a ``ContainerDefinition`` that
              is part of an inference pipeline, a unique name is automatically assigned based on the
              position of the ``ContainerDefinition`` in the pipeline. If you specify a value for
              the ``ContainerHostName`` for any ``ContainerDefinition`` that is part of an inference
              pipeline, you must specify a value for the ``ContainerHostName`` parameter of every
              ``ContainerDefinition`` in that pipeline.

            - **Image** *(string) --*

              The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored. If
              you are using your own custom algorithm instead of an algorithm provided by Amazon
              SageMaker, the inference code must meet Amazon SageMaker requirements. Amazon
              SageMaker supports both ``registry/repository[:tag]`` and
              ``registry/repository[@digest]`` image path formats. For more information, see `Using
              Your Own Algorithms with Amazon SageMaker
              <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__

            - **Mode** *(string) --*

              Whether the container hosts a single model or multiple models.

            - **ModelDataUrl** *(string) --*

              The S3 path where the model artifacts, which result from model training, are stored.
              This path must point to a single gzip compressed tar archive (.tar.gz suffix). The S3
              path is required for Amazon SageMaker built-in algorithms, but not if you use your own
              algorithms. For more information on built-in algorithms, see `Common Parameters
              <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
              .

              If you provide a value for this parameter, Amazon SageMaker uses AWS Security Token
              Service to download model artifacts from the S3 path you provide. AWS STS is activated
              in your IAM user account by default. If you previously deactivated AWS STS for a
              region, you need to reactivate AWS STS for that region. For more information, see
              `Activating and Deactivating AWS STS in an AWS Region
              <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html>`__
              in the *AWS Identity and Access Management User Guide* .

              .. warning::

                If you use a built-in algorithm to create a model, Amazon SageMaker requires that
                you provide a S3 path to the model artifacts in ``ModelDataUrl`` .

            - **Environment** *(dict) --*

              The environment variables to set in the Docker container. Each key and value in the
              ``Environment`` string to string map can have length of up to 1024. We support up to
              16 entries in the map.

              - *(string) --*

                - *(string) --*

            - **ModelPackageName** *(string) --*

              The name or Amazon Resource Name (ARN) of the model package to use to create the
              model.

        :type ExecutionRoleArn: string
        :param ExecutionRoleArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker can assume to access
          model artifacts and docker image for deployment on ML compute instances or for batch
          transform jobs. Deploying on ML compute instances is part of model hosting. For more
          information, see `Amazon SageMaker Roles
          <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-roles.html>`__ .

          .. note::

            To be able to pass this role to Amazon SageMaker, the caller of this API must have the
            ``iam:PassRole`` permission.

        :type Tags: list
        :param Tags:

          An array of key-value pairs. For more information, see `Using Cost Allocation Tags
          <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type VpcConfig: dict
        :param VpcConfig:

          A `VpcConfig <https://docs.aws.amazon.com/sagemaker/latest/dg/API_VpcConfig.html>`__
          object that specifies the VPC that you want your model to connect to. Control access to
          and from your model container by configuring the VPC. ``VpcConfig`` is used in hosting
          services and in batch transform. For more information, see `Protect Endpoints by Using an
          Amazon Virtual Private Cloud
          <https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html>`__ and `Protect Data in
          Batch Transform Jobs by Using an Amazon Virtual Private Cloud
          <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-vpc.html>`__ .

          - **SecurityGroupIds** *(list) --* **[REQUIRED]**

            The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the
            VPC that is specified in the ``Subnets`` field.

            - *(string) --*

          - **Subnets** *(list) --* **[REQUIRED]**

            The ID of the subnets in the VPC to which you want to connect your training job or
            model.

            .. note::

              Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
              availability zones of region us-east-1. If you want to create endpoints with P3
              instances in VPC mode in region us-east-1, create subnets in a/b/f availability zones
              instead.

            - *(string) --*

        :type EnableNetworkIsolation: boolean
        :param EnableNetworkIsolation:

          Isolates the model container. No inbound or outbound network calls can be made to or from
          the model container.

          .. note::

            The Semantic Segmentation built-in algorithm does not support network isolation.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ModelArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ModelArn** *(string) --*

              The ARN of the model created in Amazon SageMaker.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_model_package(
        self,
        ModelPackageName: str,
        ModelPackageDescription: str = None,
        InferenceSpecification: ClientCreateModelPackageInferenceSpecificationTypeDef = None,
        ValidationSpecification: ClientCreateModelPackageValidationSpecificationTypeDef = None,
        SourceAlgorithmSpecification: ClientCreateModelPackageSourceAlgorithmSpecificationTypeDef = None,
        CertifyForMarketplace: bool = None,
    ) -> ClientCreateModelPackageResponseTypeDef:
        """
        Creates a model package that you can use to create Amazon SageMaker models or list on AWS
        Marketplace. Buyers can subscribe to model packages listed on AWS Marketplace to create
        models in Amazon SageMaker.

        To create a model package by specifying a Docker container that contains your inference code
        and the Amazon S3 location of your model artifacts, provide values for
        ``InferenceSpecification`` . To create a model from an algorithm resource that you created
        or subscribed to in AWS Marketplace, provide a value for ``SourceAlgorithmSpecification`` .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateModelPackage>`_

        **Request Syntax**
        ::

          response = client.create_model_package(
              ModelPackageName='string',
              ModelPackageDescription='string',
              InferenceSpecification={
                  'Containers': [
                      {
                          'ContainerHostname': 'string',
                          'Image': 'string',
                          'ImageDigest': 'string',
                          'ModelDataUrl': 'string',
                          'ProductId': 'string'
                      },
                  ],
                  'SupportedTransformInstanceTypes': [
                      'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                      |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                      |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                      |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                      |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge'
                      |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.12xlarge'
                      |'ml.m5.24xlarge',
                  ],
                  'SupportedRealtimeInferenceInstanceTypes': [
                      'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'|'ml.m4.xlarge'
                      |'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'|'ml.m4.16xlarge'
                      |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.12xlarge'
                      |'ml.m5.24xlarge'|'ml.m5d.large'|'ml.m5d.xlarge'|'ml.m5d.2xlarge'
                      |'ml.m5d.4xlarge'|'ml.m5d.12xlarge'|'ml.m5d.24xlarge'|'ml.c4.large'
                      |'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'
                      |'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                      |'ml.p3.16xlarge'|'ml.c5.large'|'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                      |'ml.c5.9xlarge'|'ml.c5.18xlarge'|'ml.c5d.large'|'ml.c5d.xlarge'
                      |'ml.c5d.2xlarge'|'ml.c5d.4xlarge'|'ml.c5d.9xlarge'|'ml.c5d.18xlarge'
                      |'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'|'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                      |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'|'ml.r5.large'|'ml.r5.xlarge'
                      |'ml.r5.2xlarge'|'ml.r5.4xlarge'|'ml.r5.12xlarge'|'ml.r5.24xlarge'
                      |'ml.r5d.large'|'ml.r5d.xlarge'|'ml.r5d.2xlarge'|'ml.r5d.4xlarge'
                      |'ml.r5d.12xlarge'|'ml.r5d.24xlarge'|'ml.inf1.xlarge'|'ml.inf1.2xlarge'
                      |'ml.inf1.6xlarge'|'ml.inf1.24xlarge',
                  ],
                  'SupportedContentTypes': [
                      'string',
                  ],
                  'SupportedResponseMIMETypes': [
                      'string',
                  ]
              },
              ValidationSpecification={
                  'ValidationRole': 'string',
                  'ValidationProfiles': [
                      {
                          'ProfileName': 'string',
                          'TransformJobDefinition': {
                              'MaxConcurrentTransforms': 123,
                              'MaxPayloadInMB': 123,
                              'BatchStrategy': 'MultiRecord'|'SingleRecord',
                              'Environment': {
                                  'string': 'string'
                              },
                              'TransformInput': {
                                  'DataSource': {
                                      'S3DataSource': {
                                          'S3DataType':
                                          'ManifestFile'
                                          |'S3Prefix'
                                          |'AugmentedManifestFile',
                                          'S3Uri': 'string'
                                      }
                                  },
                                  'ContentType': 'string',
                                  'CompressionType': 'None'|'Gzip',
                                  'SplitType': 'None'|'Line'|'RecordIO'|'TFRecord'
                              },
                              'TransformOutput': {
                                  'S3OutputPath': 'string',
                                  'Accept': 'string',
                                  'AssembleWith': 'None'|'Line',
                                  'KmsKeyId': 'string'
                              },
                              'TransformResources': {
                                  'InstanceType':
                                  'ml.m4.xlarge'|'ml.m4.2xlarge'
                                  |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                  |'ml.m4.16xlarge'|'ml.c4.xlarge'
                                  |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                  |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                  |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                  |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                  |'ml.p3.16xlarge'|'ml.c5.xlarge'
                                  |'ml.c5.2xlarge'|'ml.c5.4xlarge'
                                  |'ml.c5.9xlarge'|'ml.c5.18xlarge'
                                  |'ml.m5.large'|'ml.m5.xlarge'
                                  |'ml.m5.2xlarge'|'ml.m5.4xlarge'
                                  |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                                  'InstanceCount': 123,
                                  'VolumeKmsKeyId': 'string'
                              }
                          }
                      },
                  ]
              },
              SourceAlgorithmSpecification={
                  'SourceAlgorithms': [
                      {
                          'ModelDataUrl': 'string',
                          'AlgorithmName': 'string'
                      },
                  ]
              },
              CertifyForMarketplace=True|False
          )
        :type ModelPackageName: string
        :param ModelPackageName: **[REQUIRED]**

          The name of the model package. The name must have 1 to 63 characters. Valid characters are
          a-z, A-Z, 0-9, and - (hyphen).

        :type ModelPackageDescription: string
        :param ModelPackageDescription:

          A description of the model package.

        :type InferenceSpecification: dict
        :param InferenceSpecification:

          Specifies details about inference jobs that can be run with models based on this model
          package, including the following:

          * The Amazon ECR paths of containers that contain the inference code and model artifacts.

          * The instance types that the model package supports for transform jobs and real-time
          endpoints used for inference.

          * The input and output content formats that the model package supports for inference.

          - **Containers** *(list) --* **[REQUIRED]**

            The Amazon ECR registry path of the Docker image that contains the inference code.

            - *(dict) --*

              Describes the Docker container for the model package.

              - **ContainerHostname** *(string) --*

                The DNS host name for the Docker container.

              - **Image** *(string) --* **[REQUIRED]**

                The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.

                If you are using your own custom algorithm instead of an algorithm provided by
                Amazon SageMaker, the inference code must meet Amazon SageMaker requirements. Amazon
                SageMaker supports both ``registry/repository[:tag]`` and
                ``registry/repository[@digest]`` image path formats. For more information, see
                `Using Your Own Algorithms with Amazon SageMaker
                <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

              - **ImageDigest** *(string) --*

                An MD5 hash of the training algorithm that identifies the Docker image used for
                training.

              - **ModelDataUrl** *(string) --*

                The Amazon S3 path where the model artifacts, which result from model training, are
                stored. This path must point to a single ``gzip`` compressed tar archive
                (``.tar.gz`` suffix).

              - **ProductId** *(string) --*

                The AWS Marketplace product ID of the model package.

          - **SupportedTransformInstanceTypes** *(list) --* **[REQUIRED]**

            A list of the instance types on which a transformation job can be run or on which an
            endpoint can be deployed.

            - *(string) --*

          - **SupportedRealtimeInferenceInstanceTypes** *(list) --* **[REQUIRED]**

            A list of the instance types that are used to generate inferences in real-time.

            - *(string) --*

          - **SupportedContentTypes** *(list) --* **[REQUIRED]**

            The supported MIME types for the input data.

            - *(string) --*

          - **SupportedResponseMIMETypes** *(list) --* **[REQUIRED]**

            The supported MIME types for the output data.

            - *(string) --*

        :type ValidationSpecification: dict
        :param ValidationSpecification:

          Specifies configurations for one or more transform jobs that Amazon SageMaker runs to test
          the model package.

          - **ValidationRole** *(string) --* **[REQUIRED]**

            The IAM roles to be used for the validation of the model package.

          - **ValidationProfiles** *(list) --* **[REQUIRED]**

            An array of ``ModelPackageValidationProfile`` objects, each of which specifies a batch
            transform job that Amazon SageMaker runs to validate your model package.

            - *(dict) --*

              Contains data, such as the inputs and targeted instance types that are used in the
              process of validating the model package.

              The data provided in the validation profile is made available to your buyers on AWS
              Marketplace.

              - **ProfileName** *(string) --* **[REQUIRED]**

                The name of the profile for the model package.

              - **TransformJobDefinition** *(dict) --* **[REQUIRED]**

                The ``TransformJobDefinition`` object that describes the transform job used for the
                validation of the model package.

                - **MaxConcurrentTransforms** *(integer) --*

                  The maximum number of parallel requests that can be sent to each instance in a
                  transform job. The default value is 1.

                - **MaxPayloadInMB** *(integer) --*

                  The maximum payload size allowed, in MB. A payload is the data portion of a record
                  (without metadata).

                - **BatchStrategy** *(string) --*

                  A string that determines the number of records included in a single mini-batch.

                   ``SingleRecord`` means only one record is used per mini-batch. ``MultiRecord``
                   means a mini-batch is set to contain as many records that can fit within the
                   ``MaxPayloadInMB`` limit.

                - **Environment** *(dict) --*

                  The environment variables to set in the Docker container. We support up to 16 key
                  and values entries in the map.

                  - *(string) --*

                    - *(string) --*

                - **TransformInput** *(dict) --* **[REQUIRED]**

                  A description of the input source and the way the transform job consumes it.

                  - **DataSource** *(dict) --* **[REQUIRED]**

                    Describes the location of the channel data, which is, the S3 location of the
                    input data that the model can consume.

                    - **S3DataSource** *(dict) --* **[REQUIRED]**

                      The S3 location of the data source that is associated with a channel.

                      - **S3DataType** *(string) --* **[REQUIRED]**

                        If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                        SageMaker uses all objects with the specified key name prefix for batch
                        transform.

                        If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                        manifest file containing a list of object keys that you want Amazon
                        SageMaker to use for batch transform.

                        The following values are compatible: ``ManifestFile`` , ``S3Prefix``

                        The following value is not compatible: ``AugmentedManifestFile``

                      - **S3Uri** *(string) --* **[REQUIRED]**

                        Depending on the value specified for the ``S3DataType`` , identifies either
                        a key name prefix or a manifest. For example:

                        * A key name prefix might look like this: ``s3://bucketname/exampleprefix``
                        .

                        * A manifest might look like this: ``s3://bucketname/example.manifest``
                        The manifest is an S3 object which is a JSON file with the following format:
                        ``[ {"prefix": "s3://customer_bucket/some/prefix/"},``
                        ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                        ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                        matches the following ``s3Uris`` :
                        ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                        ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                        ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete
                        set of ``S3Uris`` in this manifest constitutes the input data for the
                        channel for this datasource. The object that each ``S3Uris`` points to must
                        be readable by the IAM role that Amazon SageMaker uses to perform tasks on
                        your behalf.

                  - **ContentType** *(string) --*

                    The multipurpose internet mail extension (MIME) type of the data. Amazon
                    SageMaker uses the MIME type with each http call to transfer data to the
                    transform job.

                  - **CompressionType** *(string) --*

                    If your transform data is compressed, specify the compression type. Amazon
                    SageMaker automatically decompresses the data for the transform job accordingly.
                    The default value is ``None`` .

                  - **SplitType** *(string) --*

                    The method to use to split the transform job's data files into smaller batches.
                    Splitting is necessary when the total size of each object is too large to fit in
                    a single request. You can also use data splitting to improve performance by
                    processing multiple concurrent mini-batches. The default value for ``SplitType``
                    is ``None`` , which indicates that input data files are not split, and request
                    payloads contain the entire contents of an input object. Set the value of this
                    parameter to ``Line`` to split records on a newline character boundary.
                    ``SplitType`` also supports a number of record-oriented binary data formats.

                    When splitting is enabled, the size of a mini-batch depends on the values of the
                    ``BatchStrategy`` and ``MaxPayloadInMB`` parameters. When the value of
                    ``BatchStrategy`` is ``MultiRecord`` , Amazon SageMaker sends the maximum number
                    of records in each request, up to the ``MaxPayloadInMB`` limit. If the value of
                    ``BatchStrategy`` is ``SingleRecord`` , Amazon SageMaker sends individual
                    records in each request.

                    .. note::

                      Some data formats represent a record as a binary payload wrapped with extra
                      padding bytes. When splitting is applied to a binary data format, padding is
                      removed if the value of ``BatchStrategy`` is set to ``SingleRecord`` . Padding
                      is not removed if the value of ``BatchStrategy`` is set to ``MultiRecord`` .

                      For more information about ``RecordIO`` , see `Create a Dataset Using RecordIO
                      <https://mxnet.apache.org/api/faq/recordio>`__ in the MXNet documentation. For
                      more information about ``TFRecord`` , see `Consuming TFRecord data
                      <https://www.tensorflow.org/guide/datasets#consuming_tfrecord_data>`__ in the
                      TensorFlow documentation.

                - **TransformOutput** *(dict) --* **[REQUIRED]**

                  Identifies the Amazon S3 location where you want Amazon SageMaker to save the
                  results from the transform job.

                  - **S3OutputPath** *(string) --* **[REQUIRED]**

                    The Amazon S3 path where you want Amazon SageMaker to store the results of the
                    transform job. For example, ``s3://bucket-name/key-name-prefix`` .

                    For every S3 object used as input for the transform job, batch transform stores
                    the transformed data with an .``out`` suffix in a corresponding subfolder in the
                    location in the output prefix. For example, for the input data stored at
                    ``s3://bucket-name/input-name-prefix/dataset01/data.csv`` , batch transform
                    stores the transformed data at
                    ``s3://bucket-name/output-name-prefix/input-name-prefix/data.csv.out`` . Batch
                    transform doesn't upload partially processed objects. For an input S3 object
                    that contains multiple records, it creates an .``out`` file only if the
                    transform job succeeds on the entire file. When the input contains multiple S3
                    objects, the batch transform job processes the listed S3 objects and uploads
                    only the output for successfully processed objects. If any object fails in the
                    transform job batch transform marks the job as failed to prompt investigation.

                  - **Accept** *(string) --*

                    The MIME type used to specify the output data. Amazon SageMaker uses the MIME
                    type with each http call to transfer data from the transform job.

                  - **AssembleWith** *(string) --*

                    Defines how to assemble the results of the transform job as a single S3 object.
                    Choose a format that is most convenient to you. To concatenate the results in
                    binary format, specify ``None`` . To add a newline character at the end of every
                    transformed record, specify ``Line`` .

                  - **KmsKeyId** *(string) --*

                    The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                    encrypt the model artifacts at rest using Amazon S3 server-side encryption. The
                    ``KmsKeyId`` can be any of the following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // KMS Key Alias  ``"alias/ExampleAlias"``

                    * // Amazon Resource Name (ARN) of a KMS Key Alias
                    ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                    If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS key for
                    Amazon S3 for your role's account. For more information, see `KMS-Managed
                    Encryption Keys
                    <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in
                    the *Amazon Simple Storage Service Developer Guide.*

                    The KMS key policy must grant permission to the IAM role that you specify in
                    your  CreateModel request. For more information, see `Using Key Policies in AWS
                    KMS <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__
                    in the *AWS Key Management Service Developer Guide* .

                - **TransformResources** *(dict) --* **[REQUIRED]**

                  Identifies the ML compute instances for the transform job.

                  - **InstanceType** *(string) --* **[REQUIRED]**

                    The ML compute instance type for the transform job. If you are using built-in
                    algorithms to transform moderately sized datasets, we recommend using
                    ml.m4.xlarge or ``ml.m5.large`` instance types.

                  - **InstanceCount** *(integer) --* **[REQUIRED]**

                    The number of ML compute instances to use in the transform job. For distributed
                    transform jobs, specify a value greater than 1. The default value is ``1`` .

                  - **VolumeKmsKeyId** *(string) --*

                    The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                    encrypt model data on the storage volume attached to the ML compute instance(s)
                    that run the batch transform job. The ``VolumeKmsKeyId`` can be any of the
                    following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

        :type SourceAlgorithmSpecification: dict
        :param SourceAlgorithmSpecification:

          Details about the algorithm that was used to create the model package.

          - **SourceAlgorithms** *(list) --* **[REQUIRED]**

            A list of the algorithms that were used to create a model package.

            - *(dict) --*

              Specifies an algorithm that was used to create the model package. The algorithm must
              be either an algorithm resource in your Amazon SageMaker account or an algorithm in
              AWS Marketplace that you are subscribed to.

              - **ModelDataUrl** *(string) --*

                The Amazon S3 path where the model artifacts, which result from model training, are
                stored. This path must point to a single ``gzip`` compressed tar archive
                (``.tar.gz`` suffix).

              - **AlgorithmName** *(string) --* **[REQUIRED]**

                The name of an algorithm that was used to create the model package. The algorithm
                must be either an algorithm resource in your Amazon SageMaker account or an
                algorithm in AWS Marketplace that you are subscribed to.

        :type CertifyForMarketplace: boolean
        :param CertifyForMarketplace:

          Whether to certify the model package for listing on AWS Marketplace.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ModelPackageArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ModelPackageArn** *(string) --*

              The Amazon Resource Name (ARN) of the new model package.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_monitoring_schedule(
        self,
        MonitoringScheduleName: str,
        MonitoringScheduleConfig: ClientCreateMonitoringScheduleMonitoringScheduleConfigTypeDef,
        Tags: List[ClientCreateMonitoringScheduleTagsTypeDef] = None,
    ) -> ClientCreateMonitoringScheduleResponseTypeDef:
        """
        Creates a schedule that regularly starts Amazon SageMaker Processing Jobs to monitor the
        data captured for an Amazon SageMaker Endoint.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateMonitoringSchedule>`_

        **Request Syntax**
        ::

          response = client.create_monitoring_schedule(
              MonitoringScheduleName='string',
              MonitoringScheduleConfig={
                  'ScheduleConfig': {
                      'ScheduleExpression': 'string'
                  },
                  'MonitoringJobDefinition': {
                      'BaselineConfig': {
                          'ConstraintsResource': {
                              'S3Uri': 'string'
                          },
                          'StatisticsResource': {
                              'S3Uri': 'string'
                          }
                      },
                      'MonitoringInputs': [
                          {
                              'EndpointInput': {
                                  'EndpointName': 'string',
                                  'LocalPath': 'string',
                                  'S3InputMode': 'Pipe'|'File',
                                  'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key'
                              }
                          },
                      ],
                      'MonitoringOutputConfig': {
                          'MonitoringOutputs': [
                              {
                                  'S3Output': {
                                      'S3Uri': 'string',
                                      'LocalPath': 'string',
                                      'S3UploadMode': 'Continuous'|'EndOfJob'
                                  }
                              },
                          ],
                          'KmsKeyId': 'string'
                      },
                      'MonitoringResources': {
                          'ClusterConfig': {
                              'InstanceCount': 123,
                              'InstanceType':
                              'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'
                              |'ml.t3.2xlarge'|'ml.m4.xlarge'|'ml.m4.2xlarge'
                              |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                              |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'
                              |'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'
                              |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                              |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                              |'ml.p3.16xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                              |'ml.c5.4xlarge'|'ml.c5.9xlarge'
                              |'ml.c5.18xlarge'|'ml.m5.large'|'ml.m5.xlarge'
                              |'ml.m5.2xlarge'|'ml.m5.4xlarge'
                              |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.r5.large'
                              |'ml.r5.xlarge'|'ml.r5.2xlarge'|'ml.r5.4xlarge'
                              |'ml.r5.8xlarge'|'ml.r5.12xlarge'
                              |'ml.r5.16xlarge'|'ml.r5.24xlarge',
                              'VolumeSizeInGB': 123,
                              'VolumeKmsKeyId': 'string'
                          }
                      },
                      'MonitoringAppSpecification': {
                          'ImageUri': 'string',
                          'ContainerEntrypoint': [
                              'string',
                          ],
                          'ContainerArguments': [
                              'string',
                          ],
                          'RecordPreprocessorSourceUri': 'string',
                          'PostAnalyticsProcessorSourceUri': 'string'
                      },
                      'StoppingCondition': {
                          'MaxRuntimeInSeconds': 123
                      },
                      'Environment': {
                          'string': 'string'
                      },
                      'NetworkConfig': {
                          'EnableNetworkIsolation': True|False,
                          'VpcConfig': {
                              'SecurityGroupIds': [
                                  'string',
                              ],
                              'Subnets': [
                                  'string',
                              ]
                          }
                      },
                      'RoleArn': 'string'
                  }
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type MonitoringScheduleName: string
        :param MonitoringScheduleName: **[REQUIRED]**

          The name of the monitoring schedule. The name must be unique within an AWS Region within
          an AWS account.

        :type MonitoringScheduleConfig: dict
        :param MonitoringScheduleConfig: **[REQUIRED]**

          The configuration object that specifies the monitoring schedule and defines the monitoring
          job.

          - **ScheduleConfig** *(dict) --*

            Configures the monitoring schedule.

            - **ScheduleExpression** *(string) --* **[REQUIRED]**

              A cron expression that describes details about the monitoring schedule.

              Currently the only supported cron expressions are:

              * If you want to set the job to start every hour, please use the following:  ``Hourly:
              cron(0 * ? * * *)``

              * If you want to start the job daily:  ``cron(0 [00-23] ? * * *)``

              For example, the following are valid cron expressions:

              * Daily at noon UTC: ``cron(0 12 ? * * *)``

              * Daily at midnight UTC: ``cron(0 0 ? * * *)``

              To support running every 6, 12 hours, the following are also supported:

               ``cron(0 [00-23]/[01-24] ? * * *)``

              For example, the following are valid cron expressions:

              * Every 12 hours, starting at 5pm UTC: ``cron(0 17/12 ? * * *)``

              * Every two hours starting at midnight: ``cron(0 0/2 ? * * *)``

              .. note::

                * Even though the cron expression is set to start at 5PM UTC, note that there could
                be a delay of 0-20 minutes from the actual requested time to run the execution.

                * We recommend that if you would like a daily schedule, you do not provide this
                parameter. Amazon SageMaker will pick a time for running every day.

          - **MonitoringJobDefinition** *(dict) --* **[REQUIRED]**

            Defines the monitoring job.

            - **BaselineConfig** *(dict) --*

              Baseline configuration used to validate that the data conforms to the specified
              constraints and statistics

              - **ConstraintsResource** *(dict) --*

                The baseline constraint file in Amazon S3 that the current monitoring job should
                validated against.

                - **S3Uri** *(string) --*

                  The Amazon S3 URI for the constraints resource.

              - **StatisticsResource** *(dict) --*

                The baseline statistics file in Amazon S3 that the current monitoring job should be
                validated against.

                - **S3Uri** *(string) --*

                  The Amazon S3 URI for the statistics resource.

            - **MonitoringInputs** *(list) --* **[REQUIRED]**

              The array of inputs for the monitoring job. Currently we support monitoring an Amazon
              SageMaker Endpoint.

              - *(dict) --*

                The inputs for a monitoring job.

                - **EndpointInput** *(dict) --* **[REQUIRED]**

                  The endpoint for a monitoring job.

                  - **EndpointName** *(string) --* **[REQUIRED]**

                    An endpoint in customer's account which has enabled ``DataCaptureConfig``
                    enabled.

                  - **LocalPath** *(string) --* **[REQUIRED]**

                    Path to the filesystem where the endpoint data is available to the container.

                  - **S3InputMode** *(string) --*

                    Whether the ``Pipe`` or ``File`` is used as the input mode for transfering data
                    for the monitoring job. ``Pipe`` mode is recommended for large datasets.
                    ``File`` mode is useful for small files that fit in memory. Defaults to ``File``
                    .

                  - **S3DataDistributionType** *(string) --*

                    Whether input data distributed in Amazon S3 is fully replicated or sharded by an
                    S3 key. Defauts to ``FullyReplicated``

            - **MonitoringOutputConfig** *(dict) --* **[REQUIRED]**

              The array of outputs from the monitoring job to be uploaded to Amazon Simple Storage
              Service (Amazon S3).

              - **MonitoringOutputs** *(list) --* **[REQUIRED]**

                Monitoring outputs for monitoring jobs. This is where the output of the periodic
                monitoring jobs is uploaded.

                - *(dict) --*

                  The output object for a monitoring job.

                  - **S3Output** *(dict) --* **[REQUIRED]**

                    The Amazon S3 storage location where the results of a monitoring job are saved.

                    - **S3Uri** *(string) --* **[REQUIRED]**

                      A URI that identifies the Amazon S3 storage location where Amazon SageMaker
                      saves the results of a monitoring job.

                    - **LocalPath** *(string) --* **[REQUIRED]**

                      The local path to the Amazon S3 storage location where Amazon SageMaker saves
                      the results of a monitoring job. LocalPath is an absolute path for the output
                      data.

                    - **S3UploadMode** *(string) --*

                      Whether to upload the results of the monitoring job continuously or after the
                      job completes.

              - **KmsKeyId** *(string) --*

                The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                the model artifacts at rest using Amazon S3 server-side encryption.

            - **MonitoringResources** *(dict) --* **[REQUIRED]**

              Identifies the resources, ML compute instances, and ML storage volumes to deploy for a
              monitoring job. In distributed processing, you specify more than one instance.

              - **ClusterConfig** *(dict) --* **[REQUIRED]**

                The configuration for the cluster resources used to run the processing job.

                - **InstanceCount** *(integer) --* **[REQUIRED]**

                  The number of ML compute instances to use in the model monitoring job. For
                  distributed processing jobs, specify a value greater than 1. The default value is
                  1.

                - **InstanceType** *(string) --* **[REQUIRED]**

                  The ML compute instance type for the processing job.

                - **VolumeSizeInGB** *(integer) --* **[REQUIRED]**

                  The size of the ML storage volume, in gigabytes, that you want to provision. You
                  must specify sufficient ML storage for your scenario.

                - **VolumeKmsKeyId** *(string) --*

                  The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                  data on the storage volume attached to the ML compute instance(s) that run the
                  model monitoring job.

            - **MonitoringAppSpecification** *(dict) --* **[REQUIRED]**

              Configures the monitoring job to run a specified Docker container image.

              - **ImageUri** *(string) --* **[REQUIRED]**

                The container image to be run by the monitoring job.

              - **ContainerEntrypoint** *(list) --*

                Specifies the entrypoint for a container used to run the monitoring job.

                - *(string) --*

              - **ContainerArguments** *(list) --*

                An array of arguments for the container used to run the monitoring job.

                - *(string) --*

              - **RecordPreprocessorSourceUri** *(string) --*

                An Amazon S3 URI to a script that is called per row prior to running analysis. It
                can base64 decode the payload and convert it into a flatted json so that the
                built-in container can use the converted data. Applicable only for the built-in
                (first party) containers.

              - **PostAnalyticsProcessorSourceUri** *(string) --*

                An Amazon S3 URI to a script that is called after analysis has been performed.
                Applicable only for the built-in (first party) containers.

            - **StoppingCondition** *(dict) --*

              Specifies a time limit for how long the monitoring job is allowed to run.

              - **MaxRuntimeInSeconds** *(integer) --* **[REQUIRED]**

                The maximum runtime allowed in seconds.

            - **Environment** *(dict) --*

              Sets the environment variables in the Docker container.

              - *(string) --*

                - *(string) --*

            - **NetworkConfig** *(dict) --*

              Specifies networking options for an monitoring job.

              - **EnableNetworkIsolation** *(boolean) --*

                Whether to allow inbound and outbound network calls to and from the containers used
                for the processing job.

              - **VpcConfig** *(dict) --*

                Specifies a VPC that your training jobs and hosted models have access to. Control
                access to and from your training and model containers by configuring the VPC. For
                more information, see `Protect Endpoints by Using an Amazon Virtual Private Cloud
                <https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html>`__ and `Protect
                Training Jobs by Using an Amazon Virtual Private Cloud
                <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                - **SecurityGroupIds** *(list) --* **[REQUIRED]**

                  The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups
                  for the VPC that is specified in the ``Subnets`` field.

                  - *(string) --*

                - **Subnets** *(list) --* **[REQUIRED]**

                  The ID of the subnets in the VPC to which you want to connect your training job or
                  model.

                  .. note::

                    Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                    availability zones of region us-east-1. If you want to create endpoints with P3
                    instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                    zones instead.

                  - *(string) --*

            - **RoleArn** *(string) --* **[REQUIRED]**

              The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to
              perform tasks on your behalf.

        :type Tags: list
        :param Tags:

          (Optional) An array of key-value pairs. For more information, see `Using Cost Allocation
          Tags <
          https://docs-aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-whatURL>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MonitoringScheduleArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **MonitoringScheduleArn** *(string) --*

              The Amazon Resource Name (ARN) of the monitoring schedule.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_notebook_instance(
        self,
        NotebookInstanceName: str,
        InstanceType: Literal[
            "ml.t2.medium",
            "ml.t2.large",
            "ml.t2.xlarge",
            "ml.t2.2xlarge",
            "ml.t3.medium",
            "ml.t3.large",
            "ml.t3.xlarge",
            "ml.t3.2xlarge",
            "ml.m4.xlarge",
            "ml.m4.2xlarge",
            "ml.m4.4xlarge",
            "ml.m4.10xlarge",
            "ml.m4.16xlarge",
            "ml.m5.xlarge",
            "ml.m5.2xlarge",
            "ml.m5.4xlarge",
            "ml.m5.12xlarge",
            "ml.m5.24xlarge",
            "ml.c4.xlarge",
            "ml.c4.2xlarge",
            "ml.c4.4xlarge",
            "ml.c4.8xlarge",
            "ml.c5.xlarge",
            "ml.c5.2xlarge",
            "ml.c5.4xlarge",
            "ml.c5.9xlarge",
            "ml.c5.18xlarge",
            "ml.c5d.xlarge",
            "ml.c5d.2xlarge",
            "ml.c5d.4xlarge",
            "ml.c5d.9xlarge",
            "ml.c5d.18xlarge",
            "ml.p2.xlarge",
            "ml.p2.8xlarge",
            "ml.p2.16xlarge",
            "ml.p3.2xlarge",
            "ml.p3.8xlarge",
            "ml.p3.16xlarge",
        ],
        RoleArn: str,
        SubnetId: str = None,
        SecurityGroupIds: List[str] = None,
        KmsKeyId: str = None,
        Tags: List[ClientCreateNotebookInstanceTagsTypeDef] = None,
        LifecycleConfigName: str = None,
        DirectInternetAccess: Literal["Enabled", "Disabled"] = None,
        VolumeSizeInGB: int = None,
        AcceleratorTypes: List[
            Literal[
                "ml.eia1.medium",
                "ml.eia1.large",
                "ml.eia1.xlarge",
                "ml.eia2.medium",
                "ml.eia2.large",
                "ml.eia2.xlarge",
            ]
        ] = None,
        DefaultCodeRepository: str = None,
        AdditionalCodeRepositories: List[str] = None,
        RootAccess: Literal["Enabled", "Disabled"] = None,
    ) -> ClientCreateNotebookInstanceResponseTypeDef:
        """
        Creates an Amazon SageMaker notebook instance. A notebook instance is a machine learning
        (ML) compute instance running on a Jupyter notebook.

        In a ``CreateNotebookInstance`` request, specify the type of ML compute instance that you
        want to run. Amazon SageMaker launches the instance, installs common libraries that you can
        use to explore datasets for model training, and attaches an ML storage volume to the
        notebook instance.

        Amazon SageMaker also provides a set of example notebooks. Each notebook demonstrates how to
        use Amazon SageMaker with a specific algorithm or with a machine learning framework.

        After receiving the request, Amazon SageMaker does the following:

        * Creates a network interface in the Amazon SageMaker VPC.

        * (Option) If you specified ``SubnetId`` , Amazon SageMaker creates a network interface in
        your own VPC, which is inferred from the subnet ID that you provide in the input. When
        creating this network interface, Amazon SageMaker attaches the security group that you
        specified in the request to the network interface that it creates in your VPC.

        * Launches an EC2 instance of the type specified in the request in the Amazon SageMaker VPC.
        If you specified ``SubnetId`` of your VPC, Amazon SageMaker specifies both network
        interfaces when launching this instance. This enables inbound traffic from your own VPC to
        the notebook instance, assuming that the security groups allow it.

        After creating the notebook instance, Amazon SageMaker returns its Amazon Resource Name
        (ARN). You can't change the name of a notebook instance after you create it.

        After Amazon SageMaker creates the notebook instance, you can connect to the Jupyter server
        and work in Jupyter notebooks. For example, you can write code to explore a dataset that you
        can use for model training, train a model, host models by creating Amazon SageMaker
        endpoints, and validate hosted models.

        For more information, see `How It Works
        <https://docs.aws.amazon.com/sagemaker/latest/dg/how-it-works.html>`__ .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateNotebookInstance>`_

        **Request Syntax**
        ::

          response = client.create_notebook_instance(
              NotebookInstanceName='string',
              InstanceType=
                  'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'|'ml.t3.medium'
                  |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'|'ml.m4.xlarge'|'ml.m4.2xlarge'
                  |'ml.m4.4xlarge'|'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                  |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'
                  |'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                  |'ml.c5.9xlarge'|'ml.c5.18xlarge'|'ml.c5d.xlarge'|'ml.c5d.2xlarge'
                  |'ml.c5d.4xlarge'|'ml.c5d.9xlarge'|'ml.c5d.18xlarge'|'ml.p2.xlarge'
                  |'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                  |'ml.p3.16xlarge',
              SubnetId='string',
              SecurityGroupIds=[
                  'string',
              ],
              RoleArn='string',
              KmsKeyId='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              LifecycleConfigName='string',
              DirectInternetAccess='Enabled'|'Disabled',
              VolumeSizeInGB=123,
              AcceleratorTypes=[
                  'ml.eia1.medium'|'ml.eia1.large'|'ml.eia1.xlarge'|'ml.eia2.medium'|'ml.eia2.large'
                  |'ml.eia2.xlarge',
              ],
              DefaultCodeRepository='string',
              AdditionalCodeRepositories=[
                  'string',
              ],
              RootAccess='Enabled'|'Disabled'
          )
        :type NotebookInstanceName: string
        :param NotebookInstanceName: **[REQUIRED]**

          The name of the new notebook instance.

        :type InstanceType: string
        :param InstanceType: **[REQUIRED]**

          The type of ML compute instance to launch for the notebook instance.

        :type SubnetId: string
        :param SubnetId:

          The ID of the subnet in a VPC to which you would like to have a connectivity from your ML
          compute instance.

        :type SecurityGroupIds: list
        :param SecurityGroupIds:

          The VPC security group IDs, in the form sg-xxxxxxxx. The security groups must be for the
          same VPC as specified in the subnet.

          - *(string) --*

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          When you send any requests to AWS resources from the notebook instance, Amazon SageMaker
          assumes this role to perform tasks on your behalf. You must grant this role necessary
          permissions so Amazon SageMaker can perform these tasks. The policy must allow the Amazon
          SageMaker service principal (sagemaker.amazonaws.com) permissions to assume this role. For
          more information, see `Amazon SageMaker Roles
          <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-roles.html>`__ .

          .. note::

            To be able to pass this role to Amazon SageMaker, the caller of this API must have the
            ``iam:PassRole`` permission.

        :type KmsKeyId: string
        :param KmsKeyId:

          The Amazon Resource Name (ARN) of a AWS Key Management Service key that Amazon SageMaker
          uses to encrypt data on the storage volume attached to your notebook instance. The KMS key
          you provide must be enabled. For information, see `Enabling and Disabling Keys
          <https://docs.aws.amazon.com/kms/latest/developerguide/enabling-keys.html>`__ in the *AWS
          Key Management Service Developer Guide* .

        :type Tags: list
        :param Tags:

          A list of tags to associate with the notebook instance. You can add tags later by using
          the ``CreateTags`` API.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type LifecycleConfigName: string
        :param LifecycleConfigName:

          The name of a lifecycle configuration to associate with the notebook instance. For
          information about lifestyle configurations, see `Step 2.1\\: (Optional) Customize a
          Notebook Instance
          <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

        :type DirectInternetAccess: string
        :param DirectInternetAccess:

          Sets whether Amazon SageMaker provides internet access to the notebook instance. If you
          set this to ``Disabled`` this notebook instance will be able to access resources only in
          your VPC, and will not be able to connect to Amazon SageMaker training and endpoint
          services unless your configure a NAT Gateway in your VPC.

          For more information, see `Notebook Instances Are Internet-Enabled by Default
          <https://docs.aws.amazon.com/sagemaker/latest/dg/appendix-additional-considerations.html#appendix-notebook-and-internet-access>`__
          . You can set the value of this parameter to ``Disabled`` only if you set a value for the
          ``SubnetId`` parameter.

        :type VolumeSizeInGB: integer
        :param VolumeSizeInGB:

          The size, in GB, of the ML storage volume to attach to the notebook instance. The default
          value is 5 GB.

        :type AcceleratorTypes: list
        :param AcceleratorTypes:

          A list of Elastic Inference (EI) instance types to associate with this notebook instance.
          Currently, only one instance type can be associated with a notebook instance. For more
          information, see `Using Elastic Inference in Amazon SageMaker
          <https://docs.aws.amazon.com/sagemaker/latest/dg/ei.html>`__ .

          - *(string) --*

        :type DefaultCodeRepository: string
        :param DefaultCodeRepository:

          A Git repository to associate with the notebook instance as its default code repository.
          This can be either the name of a Git repository stored as a resource in your account, or
          the URL of a Git repository in `AWS CodeCommit
          <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in any other
          Git repository. When you open a notebook instance, it opens in the directory that contains
          this repository. For more information, see `Associating Git Repositories with Amazon
          SageMaker Notebook Instances
          <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

        :type AdditionalCodeRepositories: list
        :param AdditionalCodeRepositories:

          An array of up to three Git repositories to associate with the notebook instance. These
          can be either the names of Git repositories stored as resources in your account, or the
          URL of Git repositories in `AWS CodeCommit
          <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in any other
          Git repository. These repositories are cloned at the same level as the default repository
          of your notebook instance. For more information, see `Associating Git Repositories with
          Amazon SageMaker Notebook Instances
          <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

          - *(string) --*

        :type RootAccess: string
        :param RootAccess:

          Whether root access is enabled or disabled for users of the notebook instance. The default
          value is ``Enabled`` .

          .. note::

            Lifecycle configurations need root access to be able to set up a notebook instance.
            Because of this, lifecycle configurations associated with a notebook instance always run
            with root access even if you disable root access for users.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'NotebookInstanceArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **NotebookInstanceArn** *(string) --*

              The Amazon Resource Name (ARN) of the notebook instance.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_notebook_instance_lifecycle_config(
        self,
        NotebookInstanceLifecycleConfigName: str,
        OnCreate: List[ClientCreateNotebookInstanceLifecycleConfigOnCreateTypeDef] = None,
        OnStart: List[ClientCreateNotebookInstanceLifecycleConfigOnStartTypeDef] = None,
    ) -> ClientCreateNotebookInstanceLifecycleConfigResponseTypeDef:
        """
        Creates a lifecycle configuration that you can associate with a notebook instance. A
        *lifecycle configuration* is a collection of shell scripts that run when you create or start
        a notebook instance.

        Each lifecycle configuration script has a limit of 16384 characters.

        The value of the ``$PATH`` environment variable that is available to both scripts is
        ``/sbin:bin:/usr/sbin:/usr/bin`` .

        View CloudWatch Logs for notebook instance lifecycle configurations in log group
        ``/aws/sagemaker/NotebookInstances`` in log stream
        ``[notebook-instance-name]/[LifecycleConfigHook]`` .

        Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script runs for
        longer than 5 minutes, it fails and the notebook instance is not created or started.

        For information about notebook instance lifestyle configurations, see `Step 2.1\\:
        (Optional) Customize a Notebook Instance
        <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateNotebookInstanceLifecycleConfig>`_

        **Request Syntax**
        ::

          response = client.create_notebook_instance_lifecycle_config(
              NotebookInstanceLifecycleConfigName='string',
              OnCreate=[
                  {
                      'Content': 'string'
                  },
              ],
              OnStart=[
                  {
                      'Content': 'string'
                  },
              ]
          )
        :type NotebookInstanceLifecycleConfigName: string
        :param NotebookInstanceLifecycleConfigName: **[REQUIRED]**

          The name of the lifecycle configuration.

        :type OnCreate: list
        :param OnCreate:

          A shell script that runs only once, when you create a notebook instance. The shell script
          must be a base64-encoded string.

          - *(dict) --*

            Contains the notebook instance lifecycle configuration script.

            Each lifecycle configuration script has a limit of 16384 characters.

            The value of the ``$PATH`` environment variable that is available to both scripts is
            ``/sbin:bin:/usr/sbin:/usr/bin`` .

            View CloudWatch Logs for notebook instance lifecycle configurations in log group
            ``/aws/sagemaker/NotebookInstances`` in log stream
            ``[notebook-instance-name]/[LifecycleConfigHook]`` .

            Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script runs
            for longer than 5 minutes, it fails and the notebook instance is not created or started.

            For information about notebook instance lifestyle configurations, see `Step 2.1\\:
            (Optional) Customize a Notebook Instance
            <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

            - **Content** *(string) --*

              A base64-encoded string that contains a shell script for a notebook instance lifecycle
              configuration.

        :type OnStart: list
        :param OnStart:

          A shell script that runs every time you start a notebook instance, including when you
          create the notebook instance. The shell script must be a base64-encoded string.

          - *(dict) --*

            Contains the notebook instance lifecycle configuration script.

            Each lifecycle configuration script has a limit of 16384 characters.

            The value of the ``$PATH`` environment variable that is available to both scripts is
            ``/sbin:bin:/usr/sbin:/usr/bin`` .

            View CloudWatch Logs for notebook instance lifecycle configurations in log group
            ``/aws/sagemaker/NotebookInstances`` in log stream
            ``[notebook-instance-name]/[LifecycleConfigHook]`` .

            Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script runs
            for longer than 5 minutes, it fails and the notebook instance is not created or started.

            For information about notebook instance lifestyle configurations, see `Step 2.1\\:
            (Optional) Customize a Notebook Instance
            <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

            - **Content** *(string) --*

              A base64-encoded string that contains a shell script for a notebook instance lifecycle
              configuration.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'NotebookInstanceLifecycleConfigArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **NotebookInstanceLifecycleConfigArn** *(string) --*

              The Amazon Resource Name (ARN) of the lifecycle configuration.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_presigned_domain_url(
        self, DomainId: str, UserProfileName: str, SessionExpirationDurationInSeconds: int = None
    ) -> ClientCreatePresignedDomainUrlResponseTypeDef:
        """
        Creates a URL for a specified UserProfile in a Domain. When accessed in a web browser, the
        user will be automatically signed in to Amazon SageMaker Amazon SageMaker Studio (Studio),
        and granted access to all of the Apps and files associated with that Amazon Elastic File
        System (EFS). This operation can only be called when AuthMode equals IAM.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreatePresignedDomainUrl>`_

        **Request Syntax**
        ::

          response = client.create_presigned_domain_url(
              DomainId='string',
              UserProfileName='string',
              SessionExpirationDurationInSeconds=123
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          The name of the UserProfile to sign-in as.

        :type SessionExpirationDurationInSeconds: integer
        :param SessionExpirationDurationInSeconds:

          The session expiration duration in seconds.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AuthorizedUrl': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **AuthorizedUrl** *(string) --*

              The presigned URL.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_presigned_notebook_instance_url(
        self, NotebookInstanceName: str, SessionExpirationDurationInSeconds: int = None
    ) -> ClientCreatePresignedNotebookInstanceUrlResponseTypeDef:
        """
        Returns a URL that you can use to connect to the Jupyter server from a notebook instance. In
        the Amazon SageMaker console, when you choose ``Open`` next to a notebook instance, Amazon
        SageMaker opens a new tab showing the Jupyter server home page from the notebook instance.
        The console uses this API to get the URL and show the page.

        IAM authorization policies for this API are also enforced for every HTTP request and
        WebSocket frame that attempts to connect to the notebook instance.For example, you can
        restrict access to this API and to the URL that it returns to a list of IP addresses that
        you specify. Use the ``NotIpAddress`` condition operator and the ``aws:SourceIP`` condition
        context key to specify the list of IP addresses that you want to have access to the notebook
        instance. For more information, see `Limit Access to a Notebook Instance by IP Address
        <https://docs.aws.amazon.com/sagemaker/latest/dg/security_iam_id-based-policy-examples.html#nbi-ip-filter>`__
        .

        .. note::

          The URL that you get from a call to is valid only for 5 minutes. If you try to use the URL
          after the 5-minute limit expires, you are directed to the AWS console sign-in page.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreatePresignedNotebookInstanceUrl>`_

        **Request Syntax**
        ::

          response = client.create_presigned_notebook_instance_url(
              NotebookInstanceName='string',
              SessionExpirationDurationInSeconds=123
          )
        :type NotebookInstanceName: string
        :param NotebookInstanceName: **[REQUIRED]**

          The name of the notebook instance.

        :type SessionExpirationDurationInSeconds: integer
        :param SessionExpirationDurationInSeconds:

          The duration of the session, in seconds. The default is 12 hours.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AuthorizedUrl': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **AuthorizedUrl** *(string) --*

              A JSON object that contains the URL string.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_processing_job(
        self,
        ProcessingJobName: str,
        ProcessingResources: ClientCreateProcessingJobProcessingResourcesTypeDef,
        AppSpecification: ClientCreateProcessingJobAppSpecificationTypeDef,
        RoleArn: str,
        ProcessingInputs: List[ClientCreateProcessingJobProcessingInputsTypeDef] = None,
        ProcessingOutputConfig: ClientCreateProcessingJobProcessingOutputConfigTypeDef = None,
        StoppingCondition: ClientCreateProcessingJobStoppingConditionTypeDef = None,
        Environment: Dict[str, str] = None,
        NetworkConfig: ClientCreateProcessingJobNetworkConfigTypeDef = None,
        Tags: List[ClientCreateProcessingJobTagsTypeDef] = None,
        ExperimentConfig: ClientCreateProcessingJobExperimentConfigTypeDef = None,
    ) -> ClientCreateProcessingJobResponseTypeDef:
        """
        Creates a processing job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateProcessingJob>`_

        **Request Syntax**
        ::

          response = client.create_processing_job(
              ProcessingInputs=[
                  {
                      'InputName': 'string',
                      'S3Input': {
                          'S3Uri': 'string',
                          'LocalPath': 'string',
                          'S3DataType': 'ManifestFile'|'S3Prefix',
                          'S3InputMode': 'Pipe'|'File',
                          'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key',
                          'S3CompressionType': 'None'|'Gzip'
                      }
                  },
              ],
              ProcessingOutputConfig={
                  'Outputs': [
                      {
                          'OutputName': 'string',
                          'S3Output': {
                              'S3Uri': 'string',
                              'LocalPath': 'string',
                              'S3UploadMode': 'Continuous'|'EndOfJob'
                          }
                      },
                  ],
                  'KmsKeyId': 'string'
              },
              ProcessingJobName='string',
              ProcessingResources={
                  'ClusterConfig': {
                      'InstanceCount': 123,
                      'InstanceType':
                      'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                      |'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                      |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                      |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                      |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                      |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                      |'ml.c5.18xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                      |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.r5.large'
                      |'ml.r5.xlarge'|'ml.r5.2xlarge'|'ml.r5.4xlarge'|'ml.r5.8xlarge'
                      |'ml.r5.12xlarge'|'ml.r5.16xlarge'|'ml.r5.24xlarge',
                      'VolumeSizeInGB': 123,
                      'VolumeKmsKeyId': 'string'
                  }
              },
              StoppingCondition={
                  'MaxRuntimeInSeconds': 123
              },
              AppSpecification={
                  'ImageUri': 'string',
                  'ContainerEntrypoint': [
                      'string',
                  ],
                  'ContainerArguments': [
                      'string',
                  ]
              },
              Environment={
                  'string': 'string'
              },
              NetworkConfig={
                  'EnableNetworkIsolation': True|False,
                  'VpcConfig': {
                      'SecurityGroupIds': [
                          'string',
                      ],
                      'Subnets': [
                          'string',
                      ]
                  }
              },
              RoleArn='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              ExperimentConfig={
                  'ExperimentName': 'string',
                  'TrialName': 'string',
                  'TrialComponentDisplayName': 'string'
              }
          )
        :type ProcessingInputs: list
        :param ProcessingInputs:

          For each input, data is downloaded from S3 into the processing container before the
          processing job begins running if "S3InputMode" is set to ``File`` .

          - *(dict) --*

            The inputs for a processing job.

            - **InputName** *(string) --* **[REQUIRED]**

              The name of the inputs for the processing job.

            - **S3Input** *(dict) --* **[REQUIRED]**

              The S3 inputs for the processing job.

              - **S3Uri** *(string) --* **[REQUIRED]**

                The URI for the Amazon S3 storage where you want Amazon SageMaker to download the
                artifacts needed to run a processing job.

              - **LocalPath** *(string) --* **[REQUIRED]**

                The local path to the Amazon S3 bucket where you want Amazon SageMaker to download
                the inputs to run a processing job. ``LocalPath`` is an absolute path to the input
                data.

              - **S3DataType** *(string) --* **[REQUIRED]**

                Whether you use an ``S3Prefix`` or a ``ManifestFile`` for the data type. If you
                choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon SageMaker uses
                all objects with the specified key name prefix for the processing job. If you choose
                ``ManifestFile`` , ``S3Uri`` identifies an object that is a manifest file containing
                a list of object keys that you want Amazon SageMaker to use for the processing job.

              - **S3InputMode** *(string) --* **[REQUIRED]**

                Wether to use ``File`` or ``Pipe`` input mode. In ``File`` mode, Amazon SageMaker
                copies the data from the input source onto the local Amazon Elastic Block Store
                (Amazon EBS) volumes before starting your training algorithm. This is the most
                commonly used input mode. In ``Pipe`` mode, Amazon SageMaker streams input data from
                the source directly to your algorithm without using the EBS volume.

              - **S3DataDistributionType** *(string) --*

                Whether the data stored in Amazon S3 is ``FullyReplicated`` or ``ShardedByS3Key`` .

              - **S3CompressionType** *(string) --*

                Whether to use ``Gzip`` compresion for Amazon S3 storage.

        :type ProcessingOutputConfig: dict
        :param ProcessingOutputConfig:

          Output configuration for the processing job.

          - **Outputs** *(list) --* **[REQUIRED]**

            Output configuration information for a processing job.

            - *(dict) --*

              Describes the results of a processing job.

              - **OutputName** *(string) --* **[REQUIRED]**

                The name for the processing job output.

              - **S3Output** *(dict) --* **[REQUIRED]**

                Configuration for processing job outputs in Amazon S3.

                - **S3Uri** *(string) --* **[REQUIRED]**

                  A URI that identifies the Amazon S3 bucket where you want Amazon SageMaker to save
                  the results of a processing job.

                - **LocalPath** *(string) --* **[REQUIRED]**

                  The local path to the Amazon S3 bucket where you want Amazon SageMaker to save the
                  results of an processing job. ``LocalPath`` is an absolute path to the input data.

                - **S3UploadMode** *(string) --* **[REQUIRED]**

                  Whether to upload the results of the processing job continuously or after the job
                  completes.

          - **KmsKeyId** *(string) --*

            The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the
            processing job output. ``KmsKeyId`` can be an ID of a KMS key, ARN of a KMS key, alias
            of a KMS key, or alias of a KMS key. The ``KmsKeyId`` is applied to all outputs.

        :type ProcessingJobName: string
        :param ProcessingJobName: **[REQUIRED]**

          The name of the processing job. The name must be unique within an AWS Region in the AWS
          account.

        :type ProcessingResources: dict
        :param ProcessingResources: **[REQUIRED]**

          Identifies the resources, ML compute instances, and ML storage volumes to deploy for a
          processing job. In distributed training, you specify more than one instance.

          - **ClusterConfig** *(dict) --* **[REQUIRED]**

            The configuration for the resources in a cluster used to run the processing job.

            - **InstanceCount** *(integer) --* **[REQUIRED]**

              The number of ML compute instances to use in the processing job. For distributed
              processing jobs, specify a value greater than 1. The default value is 1.

            - **InstanceType** *(string) --* **[REQUIRED]**

              The ML compute instance type for the processing job.

            - **VolumeSizeInGB** *(integer) --* **[REQUIRED]**

              The size of the ML storage volume in gigabytes that you want to provision. You must
              specify sufficient ML storage for your scenario.

            - **VolumeKmsKeyId** *(string) --*

              The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
              data on the storage volume attached to the ML compute instance(s) that run the
              processing job.

        :type StoppingCondition: dict
        :param StoppingCondition:

          The time limit for how long the processing job is allowed to run.

          - **MaxRuntimeInSeconds** *(integer) --* **[REQUIRED]**

            Specifies the maximum runtime in seconds.

        :type AppSpecification: dict
        :param AppSpecification: **[REQUIRED]**

          Configures the processing job to run a specified Docker container image.

          - **ImageUri** *(string) --* **[REQUIRED]**

            The container image to be run by the processing job.

          - **ContainerEntrypoint** *(list) --*

            The entrypoint for a container used to run a processing job.

            - *(string) --*

          - **ContainerArguments** *(list) --*

            The arguments for a container used to run a processing job.

            - *(string) --*

        :type Environment: dict
        :param Environment:

          Sets the environment variables in the Docker container.

          - *(string) --*

            - *(string) --*

        :type NetworkConfig: dict
        :param NetworkConfig:

          Networking options for a processing job.

          - **EnableNetworkIsolation** *(boolean) --*

            Whether to allow inbound and outbound network calls to and from the containers used for
            the processing job.

          - **VpcConfig** *(dict) --*

            Specifies a VPC that your training jobs and hosted models have access to. Control access
            to and from your training and model containers by configuring the VPC. For more
            information, see `Protect Endpoints by Using an Amazon Virtual Private Cloud
            <https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html>`__ and `Protect Training
            Jobs by Using an Amazon Virtual Private Cloud
            <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

            - **SecurityGroupIds** *(list) --* **[REQUIRED]**

              The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for
              the VPC that is specified in the ``Subnets`` field.

              - *(string) --*

            - **Subnets** *(list) --* **[REQUIRED]**

              The ID of the subnets in the VPC to which you want to connect your training job or
              model.

              .. note::

                Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                availability zones of region us-east-1. If you want to create endpoints with P3
                instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                zones instead.

              - *(string) --*

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform
          tasks on your behalf.

        :type Tags: list
        :param Tags:

          (Optional) An array of key-value pairs. For more information, see `Using Cost Allocation
          Tags
          <https://docs-aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-whatURL>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type ExperimentConfig: dict
        :param ExperimentConfig:

          Configuration for the experiment.

          - **ExperimentName** *(string) --*

            The name of the experiment.

          - **TrialName** *(string) --*

            The name of the trial.

          - **TrialComponentDisplayName** *(string) --*

            Display name for the trial component.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ProcessingJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ProcessingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the processing job.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_training_job(
        self,
        TrainingJobName: str,
        AlgorithmSpecification: ClientCreateTrainingJobAlgorithmSpecificationTypeDef,
        RoleArn: str,
        OutputDataConfig: ClientCreateTrainingJobOutputDataConfigTypeDef,
        ResourceConfig: ClientCreateTrainingJobResourceConfigTypeDef,
        StoppingCondition: ClientCreateTrainingJobStoppingConditionTypeDef,
        HyperParameters: Dict[str, str] = None,
        InputDataConfig: List[ClientCreateTrainingJobInputDataConfigTypeDef] = None,
        VpcConfig: ClientCreateTrainingJobVpcConfigTypeDef = None,
        Tags: List[ClientCreateTrainingJobTagsTypeDef] = None,
        EnableNetworkIsolation: bool = None,
        EnableInterContainerTrafficEncryption: bool = None,
        EnableManagedSpotTraining: bool = None,
        CheckpointConfig: ClientCreateTrainingJobCheckpointConfigTypeDef = None,
        DebugHookConfig: ClientCreateTrainingJobDebugHookConfigTypeDef = None,
        DebugRuleConfigurations: List[ClientCreateTrainingJobDebugRuleConfigurationsTypeDef] = None,
        TensorBoardOutputConfig: ClientCreateTrainingJobTensorBoardOutputConfigTypeDef = None,
        ExperimentConfig: ClientCreateTrainingJobExperimentConfigTypeDef = None,
    ) -> ClientCreateTrainingJobResponseTypeDef:
        """
        Starts a model training job. After training completes, Amazon SageMaker saves the resulting
        model artifacts to an Amazon S3 location that you specify.

        If you choose to host your model using Amazon SageMaker hosting services, you can use the
        resulting model artifacts as part of the model. You can also use the artifacts in a machine
        learning service other than Amazon SageMaker, provided that you know how to use them for
        inferences.

        In the request body, you provide the following:

        * ``AlgorithmSpecification`` - Identifies the training algorithm to use.

        * ``HyperParameters`` - Specify these algorithm-specific parameters to enable the estimation
        of model parameters during training. Hyperparameters can be tuned to optimize this learning
        process. For a list of hyperparameters for each training algorithm provided by Amazon
        SageMaker, see `Algorithms <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

        * ``InputDataConfig`` - Describes the training dataset and the Amazon S3, EFS, or FSx
        location where it is stored.

        * ``OutputDataConfig`` - Identifies the Amazon S3 bucket where you want Amazon SageMaker to
        save the results of model training.

        * ``ResourceConfig`` - Identifies the resources, ML compute instances, and ML storage
        volumes to deploy for model training. In distributed training, you specify more than one
        instance.

        * ``EnableManagedSpotTraining`` - Optimize the cost of training machine learning models by
        up to 80% by using Amazon EC2 Spot instances. For more information, see `Managed Spot
        Training
        <https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html>`__ .

        * ``RoleARN`` - The Amazon Resource Number (ARN) that Amazon SageMaker assumes to perform
        tasks on your behalf during model training. You must grant this role the necessary
        permissions so that Amazon SageMaker can successfully complete model training.

        * ``StoppingCondition`` - To help cap training costs, use ``MaxRuntimeInSeconds`` to set a
        time limit for training. Use ``MaxWaitTimeInSeconds`` to specify how long you are willing to
        wait for a managed spot training job to complete.

        For more information about Amazon SageMaker, see `How It Works
        <https://docs.aws.amazon.com/sagemaker/latest/dg/how-it-works.html>`__ .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateTrainingJob>`_

        **Request Syntax**
        ::

          response = client.create_training_job(
              TrainingJobName='string',
              HyperParameters={
                  'string': 'string'
              },
              AlgorithmSpecification={
                  'TrainingImage': 'string',
                  'AlgorithmName': 'string',
                  'TrainingInputMode': 'Pipe'|'File',
                  'MetricDefinitions': [
                      {
                          'Name': 'string',
                          'Regex': 'string'
                      },
                  ],
                  'EnableSageMakerMetricsTimeSeries': True|False
              },
              RoleArn='string',
              InputDataConfig=[
                  {
                      'ChannelName': 'string',
                      'DataSource': {
                          'S3DataSource': {
                              'S3DataType': 'ManifestFile'|'S3Prefix'|'AugmentedManifestFile',
                              'S3Uri': 'string',
                              'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key',
                              'AttributeNames': [
                                  'string',
                              ]
                          },
                          'FileSystemDataSource': {
                              'FileSystemId': 'string',
                              'FileSystemAccessMode': 'rw'|'ro',
                              'FileSystemType': 'EFS'|'FSxLustre',
                              'DirectoryPath': 'string'
                          }
                      },
                      'ContentType': 'string',
                      'CompressionType': 'None'|'Gzip',
                      'RecordWrapperType': 'None'|'RecordIO',
                      'InputMode': 'Pipe'|'File',
                      'ShuffleConfig': {
                          'Seed': 123
                      }
                  },
              ],
              OutputDataConfig={
                  'KmsKeyId': 'string',
                  'S3OutputPath': 'string'
              },
              ResourceConfig={
                  'InstanceType':
                  'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                  |'ml.m4.16xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                  |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'
                  |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'
                  |'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                  |'ml.p3.16xlarge'|'ml.p3dn.24xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                  |'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge',
                  'InstanceCount': 123,
                  'VolumeSizeInGB': 123,
                  'VolumeKmsKeyId': 'string'
              },
              VpcConfig={
                  'SecurityGroupIds': [
                      'string',
                  ],
                  'Subnets': [
                      'string',
                  ]
              },
              StoppingCondition={
                  'MaxRuntimeInSeconds': 123,
                  'MaxWaitTimeInSeconds': 123
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              EnableNetworkIsolation=True|False,
              EnableInterContainerTrafficEncryption=True|False,
              EnableManagedSpotTraining=True|False,
              CheckpointConfig={
                  'S3Uri': 'string',
                  'LocalPath': 'string'
              },
              DebugHookConfig={
                  'LocalPath': 'string',
                  'S3OutputPath': 'string',
                  'HookParameters': {
                      'string': 'string'
                  },
                  'CollectionConfigurations': [
                      {
                          'CollectionName': 'string',
                          'CollectionParameters': {
                              'string': 'string'
                          }
                      },
                  ]
              },
              DebugRuleConfigurations=[
                  {
                      'RuleConfigurationName': 'string',
                      'LocalPath': 'string',
                      'S3OutputPath': 'string',
                      'RuleEvaluatorImage': 'string',
                      'InstanceType':
                      'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                      |'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                      |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                      |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                      |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                      |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                      |'ml.c5.18xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                      |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.r5.large'
                      |'ml.r5.xlarge'|'ml.r5.2xlarge'|'ml.r5.4xlarge'|'ml.r5.8xlarge'
                      |'ml.r5.12xlarge'|'ml.r5.16xlarge'|'ml.r5.24xlarge',
                      'VolumeSizeInGB': 123,
                      'RuleParameters': {
                          'string': 'string'
                      }
                  },
              ],
              TensorBoardOutputConfig={
                  'LocalPath': 'string',
                  'S3OutputPath': 'string'
              },
              ExperimentConfig={
                  'ExperimentName': 'string',
                  'TrialName': 'string',
                  'TrialComponentDisplayName': 'string'
              }
          )
        :type TrainingJobName: string
        :param TrainingJobName: **[REQUIRED]**

          The name of the training job. The name must be unique within an AWS Region in an AWS
          account.

        :type HyperParameters: dict
        :param HyperParameters:

          Algorithm-specific parameters that influence the quality of the model. You set
          hyperparameters before you start the learning process. For a list of hyperparameters for
          each training algorithm provided by Amazon SageMaker, see `Algorithms
          <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

          You can specify a maximum of 100 hyperparameters. Each hyperparameter is a key-value pair.
          Each key and value is limited to 256 characters, as specified by the ``Length Constraint``
          .

          - *(string) --*

            - *(string) --*

        :type AlgorithmSpecification: dict
        :param AlgorithmSpecification: **[REQUIRED]**

          The registry path of the Docker image that contains the training algorithm and
          algorithm-specific metadata, including the input mode. For more information about
          algorithms provided by Amazon SageMaker, see `Algorithms
          <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ . For information about
          providing your own algorithms, see `Using Your Own Algorithms with Amazon SageMaker
          <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

          - **TrainingImage** *(string) --*

            The registry path of the Docker image that contains the training algorithm. For
            information about docker registry paths for built-in algorithms, see `Algorithms
            Provided by Amazon SageMaker\\: Common Parameters
            <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
            . Amazon SageMaker supports both ``registry/repository[:tag]`` and
            ``registry/repository[@digest]`` image path formats. For more information, see `Using
            Your Own Algorithms with Amazon SageMaker
            <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

          - **AlgorithmName** *(string) --*

            The name of the algorithm resource to use for the training job. This must be an
            algorithm resource that you created or subscribe to on AWS Marketplace. If you specify a
            value for this parameter, you can't specify a value for ``TrainingImage`` .

          - **TrainingInputMode** *(string) --* **[REQUIRED]**

            The input mode that the algorithm supports. For the input modes that Amazon SageMaker
            algorithms support, see `Algorithms
            <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ . If an algorithm
            supports the ``File`` input mode, Amazon SageMaker downloads the training data from S3
            to the provisioned ML storage Volume, and mounts the directory to docker volume for
            training container. If an algorithm supports the ``Pipe`` input mode, Amazon SageMaker
            streams data directly from S3 to the container.

            In File mode, make sure you provision ML storage volume with sufficient capacity to
            accommodate the data download from S3. In addition to the training data, the ML storage
            volume also stores the output model. The algorithm container use ML storage volume to
            also store intermediate information, if any.

            For distributed algorithms using File mode, training data is distributed uniformly, and
            your training duration is predictable if the input data objects size is approximately
            same. Amazon SageMaker does not split the files any further for model training. If the
            object sizes are skewed, training won't be optimal as the data distribution is also
            skewed where one host in a training cluster is overloaded, thus becoming bottleneck in
            training.

          - **MetricDefinitions** *(list) --*

            A list of metric definition objects. Each object specifies the metric name and regular
            expressions used to parse algorithm logs. Amazon SageMaker publishes each metric to
            Amazon CloudWatch.

            - *(dict) --*

              Specifies a metric that the training algorithm writes to ``stderr`` or ``stdout`` .
              Amazon SageMakerhyperparameter tuning captures all defined metrics. You specify one
              metric that a hyperparameter tuning job uses as its objective metric to choose the
              best training job.

              - **Name** *(string) --* **[REQUIRED]**

                The name of the metric.

              - **Regex** *(string) --* **[REQUIRED]**

                A regular expression that searches the output of a training job and gets the value
                of the metric. For more information about using regular expressions to define
                metrics, see `Defining Objective Metrics
                <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                .

          - **EnableSageMakerMetricsTimeSeries** *(boolean) --*

            To generate and save time-series metrics during training, set to ``true`` . The default
            is ``false`` and time-series metrics aren't generated except in the following cases:

            * You use one of the Amazon SageMaker built-in algorithms

            * You use one of the following prebuilt Amazon SageMaker Docker images:

              * Tensorflow

              * MXNet

              * PyTorch

            * You specify at least one  MetricDefinition

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform
          tasks on your behalf.

          During model training, Amazon SageMaker needs your permission to read input data from an
          S3 bucket, download a Docker image that contains training code, write model artifacts to
          an S3 bucket, write logs to Amazon CloudWatch Logs, and publish metrics to Amazon
          CloudWatch. You grant permissions for all of these tasks to an IAM role. For more
          information, see `Amazon SageMaker Roles
          <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-roles.html>`__ .

          .. note::

            To be able to pass this role to Amazon SageMaker, the caller of this API must have the
            ``iam:PassRole`` permission.

        :type InputDataConfig: list
        :param InputDataConfig:

          An array of ``Channel`` objects. Each channel is a named input source. ``InputDataConfig``
          describes the input data and its location.

          Algorithms can accept input data from one or more channels. For example, an algorithm
          might have two channels of input data, ``training_data`` and ``validation_data`` . The
          configuration for each channel provides the S3, EFS, or FSx location where the input data
          is stored. It also provides information about the stored data: the MIME type, compression
          method, and whether the data is wrapped in RecordIO format.

          Depending on the input mode that the algorithm supports, Amazon SageMaker either copies
          input data files from an S3 bucket to a local directory in the Docker container, or makes
          it available as input streams. For example, if you specify an EFS location, input data
          files will be made available as input streams. They do not need to be downloaded.

          - *(dict) --*

            A channel is a named input source that training algorithms can consume.

            - **ChannelName** *(string) --* **[REQUIRED]**

              The name of the channel.

            - **DataSource** *(dict) --* **[REQUIRED]**

              The location of the channel data.

              - **S3DataSource** *(dict) --*

                The S3 location of the data source that is associated with a channel.

                - **S3DataType** *(string) --* **[REQUIRED]**

                  If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                  SageMaker uses all objects that match the specified key name prefix for model
                  training.

                  If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a manifest
                  file containing a list of object keys that you want Amazon SageMaker to use for
                  model training.

                  If you choose ``AugmentedManifestFile`` , S3Uri identifies an object that is an
                  augmented manifest file in JSON lines format. This file contains the data you want
                  to use for model training. ``AugmentedManifestFile`` can only be used if the
                  Channel's input mode is ``Pipe`` .

                - **S3Uri** *(string) --* **[REQUIRED]**

                  Depending on the value specified for the ``S3DataType`` , identifies either a key
                  name prefix or a manifest. For example:

                  * A key name prefix might look like this: ``s3://bucketname/exampleprefix`` .

                  * A manifest might look like this: ``s3://bucketname/example.manifest``   The
                  manifest is an S3 object which is a JSON file with the following format:  The
                  preceding JSON matches the following ``s3Uris`` :   ``[ {"prefix":
                  "s3://customer_bucket/some/prefix/"},``    ``"relative/path/to/custdata-1",``
                  ``"relative/path/custdata-2",``    ``...``    ``"relative/path/custdata-N"``
                  ``]``   The preceding JSON matches the following ``s3Uris`` :
                  ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                  ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                  ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete set
                  of ``s3uris`` in this manifest is the input data for the channel for this
                  datasource. The object that each ``s3uris`` points to must be readable by the IAM
                  role that Amazon SageMaker uses to perform tasks on your behalf.

                - **S3DataDistributionType** *(string) --*

                  If you want Amazon SageMaker to replicate the entire dataset on each ML compute
                  instance that is launched for model training, specify ``FullyReplicated`` .

                  If you want Amazon SageMaker to replicate a subset of data on each ML compute
                  instance that is launched for model training, specify ``ShardedByS3Key`` . If
                  there are *n* ML compute instances launched for a training job, each instance gets
                  approximately 1/*n* of the number of S3 objects. In this case, model training on
                  each machine uses only the subset of training data.

                  Don't choose more ML compute instances for training than available S3 objects. If
                  you do, some nodes won't get any data and you will pay for nodes that aren't
                  getting any training data. This applies in both File and Pipe modes. Keep this in
                  mind when developing algorithms.

                  In distributed training, where you use multiple ML compute EC2 instances, you
                  might choose ``ShardedByS3Key`` . If the algorithm requires copying training data
                  to the ML storage volume (when ``TrainingInputMode`` is set to ``File`` ), this
                  copies 1/*n* of the number of objects.

                - **AttributeNames** *(list) --*

                  A list of one or more attribute names to use that are found in a specified
                  augmented manifest file.

                  - *(string) --*

              - **FileSystemDataSource** *(dict) --*

                The file system that is associated with a channel.

                - **FileSystemId** *(string) --* **[REQUIRED]**

                  The file system id.

                - **FileSystemAccessMode** *(string) --* **[REQUIRED]**

                  The access mode of the mount of the directory associated with the channel. A
                  directory can be mounted either in ``ro`` (read-only) or ``rw`` (read-write) mode.

                - **FileSystemType** *(string) --* **[REQUIRED]**

                  The file system type.

                - **DirectoryPath** *(string) --* **[REQUIRED]**

                  The full path to the directory to associate with the channel.

            - **ContentType** *(string) --*

              The MIME type of the data.

            - **CompressionType** *(string) --*

              If training data is compressed, the compression type. The default value is ``None`` .
              ``CompressionType`` is used only in Pipe input mode. In File mode, leave this field
              unset or set it to None.

            - **RecordWrapperType** *(string) --*

              Specify RecordIO as the value when input data is in raw format but the training
              algorithm requires the RecordIO format. In this case, Amazon SageMaker wraps each
              individual S3 object in a RecordIO record. If the input data is already in RecordIO
              format, you don't need to set this attribute. For more information, see `Create a
              Dataset Using RecordIO
              <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__ .

              In File mode, leave this field unset or set it to None.

            - **InputMode** *(string) --*

              (Optional) The input mode to use for the data channel in a training job. If you don't
              set a value for ``InputMode`` , Amazon SageMaker uses the value set for
              ``TrainingInputMode`` . Use this parameter to override the ``TrainingInputMode``
              setting in a  AlgorithmSpecification request when you have a channel that needs a
              different input mode from the training job's general setting. To download the data
              from Amazon Simple Storage Service (Amazon S3) to the provisioned ML storage volume,
              and mount the directory to a Docker volume, use ``File`` input mode. To stream data
              directly from Amazon S3 to the container, choose ``Pipe`` input mode.

              To use a model for incremental training, choose ``File`` input model.

            - **ShuffleConfig** *(dict) --*

              A configuration for a shuffle option for input data in a channel. If you use
              ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key prefix
              matches. If you use ``ManifestFile`` , the order of the S3 object references in the
              ``ManifestFile`` is shuffled. If you use ``AugmentedManifestFile`` , the order of the
              JSON lines in the ``AugmentedManifestFile`` is shuffled. The shuffling order is
              determined using the ``Seed`` value.

              For Pipe input mode, shuffling is done at the start of every epoch. With large
              datasets this ensures that the order of the training data is different for each epoch,
              it helps reduce bias and possible overfitting. In a multi-node training job when
              ShuffleConfig is combined with ``S3DataDistributionType`` of ``ShardedByS3Key`` , the
              data is shuffled across nodes so that the content sent to a particular node on the
              first epoch might be sent to a different node on the second epoch.

              - **Seed** *(integer) --* **[REQUIRED]**

                Determines the shuffling order in ``ShuffleConfig`` value.

        :type OutputDataConfig: dict
        :param OutputDataConfig: **[REQUIRED]**

          Specifies the path to the S3 location where you want to store model artifacts. Amazon
          SageMaker creates subfolders for the artifacts.

          - **KmsKeyId** *(string) --*

            The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the
            model artifacts at rest using Amazon S3 server-side encryption. The ``KmsKeyId`` can be
            any of the following formats:

            * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

            * // Amazon Resource Name (ARN) of a KMS Key
            ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            * // KMS Key Alias  ``"alias/ExampleAlias"``

            * // Amazon Resource Name (ARN) of a KMS Key Alias
            ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

            If you use a KMS key ID or an alias of your master key, the Amazon SageMaker execution
            role must include permissions to call ``kms:Encrypt`` . If you don't provide a KMS key
            ID, Amazon SageMaker uses the default KMS key for Amazon S3 for your role's account.
            Amazon SageMaker uses server-side encryption with KMS-managed keys for
            ``OutputDataConfig`` . If you use a bucket policy with an ``s3:PutObject`` permission
            that only allows objects with server-side encryption, set the condition key of
            ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For more information, see
            `KMS-Managed Encryption Keys
            <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in the
            *Amazon Simple Storage Service Developer Guide.*

            The KMS key policy must grant permission to the IAM role that you specify in your
            ``CreateTrainingJob`` , ``CreateTransformJob`` , or ``CreateHyperParameterTuningJob``
            requests. For more information, see `Using Key Policies in AWS KMS
            <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the *AWS
            Key Management Service Developer Guide* .

          - **S3OutputPath** *(string) --* **[REQUIRED]**

            Identifies the S3 path where you want Amazon SageMaker to store the model artifacts. For
            example, ``s3://bucket-name/key-name-prefix`` .

        :type ResourceConfig: dict
        :param ResourceConfig: **[REQUIRED]**

          The resources, including the ML compute instances and ML storage volumes, to use for model
          training.

          ML storage volumes store model artifacts and incremental states. Training algorithms might
          also use ML storage volumes for scratch space. If you want Amazon SageMaker to use the ML
          storage volume to store the training data, choose ``File`` as the ``TrainingInputMode`` in
          the algorithm specification. For distributed training algorithms, specify an instance
          count greater than 1.

          - **InstanceType** *(string) --* **[REQUIRED]**

            The ML compute instance type.

          - **InstanceCount** *(integer) --* **[REQUIRED]**

            The number of ML compute instances to use. For distributed training, provide a value
            greater than 1.

          - **VolumeSizeInGB** *(integer) --* **[REQUIRED]**

            The size of the ML storage volume that you want to provision.

            ML storage volumes store model artifacts and incremental states. Training algorithms
            might also use the ML storage volume for scratch space. If you want to store the
            training data in the ML storage volume, choose ``File`` as the ``TrainingInputMode`` in
            the algorithm specification.

            You must specify sufficient ML storage for your scenario.

            .. note::

              Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage volume type.

            .. note::

              Certain Nitro-based instances include local storage with a fixed total size, dependent
              on the instance type. When using these instances for training, Amazon SageMaker mounts
              the local instance storage instead of Amazon EBS gp2 storage. You can't request a
              ``VolumeSizeInGB`` greater than the total size of the local instance storage.

              For a list of instance types that support local instance storage, including the total
              size per instance type, see `Instance Store Volumes
              <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
              .

          - **VolumeKmsKeyId** *(string) --*

            The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume
            attached to the ML compute instance(s) that run the training job.

            .. note::

              Certain Nitro-based instances include local storage, dependent on the instance type.
              Local storage volumes are encrypted using a hardware module on the instance. You can't
              request a ``VolumeKmsKeyId`` when using an instance type with local storage.

              For a list of instance types that support local instance storage, see `Instance Store
              Volumes
              <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
              .

              For more information about local instance storage encryption, see `SSD Instance Store
              Volumes
              <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__ .

            The ``VolumeKmsKeyId`` can be in any of the following formats:

            * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

            * // Amazon Resource Name (ARN) of a KMS Key
            ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

        :type VpcConfig: dict
        :param VpcConfig:

          A  VpcConfig object that specifies the VPC that you want your training job to connect to.
          Control access to and from your training container by configuring the VPC. For more
          information, see `Protect Training Jobs by Using an Amazon Virtual Private Cloud
          <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

          - **SecurityGroupIds** *(list) --* **[REQUIRED]**

            The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the
            VPC that is specified in the ``Subnets`` field.

            - *(string) --*

          - **Subnets** *(list) --* **[REQUIRED]**

            The ID of the subnets in the VPC to which you want to connect your training job or
            model.

            .. note::

              Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
              availability zones of region us-east-1. If you want to create endpoints with P3
              instances in VPC mode in region us-east-1, create subnets in a/b/f availability zones
              instead.

            - *(string) --*

        :type StoppingCondition: dict
        :param StoppingCondition: **[REQUIRED]**

          Specifies a limit to how long a model training job can run. When the job reaches the time
          limit, Amazon SageMaker ends the training job. Use this API to cap model training costs.

          To stop a job, Amazon SageMaker sends the algorithm the ``SIGTERM`` signal, which delays
          job termination for 120 seconds. Algorithms can use this 120-second window to save the
          model artifacts, so the results of training are not lost.

          - **MaxRuntimeInSeconds** *(integer) --*

            The maximum length of time, in seconds, that the training or compilation job can run. If
            job does not complete during this time, Amazon SageMaker ends the job. If value is not
            specified, default value is 1 day. The maximum value is 28 days.

          - **MaxWaitTimeInSeconds** *(integer) --*

            The maximum length of time, in seconds, how long you are willing to wait for a managed
            spot training job to complete. It is the amount of time spent waiting for Spot capacity
            plus the amount of time the training job runs. It must be equal to or greater than
            ``MaxRuntimeInSeconds`` .

        :type Tags: list
        :param Tags:

          An array of key-value pairs. For more information, see `Using Cost Allocation Tags
          <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type EnableNetworkIsolation: boolean
        :param EnableNetworkIsolation:

          Isolates the training container. No inbound or outbound network calls can be made, except
          for calls between peers within a training cluster for distributed training. If you enable
          network isolation for training jobs that are configured to use a VPC, Amazon SageMaker
          downloads and uploads customer data and model artifacts through the specified VPC, but the
          training container does not have network access.

          .. note::

            The Semantic Segmentation built-in algorithm does not support network isolation.

        :type EnableInterContainerTrafficEncryption: boolean
        :param EnableInterContainerTrafficEncryption:

          To encrypt all communications between ML compute instances in distributed training, choose
          ``True`` . Encryption provides greater security for distributed training, but training
          might take longer. How long it takes depends on the amount of communication between
          compute instances, especially if you use a deep learning algorithm in distributed
          training. For more information, see `Protect Communications Between ML Compute Instances
          in a Distributed Training Job
          <https://docs.aws.amazon.com/sagemaker/latest/dg/train-encrypt.html>`__ .

        :type EnableManagedSpotTraining: boolean
        :param EnableManagedSpotTraining:

          To train models using managed spot training, choose ``True`` . Managed spot training
          provides a fully managed and scalable infrastructure for training machine learning models.
          this option is useful when training jobs can be interrupted and when there is flexibility
          when the training job is run.

          The complete and intermediate results of jobs are stored in an Amazon S3 bucket, and can
          be used as a starting point to train models incrementally. Amazon SageMaker provides
          metrics and logs in CloudWatch. They can be used to see when managed spot training jobs
          are running, interrupted, resumed, or completed.

        :type CheckpointConfig: dict
        :param CheckpointConfig:

          Contains information about the output location for managed spot training checkpoint data.

          - **S3Uri** *(string) --* **[REQUIRED]**

            Identifies the S3 path where you want Amazon SageMaker to store checkpoints. For
            example, ``s3://bucket-name/key-name-prefix`` .

          - **LocalPath** *(string) --*

            (Optional) The local directory where checkpoints are written. The default directory is
            ``/opt/ml/checkpoints/`` .

        :type DebugHookConfig: dict
        :param DebugHookConfig:

          Configuration information for the debug hook parameters, collection configuration, and
          storage paths.

          - **LocalPath** *(string) --*

            Path to local storage location for tensors. Defaults to ``/opt/ml/output/tensors/`` .

          - **S3OutputPath** *(string) --* **[REQUIRED]**

            Path to Amazon S3 storage location for tensors.

          - **HookParameters** *(dict) --*

            Configuration information for the debug hook parameters.

            - *(string) --*

              - *(string) --*

          - **CollectionConfigurations** *(list) --*

            Configuration information for tensor collections.

            - *(dict) --*

              Configuration information for tensor collections.

              - **CollectionName** *(string) --*

                The name of the tensor collection.

              - **CollectionParameters** *(dict) --*

                Parameter values for the tensor collection. The allowed parameters are ``"name"`` ,
                ``"include_regex"`` , ``"reduction_config"`` , ``"save_config"`` ,
                ``"tensor_names"`` , and ``"save_histogram"`` .

                - *(string) --*

                  - *(string) --*

        :type DebugRuleConfigurations: list
        :param DebugRuleConfigurations:

          Configuration information for debugging rules.

          - *(dict) --*

            Configuration information for debugging rules.

            - **RuleConfigurationName** *(string) --* **[REQUIRED]**

              The name of the rule configuration. It must be unique relative to other rule
              configuration names.

            - **LocalPath** *(string) --*

              Path to local storage location for rules. Defaults to
              ``/opt/ml/processing/output/rule/`` .

            - **S3OutputPath** *(string) --*

              Path to Amazon S3 storage location for rules.

            - **RuleEvaluatorImage** *(string) --* **[REQUIRED]**

              The Amazon Elastic Container (ECR) Image for the managed rule evaluation.

            - **InstanceType** *(string) --*

              The instance type to deploy for a training job.

            - **VolumeSizeInGB** *(integer) --*

              The size, in GB, of the ML storage volume attached to the notebook instance.

            - **RuleParameters** *(dict) --*

              Runtime configuration for rule container.

              - *(string) --*

                - *(string) --*

        :type TensorBoardOutputConfig: dict
        :param TensorBoardOutputConfig:

          Configuration of storage locations for TensorBoard output.

          - **LocalPath** *(string) --*

            Path to local storage location for tensorBoard output. Defaults to
            ``/opt/ml/output/tensorboard`` .

          - **S3OutputPath** *(string) --* **[REQUIRED]**

            Path to Amazon S3 storage location for TensorBoard output.

        :type ExperimentConfig: dict
        :param ExperimentConfig:

          Configuration for the experiment.

          - **ExperimentName** *(string) --*

            The name of the experiment.

          - **TrialName** *(string) --*

            The name of the trial.

          - **TrialComponentDisplayName** *(string) --*

            Display name for the trial component.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrainingJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrainingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the training job.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_transform_job(
        self,
        TransformJobName: str,
        ModelName: str,
        TransformInput: ClientCreateTransformJobTransformInputTypeDef,
        TransformOutput: ClientCreateTransformJobTransformOutputTypeDef,
        TransformResources: ClientCreateTransformJobTransformResourcesTypeDef,
        MaxConcurrentTransforms: int = None,
        MaxPayloadInMB: int = None,
        BatchStrategy: Literal["MultiRecord", "SingleRecord"] = None,
        Environment: Dict[str, str] = None,
        DataProcessing: ClientCreateTransformJobDataProcessingTypeDef = None,
        Tags: List[ClientCreateTransformJobTagsTypeDef] = None,
        ExperimentConfig: ClientCreateTransformJobExperimentConfigTypeDef = None,
    ) -> ClientCreateTransformJobResponseTypeDef:
        """
        Starts a transform job. A transform job uses a trained model to get inferences on a dataset
        and saves these results to an Amazon S3 location that you specify.

        To perform batch transformations, you create a transform job and use the data that you have
        readily available.

        In the request body, you provide the following:

        * ``TransformJobName`` - Identifies the transform job. The name must be unique within an AWS
        Region in an AWS account.

        * ``ModelName`` - Identifies the model to use. ``ModelName`` must be the name of an existing
        Amazon SageMaker model in the same AWS Region and AWS account. For information on creating a
        model, see  CreateModel .

        * ``TransformInput`` - Describes the dataset to be transformed and the Amazon S3 location
        where it is stored.

        * ``TransformOutput`` - Identifies the Amazon S3 location where you want Amazon SageMaker to
        save the results from the transform job.

        * ``TransformResources`` - Identifies the ML compute instances for the transform job.

        For more information about how batch transformation works, see `Batch Transform
        <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform.html>`__ .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateTransformJob>`_

        **Request Syntax**
        ::

          response = client.create_transform_job(
              TransformJobName='string',
              ModelName='string',
              MaxConcurrentTransforms=123,
              MaxPayloadInMB=123,
              BatchStrategy='MultiRecord'|'SingleRecord',
              Environment={
                  'string': 'string'
              },
              TransformInput={
                  'DataSource': {
                      'S3DataSource': {
                          'S3DataType': 'ManifestFile'|'S3Prefix'|'AugmentedManifestFile',
                          'S3Uri': 'string'
                      }
                  },
                  'ContentType': 'string',
                  'CompressionType': 'None'|'Gzip',
                  'SplitType': 'None'|'Line'|'RecordIO'|'TFRecord'
              },
              TransformOutput={
                  'S3OutputPath': 'string',
                  'Accept': 'string',
                  'AssembleWith': 'None'|'Line',
                  'KmsKeyId': 'string'
              },
              TransformResources={
                  'InstanceType':
                  'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                  |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                  |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                  |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                  |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge'
                  |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                  |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                  'InstanceCount': 123,
                  'VolumeKmsKeyId': 'string'
              },
              DataProcessing={
                  'InputFilter': 'string',
                  'OutputFilter': 'string',
                  'JoinSource': 'Input'|'None'
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              ExperimentConfig={
                  'ExperimentName': 'string',
                  'TrialName': 'string',
                  'TrialComponentDisplayName': 'string'
              }
          )
        :type TransformJobName: string
        :param TransformJobName: **[REQUIRED]**

          The name of the transform job. The name must be unique within an AWS Region in an AWS
          account.

        :type ModelName: string
        :param ModelName: **[REQUIRED]**

          The name of the model that you want to use for the transform job. ``ModelName`` must be
          the name of an existing Amazon SageMaker model within an AWS Region in an AWS account.

        :type MaxConcurrentTransforms: integer
        :param MaxConcurrentTransforms:

          The maximum number of parallel requests that can be sent to each instance in a transform
          job. If ``MaxConcurrentTransforms`` is set to ``0`` or left unset, Amazon SageMaker checks
          the optional execution-parameters to determine the settings for your chosen algorithm. If
          the execution-parameters endpoint is not enabled, the default value is ``1`` . For more
          information on execution-parameters, see `How Containers Serve Requests
          <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-batch-code.html#your-algorithms-batch-code-how-containe-serves-requests>`__
          . For built-in algorithms, you don't need to set a value for ``MaxConcurrentTransforms`` .

        :type MaxPayloadInMB: integer
        :param MaxPayloadInMB:

          The maximum allowed size of the payload, in MB. A *payload* is the data portion of a
          record (without metadata). The value in ``MaxPayloadInMB`` must be greater than, or equal
          to, the size of a single record. To estimate the size of a record in MB, divide the size
          of your dataset by the number of records. To ensure that the records fit within the
          maximum payload size, we recommend using a slightly larger value. The default value is
          ``6`` MB.

          For cases where the payload might be arbitrarily large and is transmitted using HTTP
          chunked encoding, set the value to ``0`` . This feature works only in supported
          algorithms. Currently, Amazon SageMaker built-in algorithms do not support HTTP chunked
          encoding.

        :type BatchStrategy: string
        :param BatchStrategy:

          Specifies the number of records to include in a mini-batch for an HTTP inference request.
          A *record*  is a single unit of input data that inference can be made on. For example, a
          single line in a CSV file is a record.

          To enable the batch strategy, you must set the ``SplitType`` property of the
          DataProcessing object to ``Line`` , ``RecordIO`` , or ``TFRecord`` .

          To use only one record when making an HTTP invocation request to a container, set
          ``BatchStrategy`` to ``SingleRecord`` and ``SplitType`` to ``Line`` .

          To fit as many records in a mini-batch as can fit within the ``MaxPayloadInMB`` limit, set
          ``BatchStrategy`` to ``MultiRecord`` and ``SplitType`` to ``Line`` .

        :type Environment: dict
        :param Environment:

          The environment variables to set in the Docker container. We support up to 16 key and
          values entries in the map.

          - *(string) --*

            - *(string) --*

        :type TransformInput: dict
        :param TransformInput: **[REQUIRED]**

          Describes the input source and the way the transform job consumes it.

          - **DataSource** *(dict) --* **[REQUIRED]**

            Describes the location of the channel data, which is, the S3 location of the input data
            that the model can consume.

            - **S3DataSource** *(dict) --* **[REQUIRED]**

              The S3 location of the data source that is associated with a channel.

              - **S3DataType** *(string) --* **[REQUIRED]**

                If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                SageMaker uses all objects with the specified key name prefix for batch transform.

                If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a manifest
                file containing a list of object keys that you want Amazon SageMaker to use for
                batch transform.

                The following values are compatible: ``ManifestFile`` , ``S3Prefix``

                The following value is not compatible: ``AugmentedManifestFile``

              - **S3Uri** *(string) --* **[REQUIRED]**

                Depending on the value specified for the ``S3DataType`` , identifies either a key
                name prefix or a manifest. For example:

                * A key name prefix might look like this: ``s3://bucketname/exampleprefix`` .

                * A manifest might look like this: ``s3://bucketname/example.manifest``   The
                manifest is an S3 object which is a JSON file with the following format:   ``[
                {"prefix": "s3://customer_bucket/some/prefix/"},``
                ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``    ``...``
                ``"relative/path/custdata-N"``    ``]``   The preceding JSON matches the following
                ``s3Uris`` :   ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete set of
                ``S3Uris`` in this manifest constitutes the input data for the channel for this
                datasource. The object that each ``S3Uris`` points to must be readable by the IAM
                role that Amazon SageMaker uses to perform tasks on your behalf.

          - **ContentType** *(string) --*

            The multipurpose internet mail extension (MIME) type of the data. Amazon SageMaker uses
            the MIME type with each http call to transfer data to the transform job.

          - **CompressionType** *(string) --*

            If your transform data is compressed, specify the compression type. Amazon SageMaker
            automatically decompresses the data for the transform job accordingly. The default value
            is ``None`` .

          - **SplitType** *(string) --*

            The method to use to split the transform job's data files into smaller batches.
            Splitting is necessary when the total size of each object is too large to fit in a
            single request. You can also use data splitting to improve performance by processing
            multiple concurrent mini-batches. The default value for ``SplitType`` is ``None`` ,
            which indicates that input data files are not split, and request payloads contain the
            entire contents of an input object. Set the value of this parameter to ``Line`` to split
            records on a newline character boundary. ``SplitType`` also supports a number of
            record-oriented binary data formats.

            When splitting is enabled, the size of a mini-batch depends on the values of the
            ``BatchStrategy`` and ``MaxPayloadInMB`` parameters. When the value of ``BatchStrategy``
            is ``MultiRecord`` , Amazon SageMaker sends the maximum number of records in each
            request, up to the ``MaxPayloadInMB`` limit. If the value of ``BatchStrategy`` is
            ``SingleRecord`` , Amazon SageMaker sends individual records in each request.

            .. note::

              Some data formats represent a record as a binary payload wrapped with extra padding
              bytes. When splitting is applied to a binary data format, padding is removed if the
              value of ``BatchStrategy`` is set to ``SingleRecord`` . Padding is not removed if the
              value of ``BatchStrategy`` is set to ``MultiRecord`` .

              For more information about ``RecordIO`` , see `Create a Dataset Using RecordIO
              <https://mxnet.apache.org/api/faq/recordio>`__ in the MXNet documentation. For more
              information about ``TFRecord`` , see `Consuming TFRecord data
              <https://www.tensorflow.org/guide/datasets#consuming_tfrecord_data>`__ in the
              TensorFlow documentation.

        :type TransformOutput: dict
        :param TransformOutput: **[REQUIRED]**

          Describes the results of the transform job.

          - **S3OutputPath** *(string) --* **[REQUIRED]**

            The Amazon S3 path where you want Amazon SageMaker to store the results of the transform
            job. For example, ``s3://bucket-name/key-name-prefix`` .

            For every S3 object used as input for the transform job, batch transform stores the
            transformed data with an .``out`` suffix in a corresponding subfolder in the location in
            the output prefix. For example, for the input data stored at
            ``s3://bucket-name/input-name-prefix/dataset01/data.csv`` , batch transform stores the
            transformed data at
            ``s3://bucket-name/output-name-prefix/input-name-prefix/data.csv.out`` . Batch transform
            doesn't upload partially processed objects. For an input S3 object that contains
            multiple records, it creates an .``out`` file only if the transform job succeeds on the
            entire file. When the input contains multiple S3 objects, the batch transform job
            processes the listed S3 objects and uploads only the output for successfully processed
            objects. If any object fails in the transform job batch transform marks the job as
            failed to prompt investigation.

          - **Accept** *(string) --*

            The MIME type used to specify the output data. Amazon SageMaker uses the MIME type with
            each http call to transfer data from the transform job.

          - **AssembleWith** *(string) --*

            Defines how to assemble the results of the transform job as a single S3 object. Choose a
            format that is most convenient to you. To concatenate the results in binary format,
            specify ``None`` . To add a newline character at the end of every transformed record,
            specify ``Line`` .

          - **KmsKeyId** *(string) --*

            The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the
            model artifacts at rest using Amazon S3 server-side encryption. The ``KmsKeyId`` can be
            any of the following formats:

            * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

            * // Amazon Resource Name (ARN) of a KMS Key
            ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            * // KMS Key Alias  ``"alias/ExampleAlias"``

            * // Amazon Resource Name (ARN) of a KMS Key Alias
            ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

            If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon
            S3 for your role's account. For more information, see `KMS-Managed Encryption Keys
            <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in the
            *Amazon Simple Storage Service Developer Guide.*

            The KMS key policy must grant permission to the IAM role that you specify in your
            CreateModel request. For more information, see `Using Key Policies in AWS KMS
            <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the *AWS
            Key Management Service Developer Guide* .

        :type TransformResources: dict
        :param TransformResources: **[REQUIRED]**

          Describes the resources, including ML instance types and ML instance count, to use for the
          transform job.

          - **InstanceType** *(string) --* **[REQUIRED]**

            The ML compute instance type for the transform job. If you are using built-in algorithms
            to transform moderately sized datasets, we recommend using ml.m4.xlarge or
            ``ml.m5.large`` instance types.

          - **InstanceCount** *(integer) --* **[REQUIRED]**

            The number of ML compute instances to use in the transform job. For distributed
            transform jobs, specify a value greater than 1. The default value is ``1`` .

          - **VolumeKmsKeyId** *(string) --*

            The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt model
            data on the storage volume attached to the ML compute instance(s) that run the batch
            transform job. The ``VolumeKmsKeyId`` can be any of the following formats:

            * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

            * // Amazon Resource Name (ARN) of a KMS Key
            ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

        :type DataProcessing: dict
        :param DataProcessing:

          The data structure used to specify the data to be used for inference in a batch transform
          job and to associate the data that is relevant to the prediction results in the output.
          The input filter provided allows you to exclude input data that is not needed for
          inference in a batch transform job. The output filter provided allows you to include input
          data relevant to interpreting the predictions in the output from the job. For more
          information, see `Associate Prediction Results with their Corresponding Input Records
          <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html>`__
          .

          - **InputFilter** *(string) --*

            A `JSONPath
            <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html#data-processing-operators>`__
            expression used to select a portion of the input data to pass to the algorithm. Use the
            ``InputFilter`` parameter to exclude fields, such as an ID column, from the input. If
            you want Amazon SageMaker to pass the entire input dataset to the algorithm, accept the
            default value ``$`` .

            Examples: ``"$"`` , ``"$[1:]"`` , ``"$.features"``

          - **OutputFilter** *(string) --*

            A `JSONPath
            <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html#data-processing-operators>`__
            expression used to select a portion of the joined dataset to save in the output file for
            a batch transform job. If you want Amazon SageMaker to store the entire input dataset in
            the output file, leave the default value, ``$`` . If you specify indexes that aren't
            within the dimension size of the joined dataset, you get an error.

            Examples: ``"$"`` , ``"$[0,5:]"`` , ``"$['id','SageMakerOutput']"``

          - **JoinSource** *(string) --*

            Specifies the source of the data to join with the transformed data. The valid values are
            ``None`` and ``Input`` . The default value is ``None`` , which specifies not to join the
            input with the transformed data. If you want the batch transform job to join the
            original input data with the transformed data, set ``JoinSource`` to ``Input`` .

            For JSON or JSONLines objects, such as a JSON array, Amazon SageMaker adds the
            transformed data to the input JSON object in an attribute called ``SageMakerOutput`` .
            The joined result for JSON must be a key-value pair object. If the input is not a
            key-value pair object, Amazon SageMaker creates a new JSON file. In the new JSON file,
            and the input data is stored under the ``SageMakerInput`` key and the results are stored
            in ``SageMakerOutput`` .

            For CSV files, Amazon SageMaker combines the transformed data with the input data at the
            end of the input data and stores it in the output file. The joined data has the joined
            input data followed by the transformed data and the output is a CSV file.

        :type Tags: list
        :param Tags:

          (Optional) An array of key-value pairs. For more information, see `Using Cost Allocation
          Tags
          <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type ExperimentConfig: dict
        :param ExperimentConfig:

          Configuration for the experiment.

          - **ExperimentName** *(string) --*

            The name of the experiment.

          - **TrialName** *(string) --*

            The name of the trial.

          - **TrialComponentDisplayName** *(string) --*

            Display name for the trial component.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TransformJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TransformJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the transform job.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_trial(
        self,
        TrialName: str,
        ExperimentName: str,
        DisplayName: str = None,
        Tags: List[ClientCreateTrialTagsTypeDef] = None,
    ) -> ClientCreateTrialResponseTypeDef:
        """
        Creates an Amazon SageMaker *trial* . A trial is a set of steps called *trial components*
        that produce a machine learning model. A trial is part of a single Amazon SageMaker
        *experiment* .

        When you use Amazon SageMaker Studio or the Amazon SageMaker Python SDK, all experiments,
        trials, and trial components are automatically tracked, logged, and indexed. When you use
        the AWS SDK for Python (Boto), you must use the logging APIs provided by the SDK.

        You can add tags to a trial and then use the  Search API to search for the tags.

        To get a list of all your trials, call the  ListTrials API. To view a trial's properties,
        call the  DescribeTrial API. To create a trial component, call the  CreateTrialComponent
        API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateTrial>`_

        **Request Syntax**
        ::

          response = client.create_trial(
              TrialName='string',
              DisplayName='string',
              ExperimentName='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type TrialName: string
        :param TrialName: **[REQUIRED]**

          The name of the trial. The name must be unique in your AWS account and is not
          case-sensitive.

        :type DisplayName: string
        :param DisplayName:

          The name of the trial as displayed. The name doesn't need to be unique. If ``DisplayName``
          isn't specified, ``TrialName`` is displayed.

        :type ExperimentName: string
        :param ExperimentName: **[REQUIRED]**

          The name of the experiment to associate the trial with.

        :type Tags: list
        :param Tags:

          A list of tags to associate with the trial. You can use  Search API to search on the tags.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_trial_component(
        self,
        TrialComponentName: str,
        DisplayName: str = None,
        Status: ClientCreateTrialComponentStatusTypeDef = None,
        StartTime: datetime = None,
        EndTime: datetime = None,
        Parameters: Dict[str, ClientCreateTrialComponentParametersTypeDef] = None,
        InputArtifacts: Dict[str, ClientCreateTrialComponentInputArtifactsTypeDef] = None,
        OutputArtifacts: Dict[str, ClientCreateTrialComponentOutputArtifactsTypeDef] = None,
        Tags: List[ClientCreateTrialComponentTagsTypeDef] = None,
    ) -> ClientCreateTrialComponentResponseTypeDef:
        """
        Creates a *trial component* , which is a stage of a machine learning *trial* . A trial is
        composed of one or more trial components. A trial component can be used in multiple trials.

        Trial components include pre-processing jobs, training jobs, and batch transform jobs.

        When you use Amazon SageMaker Studio or the Amazon SageMaker Python SDK, all experiments,
        trials, and trial components are automatically tracked, logged, and indexed. When you use
        the AWS SDK for Python (Boto), you must use the logging APIs provided by the SDK.

        You can add tags to a trial component and then use the  Search API to search for the tags.

        .. note::

          You can create a trial component through a direct call to the ``CreateTrialComponent``
          API. However, you can't specify the ``Source`` property of the component in the request,
          therefore, the component isn't associated with an Amazon SageMaker job. You must use
          Amazon SageMaker Studio, the Amazon SageMaker Python SDK, or the AWS SDK for Python (Boto)
          to create the component with a valid ``Source`` property.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateTrialComponent>`_

        **Request Syntax**
        ::

          response = client.create_trial_component(
              TrialComponentName='string',
              DisplayName='string',
              Status={
                  'PrimaryStatus': 'InProgress'|'Completed'|'Failed',
                  'Message': 'string'
              },
              StartTime=datetime(2015, 1, 1),
              EndTime=datetime(2015, 1, 1),
              Parameters={
                  'string': {
                      'StringValue': 'string',
                      'NumberValue': 123.0
                  }
              },
              InputArtifacts={
                  'string': {
                      'MediaType': 'string',
                      'Value': 'string'
                  }
              },
              OutputArtifacts={
                  'string': {
                      'MediaType': 'string',
                      'Value': 'string'
                  }
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type TrialComponentName: string
        :param TrialComponentName: **[REQUIRED]**

          The name of the component. The name must be unique in your AWS account and is not
          case-sensitive.

        :type DisplayName: string
        :param DisplayName:

          The name of the component as displayed. The name doesn't need to be unique. If
          ``DisplayName`` isn't specified, ``TrialComponentName`` is displayed.

        :type Status: dict
        :param Status:

          The status of the component. States include:

          * InProgress

          * Completed

          * Failed

          - **PrimaryStatus** *(string) --*

            The status of the trial component.

          - **Message** *(string) --*

            If the component failed, a message describing why.

        :type StartTime: datetime
        :param StartTime:

          When the component started.

        :type EndTime: datetime
        :param EndTime:

          When the component ended.

        :type Parameters: dict
        :param Parameters:

          The hyperparameters for the component.

          - *(string) --*

            - *(dict) --*

              The value of a hyperparameter. Only one of ``NumberValue`` or ``StringValue`` can be
              specified.

              This object is specified in the  CreateTrialComponent request.

              - **StringValue** *(string) --*

                The string value of a categorical hyperparameter. If you specify a value for this
                parameter, you can't specify the ``NumberValue`` parameter.

              - **NumberValue** *(float) --*

                The numeric value of a numeric hyperparameter. If you specify a value for this
                parameter, you can't specify the ``StringValue`` parameter.

        :type InputArtifacts: dict
        :param InputArtifacts:

          The input artifacts for the component. Examples of input artifacts are datasets,
          algorithms, hyperparameters, source code, and instance types.

          - *(string) --*

            - *(dict) --*

              Represents an input or output artifact of a trial component. You specify
              ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and ``OutputArtifacts``
              parameters in the  CreateTrialComponent request.

              Examples of input artifacts are datasets, algorithms, hyperparameters, source code,
              and instance types. Examples of output artifacts are metrics, snapshots, logs, and
              images.

              - **MediaType** *(string) --*

                The media type of the artifact, which indicates the type of data in the artifact
                file. The media type consists of a *type* and a *subtype* concatenated with a slash
                (/) character, for example, text/csv, image/jpeg, and s3/uri. The type specifies the
                category of the media. The subtype specifies the kind of data.

              - **Value** *(string) --* **[REQUIRED]**

                The location of the artifact.

        :type OutputArtifacts: dict
        :param OutputArtifacts:

          The output artifacts for the component. Examples of output artifacts are metrics,
          snapshots, logs, and images.

          - *(string) --*

            - *(dict) --*

              Represents an input or output artifact of a trial component. You specify
              ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and ``OutputArtifacts``
              parameters in the  CreateTrialComponent request.

              Examples of input artifacts are datasets, algorithms, hyperparameters, source code,
              and instance types. Examples of output artifacts are metrics, snapshots, logs, and
              images.

              - **MediaType** *(string) --*

                The media type of the artifact, which indicates the type of data in the artifact
                file. The media type consists of a *type* and a *subtype* concatenated with a slash
                (/) character, for example, text/csv, image/jpeg, and s3/uri. The type specifies the
                category of the media. The subtype specifies the kind of data.

              - **Value** *(string) --* **[REQUIRED]**

                The location of the artifact.

        :type Tags: list
        :param Tags:

          A list of tags to associate with the component. You can use  Search API to search on the
          tags.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialComponentArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialComponentArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial component.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_user_profile(
        self,
        DomainId: str,
        UserProfileName: str,
        SingleSignOnUserIdentifier: str = None,
        SingleSignOnUserValue: str = None,
        Tags: List[ClientCreateUserProfileTagsTypeDef] = None,
        UserSettings: ClientCreateUserProfileUserSettingsTypeDef = None,
    ) -> ClientCreateUserProfileResponseTypeDef:
        """
        Creates a new user profile. A user profile represents a single user within a Domain, and is
        the main way to reference a "person" for the purposes of sharing, reporting and other
        user-oriented features. This entity is created during on-boarding. If an administrator
        invites a person by email or imports them from SSO, a new UserProfile is automatically
        created. This entity is the primary holder of settings for an individual user and has a
        reference to the user's private Amazon Elastic File System (EFS) home directory.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateUserProfile>`_

        **Request Syntax**
        ::

          response = client.create_user_profile(
              DomainId='string',
              UserProfileName='string',
              SingleSignOnUserIdentifier='string',
              SingleSignOnUserValue='string',
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ],
              UserSettings={
                  'ExecutionRole': 'string',
                  'SecurityGroups': [
                      'string',
                  ],
                  'SharingSettings': {
                      'NotebookOutputOption': 'Allowed'|'Disabled',
                      'S3OutputPath': 'string',
                      'S3KmsKeyId': 'string'
                  },
                  'JupyterServerAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'KernelGatewayAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'TensorBoardAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  }
              }
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The ID of the associated Domain.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          A name for the UserProfile.

        :type SingleSignOnUserIdentifier: string
        :param SingleSignOnUserIdentifier:

          A specifier for the type of value specified in SingleSignOnUserValue. Currently, the only
          supported value is "UserName". If the Domain's AuthMode is SSO, this field is required. If
          the Domain's AuthMode is not SSO, this field cannot be specified.

        :type SingleSignOnUserValue: string
        :param SingleSignOnUserValue:

          The username of the associated AWS Single Sign-On User for this UserProfile. If the
          Domain's AuthMode is SSO, this field is required, and must match a valid username of a
          user in your directory. If the Domain's AuthMode is not SSO, this field cannot be
          specified.

        :type Tags: list
        :param Tags:

          Each tag consists of a key and an optional value. Tag keys must be unique per resource.

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :type UserSettings: dict
        :param UserSettings:

          A collection of settings.

          - **ExecutionRole** *(string) --*

            The execution role for the user.

          - **SecurityGroups** *(list) --*

            The security groups.

            - *(string) --*

          - **SharingSettings** *(dict) --*

            The sharing settings.

            - **NotebookOutputOption** *(string) --*

              The notebook output option.

            - **S3OutputPath** *(string) --*

              The Amazon S3 output path.

            - **S3KmsKeyId** *(string) --*

              The AWS Key Management Service encryption key ID.

          - **JupyterServerAppSettings** *(dict) --*

            The Jupyter server's app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **KernelGatewayAppSettings** *(dict) --*

            The kernel gateway app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **TensorBoardAppSettings** *(dict) --*

            The TensorBoard app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'UserProfileArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **UserProfileArn** *(string) --*

              The user profile Amazon Resource Name (ARN).
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_workteam(
        self,
        WorkteamName: str,
        MemberDefinitions: List[ClientCreateWorkteamMemberDefinitionsTypeDef],
        Description: str,
        NotificationConfiguration: ClientCreateWorkteamNotificationConfigurationTypeDef = None,
        Tags: List[ClientCreateWorkteamTagsTypeDef] = None,
    ) -> ClientCreateWorkteamResponseTypeDef:
        """
        Creates a new work team for labeling your data. A work team is defined by one or more Amazon
        Cognito user pools. You must first create the user pools before you can create a work team.

        You cannot create more than 25 work teams in an account and region.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/CreateWorkteam>`_

        **Request Syntax**
        ::

          response = client.create_workteam(
              WorkteamName='string',
              MemberDefinitions=[
                  {
                      'CognitoMemberDefinition': {
                          'UserPool': 'string',
                          'UserGroup': 'string',
                          'ClientId': 'string'
                      }
                  },
              ],
              Description='string',
              NotificationConfiguration={
                  'NotificationTopicArn': 'string'
              },
              Tags=[
                  {
                      'Key': 'string',
                      'Value': 'string'
                  },
              ]
          )
        :type WorkteamName: string
        :param WorkteamName: **[REQUIRED]**

          The name of the work team. Use this name to identify the work team.

        :type MemberDefinitions: list
        :param MemberDefinitions: **[REQUIRED]**

          A list of ``MemberDefinition`` objects that contains objects that identify the Amazon
          Cognito user pool that makes up the work team. For more information, see `Amazon Cognito
          User Pools
          <https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools.html>`__
          .

          All of the ``CognitoMemberDefinition`` objects that make up the member definition must
          have the same ``ClientId`` and ``UserPool`` values.

          - *(dict) --*

            Defines the Amazon Cognito user group that is part of a work team.

            - **CognitoMemberDefinition** *(dict) --*

              The Amazon Cognito user group that is part of the work team.

              - **UserPool** *(string) --* **[REQUIRED]**

                An identifier for a user pool. The user pool must be in the same region as the
                service that you are calling.

              - **UserGroup** *(string) --* **[REQUIRED]**

                An identifier for a user group.

              - **ClientId** *(string) --* **[REQUIRED]**

                An identifier for an application client. You must create the app client ID using
                Amazon Cognito.

        :type Description: string
        :param Description: **[REQUIRED]**

          A description of the work team.

        :type NotificationConfiguration: dict
        :param NotificationConfiguration:

          Configures notification of workers regarding available or expiring work items.

          - **NotificationTopicArn** *(string) --*

            The ARN for the SNS topic to which notifications should be published.

        :type Tags: list
        :param Tags:

          An array of key-value pairs.

          For more information, see `Resource Tag
          <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html>`__
          and `Using Cost Allocation Tags
          <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
          in the *AWS Billing and Cost Management User Guide* .

          - *(dict) --*

            Describes a tag.

            - **Key** *(string) --* **[REQUIRED]**

              The tag key.

            - **Value** *(string) --* **[REQUIRED]**

              The tag value.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'WorkteamArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **WorkteamArn** *(string) --*

              The Amazon Resource Name (ARN) of the work team. You can use this ARN to identify the
              work team.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_algorithm(self, AlgorithmName: str) -> None:
        """
        Removes the specified algorithm from your account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteAlgorithm>`_

        **Request Syntax**
        ::

          response = client.delete_algorithm(
              AlgorithmName='string'
          )
        :type AlgorithmName: string
        :param AlgorithmName: **[REQUIRED]**

          The name of the algorithm to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_app(
        self,
        DomainId: str,
        UserProfileName: str,
        AppType: Literal["JupyterServer", "KernelGateway", "TensorBoard"],
        AppName: str,
    ) -> None:
        """
        Used to stop and delete an app.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteApp>`_

        **Request Syntax**
        ::

          response = client.delete_app(
              DomainId='string',
              UserProfileName='string',
              AppType='JupyterServer'|'KernelGateway'|'TensorBoard',
              AppName='string'
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          The user profile name.

        :type AppType: string
        :param AppType: **[REQUIRED]**

          The type of app.

        :type AppName: string
        :param AppName: **[REQUIRED]**

          The name of the app.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_code_repository(self, CodeRepositoryName: str) -> None:
        """
        Deletes the specified Git repository from your account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteCodeRepository>`_

        **Request Syntax**
        ::

          response = client.delete_code_repository(
              CodeRepositoryName='string'
          )
        :type CodeRepositoryName: string
        :param CodeRepositoryName: **[REQUIRED]**

          The name of the Git repository to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_domain(
        self, DomainId: str, RetentionPolicy: ClientDeleteDomainRetentionPolicyTypeDef = None
    ) -> None:
        """
        Used to delete a domain. If you on-boarded with IAM mode, you will need to delete your
        domain to on-board again using SSO. Use with caution. All of the members of the domain will
        lose access to their EFS volume, including data, notebooks, and other artifacts.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteDomain>`_

        **Request Syntax**
        ::

          response = client.delete_domain(
              DomainId='string',
              RetentionPolicy={
                  'HomeEfsFileSystem': 'Retain'|'Delete'
              }
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type RetentionPolicy: dict
        :param RetentionPolicy:

          The retention policy for this domain, which specifies which resources will be retained
          after the Domain is deleted. By default, all resources are retained (not automatically
          deleted).

          - **HomeEfsFileSystem** *(string) --*

            The home Amazon Elastic File System (EFS).

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_endpoint(self, EndpointName: str) -> None:
        """
        Deletes an endpoint. Amazon SageMaker frees up all of the resources that were deployed when
        the endpoint was created.

        Amazon SageMaker retires any custom KMS key grants associated with the endpoint, meaning you
        don't need to use the `RevokeGrant
        <http://docs.aws.amazon.com/kms/latest/APIReference/API_RevokeGrant.html>`__ API call.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteEndpoint>`_

        **Request Syntax**
        ::

          response = client.delete_endpoint(
              EndpointName='string'
          )
        :type EndpointName: string
        :param EndpointName: **[REQUIRED]**

          The name of the endpoint that you want to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_endpoint_config(self, EndpointConfigName: str) -> None:
        """
        Deletes an endpoint configuration. The ``DeleteEndpointConfig`` API deletes only the
        specified configuration. It does not delete endpoints created using the configuration.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteEndpointConfig>`_

        **Request Syntax**
        ::

          response = client.delete_endpoint_config(
              EndpointConfigName='string'
          )
        :type EndpointConfigName: string
        :param EndpointConfigName: **[REQUIRED]**

          The name of the endpoint configuration that you want to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_experiment(self, ExperimentName: str) -> ClientDeleteExperimentResponseTypeDef:
        """
        Deletes an Amazon SageMaker experiment. All trials associated with the experiment must be
        deleted first. Use the  ListTrials API to get a list of the trials associated with the
        experiment.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteExperiment>`_

        **Request Syntax**
        ::

          response = client.delete_experiment(
              ExperimentName='string'
          )
        :type ExperimentName: string
        :param ExperimentName: **[REQUIRED]**

          The name of the experiment to delete.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExperimentArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ExperimentArn** *(string) --*

              The Amazon Resource Name (ARN) of the experiment that is being deleted.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_flow_definition(self, FlowDefinitionName: str) -> Dict[str, Any]:
        """
        Deletes the specified flow definition.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteFlowDefinition>`_

        **Request Syntax**
        ::

          response = client.delete_flow_definition(
              FlowDefinitionName='string'
          )
        :type FlowDefinitionName: string
        :param FlowDefinitionName: **[REQUIRED]**

          The name of the flow definition you are deleting.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {}
          **Response Structure**

          - *(dict) --*
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_model(self, ModelName: str) -> None:
        """
        Deletes a model. The ``DeleteModel`` API deletes only the model entry that was created in
        Amazon SageMaker when you called the `CreateModel
        <https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateModel.html>`__ API. It does not
        delete model artifacts, inference code, or the IAM role that you specified when creating the
        model.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteModel>`_

        **Request Syntax**
        ::

          response = client.delete_model(
              ModelName='string'
          )
        :type ModelName: string
        :param ModelName: **[REQUIRED]**

          The name of the model to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_model_package(self, ModelPackageName: str) -> None:
        """
        Deletes a model package.

        A model package is used to create Amazon SageMaker models or list on AWS Marketplace. Buyers
        can subscribe to model packages listed on AWS Marketplace to create models in Amazon
        SageMaker.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteModelPackage>`_

        **Request Syntax**
        ::

          response = client.delete_model_package(
              ModelPackageName='string'
          )
        :type ModelPackageName: string
        :param ModelPackageName: **[REQUIRED]**

          The name of the model package. The name must have 1 to 63 characters. Valid characters are
          a-z, A-Z, 0-9, and - (hyphen).

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_monitoring_schedule(self, MonitoringScheduleName: str) -> None:
        """
        Deletes a monitoring schedule. Also stops the schedule had not already been stopped. This
        does not delete the job execution history of the monitoring schedule.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteMonitoringSchedule>`_

        **Request Syntax**
        ::

          response = client.delete_monitoring_schedule(
              MonitoringScheduleName='string'
          )
        :type MonitoringScheduleName: string
        :param MonitoringScheduleName: **[REQUIRED]**

          The name of the monitoring schedule to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_notebook_instance(self, NotebookInstanceName: str) -> None:
        """
        Deletes an Amazon SageMaker notebook instance. Before you can delete a notebook instance,
        you must call the ``StopNotebookInstance`` API.

        .. warning::

          When you delete a notebook instance, you lose all of your data. Amazon SageMaker removes
          the ML compute instance, and deletes the ML storage volume and the network interface
          associated with the notebook instance.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteNotebookInstance>`_

        **Request Syntax**
        ::

          response = client.delete_notebook_instance(
              NotebookInstanceName='string'
          )
        :type NotebookInstanceName: string
        :param NotebookInstanceName: **[REQUIRED]**

          The name of the Amazon SageMaker notebook instance to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_notebook_instance_lifecycle_config(
        self, NotebookInstanceLifecycleConfigName: str
    ) -> None:
        """
        Deletes a notebook instance lifecycle configuration.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteNotebookInstanceLifecycleConfig>`_

        **Request Syntax**
        ::

          response = client.delete_notebook_instance_lifecycle_config(
              NotebookInstanceLifecycleConfigName='string'
          )
        :type NotebookInstanceLifecycleConfigName: string
        :param NotebookInstanceLifecycleConfigName: **[REQUIRED]**

          The name of the lifecycle configuration to delete.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_tags(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
        """
        Deletes the specified tags from an Amazon SageMaker resource.

        To list a resource's tags, use the ``ListTags`` API.

        .. note::

          When you call this API to delete tags from a hyperparameter tuning job, the deleted tags
          are not removed from training jobs that the hyperparameter tuning job launched before you
          called this API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteTags>`_

        **Request Syntax**
        ::

          response = client.delete_tags(
              ResourceArn='string',
              TagKeys=[
                  'string',
              ]
          )
        :type ResourceArn: string
        :param ResourceArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the resource whose tags you want to delete.

        :type TagKeys: list
        :param TagKeys: **[REQUIRED]**

          An array or one or more tag keys to delete.

          - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {}
          **Response Structure**

          - *(dict) --*
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_trial(self, TrialName: str) -> ClientDeleteTrialResponseTypeDef:
        """
        Deletes the specified trial. All trial components that make up the trial must be deleted
        first. Use the  DescribeTrialComponent API to get the list of trial components.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteTrial>`_

        **Request Syntax**
        ::

          response = client.delete_trial(
              TrialName='string'
          )
        :type TrialName: string
        :param TrialName: **[REQUIRED]**

          The name of the trial to delete.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial that is being deleted.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_trial_component(
        self, TrialComponentName: str
    ) -> ClientDeleteTrialComponentResponseTypeDef:
        """
        Deletes the specified trial component. A trial component must be disassociated from all
        trials before the trial component can be deleted. To disassociate a trial component from a
        trial, call the  DisassociateTrialComponent API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteTrialComponent>`_

        **Request Syntax**
        ::

          response = client.delete_trial_component(
              TrialComponentName='string'
          )
        :type TrialComponentName: string
        :param TrialComponentName: **[REQUIRED]**

          The name of the component to delete.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialComponentArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialComponentArn** *(string) --*

              The Amazon Resource Name (ARN) of the component is being deleted.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_user_profile(self, DomainId: str, UserProfileName: str) -> None:
        """
        Deletes a user profile.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteUserProfile>`_

        **Request Syntax**
        ::

          response = client.delete_user_profile(
              DomainId='string',
              UserProfileName='string'
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          The user profile name.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_workteam(self, WorkteamName: str) -> ClientDeleteWorkteamResponseTypeDef:
        """
        Deletes an existing work team. This operation can't be undone.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DeleteWorkteam>`_

        **Request Syntax**
        ::

          response = client.delete_workteam(
              WorkteamName='string'
          )
        :type WorkteamName: string
        :param WorkteamName: **[REQUIRED]**

          The name of the work team to delete.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Success': True|False
            }
          **Response Structure**

          - *(dict) --*

            - **Success** *(boolean) --*

              Returns ``true`` if the work team was successfully deleted; otherwise, returns
              ``false`` .
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_algorithm(self, AlgorithmName: str) -> ClientDescribeAlgorithmResponseTypeDef:
        """
        Returns a description of the specified algorithm that is in your account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeAlgorithm>`_

        **Request Syntax**
        ::

          response = client.describe_algorithm(
              AlgorithmName='string'
          )
        :type AlgorithmName: string
        :param AlgorithmName: **[REQUIRED]**

          The name of the algorithm to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AlgorithmName': 'string',
                'AlgorithmArn': 'string',
                'AlgorithmDescription': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'TrainingSpecification': {
                    'TrainingImage': 'string',
                    'TrainingImageDigest': 'string',
                    'SupportedHyperParameters': [
                        {
                            'Name': 'string',
                            'Description': 'string',
                            'Type': 'Integer'|'Continuous'|'Categorical'|'FreeText',
                            'Range': {
                                'IntegerParameterRangeSpecification': {
                                    'MinValue': 'string',
                                    'MaxValue': 'string'
                                },
                                'ContinuousParameterRangeSpecification': {
                                    'MinValue': 'string',
                                    'MaxValue': 'string'
                                },
                                'CategoricalParameterRangeSpecification': {
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'IsTunable': True|False,
                            'IsRequired': True|False,
                            'DefaultValue': 'string'
                        },
                    ],
                    'SupportedTrainingInstanceTypes': [
                        'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                        |'ml.m4.16xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                        |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'
                        |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'
                        |'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                        |'ml.p3.16xlarge'|'ml.p3dn.24xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                        |'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge',
                    ],
                    'SupportsDistributedTraining': True|False,
                    'MetricDefinitions': [
                        {
                            'Name': 'string',
                            'Regex': 'string'
                        },
                    ],
                    'TrainingChannels': [
                        {
                            'Name': 'string',
                            'Description': 'string',
                            'IsRequired': True|False,
                            'SupportedContentTypes': [
                                'string',
                            ],
                            'SupportedCompressionTypes': [
                                'None'|'Gzip',
                            ],
                            'SupportedInputModes': [
                                'Pipe'|'File',
                            ]
                        },
                    ],
                    'SupportedTuningJobObjectiveMetrics': [
                        {
                            'Type': 'Maximize'|'Minimize',
                            'MetricName': 'string'
                        },
                    ]
                },
                'InferenceSpecification': {
                    'Containers': [
                        {
                            'ContainerHostname': 'string',
                            'Image': 'string',
                            'ImageDigest': 'string',
                            'ModelDataUrl': 'string',
                            'ProductId': 'string'
                        },
                    ],
                    'SupportedTransformInstanceTypes': [
                        'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                        |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                        |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                        |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge'
                        |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                    ],
                    'SupportedRealtimeInferenceInstanceTypes': [
                        'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'|'ml.m4.xlarge'
                        |'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'|'ml.m4.16xlarge'
                        |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.m5d.large'|'ml.m5d.xlarge'
                        |'ml.m5d.2xlarge'|'ml.m5d.4xlarge'|'ml.m5d.12xlarge'|'ml.m5d.24xlarge'
                        |'ml.c4.large'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                        |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.large'
                        |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                        |'ml.c5.18xlarge'|'ml.c5d.large'|'ml.c5d.xlarge'|'ml.c5d.2xlarge'
                        |'ml.c5d.4xlarge'|'ml.c5d.9xlarge'|'ml.c5d.18xlarge'|'ml.g4dn.xlarge'
                        |'ml.g4dn.2xlarge'|'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                        |'ml.g4dn.16xlarge'|'ml.r5.large'|'ml.r5.xlarge'|'ml.r5.2xlarge'
                        |'ml.r5.4xlarge'|'ml.r5.12xlarge'|'ml.r5.24xlarge'|'ml.r5d.large'
                        |'ml.r5d.xlarge'|'ml.r5d.2xlarge'|'ml.r5d.4xlarge'|'ml.r5d.12xlarge'
                        |'ml.r5d.24xlarge'|'ml.inf1.xlarge'|'ml.inf1.2xlarge'|'ml.inf1.6xlarge'
                        |'ml.inf1.24xlarge',
                    ],
                    'SupportedContentTypes': [
                        'string',
                    ],
                    'SupportedResponseMIMETypes': [
                        'string',
                    ]
                },
                'ValidationSpecification': {
                    'ValidationRole': 'string',
                    'ValidationProfiles': [
                        {
                            'ProfileName': 'string',
                            'TrainingJobDefinition': {
                                'TrainingInputMode': 'Pipe'|'File',
                                'HyperParameters': {
                                    'string': 'string'
                                },
                                'InputDataConfig': [
                                    {
                                        'ChannelName': 'string',
                                        'DataSource': {
                                            'S3DataSource': {
                                                'S3DataType':
                                                'ManifestFile'|'S3Prefix'
                                                |'AugmentedManifestFile',
                                                'S3Uri': 'string',
                                                'S3DataDistributionType':
                                                'FullyReplicated'
                                                |'ShardedByS3Key',
                                                'AttributeNames': [
                                                    'string',
                                                ]
                                            },
                                            'FileSystemDataSource': {
                                                'FileSystemId': 'string',
                                                'FileSystemAccessMode': 'rw'|'ro',
                                                'FileSystemType': 'EFS'|'FSxLustre',
                                                'DirectoryPath': 'string'
                                            }
                                        },
                                        'ContentType': 'string',
                                        'CompressionType': 'None'|'Gzip',
                                        'RecordWrapperType': 'None'|'RecordIO',
                                        'InputMode': 'Pipe'|'File',
                                        'ShuffleConfig': {
                                            'Seed': 123
                                        }
                                    },
                                ],
                                'OutputDataConfig': {
                                    'KmsKeyId': 'string',
                                    'S3OutputPath': 'string'
                                },
                                'ResourceConfig': {
                                    'InstanceType':
                                    'ml.m4.xlarge'|'ml.m4.2xlarge'
                                    |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                    |'ml.m4.16xlarge'|'ml.m5.large'
                                    |'ml.m5.xlarge'|'ml.m5.2xlarge'
                                    |'ml.m5.4xlarge'|'ml.m5.12xlarge'
                                    |'ml.m5.24xlarge'|'ml.c4.xlarge'
                                    |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                    |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                    |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                    |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                    |'ml.p3.16xlarge'|'ml.p3dn.24xlarge'
                                    |'ml.c5.xlarge'|'ml.c5.2xlarge'
                                    |'ml.c5.4xlarge'|'ml.c5.9xlarge'
                                    |'ml.c5.18xlarge',
                                    'InstanceCount': 123,
                                    'VolumeSizeInGB': 123,
                                    'VolumeKmsKeyId': 'string'
                                },
                                'StoppingCondition': {
                                    'MaxRuntimeInSeconds': 123,
                                    'MaxWaitTimeInSeconds': 123
                                }
                            },
                            'TransformJobDefinition': {
                                'MaxConcurrentTransforms': 123,
                                'MaxPayloadInMB': 123,
                                'BatchStrategy': 'MultiRecord'|'SingleRecord',
                                'Environment': {
                                    'string': 'string'
                                },
                                'TransformInput': {
                                    'DataSource': {
                                        'S3DataSource': {
                                            'S3DataType':
                                            'ManifestFile'
                                            |'S3Prefix'
                                            |'AugmentedManifestFile',
                                            'S3Uri': 'string'
                                        }
                                    },
                                    'ContentType': 'string',
                                    'CompressionType': 'None'|'Gzip',
                                    'SplitType': 'None'|'Line'|'RecordIO'|'TFRecord'
                                },
                                'TransformOutput': {
                                    'S3OutputPath': 'string',
                                    'Accept': 'string',
                                    'AssembleWith': 'None'|'Line',
                                    'KmsKeyId': 'string'
                                },
                                'TransformResources': {
                                    'InstanceType':
                                    'ml.m4.xlarge'|'ml.m4.2xlarge'
                                    |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                    |'ml.m4.16xlarge'|'ml.c4.xlarge'
                                    |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                    |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                    |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                    |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                    |'ml.p3.16xlarge'|'ml.c5.xlarge'
                                    |'ml.c5.2xlarge'|'ml.c5.4xlarge'
                                    |'ml.c5.9xlarge'|'ml.c5.18xlarge'
                                    |'ml.m5.large'|'ml.m5.xlarge'
                                    |'ml.m5.2xlarge'|'ml.m5.4xlarge'
                                    |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                                    'InstanceCount': 123,
                                    'VolumeKmsKeyId': 'string'
                                }
                            }
                        },
                    ]
                },
                'AlgorithmStatus': 'Pending'|'InProgress'|'Completed'|'Failed'|'Deleting',
                'AlgorithmStatusDetails': {
                    'ValidationStatuses': [
                        {
                            'Name': 'string',
                            'Status': 'NotStarted'|'InProgress'|'Completed'|'Failed',
                            'FailureReason': 'string'
                        },
                    ],
                    'ImageScanStatuses': [
                        {
                            'Name': 'string',
                            'Status': 'NotStarted'|'InProgress'|'Completed'|'Failed',
                            'FailureReason': 'string'
                        },
                    ]
                },
                'ProductId': 'string',
                'CertifyForMarketplace': True|False
            }
          **Response Structure**

          - *(dict) --*

            - **AlgorithmName** *(string) --*

              The name of the algorithm being described.

            - **AlgorithmArn** *(string) --*

              The Amazon Resource Name (ARN) of the algorithm.

            - **AlgorithmDescription** *(string) --*

              A brief summary about the algorithm.

            - **CreationTime** *(datetime) --*

              A timestamp specifying when the algorithm was created.

            - **TrainingSpecification** *(dict) --*

              Details about training jobs run by this algorithm.

              - **TrainingImage** *(string) --*

                The Amazon ECR registry path of the Docker image that contains the training
                algorithm.

              - **TrainingImageDigest** *(string) --*

                An MD5 hash of the training algorithm that identifies the Docker image used for
                training.

              - **SupportedHyperParameters** *(list) --*

                A list of the ``HyperParameterSpecification`` objects, that define the supported
                hyperparameters. This is required if the algorithm supports automatic model tuning.>

                - *(dict) --*

                  Defines a hyperparameter to be used by an algorithm.

                  - **Name** *(string) --*

                    The name of this hyperparameter. The name must be unique.

                  - **Description** *(string) --*

                    A brief description of the hyperparameter.

                  - **Type** *(string) --*

                    The type of this hyperparameter. The valid types are ``Integer`` ,
                    ``Continuous`` , ``Categorical`` , and ``FreeText`` .

                  - **Range** *(dict) --*

                    The allowed range for this hyperparameter.

                    - **IntegerParameterRangeSpecification** *(dict) --*

                      A ``IntegerParameterRangeSpecification`` object that defines the possible
                      values for an integer hyperparameter.

                      - **MinValue** *(string) --*

                        The minimum integer value allowed.

                      - **MaxValue** *(string) --*

                        The maximum integer value allowed.

                    - **ContinuousParameterRangeSpecification** *(dict) --*

                      A ``ContinuousParameterRangeSpecification`` object that defines the possible
                      values for a continuous hyperparameter.

                      - **MinValue** *(string) --*

                        The minimum floating-point value allowed.

                      - **MaxValue** *(string) --*

                        The maximum floating-point value allowed.

                    - **CategoricalParameterRangeSpecification** *(dict) --*

                      A ``CategoricalParameterRangeSpecification`` object that defines the possible
                      values for a categorical hyperparameter.

                      - **Values** *(list) --*

                        The allowed categories for the hyperparameter.

                        - *(string) --*

                  - **IsTunable** *(boolean) --*

                    Indicates whether this hyperparameter is tunable in a hyperparameter tuning job.

                  - **IsRequired** *(boolean) --*

                    Indicates whether this hyperparameter is required.

                  - **DefaultValue** *(string) --*

                    The default value for this hyperparameter. If a default value is specified, a
                    hyperparameter cannot be required.

              - **SupportedTrainingInstanceTypes** *(list) --*

                A list of the instance types that this algorithm can use for training.

                - *(string) --*

              - **SupportsDistributedTraining** *(boolean) --*

                Indicates whether the algorithm supports distributed training. If set to false,
                buyers can't request more than one instance during training.

              - **MetricDefinitions** *(list) --*

                A list of ``MetricDefinition`` objects, which are used for parsing metrics generated
                by the algorithm.

                - *(dict) --*

                  Specifies a metric that the training algorithm writes to ``stderr`` or ``stdout``
                  . Amazon SageMakerhyperparameter tuning captures all defined metrics. You specify
                  one metric that a hyperparameter tuning job uses as its objective metric to choose
                  the best training job.

                  - **Name** *(string) --*

                    The name of the metric.

                  - **Regex** *(string) --*

                    A regular expression that searches the output of a training job and gets the
                    value of the metric. For more information about using regular expressions to
                    define metrics, see `Defining Objective Metrics
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                    .

              - **TrainingChannels** *(list) --*

                A list of ``ChannelSpecification`` objects, which specify the input sources to be
                used by the algorithm.

                - *(dict) --*

                  Defines a named input source, called a channel, to be used by an algorithm.

                  - **Name** *(string) --*

                    The name of the channel.

                  - **Description** *(string) --*

                    A brief description of the channel.

                  - **IsRequired** *(boolean) --*

                    Indicates whether the channel is required by the algorithm.

                  - **SupportedContentTypes** *(list) --*

                    The supported MIME types for the data.

                    - *(string) --*

                  - **SupportedCompressionTypes** *(list) --*

                    The allowed compression types, if data compression is used.

                    - *(string) --*

                  - **SupportedInputModes** *(list) --*

                    The allowed input mode, either FILE or PIPE.

                    In FILE mode, Amazon SageMaker copies the data from the input source onto the
                    local Amazon Elastic Block Store (Amazon EBS) volumes before starting your
                    training algorithm. This is the most commonly used input mode.

                    In PIPE mode, Amazon SageMaker streams input data from the source directly to
                    your algorithm without using the EBS volume.

                    - *(string) --*

              - **SupportedTuningJobObjectiveMetrics** *(list) --*

                A list of the metrics that the algorithm emits that can be used as the objective
                metric in a hyperparameter tuning job.

                - *(dict) --*

                  Defines the objective metric for a hyperparameter tuning job. Hyperparameter
                  tuning uses the value of this metric to evaluate the training jobs it launches,
                  and returns the training job that results in either the highest or lowest value
                  for this metric, depending on the value you specify for the ``Type`` parameter.

                  - **Type** *(string) --*

                    Whether to minimize or maximize the objective metric.

                  - **MetricName** *(string) --*

                    The name of the metric to use for the objective metric.

            - **InferenceSpecification** *(dict) --*

              Details about inference jobs that the algorithm runs.

              - **Containers** *(list) --*

                The Amazon ECR registry path of the Docker image that contains the inference code.

                - *(dict) --*

                  Describes the Docker container for the model package.

                  - **ContainerHostname** *(string) --*

                    The DNS host name for the Docker container.

                  - **Image** *(string) --*

                    The Amazon EC2 Container Registry (Amazon ECR) path where inference code is
                    stored.

                    If you are using your own custom algorithm instead of an algorithm provided by
                    Amazon SageMaker, the inference code must meet Amazon SageMaker requirements.
                    Amazon SageMaker supports both ``registry/repository[:tag]`` and
                    ``registry/repository[@digest]`` image path formats. For more information, see
                    `Using Your Own Algorithms with Amazon SageMaker
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

                  - **ImageDigest** *(string) --*

                    An MD5 hash of the training algorithm that identifies the Docker image used for
                    training.

                  - **ModelDataUrl** *(string) --*

                    The Amazon S3 path where the model artifacts, which result from model training,
                    are stored. This path must point to a single ``gzip`` compressed tar archive
                    (``.tar.gz`` suffix).

                  - **ProductId** *(string) --*

                    The AWS Marketplace product ID of the model package.

              - **SupportedTransformInstanceTypes** *(list) --*

                A list of the instance types on which a transformation job can be run or on which an
                endpoint can be deployed.

                - *(string) --*

              - **SupportedRealtimeInferenceInstanceTypes** *(list) --*

                A list of the instance types that are used to generate inferences in real-time.

                - *(string) --*

              - **SupportedContentTypes** *(list) --*

                The supported MIME types for the input data.

                - *(string) --*

              - **SupportedResponseMIMETypes** *(list) --*

                The supported MIME types for the output data.

                - *(string) --*

            - **ValidationSpecification** *(dict) --*

              Details about configurations for one or more training jobs that Amazon SageMaker runs
              to test the algorithm.

              - **ValidationRole** *(string) --*

                The IAM roles that Amazon SageMaker uses to run the training jobs.

              - **ValidationProfiles** *(list) --*

                An array of ``AlgorithmValidationProfile`` objects, each of which specifies a
                training job and batch transform job that Amazon SageMaker runs to validate your
                algorithm.

                - *(dict) --*

                  Defines a training job and a batch transform job that Amazon SageMaker runs to
                  validate your algorithm.

                  The data provided in the validation profile is made available to your buyers on
                  AWS Marketplace.

                  - **ProfileName** *(string) --*

                    The name of the profile for the algorithm. The name must have 1 to 63
                    characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).

                  - **TrainingJobDefinition** *(dict) --*

                    The ``TrainingJobDefinition`` object that describes the training job that Amazon
                    SageMaker runs to validate your algorithm.

                    - **TrainingInputMode** *(string) --*

                      The input mode used by the algorithm for the training job. For the input modes
                      that Amazon SageMaker algorithms support, see `Algorithms
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

                      If an algorithm supports the ``File`` input mode, Amazon SageMaker downloads
                      the training data from S3 to the provisioned ML storage Volume, and mounts the
                      directory to docker volume for training container. If an algorithm supports
                      the ``Pipe`` input mode, Amazon SageMaker streams data directly from S3 to the
                      container.

                    - **HyperParameters** *(dict) --*

                      The hyperparameters used for the training job.

                      - *(string) --*

                        - *(string) --*

                    - **InputDataConfig** *(list) --*

                      An array of ``Channel`` objects, each of which specifies an input source.

                      - *(dict) --*

                        A channel is a named input source that training algorithms can consume.

                        - **ChannelName** *(string) --*

                          The name of the channel.

                        - **DataSource** *(dict) --*

                          The location of the channel data.

                          - **S3DataSource** *(dict) --*

                            The S3 location of the data source that is associated with a channel.

                            - **S3DataType** *(string) --*

                              If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix.
                              Amazon SageMaker uses all objects that match the specified key name
                              prefix for model training.

                              If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that
                              is a manifest file containing a list of object keys that you want
                              Amazon SageMaker to use for model training.

                              If you choose ``AugmentedManifestFile`` , S3Uri identifies an object
                              that is an augmented manifest file in JSON lines format. This file
                              contains the data you want to use for model training.
                              ``AugmentedManifestFile`` can only be used if the Channel's input mode
                              is ``Pipe`` .

                            - **S3Uri** *(string) --*

                              Depending on the value specified for the ``S3DataType`` , identifies
                              either a key name prefix or a manifest. For example:

                              * A key name prefix might look like this:
                              ``s3://bucketname/exampleprefix`` .

                              * A manifest might look like this:
                              ``s3://bucketname/example.manifest``   The manifest is an S3 object
                              which is a JSON file with the following format:  The preceding JSON
                              matches the following ``s3Uris`` :   ``[ {"prefix":
                              "s3://customer_bucket/some/prefix/"},``
                              ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                              ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding
                              JSON matches the following ``s3Uris`` :
                              ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                              ``s3://customer_bucket/some/prefix/relative/path/custdata-2``
                              ``...``
                              ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The
                              complete set of ``s3uris`` in this manifest is the input data for the
                              channel for this datasource. The object that each ``s3uris`` points to
                              must be readable by the IAM role that Amazon SageMaker uses to perform
                              tasks on your behalf.

                            - **S3DataDistributionType** *(string) --*

                              If you want Amazon SageMaker to replicate the entire dataset on each
                              ML compute instance that is launched for model training, specify
                              ``FullyReplicated`` .

                              If you want Amazon SageMaker to replicate a subset of data on each ML
                              compute instance that is launched for model training, specify
                              ``ShardedByS3Key`` . If there are *n* ML compute instances launched
                              for a training job, each instance gets approximately 1/*n* of the
                              number of S3 objects. In this case, model training on each machine
                              uses only the subset of training data.

                              Don't choose more ML compute instances for training than available S3
                              objects. If you do, some nodes won't get any data and you will pay for
                              nodes that aren't getting any training data. This applies in both File
                              and Pipe modes. Keep this in mind when developing algorithms.

                              In distributed training, where you use multiple ML compute EC2
                              instances, you might choose ``ShardedByS3Key`` . If the algorithm
                              requires copying training data to the ML storage volume (when
                              ``TrainingInputMode`` is set to ``File`` ), this copies 1/*n* of the
                              number of objects.

                            - **AttributeNames** *(list) --*

                              A list of one or more attribute names to use that are found in a
                              specified augmented manifest file.

                              - *(string) --*

                          - **FileSystemDataSource** *(dict) --*

                            The file system that is associated with a channel.

                            - **FileSystemId** *(string) --*

                              The file system id.

                            - **FileSystemAccessMode** *(string) --*

                              The access mode of the mount of the directory associated with the
                              channel. A directory can be mounted either in ``ro`` (read-only) or
                              ``rw`` (read-write) mode.

                            - **FileSystemType** *(string) --*

                              The file system type.

                            - **DirectoryPath** *(string) --*

                              The full path to the directory to associate with the channel.

                        - **ContentType** *(string) --*

                          The MIME type of the data.

                        - **CompressionType** *(string) --*

                          If training data is compressed, the compression type. The default value is
                          ``None`` . ``CompressionType`` is used only in Pipe input mode. In File
                          mode, leave this field unset or set it to None.

                        - **RecordWrapperType** *(string) --*

                          Specify RecordIO as the value when input data is in raw format but the
                          training algorithm requires the RecordIO format. In this case, Amazon
                          SageMaker wraps each individual S3 object in a RecordIO record. If the
                          input data is already in RecordIO format, you don't need to set this
                          attribute. For more information, see `Create a Dataset Using RecordIO
                          <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__
                          .

                          In File mode, leave this field unset or set it to None.

                        - **InputMode** *(string) --*

                          (Optional) The input mode to use for the data channel in a training job.
                          If you don't set a value for ``InputMode`` , Amazon SageMaker uses the
                          value set for ``TrainingInputMode`` . Use this parameter to override the
                          ``TrainingInputMode`` setting in a  AlgorithmSpecification request when
                          you have a channel that needs a different input mode from the training
                          job's general setting. To download the data from Amazon Simple Storage
                          Service (Amazon S3) to the provisioned ML storage volume, and mount the
                          directory to a Docker volume, use ``File`` input mode. To stream data
                          directly from Amazon S3 to the container, choose ``Pipe`` input mode.

                          To use a model for incremental training, choose ``File`` input model.

                        - **ShuffleConfig** *(dict) --*

                          A configuration for a shuffle option for input data in a channel. If you
                          use ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3
                          key prefix matches. If you use ``ManifestFile`` , the order of the S3
                          object references in the ``ManifestFile`` is shuffled. If you use
                          ``AugmentedManifestFile`` , the order of the JSON lines in the
                          ``AugmentedManifestFile`` is shuffled. The shuffling order is determined
                          using the ``Seed`` value.

                          For Pipe input mode, shuffling is done at the start of every epoch. With
                          large datasets this ensures that the order of the training data is
                          different for each epoch, it helps reduce bias and possible overfitting.
                          In a multi-node training job when ShuffleConfig is combined with
                          ``S3DataDistributionType`` of ``ShardedByS3Key`` , the data is shuffled
                          across nodes so that the content sent to a particular node on the first
                          epoch might be sent to a different node on the second epoch.

                          - **Seed** *(integer) --*

                            Determines the shuffling order in ``ShuffleConfig`` value.

                    - **OutputDataConfig** *(dict) --*

                      the path to the S3 bucket where you want to store model artifacts. Amazon
                      SageMaker creates subfolders for the artifacts.

                      - **KmsKeyId** *(string) --*

                        The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                        encrypt the model artifacts at rest using Amazon S3 server-side encryption.
                        The ``KmsKeyId`` can be any of the following formats:

                        * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // Amazon Resource Name (ARN) of a KMS Key
                        ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // KMS Key Alias  ``"alias/ExampleAlias"``

                        * // Amazon Resource Name (ARN) of a KMS Key Alias
                        ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                        If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                        execution role must include permissions to call ``kms:Encrypt`` . If you
                        don't provide a KMS key ID, Amazon SageMaker uses the default KMS key for
                        Amazon S3 for your role's account. Amazon SageMaker uses server-side
                        encryption with KMS-managed keys for ``OutputDataConfig`` . If you use a
                        bucket policy with an ``s3:PutObject`` permission that only allows objects
                        with server-side encryption, set the condition key of
                        ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For more information,
                        see `KMS-Managed Encryption Keys
                        <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__
                        in the *Amazon Simple Storage Service Developer Guide.*

                        The KMS key policy must grant permission to the IAM role that you specify in
                        your ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                        ``CreateHyperParameterTuningJob`` requests. For more information, see `Using
                        Key Policies in AWS KMS
                        <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__
                        in the *AWS Key Management Service Developer Guide* .

                      - **S3OutputPath** *(string) --*

                        Identifies the S3 path where you want Amazon SageMaker to store the model
                        artifacts. For example, ``s3://bucket-name/key-name-prefix`` .

                    - **ResourceConfig** *(dict) --*

                      The resources, including the ML compute instances and ML storage volumes, to
                      use for model training.

                      - **InstanceType** *(string) --*

                        The ML compute instance type.

                      - **InstanceCount** *(integer) --*

                        The number of ML compute instances to use. For distributed training, provide
                        a value greater than 1.

                      - **VolumeSizeInGB** *(integer) --*

                        The size of the ML storage volume that you want to provision.

                        ML storage volumes store model artifacts and incremental states. Training
                        algorithms might also use the ML storage volume for scratch space. If you
                        want to store the training data in the ML storage volume, choose ``File`` as
                        the ``TrainingInputMode`` in the algorithm specification.

                        You must specify sufficient ML storage for your scenario.

                        .. note::

                          Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage
                          volume type.

                        .. note::

                          Certain Nitro-based instances include local storage with a fixed total
                          size, dependent on the instance type. When using these instances for
                          training, Amazon SageMaker mounts the local instance storage instead of
                          Amazon EBS gp2 storage. You can't request a ``VolumeSizeInGB`` greater
                          than the total size of the local instance storage.

                          For a list of instance types that support local instance storage,
                          including the total size per instance type, see `Instance Store Volumes
                          <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                          .

                      - **VolumeKmsKeyId** *(string) --*

                        The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage
                        volume attached to the ML compute instance(s) that run the training job.

                        .. note::

                          Certain Nitro-based instances include local storage, dependent on the
                          instance type. Local storage volumes are encrypted using a hardware module
                          on the instance. You can't request a ``VolumeKmsKeyId`` when using an
                          instance type with local storage.

                          For a list of instance types that support local instance storage, see
                          `Instance Store Volumes
                          <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                          .

                          For more information about local instance storage encryption, see `SSD
                          Instance Store Volumes
                          <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__
                          .

                        The ``VolumeKmsKeyId`` can be in any of the following formats:

                        * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // Amazon Resource Name (ARN) of a KMS Key
                        ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                    - **StoppingCondition** *(dict) --*

                      Specifies a limit to how long a model training job can run. When the job
                      reaches the time limit, Amazon SageMaker ends the training job. Use this API
                      to cap model training costs.

                      To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which
                      delays job termination for 120 seconds. Algorithms can use this 120-second
                      window to save the model artifacts.

                      - **MaxRuntimeInSeconds** *(integer) --*

                        The maximum length of time, in seconds, that the training or compilation job
                        can run. If job does not complete during this time, Amazon SageMaker ends
                        the job. If value is not specified, default value is 1 day. The maximum
                        value is 28 days.

                      - **MaxWaitTimeInSeconds** *(integer) --*

                        The maximum length of time, in seconds, how long you are willing to wait for
                        a managed spot training job to complete. It is the amount of time spent
                        waiting for Spot capacity plus the amount of time the training job runs. It
                        must be equal to or greater than ``MaxRuntimeInSeconds`` .

                  - **TransformJobDefinition** *(dict) --*

                    The ``TransformJobDefinition`` object that describes the transform job that
                    Amazon SageMaker runs to validate your algorithm.

                    - **MaxConcurrentTransforms** *(integer) --*

                      The maximum number of parallel requests that can be sent to each instance in a
                      transform job. The default value is 1.

                    - **MaxPayloadInMB** *(integer) --*

                      The maximum payload size allowed, in MB. A payload is the data portion of a
                      record (without metadata).

                    - **BatchStrategy** *(string) --*

                      A string that determines the number of records included in a single
                      mini-batch.

                       ``SingleRecord`` means only one record is used per mini-batch.
                       ``MultiRecord`` means a mini-batch is set to contain as many records that can
                       fit within the ``MaxPayloadInMB`` limit.

                    - **Environment** *(dict) --*

                      The environment variables to set in the Docker container. We support up to 16
                      key and values entries in the map.

                      - *(string) --*

                        - *(string) --*

                    - **TransformInput** *(dict) --*

                      A description of the input source and the way the transform job consumes it.

                      - **DataSource** *(dict) --*

                        Describes the location of the channel data, which is, the S3 location of the
                        input data that the model can consume.

                        - **S3DataSource** *(dict) --*

                          The S3 location of the data source that is associated with a channel.

                          - **S3DataType** *(string) --*

                            If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix.
                            Amazon SageMaker uses all objects with the specified key name prefix for
                            batch transform.

                            If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is
                            a manifest file containing a list of object keys that you want Amazon
                            SageMaker to use for batch transform.

                            The following values are compatible: ``ManifestFile`` , ``S3Prefix``

                            The following value is not compatible: ``AugmentedManifestFile``

                          - **S3Uri** *(string) --*

                            Depending on the value specified for the ``S3DataType`` , identifies
                            either a key name prefix or a manifest. For example:

                            * A key name prefix might look like this:
                            ``s3://bucketname/exampleprefix`` .

                            * A manifest might look like this: ``s3://bucketname/example.manifest``
                            The manifest is an S3 object which is a JSON file with the following
                            format:   ``[ {"prefix": "s3://customer_bucket/some/prefix/"},``
                            ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                            ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                            matches the following ``s3Uris`` :
                            ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                            ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                            ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The
                            complete set of ``S3Uris`` in this manifest constitutes the input data
                            for the channel for this datasource. The object that each ``S3Uris``
                            points to must be readable by the IAM role that Amazon SageMaker uses to
                            perform tasks on your behalf.

                      - **ContentType** *(string) --*

                        The multipurpose internet mail extension (MIME) type of the data. Amazon
                        SageMaker uses the MIME type with each http call to transfer data to the
                        transform job.

                      - **CompressionType** *(string) --*

                        If your transform data is compressed, specify the compression type. Amazon
                        SageMaker automatically decompresses the data for the transform job
                        accordingly. The default value is ``None`` .

                      - **SplitType** *(string) --*

                        The method to use to split the transform job's data files into smaller
                        batches. Splitting is necessary when the total size of each object is too
                        large to fit in a single request. You can also use data splitting to improve
                        performance by processing multiple concurrent mini-batches. The default
                        value for ``SplitType`` is ``None`` , which indicates that input data files
                        are not split, and request payloads contain the entire contents of an input
                        object. Set the value of this parameter to ``Line`` to split records on a
                        newline character boundary. ``SplitType`` also supports a number of
                        record-oriented binary data formats.

                        When splitting is enabled, the size of a mini-batch depends on the values of
                        the ``BatchStrategy`` and ``MaxPayloadInMB`` parameters. When the value of
                        ``BatchStrategy`` is ``MultiRecord`` , Amazon SageMaker sends the maximum
                        number of records in each request, up to the ``MaxPayloadInMB`` limit. If
                        the value of ``BatchStrategy`` is ``SingleRecord`` , Amazon SageMaker sends
                        individual records in each request.

                        .. note::

                          Some data formats represent a record as a binary payload wrapped with
                          extra padding bytes. When splitting is applied to a binary data format,
                          padding is removed if the value of ``BatchStrategy`` is set to
                          ``SingleRecord`` . Padding is not removed if the value of
                          ``BatchStrategy`` is set to ``MultiRecord`` .

                          For more information about ``RecordIO`` , see `Create a Dataset Using
                          RecordIO <https://mxnet.apache.org/api/faq/recordio>`__ in the MXNet
                          documentation. For more information about ``TFRecord`` , see `Consuming
                          TFRecord data
                          <https://www.tensorflow.org/guide/datasets#consuming_tfrecord_data>`__ in
                          the TensorFlow documentation.

                    - **TransformOutput** *(dict) --*

                      Identifies the Amazon S3 location where you want Amazon SageMaker to save the
                      results from the transform job.

                      - **S3OutputPath** *(string) --*

                        The Amazon S3 path where you want Amazon SageMaker to store the results of
                        the transform job. For example, ``s3://bucket-name/key-name-prefix`` .

                        For every S3 object used as input for the transform job, batch transform
                        stores the transformed data with an .``out`` suffix in a corresponding
                        subfolder in the location in the output prefix. For example, for the input
                        data stored at ``s3://bucket-name/input-name-prefix/dataset01/data.csv`` ,
                        batch transform stores the transformed data at
                        ``s3://bucket-name/output-name-prefix/input-name-prefix/data.csv.out`` .
                        Batch transform doesn't upload partially processed objects. For an input S3
                        object that contains multiple records, it creates an .``out`` file only if
                        the transform job succeeds on the entire file. When the input contains
                        multiple S3 objects, the batch transform job processes the listed S3 objects
                        and uploads only the output for successfully processed objects. If any
                        object fails in the transform job batch transform marks the job as failed to
                        prompt investigation.

                      - **Accept** *(string) --*

                        The MIME type used to specify the output data. Amazon SageMaker uses the
                        MIME type with each http call to transfer data from the transform job.

                      - **AssembleWith** *(string) --*

                        Defines how to assemble the results of the transform job as a single S3
                        object. Choose a format that is most convenient to you. To concatenate the
                        results in binary format, specify ``None`` . To add a newline character at
                        the end of every transformed record, specify ``Line`` .

                      - **KmsKeyId** *(string) --*

                        The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                        encrypt the model artifacts at rest using Amazon S3 server-side encryption.
                        The ``KmsKeyId`` can be any of the following formats:

                        * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // Amazon Resource Name (ARN) of a KMS Key
                        ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // KMS Key Alias  ``"alias/ExampleAlias"``

                        * // Amazon Resource Name (ARN) of a KMS Key Alias
                        ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                        If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS key
                        for Amazon S3 for your role's account. For more information, see
                        `KMS-Managed Encryption Keys
                        <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__
                        in the *Amazon Simple Storage Service Developer Guide.*

                        The KMS key policy must grant permission to the IAM role that you specify in
                        your  CreateModel request. For more information, see `Using Key Policies in
                        AWS KMS
                        <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__
                        in the *AWS Key Management Service Developer Guide* .

                    - **TransformResources** *(dict) --*

                      Identifies the ML compute instances for the transform job.

                      - **InstanceType** *(string) --*

                        The ML compute instance type for the transform job. If you are using
                        built-in algorithms to transform moderately sized datasets, we recommend
                        using ml.m4.xlarge or ``ml.m5.large`` instance types.

                      - **InstanceCount** *(integer) --*

                        The number of ML compute instances to use in the transform job. For
                        distributed transform jobs, specify a value greater than 1. The default
                        value is ``1`` .

                      - **VolumeKmsKeyId** *(string) --*

                        The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                        encrypt model data on the storage volume attached to the ML compute
                        instance(s) that run the batch transform job. The ``VolumeKmsKeyId`` can be
                        any of the following formats:

                        * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // Amazon Resource Name (ARN) of a KMS Key
                        ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            - **AlgorithmStatus** *(string) --*

              The current status of the algorithm.

            - **AlgorithmStatusDetails** *(dict) --*

              Details about the current status of the algorithm.

              - **ValidationStatuses** *(list) --*

                The status of algorithm validation.

                - *(dict) --*

                  Represents the overall status of an algorithm.

                  - **Name** *(string) --*

                    The name of the algorithm for which the overall status is being reported.

                  - **Status** *(string) --*

                    The current status.

                  - **FailureReason** *(string) --*

                    if the overall status is ``Failed`` , the reason for the failure.

              - **ImageScanStatuses** *(list) --*

                The status of the scan of the algorithm's Docker image container.

                - *(dict) --*

                  Represents the overall status of an algorithm.

                  - **Name** *(string) --*

                    The name of the algorithm for which the overall status is being reported.

                  - **Status** *(string) --*

                    The current status.

                  - **FailureReason** *(string) --*

                    if the overall status is ``Failed`` , the reason for the failure.

            - **ProductId** *(string) --*

              The product identifier of the algorithm.

            - **CertifyForMarketplace** *(boolean) --*

              Whether the algorithm is certified to be listed in AWS Marketplace.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_app(
        self,
        DomainId: str,
        UserProfileName: str,
        AppType: Literal["JupyterServer", "KernelGateway", "TensorBoard"],
        AppName: str,
    ) -> ClientDescribeAppResponseTypeDef:
        """
        Describes the app.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeApp>`_

        **Request Syntax**
        ::

          response = client.describe_app(
              DomainId='string',
              UserProfileName='string',
              AppType='JupyterServer'|'KernelGateway'|'TensorBoard',
              AppName='string'
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          The user profile name.

        :type AppType: string
        :param AppType: **[REQUIRED]**

          The type of app.

        :type AppName: string
        :param AppName: **[REQUIRED]**

          The name of the app.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AppArn': 'string',
                'AppType': 'JupyterServer'|'KernelGateway'|'TensorBoard',
                'AppName': 'string',
                'DomainId': 'string',
                'UserProfileName': 'string',
                'Status': 'Deleted'|'Deleting'|'Failed'|'InService'|'Pending',
                'LastHealthCheckTimestamp': datetime(2015, 1, 1),
                'LastUserActivityTimestamp': datetime(2015, 1, 1),
                'CreationTime': datetime(2015, 1, 1),
                'FailureReason': 'string',
                'ResourceSpec': {
                    'EnvironmentArn': 'string',
                    'InstanceType':
                    'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'|'ml.t3.large'
                    |'ml.t3.xlarge'|'ml.t3.2xlarge'|'ml.m5.large'|'ml.m5.xlarge'
                    |'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                    |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'|'ml.c5.xlarge'
                    |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.12xlarge'
                    |'ml.c5.18xlarge'|'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                    |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                    |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                    |'ml.g4dn.16xlarge'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **AppArn** *(string) --*

              The app's Amazon Resource Name (ARN).

            - **AppType** *(string) --*

              The type of app.

            - **AppName** *(string) --*

              The name of the app.

            - **DomainId** *(string) --*

              The domain ID.

            - **UserProfileName** *(string) --*

              The user profile name.

            - **Status** *(string) --*

              The status.

            - **LastHealthCheckTimestamp** *(datetime) --*

              The timestamp of the last health check.

            - **LastUserActivityTimestamp** *(datetime) --*

              The timestamp of the last user's activity.

            - **CreationTime** *(datetime) --*

              The creation time.

            - **FailureReason** *(string) --*

              The failure reason.

            - **ResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_auto_ml_job(self, AutoMLJobName: str) -> ClientDescribeAutoMlJobResponseTypeDef:
        """
        Returns information about an Amazon SageMaker job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeAutoMLJob>`_

        **Request Syntax**
        ::

          response = client.describe_auto_ml_job(
              AutoMLJobName='string'
          )
        :type AutoMLJobName: string
        :param AutoMLJobName: **[REQUIRED]**

          Request information about a job using that job's unique name.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AutoMLJobName': 'string',
                'AutoMLJobArn': 'string',
                'InputDataConfig': [
                    {
                        'DataSource': {
                            'S3DataSource': {
                                'S3DataType': 'ManifestFile'|'S3Prefix',
                                'S3Uri': 'string'
                            }
                        },
                        'CompressionType': 'None'|'Gzip',
                        'TargetAttributeName': 'string'
                    },
                ],
                'OutputDataConfig': {
                    'KmsKeyId': 'string',
                    'S3OutputPath': 'string'
                },
                'RoleArn': 'string',
                'AutoMLJobObjective': {
                    'MetricName': 'Accuracy'|'MSE'|'F1'|'F1macro'
                },
                'ProblemType': 'BinaryClassification'|'MulticlassClassification'|'Regression',
                'AutoMLJobConfig': {
                    'CompletionCriteria': {
                        'MaxCandidates': 123,
                        'MaxRuntimePerTrainingJobInSeconds': 123,
                        'MaxAutoMLJobRuntimeInSeconds': 123
                    },
                    'SecurityConfig': {
                        'VolumeKmsKeyId': 'string',
                        'EnableInterContainerTrafficEncryption': True|False,
                        'VpcConfig': {
                            'SecurityGroupIds': [
                                'string',
                            ],
                            'Subnets': [
                                'string',
                            ]
                        }
                    }
                },
                'CreationTime': datetime(2015, 1, 1),
                'EndTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'FailureReason': 'string',
                'BestCandidate': {
                    'CandidateName': 'string',
                    'FinalAutoMLJobObjectiveMetric': {
                        'Type': 'Maximize'|'Minimize',
                        'MetricName': 'Accuracy'|'MSE'|'F1'|'F1macro',
                        'Value': ...
                    },
                    'ObjectiveStatus': 'Succeeded'|'Pending'|'Failed',
                    'CandidateSteps': [
                        {
                            'CandidateStepType':
                            'AWS::SageMaker::TrainingJob'
                            |'AWS::SageMaker::TransformJob'
                            |'AWS::SageMaker::ProcessingJob',
                            'CandidateStepArn': 'string',
                            'CandidateStepName': 'string'
                        },
                    ],
                    'CandidateStatus': 'Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
                    'InferenceContainers': [
                        {
                            'Image': 'string',
                            'ModelDataUrl': 'string',
                            'Environment': {
                                'string': 'string'
                            }
                        },
                    ],
                    'CreationTime': datetime(2015, 1, 1),
                    'EndTime': datetime(2015, 1, 1),
                    'LastModifiedTime': datetime(2015, 1, 1),
                    'FailureReason': 'string'
                },
                'AutoMLJobStatus': 'Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
                'AutoMLJobSecondaryStatus':
                'Starting'|'AnalyzingData'|'FeatureEngineering'|'ModelTuning'
                |'MaxCandidatesReached'|'Failed'|'Stopped'|'MaxAutoMLJobRuntimeReached'
                |'Stopping'|'CandidateDefinitionsGenerated',
                'GenerateCandidateDefinitionsOnly': True|False,
                'AutoMLJobArtifacts': {
                    'CandidateDefinitionNotebookLocation': 'string',
                    'DataExplorationNotebookLocation': 'string'
                },
                'ResolvedAttributes': {
                    'AutoMLJobObjective': {
                        'MetricName': 'Accuracy'|'MSE'|'F1'|'F1macro'
                    },
                    'ProblemType': 'BinaryClassification'|'MulticlassClassification'|'Regression',
                    'CompletionCriteria': {
                        'MaxCandidates': 123,
                        'MaxRuntimePerTrainingJobInSeconds': 123,
                        'MaxAutoMLJobRuntimeInSeconds': 123
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            - **AutoMLJobName** *(string) --*

              Returns the name of a job.

            - **AutoMLJobArn** *(string) --*

              Returns the job's ARN.

            - **InputDataConfig** *(list) --*

              Returns the job's input data config.

              - *(dict) --*

                Similar to Channel. A channel is a named input source that training algorithms can
                consume. Refer to Channel for detailed descriptions.

                - **DataSource** *(dict) --*

                  The data source.

                  - **S3DataSource** *(dict) --*

                    The Amazon S3 location of the data.

                    - **S3DataType** *(string) --*

                      The data type.

                    - **S3Uri** *(string) --*

                      The URL to the Amazon S3 data source.

                - **CompressionType** *(string) --*

                  You can use Gzip or None. The default value is None.

                - **TargetAttributeName** *(string) --*

                  The name of the target variable in supervised learning, a.k.a. ‘y’.

            - **OutputDataConfig** *(dict) --*

              Returns the job's output data config.

              - **KmsKeyId** *(string) --*

                The AWS KMS encryption key ID.

              - **S3OutputPath** *(string) --*

                The Amazon S3 output path. Must be 128 characters or less.

            - **RoleArn** *(string) --*

              The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role
              that has read permission to the input data location and write permission to the output
              data location in Amazon S3.

            - **AutoMLJobObjective** *(dict) --*

              Returns the job's objective.

              - **MetricName** *(string) --*

                The name of the metric.

            - **ProblemType** *(string) --*

              Returns the job's problem type.

            - **AutoMLJobConfig** *(dict) --*

              Returns the job's config.

              - **CompletionCriteria** *(dict) --*

                How long a job is allowed to run, or how many candidates a job is allowed to
                generate.

                - **MaxCandidates** *(integer) --*

                  The maximum number of times a training job is allowed to run.

                - **MaxRuntimePerTrainingJobInSeconds** *(integer) --*

                  The maximum time, in seconds, a job is allowed to run.

                - **MaxAutoMLJobRuntimeInSeconds** *(integer) --*

                  The maximum time, in seconds, an AutoML job is allowed to wait for a trial to
                  complete. It must be equal to or greater than MaxRuntimePerTrainingJobInSeconds.

              - **SecurityConfig** *(dict) --*

                Security configuration for traffic encryption or Amazon VPC settings.

                - **VolumeKmsKeyId** *(string) --*

                  The key used to encrypt stored data.

                - **EnableInterContainerTrafficEncryption** *(boolean) --*

                  Whether to use traffic encryption between the container layers.

                - **VpcConfig** *(dict) --*

                  VPC configuration.

                  - **SecurityGroupIds** *(list) --*

                    The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups
                    for the VPC that is specified in the ``Subnets`` field.

                    - *(string) --*

                  - **Subnets** *(list) --*

                    The ID of the subnets in the VPC to which you want to connect your training job
                    or model.

                    .. note::

                      Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                      availability zones of region us-east-1. If you want to create endpoints with
                      P3 instances in VPC mode in region us-east-1, create subnets in a/b/f
                      availability zones instead.

                    - *(string) --*

            - **CreationTime** *(datetime) --*

              Returns the job's creation time.

            - **EndTime** *(datetime) --*

              Returns the job's end time.

            - **LastModifiedTime** *(datetime) --*

              Returns the job's last modified time.

            - **FailureReason** *(string) --*

              Returns the job's FailureReason.

            - **BestCandidate** *(dict) --*

              Returns the job's BestCandidate.

              - **CandidateName** *(string) --*

                The candidate name.

              - **FinalAutoMLJobObjectiveMetric** *(dict) --*

                The candidate result from a job.

                - **Type** *(string) --*

                  The metric type used.

                - **MetricName** *(string) --*

                  The name of the metric.

                - **Value** *(float) --*

                  The value of the metric.

              - **ObjectiveStatus** *(string) --*

                The objective status.

              - **CandidateSteps** *(list) --*

                The candidate's steps.

                - *(dict) --*

                  Information about the steps for a Candidate, and what step it is working on.

                  - **CandidateStepType** *(string) --*

                    Whether the Candidate is at the transform, training, or processing step.

                  - **CandidateStepArn** *(string) --*

                    The ARN for the Candidate's step.

                  - **CandidateStepName** *(string) --*

                    The name for the Candidate's step.

              - **CandidateStatus** *(string) --*

                The candidate's status.

              - **InferenceContainers** *(list) --*

                The inference containers.

                - *(dict) --*

                  A list of container definitions that describe the different containers that make
                  up one AutoML candidate. Refer to ContainerDefinition for more details.

                  - **Image** *(string) --*

                    The ECR path of the container. Refer to ContainerDefinition for more details.

                  - **ModelDataUrl** *(string) --*

                    The location of the model artifacts. Refer to ContainerDefinition for more
                    details.

                  - **Environment** *(dict) --*

                    Environment variables to set in the container. Refer to ContainerDefinition for
                    more details.

                    - *(string) --*

                      - *(string) --*

              - **CreationTime** *(datetime) --*

                The creation time.

              - **EndTime** *(datetime) --*

                The end time.

              - **LastModifiedTime** *(datetime) --*

                The last modified time.

              - **FailureReason** *(string) --*

                The failure reason.

            - **AutoMLJobStatus** *(string) --*

              Returns the job's AutoMLJobStatus.

            - **AutoMLJobSecondaryStatus** *(string) --*

              Returns the job's AutoMLJobSecondaryStatus.

            - **GenerateCandidateDefinitionsOnly** *(boolean) --*

              Returns the job's output from GenerateCandidateDefinitionsOnly.

            - **AutoMLJobArtifacts** *(dict) --*

              Returns information on the job's artifacts found in AutoMLJobArtifacts.

              - **CandidateDefinitionNotebookLocation** *(string) --*

                The URL to the notebook location.

              - **DataExplorationNotebookLocation** *(string) --*

                The URL to the notebook location.

            - **ResolvedAttributes** *(dict) --*

              This contains ProblemType, AutoMLJobObjective and CompletionCriteria. They’re
              auto-inferred values, if not provided by you. If you do provide them, then they’ll be
              the same as provided.

              - **AutoMLJobObjective** *(dict) --*

                Applies a metric to minimize or maximize for the job's objective.

                - **MetricName** *(string) --*

                  The name of the metric.

              - **ProblemType** *(string) --*

                The problem type.

              - **CompletionCriteria** *(dict) --*

                How long a job is allowed to run, or how many candidates a job is allowed to
                generate.

                - **MaxCandidates** *(integer) --*

                  The maximum number of times a training job is allowed to run.

                - **MaxRuntimePerTrainingJobInSeconds** *(integer) --*

                  The maximum time, in seconds, a job is allowed to run.

                - **MaxAutoMLJobRuntimeInSeconds** *(integer) --*

                  The maximum time, in seconds, an AutoML job is allowed to wait for a trial to
                  complete. It must be equal to or greater than MaxRuntimePerTrainingJobInSeconds.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_code_repository(
        self, CodeRepositoryName: str
    ) -> ClientDescribeCodeRepositoryResponseTypeDef:
        """
        Gets details about the specified Git repository.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeCodeRepository>`_

        **Request Syntax**
        ::

          response = client.describe_code_repository(
              CodeRepositoryName='string'
          )
        :type CodeRepositoryName: string
        :param CodeRepositoryName: **[REQUIRED]**

          The name of the Git repository to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CodeRepositoryName': 'string',
                'CodeRepositoryArn': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'GitConfig': {
                    'RepositoryUrl': 'string',
                    'Branch': 'string',
                    'SecretArn': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **CodeRepositoryName** *(string) --*

              The name of the Git repository.

            - **CodeRepositoryArn** *(string) --*

              The Amazon Resource Name (ARN) of the Git repository.

            - **CreationTime** *(datetime) --*

              The date and time that the repository was created.

            - **LastModifiedTime** *(datetime) --*

              The date and time that the repository was last changed.

            - **GitConfig** *(dict) --*

              Configuration details about the repository, including the URL where the repository is
              located, the default branch, and the Amazon Resource Name (ARN) of the AWS Secrets
              Manager secret that contains the credentials used to access the repository.

              - **RepositoryUrl** *(string) --*

                The URL where the Git repository is located.

              - **Branch** *(string) --*

                The default branch for the Git repository.

              - **SecretArn** *(string) --*

                The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the
                credentials used to access the git repository. The secret must have a staging label
                of ``AWSCURRENT`` and must be in the following format:

                 ``{"username": *UserName* , "password": *Password* }``
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_compilation_job(
        self, CompilationJobName: str
    ) -> ClientDescribeCompilationJobResponseTypeDef:
        """
        Returns information about a model compilation job.

        To create a model compilation job, use  CreateCompilationJob . To get information about
        multiple model compilation jobs, use  ListCompilationJobs .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeCompilationJob>`_

        **Request Syntax**
        ::

          response = client.describe_compilation_job(
              CompilationJobName='string'
          )
        :type CompilationJobName: string
        :param CompilationJobName: **[REQUIRED]**

          The name of the model compilation job that you want information about.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CompilationJobName': 'string',
                'CompilationJobArn': 'string',
                'CompilationJobStatus':
                'INPROGRESS'|'COMPLETED'|'FAILED'|'STARTING'|'STOPPING'|'STOPPED',
                'CompilationStartTime': datetime(2015, 1, 1),
                'CompilationEndTime': datetime(2015, 1, 1),
                'StoppingCondition': {
                    'MaxRuntimeInSeconds': 123,
                    'MaxWaitTimeInSeconds': 123
                },
                'CreationTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'FailureReason': 'string',
                'ModelArtifacts': {
                    'S3ModelArtifacts': 'string'
                },
                'RoleArn': 'string',
                'InputConfig': {
                    'S3Uri': 'string',
                    'DataInputConfig': 'string',
                    'Framework': 'TENSORFLOW'|'MXNET'|'ONNX'|'PYTORCH'|'XGBOOST'
                },
                'OutputConfig': {
                    'S3OutputLocation': 'string',
                    'TargetDevice':
                    'lambda'|'ml_m4'|'ml_m5'|'ml_c4'|'ml_c5'|'ml_p2'|'ml_p3'|'ml_inf1'
                    |'jetson_tx1'|'jetson_tx2'|'jetson_nano'|'rasp3b'|'deeplens'
                    |'rk3399'|'rk3288'|'aisage'|'sbe_c'|'qcs605'|'qcs603'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **CompilationJobName** *(string) --*

              The name of the model compilation job.

            - **CompilationJobArn** *(string) --*

              The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker assumes to perform
              the model compilation job.

            - **CompilationJobStatus** *(string) --*

              The status of the model compilation job.

            - **CompilationStartTime** *(datetime) --*

              The time when the model compilation job started the ``CompilationJob`` instances.

              You are billed for the time between this timestamp and the timestamp in the
              DescribeCompilationJobResponse$CompilationEndTime field. In Amazon CloudWatch Logs,
              the start time might be later than this time. That's because it takes time to download
              the compilation job, which depends on the size of the compilation job container.

            - **CompilationEndTime** *(datetime) --*

              The time when the model compilation job on a compilation job instance ended. For a
              successful or stopped job, this is when the job's model artifacts have finished
              uploading. For a failed job, this is when Amazon SageMaker detected that the job
              failed.

            - **StoppingCondition** *(dict) --*

              Specifies a limit to how long a model compilation job can run. When the job reaches
              the time limit, Amazon SageMaker ends the compilation job. Use this API to cap model
              training costs.

              - **MaxRuntimeInSeconds** *(integer) --*

                The maximum length of time, in seconds, that the training or compilation job can
                run. If job does not complete during this time, Amazon SageMaker ends the job. If
                value is not specified, default value is 1 day. The maximum value is 28 days.

              - **MaxWaitTimeInSeconds** *(integer) --*

                The maximum length of time, in seconds, how long you are willing to wait for a
                managed spot training job to complete. It is the amount of time spent waiting for
                Spot capacity plus the amount of time the training job runs. It must be equal to or
                greater than ``MaxRuntimeInSeconds`` .

            - **CreationTime** *(datetime) --*

              The time that the model compilation job was created.

            - **LastModifiedTime** *(datetime) --*

              The time that the status of the model compilation job was last modified.

            - **FailureReason** *(string) --*

              If a model compilation job failed, the reason it failed.

            - **ModelArtifacts** *(dict) --*

              Information about the location in Amazon S3 that has been configured for storing the
              model artifacts used in the compilation job.

              - **S3ModelArtifacts** *(string) --*

                The path of the S3 object that contains the model artifacts. For example,
                ``s3://bucket-name/keynameprefix/model.tar.gz`` .

            - **RoleArn** *(string) --*

              The Amazon Resource Name (ARN) of the model compilation job.

            - **InputConfig** *(dict) --*

              Information about the location in Amazon S3 of the input model artifacts, the name and
              shape of the expected data inputs, and the framework in which the model was trained.

              - **S3Uri** *(string) --*

                The S3 path where the model artifacts, which result from model training, are stored.
                This path must point to a single gzip compressed tar archive (.tar.gz suffix).

              - **DataInputConfig** *(string) --*

                Specifies the name and shape of the expected data inputs for your trained model with
                a JSON dictionary form. The data inputs are  InputConfig$Framework specific.

                * ``TensorFlow`` : You must specify the name and shape (NHWC format) of the expected
                data inputs using a dictionary format for your trained model. The dictionary formats
                required for the console and CLI are different.

                  * Examples for one input:

                    * If using the console, ``{"input":[1,1024,1024,3]}``

                    * If using the CLI, ``{\\"input\\":[1,1024,1024,3]}``

                  * Examples for two inputs:

                    * If using the console, ``{"data1": [1,28,28,1], "data2":[1,28,28,1]}``

                    * If using the CLI, ``{\\"data1\\": [1,28,28,1], \\"data2\\":[1,28,28,1]}``

                * ``MXNET/ONNX`` : You must specify the name and shape (NCHW format) of the expected
                data inputs in order using a dictionary format for your trained model. The
                dictionary formats required for the console and CLI are different.

                  * Examples for one input:

                    * If using the console, ``{"data":[1,3,1024,1024]}``

                    * If using the CLI, ``{\\"data\\":[1,3,1024,1024]}``

                  * Examples for two inputs:

                    * If using the console, ``{"var1": [1,1,28,28], "var2":[1,1,28,28]}``

                    * If using the CLI, ``{\\"var1\\": [1,1,28,28], \\"var2\\":[1,1,28,28]}``

                * ``PyTorch`` : You can either specify the name and shape (NCHW format) of expected
                data inputs in order using a dictionary format for your trained model or you can
                specify the shape only using a list format. The dictionary formats required for the
                console and CLI are different. The list formats for the console and CLI are the
                same.

                  * Examples for one input in dictionary format:

                    * If using the console, ``{"input0":[1,3,224,224]}``

                    * If using the CLI, ``{\\"input0\\":[1,3,224,224]}``

                  * Example for one input in list format: ``[[1,3,224,224]]``

                  * Examples for two inputs in dictionary format:

                    * If using the console, ``{"input0":[1,3,224,224], "input1":[1,3,224,224]}``

                    * If using the CLI, ``{\\"input0\\":[1,3,224,224], \\"input1\\":[1,3,224,224]}``

                  * Example for two inputs in list format: ``[[1,3,224,224], [1,3,224,224]]``

                * ``XGBOOST`` : input data name and shape are not needed.

              - **Framework** *(string) --*

                Identifies the framework in which the model was trained. For example: TENSORFLOW.

            - **OutputConfig** *(dict) --*

              Information about the output location for the compiled model and the target device
              that the model runs on.

              - **S3OutputLocation** *(string) --*

                Identifies the S3 path where you want Amazon SageMaker to store the model artifacts.
                For example, s3://bucket-name/key-name-prefix.

              - **TargetDevice** *(string) --*

                Identifies the device that you want to run your model on after it has been compiled.
                For example: ml_c5.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_domain(self, DomainId: str) -> ClientDescribeDomainResponseTypeDef:
        """
        The desciption of the domain.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeDomain>`_

        **Request Syntax**
        ::

          response = client.describe_domain(
              DomainId='string'
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'DomainArn': 'string',
                'DomainId': 'string',
                'DomainName': 'string',
                'HomeEfsFileSystemId': 'string',
                'SingleSignOnManagedApplicationInstanceId': 'string',
                'Status': 'Deleting'|'Failed'|'InService'|'Pending',
                'CreationTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'FailureReason': 'string',
                'AuthMode': 'SSO'|'IAM',
                'DefaultUserSettings': {
                    'ExecutionRole': 'string',
                    'SecurityGroups': [
                        'string',
                    ],
                    'SharingSettings': {
                        'NotebookOutputOption': 'Allowed'|'Disabled',
                        'S3OutputPath': 'string',
                        'S3KmsKeyId': 'string'
                    },
                    'JupyterServerAppSettings': {
                        'DefaultResourceSpec': {
                            'EnvironmentArn': 'string',
                            'InstanceType':
                            'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                            |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                            |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                            |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                            |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                            |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                            |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                            |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                            |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                            |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                            |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'
                        }
                    },
                    'KernelGatewayAppSettings': {
                        'DefaultResourceSpec': {
                            'EnvironmentArn': 'string',
                            'InstanceType':
                            'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                            |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                            |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                            |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                            |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                            |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                            |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                            |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                            |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                            |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                            |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'
                        }
                    },
                    'TensorBoardAppSettings': {
                        'DefaultResourceSpec': {
                            'EnvironmentArn': 'string',
                            'InstanceType':
                            'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                            |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                            |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                            |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                            |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                            |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                            |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                            |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                            |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                            |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                            |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'
                        }
                    }
                },
                'HomeEfsFileSystemKmsKeyId': 'string',
                'SubnetIds': [
                    'string',
                ],
                'Url': 'string',
                'VpcId': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **DomainArn** *(string) --*

              The domain's Amazon Resource Name (ARN).

            - **DomainId** *(string) --*

              The domain ID.

            - **DomainName** *(string) --*

              The domain name.

            - **HomeEfsFileSystemId** *(string) --*

              The ID of the Amazon Elastic File System (EFS) managed by this Domain.

            - **SingleSignOnManagedApplicationInstanceId** *(string) --*

              The SSO managed application instance ID.

            - **Status** *(string) --*

              The status.

            - **CreationTime** *(datetime) --*

              The creation time.

            - **LastModifiedTime** *(datetime) --*

              The last modified time.

            - **FailureReason** *(string) --*

              The failure reason.

            - **AuthMode** *(string) --*

              The domain's authentication mode.

            - **DefaultUserSettings** *(dict) --*

              Settings which are applied to all UserProfile in this domain, if settings are not
              explicitly specified in a given UserProfile.

              - **ExecutionRole** *(string) --*

                The execution role for the user.

              - **SecurityGroups** *(list) --*

                The security groups.

                - *(string) --*

              - **SharingSettings** *(dict) --*

                The sharing settings.

                - **NotebookOutputOption** *(string) --*

                  The notebook output option.

                - **S3OutputPath** *(string) --*

                  The Amazon S3 output path.

                - **S3KmsKeyId** *(string) --*

                  The AWS Key Management Service encryption key ID.

              - **JupyterServerAppSettings** *(dict) --*

                The Jupyter server's app settings.

                - **DefaultResourceSpec** *(dict) --*

                  The instance type and quantity.

                  - **EnvironmentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the environment.

                  - **InstanceType** *(string) --*

                    The instance type.

              - **KernelGatewayAppSettings** *(dict) --*

                The kernel gateway app settings.

                - **DefaultResourceSpec** *(dict) --*

                  The instance type and quantity.

                  - **EnvironmentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the environment.

                  - **InstanceType** *(string) --*

                    The instance type.

              - **TensorBoardAppSettings** *(dict) --*

                The TensorBoard app settings.

                - **DefaultResourceSpec** *(dict) --*

                  The instance type and quantity.

                  - **EnvironmentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the environment.

                  - **InstanceType** *(string) --*

                    The instance type.

            - **HomeEfsFileSystemKmsKeyId** *(string) --*

              The AWS Key Management Service encryption key ID.

            - **SubnetIds** *(list) --*

              Security setting to limit to a set of subnets.

              - *(string) --*

            - **Url** *(string) --*

              The domain's URL.

            - **VpcId** *(string) --*

              The ID of the Amazon Virtual Private Cloud.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_endpoint(self, EndpointName: str) -> ClientDescribeEndpointResponseTypeDef:
        """
        Returns the description of an endpoint.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeEndpoint>`_

        **Request Syntax**
        ::

          response = client.describe_endpoint(
              EndpointName='string'
          )
        :type EndpointName: string
        :param EndpointName: **[REQUIRED]**

          The name of the endpoint.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointName': 'string',
                'EndpointArn': 'string',
                'EndpointConfigName': 'string',
                'ProductionVariants': [
                    {
                        'VariantName': 'string',
                        'DeployedImages': [
                            {
                                'SpecifiedImage': 'string',
                                'ResolvedImage': 'string',
                                'ResolutionTime': datetime(2015, 1, 1)
                            },
                        ],
                        'CurrentWeight': ...,
                        'DesiredWeight': ...,
                        'CurrentInstanceCount': 123,
                        'DesiredInstanceCount': 123
                    },
                ],
                'DataCaptureConfig': {
                    'EnableCapture': True|False,
                    'CaptureStatus': 'Started'|'Stopped',
                    'CurrentSamplingPercentage': 123,
                    'DestinationS3Uri': 'string',
                    'KmsKeyId': 'string'
                },
                'EndpointStatus':
                'OutOfService'|'Creating'|'Updating'|'SystemUpdating'|'RollingBack'
                |'InService'|'Deleting'|'Failed',
                'FailureReason': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1)
            }
          **Response Structure**

          - *(dict) --*

            - **EndpointName** *(string) --*

              Name of the endpoint.

            - **EndpointArn** *(string) --*

              The Amazon Resource Name (ARN) of the endpoint.

            - **EndpointConfigName** *(string) --*

              The name of the endpoint configuration associated with this endpoint.

            - **ProductionVariants** *(list) --*

              An array of  ProductionVariantSummary objects, one for each model hosted behind this
              endpoint.

              - *(dict) --*

                Describes weight and capacities for a production variant associated with an
                endpoint. If you sent a request to the ``UpdateEndpointWeightsAndCapacities`` API
                and the endpoint status is ``Updating`` , you get different desired and current
                values.

                - **VariantName** *(string) --*

                  The name of the variant.

                - **DeployedImages** *(list) --*

                  An array of ``DeployedImage`` objects that specify the Amazon EC2 Container
                  Registry paths of the inference images deployed on instances of this
                  ``ProductionVariant`` .

                  - *(dict) --*

                    Gets the Amazon EC2 Container Registry path of the docker image of the model
                    that is hosted in this  ProductionVariant .

                    If you used the ``registry/repository[:tag]`` form to specify the image path of
                    the primary container when you created the model hosted in this
                    ``ProductionVariant`` , the path resolves to a path of the form
                    ``registry/repository[@digest]`` . A digest is a hash value that identifies a
                    specific version of an image. For information about Amazon ECR paths, see
                    `Pulling an Image
                    <https://docs.aws.amazon.com/AmazonECR/latest/userguide/docker-pull-ecr-image.html>`__
                    in the *Amazon ECR User Guide* .

                    - **SpecifiedImage** *(string) --*

                      The image path you specified when you created the model.

                    - **ResolvedImage** *(string) --*

                      The specific digest path of the image hosted in this ``ProductionVariant`` .

                    - **ResolutionTime** *(datetime) --*

                      The date and time when the image path for the model resolved to the
                      ``ResolvedImage``

                - **CurrentWeight** *(float) --*

                  The weight associated with the variant.

                - **DesiredWeight** *(float) --*

                  The requested weight, as specified in the ``UpdateEndpointWeightsAndCapacities``
                  request.

                - **CurrentInstanceCount** *(integer) --*

                  The number of instances associated with the variant.

                - **DesiredInstanceCount** *(integer) --*

                  The number of instances requested in the ``UpdateEndpointWeightsAndCapacities``
                  request.

            - **DataCaptureConfig** *(dict) --*

              - **EnableCapture** *(boolean) --*

              - **CaptureStatus** *(string) --*

              - **CurrentSamplingPercentage** *(integer) --*

              - **DestinationS3Uri** *(string) --*

              - **KmsKeyId** *(string) --*

            - **EndpointStatus** *(string) --*

              The status of the endpoint.

              * ``OutOfService`` : Endpoint is not available to take incoming requests.

              * ``Creating`` :  CreateEndpoint is executing.

              * ``Updating`` :  UpdateEndpoint or  UpdateEndpointWeightsAndCapacities is executing.

              * ``SystemUpdating`` : Endpoint is undergoing maintenance and cannot be updated or
              deleted or re-scaled until it has completed. This maintenance operation does not
              change any customer-specified values such as VPC config, KMS encryption, model,
              instance type, or instance count.

              * ``RollingBack`` : Endpoint fails to scale up or down or change its variant weight
              and is in the process of rolling back to its previous configuration. Once the rollback
              completes, endpoint returns to an ``InService`` status. This transitional status only
              applies to an endpoint that has autoscaling enabled and is undergoing variant weight
              or capacity changes as part of an  UpdateEndpointWeightsAndCapacities call or when the
              UpdateEndpointWeightsAndCapacities operation is called explicitly.

              * ``InService`` : Endpoint is available to process incoming requests.

              * ``Deleting`` :  DeleteEndpoint is executing.

              * ``Failed`` : Endpoint could not be created, updated, or re-scaled. Use
              DescribeEndpointOutput$FailureReason for information about the failure.
              DeleteEndpoint is the only operation that can be performed on a failed endpoint.

            - **FailureReason** *(string) --*

              If the status of the endpoint is ``Failed`` , the reason why it failed.

            - **CreationTime** *(datetime) --*

              A timestamp that shows when the endpoint was created.

            - **LastModifiedTime** *(datetime) --*

              A timestamp that shows when the endpoint was last modified.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_endpoint_config(
        self, EndpointConfigName: str
    ) -> ClientDescribeEndpointConfigResponseTypeDef:
        """
        Returns the description of an endpoint configuration created using the
        ``CreateEndpointConfig`` API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeEndpointConfig>`_

        **Request Syntax**
        ::

          response = client.describe_endpoint_config(
              EndpointConfigName='string'
          )
        :type EndpointConfigName: string
        :param EndpointConfigName: **[REQUIRED]**

          The name of the endpoint configuration.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointConfigName': 'string',
                'EndpointConfigArn': 'string',
                'ProductionVariants': [
                    {
                        'VariantName': 'string',
                        'ModelName': 'string',
                        'InitialInstanceCount': 123,
                        'InstanceType':
                        'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'
                        |'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'
                        |'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.large'
                        |'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.m5d.large'
                        |'ml.m5d.xlarge'|'ml.m5d.2xlarge'|'ml.m5d.4xlarge'
                        |'ml.m5d.12xlarge'|'ml.m5d.24xlarge'|'ml.c4.large'
                        |'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                        |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'
                        |'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                        |'ml.p3.16xlarge'|'ml.c5.large'|'ml.c5.xlarge'
                        |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                        |'ml.c5.18xlarge'|'ml.c5d.large'|'ml.c5d.xlarge'
                        |'ml.c5d.2xlarge'|'ml.c5d.4xlarge'|'ml.c5d.9xlarge'
                        |'ml.c5d.18xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                        |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                        |'ml.g4dn.16xlarge'|'ml.r5.large'|'ml.r5.xlarge'
                        |'ml.r5.2xlarge'|'ml.r5.4xlarge'|'ml.r5.12xlarge'
                        |'ml.r5.24xlarge'|'ml.r5d.large'|'ml.r5d.xlarge'
                        |'ml.r5d.2xlarge'|'ml.r5d.4xlarge'|'ml.r5d.12xlarge'
                        |'ml.r5d.24xlarge'|'ml.inf1.xlarge'|'ml.inf1.2xlarge'
                        |'ml.inf1.6xlarge'|'ml.inf1.24xlarge',
                        'InitialVariantWeight': ...,
                        'AcceleratorType':
                        'ml.eia1.medium'|'ml.eia1.large'|'ml.eia1.xlarge'
                        |'ml.eia2.medium'|'ml.eia2.large'|'ml.eia2.xlarge'
                    },
                ],
                'DataCaptureConfig': {
                    'EnableCapture': True|False,
                    'InitialSamplingPercentage': 123,
                    'DestinationS3Uri': 'string',
                    'KmsKeyId': 'string',
                    'CaptureOptions': [
                        {
                            'CaptureMode': 'Input'|'Output'
                        },
                    ],
                    'CaptureContentTypeHeader': {
                        'CsvContentTypes': [
                            'string',
                        ],
                        'JsonContentTypes': [
                            'string',
                        ]
                    }
                },
                'KmsKeyId': 'string',
                'CreationTime': datetime(2015, 1, 1)
            }
          **Response Structure**

          - *(dict) --*

            - **EndpointConfigName** *(string) --*

              Name of the Amazon SageMaker endpoint configuration.

            - **EndpointConfigArn** *(string) --*

              The Amazon Resource Name (ARN) of the endpoint configuration.

            - **ProductionVariants** *(list) --*

              An array of ``ProductionVariant`` objects, one for each model that you want to host at
              this endpoint.

              - *(dict) --*

                Identifies a model that you want to host and the resources to deploy for hosting it.
                If you are deploying multiple models, tell Amazon SageMaker how to distribute
                traffic among the models by specifying variant weights.

                - **VariantName** *(string) --*

                  The name of the production variant.

                - **ModelName** *(string) --*

                  The name of the model that you want to host. This is the name that you specified
                  when creating the model.

                - **InitialInstanceCount** *(integer) --*

                  Number of instances to launch initially.

                - **InstanceType** *(string) --*

                  The ML compute instance type.

                - **InitialVariantWeight** *(float) --*

                  Determines initial traffic distribution among all of the models that you specify
                  in the endpoint configuration. The traffic to a production variant is determined
                  by the ratio of the ``VariantWeight`` to the sum of all ``VariantWeight`` values
                  across all ProductionVariants. If unspecified, it defaults to 1.0.

                - **AcceleratorType** *(string) --*

                  The size of the Elastic Inference (EI) instance to use for the production variant.
                  EI instances provide on-demand GPU computing for inference. For more information,
                  see `Using Elastic Inference in Amazon SageMaker
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/ei.html>`__ .

            - **DataCaptureConfig** *(dict) --*

              - **EnableCapture** *(boolean) --*

              - **InitialSamplingPercentage** *(integer) --*

              - **DestinationS3Uri** *(string) --*

              - **KmsKeyId** *(string) --*

              - **CaptureOptions** *(list) --*

                - *(dict) --*

                  - **CaptureMode** *(string) --*

              - **CaptureContentTypeHeader** *(dict) --*

                - **CsvContentTypes** *(list) --*

                  - *(string) --*

                - **JsonContentTypes** *(list) --*

                  - *(string) --*

            - **KmsKeyId** *(string) --*

              AWS KMS key ID Amazon SageMaker uses to encrypt data when storing it on the ML storage
              volume attached to the instance.

            - **CreationTime** *(datetime) --*

              A timestamp that shows when the endpoint configuration was created.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_experiment(self, ExperimentName: str) -> ClientDescribeExperimentResponseTypeDef:
        """
        Provides a list of an experiment's properties.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeExperiment>`_

        **Request Syntax**
        ::

          response = client.describe_experiment(
              ExperimentName='string'
          )
        :type ExperimentName: string
        :param ExperimentName: **[REQUIRED]**

          The name of the experiment to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExperimentName': 'string',
                'ExperimentArn': 'string',
                'DisplayName': 'string',
                'Source': {
                    'SourceArn': 'string',
                    'SourceType': 'string'
                },
                'Description': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'CreatedBy': {
                    'UserProfileArn': 'string',
                    'UserProfileName': 'string',
                    'DomainId': 'string'
                },
                'LastModifiedTime': datetime(2015, 1, 1),
                'LastModifiedBy': {
                    'UserProfileArn': 'string',
                    'UserProfileName': 'string',
                    'DomainId': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **ExperimentName** *(string) --*

              The name of the experiment.

            - **ExperimentArn** *(string) --*

              The Amazon Resource Name (ARN) of the experiment.

            - **DisplayName** *(string) --*

              The name of the experiment as displayed. If ``DisplayName`` isn't specified,
              ``ExperimentName`` is displayed.

            - **Source** *(dict) --*

              The ARN of the source and, optionally, the type.

              - **SourceArn** *(string) --*

                The Amazon Resource Name (ARN) of the source.

              - **SourceType** *(string) --*

                The source type.

            - **Description** *(string) --*

              The description of the experiment.

            - **CreationTime** *(datetime) --*

              When the experiment was created.

            - **CreatedBy** *(dict) --*

              Who created the experiment.

              - **UserProfileArn** *(string) --*

                The Amazon Resource Name (ARN) of the user's profile.

              - **UserProfileName** *(string) --*

                The name of the user's profile.

              - **DomainId** *(string) --*

                The domain associated with the user.

            - **LastModifiedTime** *(datetime) --*

              When the experiment was last modified.

            - **LastModifiedBy** *(dict) --*

              Who last modified the experiment.

              - **UserProfileArn** *(string) --*

                The Amazon Resource Name (ARN) of the user's profile.

              - **UserProfileName** *(string) --*

                The name of the user's profile.

              - **DomainId** *(string) --*

                The domain associated with the user.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_flow_definition(
        self, FlowDefinitionName: str
    ) -> ClientDescribeFlowDefinitionResponseTypeDef:
        """
        Returns information about the specified flow definition.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeFlowDefinition>`_

        **Request Syntax**
        ::

          response = client.describe_flow_definition(
              FlowDefinitionName='string'
          )
        :type FlowDefinitionName: string
        :param FlowDefinitionName: **[REQUIRED]**

          The name of the flow definition.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'FlowDefinitionArn': 'string',
                'FlowDefinitionName': 'string',
                'FlowDefinitionStatus': 'Initializing'|'Active'|'Failed'|'Deleting'|'Deleted',
                'CreationTime': datetime(2015, 1, 1),
                'HumanLoopActivationConfig': {
                    'HumanLoopRequestSource': {
                        'AwsManagedHumanLoopRequestSource':
                        'AWS/Rekognition/DetectModerationLabels/Image/V3'
                        |'AWS/Textract/AnalyzeDocument/Forms/V1'
                    },
                    'HumanLoopActivationConditionsConfig': {
                        'HumanLoopActivationConditions': 'string'
                    }
                },
                'HumanLoopConfig': {
                    'WorkteamArn': 'string',
                    'HumanTaskUiArn': 'string',
                    'TaskTitle': 'string',
                    'TaskDescription': 'string',
                    'TaskCount': 123,
                    'TaskAvailabilityLifetimeInSeconds': 123,
                    'TaskTimeLimitInSeconds': 123,
                    'TaskKeywords': [
                        'string',
                    ],
                    'PublicWorkforceTaskPrice': {
                        'AmountInUsd': {
                            'Dollars': 123,
                            'Cents': 123,
                            'TenthFractionsOfACent': 123
                        }
                    }
                },
                'OutputConfig': {
                    'S3OutputPath': 'string',
                    'KmsKeyId': 'string'
                },
                'RoleArn': 'string',
                'FailureReason': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **FlowDefinitionArn** *(string) --*

              The Amazon Resource Name (ARN) of the flow defintion.

            - **FlowDefinitionName** *(string) --*

              The Amazon Resource Name (ARN) of the flow definition.

            - **FlowDefinitionStatus** *(string) --*

              The status of the flow definition. Valid values are listed below.

            - **CreationTime** *(datetime) --*

              The timestamp when the flow definition was created.

            - **HumanLoopActivationConfig** *(dict) --*

              An object containing information about what triggers a human review workflow.

              - **HumanLoopRequestSource** *(dict) --*

                Container for configuring the source of human task requests.

                - **AwsManagedHumanLoopRequestSource** *(string) --*

                  Specifies whether Amazon Rekognition or Amazon Textract are used as the
                  integration source. The default field settings and JSON parsing rules are
                  different based on the integration source. Valid values:

              - **HumanLoopActivationConditionsConfig** *(dict) --*

                Container structure for defining under what conditions SageMaker creates a human
                loop.

                - **HumanLoopActivationConditions** *(string) --*

                  JSON expressing use-case specific conditions declaratively. If any condition is
                  matched, atomic tasks are created against the configured work team. The set of
                  conditions is different for Rekognition and Textract.

            - **HumanLoopConfig** *(dict) --*

              An object containing information about who works on the task, the workforce task
              price, and other task details.

              - **WorkteamArn** *(string) --*

                Amazon Resource Name (ARN) of a team of workers.

              - **HumanTaskUiArn** *(string) --*

                The Amazon Resource Name (ARN) of the human task user interface.

              - **TaskTitle** *(string) --*

                A title for the human worker task.

              - **TaskDescription** *(string) --*

                A description for the human worker task.

              - **TaskCount** *(integer) --*

                The number of human tasks.

              - **TaskAvailabilityLifetimeInSeconds** *(integer) --*

                The length of time that a task remains available for labeling by human workers.

              - **TaskTimeLimitInSeconds** *(integer) --*

                The amount of time that a worker has to complete a task.

              - **TaskKeywords** *(list) --*

                Keywords used to describe the task so that workers can discover the task.

                - *(string) --*

              - **PublicWorkforceTaskPrice** *(dict) --*

                Defines the amount of money paid to an Amazon Mechanical Turk worker for each task
                performed.

                Use one of the following prices for bounding box tasks. Prices are in US dollars and
                should be based on the complexity of the task; the longer it takes in your initial
                testing, the more you should offer.

                * 0.036

                * 0.048

                * 0.060

                * 0.072

                * 0.120

                * 0.240

                * 0.360

                * 0.480

                * 0.600

                * 0.720

                * 0.840

                * 0.960

                * 1.080

                * 1.200

                Use one of the following prices for image classification, text classification, and
                custom tasks. Prices are in US dollars.

                * 0.012

                * 0.024

                * 0.036

                * 0.048

                * 0.060

                * 0.072

                * 0.120

                * 0.240

                * 0.360

                * 0.480

                * 0.600

                * 0.720

                * 0.840

                * 0.960

                * 1.080

                * 1.200

                Use one of the following prices for semantic segmentation tasks. Prices are in US
                dollars.

                * 0.840

                * 0.960

                * 1.080

                * 1.200

                Use one of the following prices for Textract AnalyzeDocument Important Form Key
                Amazon Augmented AI review tasks. Prices are in US dollars.

                * 2.400

                * 2.280

                * 2.160

                * 2.040

                * 1.920

                * 1.800

                * 1.680

                * 1.560

                * 1.440

                * 1.320

                * 1.200

                * 1.080

                * 0.960

                * 0.840

                * 0.720

                * 0.600

                * 0.480

                * 0.360

                * 0.240

                * 0.120

                * 0.072

                * 0.060

                * 0.048

                * 0.036

                * 0.024

                * 0.012

                Use one of the following prices for Rekognition DetectModerationLabels Amazon
                Augmented AI review tasks. Prices are in US dollars.

                * 1.200

                * 1.080

                * 0.960

                * 0.840

                * 0.720

                * 0.600

                * 0.480

                * 0.360

                * 0.240

                * 0.120

                * 0.072

                * 0.060

                * 0.048

                * 0.036

                * 0.024

                * 0.012

                Use one of the following prices for Amazon Augmented AI custom human review tasks.
                Prices are in US dollars.

                * 1.200

                * 1.080

                * 0.960

                * 0.840

                * 0.720

                * 0.600

                * 0.480

                * 0.360

                * 0.240

                * 0.120

                * 0.072

                * 0.060

                * 0.048

                * 0.036

                * 0.024

                * 0.012

                - **AmountInUsd** *(dict) --*

                  Defines the amount of money paid to an Amazon Mechanical Turk worker in United
                  States dollars.

                  - **Dollars** *(integer) --*

                    The whole number of dollars in the amount.

                  - **Cents** *(integer) --*

                    The fractional portion, in cents, of the amount.

                  - **TenthFractionsOfACent** *(integer) --*

                    Fractions of a cent, in tenths.

            - **OutputConfig** *(dict) --*

              An object containing information about the output file.

              - **S3OutputPath** *(string) --*

                The Amazon S3 path where the object containing human output will be made available.

              - **KmsKeyId** *(string) --*

                The Amazon Key Management Service (KMS) key ID for server-side encryption.

            - **RoleArn** *(string) --*

              The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
              execution role for the flow definition.

            - **FailureReason** *(string) --*
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_human_task_ui(
        self, HumanTaskUiName: str
    ) -> ClientDescribeHumanTaskUiResponseTypeDef:
        """
        Returns information about the requested human task user interface.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeHumanTaskUi>`_

        **Request Syntax**
        ::

          response = client.describe_human_task_ui(
              HumanTaskUiName='string'
          )
        :type HumanTaskUiName: string
        :param HumanTaskUiName: **[REQUIRED]**

          The name of the human task user interface you want information about.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'HumanTaskUiArn': 'string',
                'HumanTaskUiName': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'UiTemplate': {
                    'Url': 'string',
                    'ContentSha256': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **HumanTaskUiArn** *(string) --*

              The Amazon Resource Name (ARN) of the human task user interface.

            - **HumanTaskUiName** *(string) --*

              The name of the human task user interface.

            - **CreationTime** *(datetime) --*

              The timestamp when the human task user interface was created.

            - **UiTemplate** *(dict) --*

              Container for user interface template information.

              - **Url** *(string) --*

                The URL for the user interface template.

              - **ContentSha256** *(string) --*

                The SHA 256 hash that you used to create the request signature.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_hyper_parameter_tuning_job(
        self, HyperParameterTuningJobName: str
    ) -> ClientDescribeHyperParameterTuningJobResponseTypeDef:
        """
        Gets a description of a hyperparameter tuning job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeHyperParameterTuningJob>`_

        **Request Syntax**
        ::

          response = client.describe_hyper_parameter_tuning_job(
              HyperParameterTuningJobName='string'
          )
        :type HyperParameterTuningJobName: string
        :param HyperParameterTuningJobName: **[REQUIRED]**

          The name of the tuning job to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'HyperParameterTuningJobName': 'string',
                'HyperParameterTuningJobArn': 'string',
                'HyperParameterTuningJobConfig': {
                    'Strategy': 'Bayesian'|'Random',
                    'HyperParameterTuningJobObjective': {
                        'Type': 'Maximize'|'Minimize',
                        'MetricName': 'string'
                    },
                    'ResourceLimits': {
                        'MaxNumberOfTrainingJobs': 123,
                        'MaxParallelTrainingJobs': 123
                    },
                    'ParameterRanges': {
                        'IntegerParameterRanges': [
                            {
                                'Name': 'string',
                                'MinValue': 'string',
                                'MaxValue': 'string',
                                'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                            },
                        ],
                        'ContinuousParameterRanges': [
                            {
                                'Name': 'string',
                                'MinValue': 'string',
                                'MaxValue': 'string',
                                'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                            },
                        ],
                        'CategoricalParameterRanges': [
                            {
                                'Name': 'string',
                                'Values': [
                                    'string',
                                ]
                            },
                        ]
                    },
                    'TrainingJobEarlyStoppingType': 'Off'|'Auto',
                    'TuningJobCompletionCriteria': {
                        'TargetObjectiveMetricValue': ...
                    }
                },
                'TrainingJobDefinition': {
                    'DefinitionName': 'string',
                    'TuningObjective': {
                        'Type': 'Maximize'|'Minimize',
                        'MetricName': 'string'
                    },
                    'HyperParameterRanges': {
                        'IntegerParameterRanges': [
                            {
                                'Name': 'string',
                                'MinValue': 'string',
                                'MaxValue': 'string',
                                'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                            },
                        ],
                        'ContinuousParameterRanges': [
                            {
                                'Name': 'string',
                                'MinValue': 'string',
                                'MaxValue': 'string',
                                'ScalingType': 'Auto'|'Linear'|'Logarithmic'|'ReverseLogarithmic'
                            },
                        ],
                        'CategoricalParameterRanges': [
                            {
                                'Name': 'string',
                                'Values': [
                                    'string',
                                ]
                            },
                        ]
                    },
                    'StaticHyperParameters': {
                        'string': 'string'
                    },
                    'AlgorithmSpecification': {
                        'TrainingImage': 'string',
                        'TrainingInputMode': 'Pipe'|'File',
                        'AlgorithmName': 'string',
                        'MetricDefinitions': [
                            {
                                'Name': 'string',
                                'Regex': 'string'
                            },
                        ]
                    },
                    'RoleArn': 'string',
                    'InputDataConfig': [
                        {
                            'ChannelName': 'string',
                            'DataSource': {
                                'S3DataSource': {
                                    'S3DataType': 'ManifestFile'|'S3Prefix'|'AugmentedManifestFile',
                                    'S3Uri': 'string',
                                    'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key',
                                    'AttributeNames': [
                                        'string',
                                    ]
                                },
                                'FileSystemDataSource': {
                                    'FileSystemId': 'string',
                                    'FileSystemAccessMode': 'rw'|'ro',
                                    'FileSystemType': 'EFS'|'FSxLustre',
                                    'DirectoryPath': 'string'
                                }
                            },
                            'ContentType': 'string',
                            'CompressionType': 'None'|'Gzip',
                            'RecordWrapperType': 'None'|'RecordIO',
                            'InputMode': 'Pipe'|'File',
                            'ShuffleConfig': {
                                'Seed': 123
                            }
                        },
                    ],
                    'VpcConfig': {
                        'SecurityGroupIds': [
                            'string',
                        ],
                        'Subnets': [
                            'string',
                        ]
                    },
                    'OutputDataConfig': {
                        'KmsKeyId': 'string',
                        'S3OutputPath': 'string'
                    },
                    'ResourceConfig': {
                        'InstanceType':
                        'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'
                        |'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.large'
                        |'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'
                        |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'
                        |'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'
                        |'ml.p3dn.24xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                        |'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge',
                        'InstanceCount': 123,
                        'VolumeSizeInGB': 123,
                        'VolumeKmsKeyId': 'string'
                    },
                    'StoppingCondition': {
                        'MaxRuntimeInSeconds': 123,
                        'MaxWaitTimeInSeconds': 123
                    },
                    'EnableNetworkIsolation': True|False,
                    'EnableInterContainerTrafficEncryption': True|False,
                    'EnableManagedSpotTraining': True|False,
                    'CheckpointConfig': {
                        'S3Uri': 'string',
                        'LocalPath': 'string'
                    }
                },
                'TrainingJobDefinitions': [
                    {
                        'DefinitionName': 'string',
                        'TuningObjective': {
                            'Type': 'Maximize'|'Minimize',
                            'MetricName': 'string'
                        },
                        'HyperParameterRanges': {
                            'IntegerParameterRanges': [
                                {
                                    'Name': 'string',
                                    'MinValue': 'string',
                                    'MaxValue': 'string',
                                    'ScalingType':
                                    'Auto'|'Linear'|'Logarithmic'
                                    |'ReverseLogarithmic'
                                },
                            ],
                            'ContinuousParameterRanges': [
                                {
                                    'Name': 'string',
                                    'MinValue': 'string',
                                    'MaxValue': 'string',
                                    'ScalingType':
                                    'Auto'|'Linear'|'Logarithmic'
                                    |'ReverseLogarithmic'
                                },
                            ],
                            'CategoricalParameterRanges': [
                                {
                                    'Name': 'string',
                                    'Values': [
                                        'string',
                                    ]
                                },
                            ]
                        },
                        'StaticHyperParameters': {
                            'string': 'string'
                        },
                        'AlgorithmSpecification': {
                            'TrainingImage': 'string',
                            'TrainingInputMode': 'Pipe'|'File',
                            'AlgorithmName': 'string',
                            'MetricDefinitions': [
                                {
                                    'Name': 'string',
                                    'Regex': 'string'
                                },
                            ]
                        },
                        'RoleArn': 'string',
                        'InputDataConfig': [
                            {
                                'ChannelName': 'string',
                                'DataSource': {
                                    'S3DataSource': {
                                        'S3DataType':
                                        'ManifestFile'|'S3Prefix'
                                        |'AugmentedManifestFile',
                                        'S3Uri': 'string',
                                        'S3DataDistributionType':
                                        'FullyReplicated'
                                        |'ShardedByS3Key',
                                        'AttributeNames': [
                                            'string',
                                        ]
                                    },
                                    'FileSystemDataSource': {
                                        'FileSystemId': 'string',
                                        'FileSystemAccessMode': 'rw'|'ro',
                                        'FileSystemType': 'EFS'|'FSxLustre',
                                        'DirectoryPath': 'string'
                                    }
                                },
                                'ContentType': 'string',
                                'CompressionType': 'None'|'Gzip',
                                'RecordWrapperType': 'None'|'RecordIO',
                                'InputMode': 'Pipe'|'File',
                                'ShuffleConfig': {
                                    'Seed': 123
                                }
                            },
                        ],
                        'VpcConfig': {
                            'SecurityGroupIds': [
                                'string',
                            ],
                            'Subnets': [
                                'string',
                            ]
                        },
                        'OutputDataConfig': {
                            'KmsKeyId': 'string',
                            'S3OutputPath': 'string'
                        },
                        'ResourceConfig': {
                            'InstanceType':
                            'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'
                            |'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.large'
                            |'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                            |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'
                            |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'
                            |'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                            |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'
                            |'ml.p3dn.24xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                            |'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge',
                            'InstanceCount': 123,
                            'VolumeSizeInGB': 123,
                            'VolumeKmsKeyId': 'string'
                        },
                        'StoppingCondition': {
                            'MaxRuntimeInSeconds': 123,
                            'MaxWaitTimeInSeconds': 123
                        },
                        'EnableNetworkIsolation': True|False,
                        'EnableInterContainerTrafficEncryption': True|False,
                        'EnableManagedSpotTraining': True|False,
                        'CheckpointConfig': {
                            'S3Uri': 'string',
                            'LocalPath': 'string'
                        }
                    },
                ],
                'HyperParameterTuningJobStatus':
                'Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
                'CreationTime': datetime(2015, 1, 1),
                'HyperParameterTuningEndTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'TrainingJobStatusCounters': {
                    'Completed': 123,
                    'InProgress': 123,
                    'RetryableError': 123,
                    'NonRetryableError': 123,
                    'Stopped': 123
                },
                'ObjectiveStatusCounters': {
                    'Succeeded': 123,
                    'Pending': 123,
                    'Failed': 123
                },
                'BestTrainingJob': {
                    'TrainingJobDefinitionName': 'string',
                    'TrainingJobName': 'string',
                    'TrainingJobArn': 'string',
                    'TuningJobName': 'string',
                    'CreationTime': datetime(2015, 1, 1),
                    'TrainingStartTime': datetime(2015, 1, 1),
                    'TrainingEndTime': datetime(2015, 1, 1),
                    'TrainingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                    'TunedHyperParameters': {
                        'string': 'string'
                    },
                    'FailureReason': 'string',
                    'FinalHyperParameterTuningJobObjectiveMetric': {
                        'Type': 'Maximize'|'Minimize',
                        'MetricName': 'string',
                        'Value': ...
                    },
                    'ObjectiveStatus': 'Succeeded'|'Pending'|'Failed'
                },
                'OverallBestTrainingJob': {
                    'TrainingJobDefinitionName': 'string',
                    'TrainingJobName': 'string',
                    'TrainingJobArn': 'string',
                    'TuningJobName': 'string',
                    'CreationTime': datetime(2015, 1, 1),
                    'TrainingStartTime': datetime(2015, 1, 1),
                    'TrainingEndTime': datetime(2015, 1, 1),
                    'TrainingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                    'TunedHyperParameters': {
                        'string': 'string'
                    },
                    'FailureReason': 'string',
                    'FinalHyperParameterTuningJobObjectiveMetric': {
                        'Type': 'Maximize'|'Minimize',
                        'MetricName': 'string',
                        'Value': ...
                    },
                    'ObjectiveStatus': 'Succeeded'|'Pending'|'Failed'
                },
                'WarmStartConfig': {
                    'ParentHyperParameterTuningJobs': [
                        {
                            'HyperParameterTuningJobName': 'string'
                        },
                    ],
                    'WarmStartType': 'IdenticalDataAndAlgorithm'|'TransferLearning'
                },
                'FailureReason': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **HyperParameterTuningJobName** *(string) --*

              The name of the tuning job.

            - **HyperParameterTuningJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the tuning job.

            - **HyperParameterTuningJobConfig** *(dict) --*

              The  HyperParameterTuningJobConfig object that specifies the configuration of the
              tuning job.

              - **Strategy** *(string) --*

                Specifies how hyperparameter tuning chooses the combinations of hyperparameter
                values to use for the training job it launches. To use the Bayesian search strategy,
                set this to ``Bayesian`` . To randomly search, set it to ``Random`` . For
                information about search strategies, see `How Hyperparameter Tuning Works
                <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html>`__
                .

              - **HyperParameterTuningJobObjective** *(dict) --*

                The  HyperParameterTuningJobObjective object that specifies the objective metric for
                this tuning job.

                - **Type** *(string) --*

                  Whether to minimize or maximize the objective metric.

                - **MetricName** *(string) --*

                  The name of the metric to use for the objective metric.

              - **ResourceLimits** *(dict) --*

                The  ResourceLimits object that specifies the maximum number of training jobs and
                parallel training jobs for this tuning job.

                - **MaxNumberOfTrainingJobs** *(integer) --*

                  The maximum number of training jobs that a hyperparameter tuning job can launch.

                - **MaxParallelTrainingJobs** *(integer) --*

                  The maximum number of concurrent training jobs that a hyperparameter tuning job
                  can launch.

              - **ParameterRanges** *(dict) --*

                The  ParameterRanges object that specifies the ranges of hyperparameters that this
                tuning job searches.

                - **IntegerParameterRanges** *(list) --*

                  The array of  IntegerParameterRange objects that specify ranges of integer
                  hyperparameters that a hyperparameter tuning job searches.

                  - *(dict) --*

                    For a hyperparameter of the integer type, specifies the range that a
                    hyperparameter tuning job searches.

                    - **Name** *(string) --*

                      The name of the hyperparameter to search.

                    - **MinValue** *(string) --*

                      The minimum value of the hyperparameter to search.

                    - **MaxValue** *(string) --*

                      The maximum value of the hyperparameter to search.

                    - **ScalingType** *(string) --*

                      The scale that hyperparameter tuning uses to search the hyperparameter range.
                      For information about choosing a hyperparameter scale, see `Hyperparameter
                      Scaling
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                      . One of the following values:

                        Auto

                      Amazon SageMaker hyperparameter tuning chooses the best scale for the
                      hyperparameter.

                        Linear

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a linear scale.

                        Logarithmic

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a logarithmic scale.

                      Logarithmic scaling works only for ranges that have only values greater than
                      0.

                - **ContinuousParameterRanges** *(list) --*

                  The array of  ContinuousParameterRange objects that specify ranges of continuous
                  hyperparameters that a hyperparameter tuning job searches.

                  - *(dict) --*

                    A list of continuous hyperparameters to tune.

                    - **Name** *(string) --*

                      The name of the continuous hyperparameter to tune.

                    - **MinValue** *(string) --*

                      The minimum value for the hyperparameter. The tuning job uses floating-point
                      values between this value and ``MaxValue`` for tuning.

                    - **MaxValue** *(string) --*

                      The maximum value for the hyperparameter. The tuning job uses floating-point
                      values between ``MinValue`` value and this value for tuning.

                    - **ScalingType** *(string) --*

                      The scale that hyperparameter tuning uses to search the hyperparameter range.
                      For information about choosing a hyperparameter scale, see `Hyperparameter
                      Scaling
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                      . One of the following values:

                        Auto

                      Amazon SageMaker hyperparameter tuning chooses the best scale for the
                      hyperparameter.

                        Linear

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a linear scale.

                        Logarithmic

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a logarithmic scale.

                      Logarithmic scaling works only for ranges that have only values greater than
                      0.

                        ReverseLogarithmic

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a reverse logarithmic scale.

                      Reverse logarithmic scaling works only for ranges that are entirely within the
                      range 0<=x<1.0.

                - **CategoricalParameterRanges** *(list) --*

                  The array of  CategoricalParameterRange objects that specify ranges of categorical
                  hyperparameters that a hyperparameter tuning job searches.

                  - *(dict) --*

                    A list of categorical hyperparameters to tune.

                    - **Name** *(string) --*

                      The name of the categorical hyperparameter to tune.

                    - **Values** *(list) --*

                      A list of the categories for the hyperparameter.

                      - *(string) --*

              - **TrainingJobEarlyStoppingType** *(string) --*

                Specifies whether to use early stopping for training jobs launched by the
                hyperparameter tuning job. This can be one of the following values (the default
                value is ``OFF`` ):

                  OFF

                Training jobs launched by the hyperparameter tuning job do not use early stopping.

                  AUTO

                Amazon SageMaker stops training jobs launched by the hyperparameter tuning job when
                they are unlikely to perform better than previously completed training jobs. For
                more information, see `Stop Training Jobs Early
                <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-early-stopping.html>`__
                .

              - **TuningJobCompletionCriteria** *(dict) --*

                The tuning job's completion criteria.

                - **TargetObjectiveMetricValue** *(float) --*

                  The objective metric's value.

            - **TrainingJobDefinition** *(dict) --*

              The  HyperParameterTrainingJobDefinition object that specifies the definition of the
              training jobs that this tuning job launches.

              - **DefinitionName** *(string) --*

                The job definition name.

              - **TuningObjective** *(dict) --*

                Defines the objective metric for a hyperparameter tuning job. Hyperparameter tuning
                uses the value of this metric to evaluate the training jobs it launches, and returns
                the training job that results in either the highest or lowest value for this metric,
                depending on the value you specify for the ``Type`` parameter.

                - **Type** *(string) --*

                  Whether to minimize or maximize the objective metric.

                - **MetricName** *(string) --*

                  The name of the metric to use for the objective metric.

              - **HyperParameterRanges** *(dict) --*

                Specifies ranges of integer, continuous, and categorical hyperparameters that a
                hyperparameter tuning job searches. The hyperparameter tuning job launches training
                jobs with hyperparameter values within these ranges to find the combination of
                values that result in the training job with the best performance as measured by the
                objective metric of the hyperparameter tuning job.

                .. note::

                  You can specify a maximum of 20 hyperparameters that a hyperparameter tuning job
                  can search over. Every possible value of a categorical parameter range counts
                  against this limit.

                - **IntegerParameterRanges** *(list) --*

                  The array of  IntegerParameterRange objects that specify ranges of integer
                  hyperparameters that a hyperparameter tuning job searches.

                  - *(dict) --*

                    For a hyperparameter of the integer type, specifies the range that a
                    hyperparameter tuning job searches.

                    - **Name** *(string) --*

                      The name of the hyperparameter to search.

                    - **MinValue** *(string) --*

                      The minimum value of the hyperparameter to search.

                    - **MaxValue** *(string) --*

                      The maximum value of the hyperparameter to search.

                    - **ScalingType** *(string) --*

                      The scale that hyperparameter tuning uses to search the hyperparameter range.
                      For information about choosing a hyperparameter scale, see `Hyperparameter
                      Scaling
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                      . One of the following values:

                        Auto

                      Amazon SageMaker hyperparameter tuning chooses the best scale for the
                      hyperparameter.

                        Linear

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a linear scale.

                        Logarithmic

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a logarithmic scale.

                      Logarithmic scaling works only for ranges that have only values greater than
                      0.

                - **ContinuousParameterRanges** *(list) --*

                  The array of  ContinuousParameterRange objects that specify ranges of continuous
                  hyperparameters that a hyperparameter tuning job searches.

                  - *(dict) --*

                    A list of continuous hyperparameters to tune.

                    - **Name** *(string) --*

                      The name of the continuous hyperparameter to tune.

                    - **MinValue** *(string) --*

                      The minimum value for the hyperparameter. The tuning job uses floating-point
                      values between this value and ``MaxValue`` for tuning.

                    - **MaxValue** *(string) --*

                      The maximum value for the hyperparameter. The tuning job uses floating-point
                      values between ``MinValue`` value and this value for tuning.

                    - **ScalingType** *(string) --*

                      The scale that hyperparameter tuning uses to search the hyperparameter range.
                      For information about choosing a hyperparameter scale, see `Hyperparameter
                      Scaling
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                      . One of the following values:

                        Auto

                      Amazon SageMaker hyperparameter tuning chooses the best scale for the
                      hyperparameter.

                        Linear

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a linear scale.

                        Logarithmic

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a logarithmic scale.

                      Logarithmic scaling works only for ranges that have only values greater than
                      0.

                        ReverseLogarithmic

                      Hyperparameter tuning searches the values in the hyperparameter range by using
                      a reverse logarithmic scale.

                      Reverse logarithmic scaling works only for ranges that are entirely within the
                      range 0<=x<1.0.

                - **CategoricalParameterRanges** *(list) --*

                  The array of  CategoricalParameterRange objects that specify ranges of categorical
                  hyperparameters that a hyperparameter tuning job searches.

                  - *(dict) --*

                    A list of categorical hyperparameters to tune.

                    - **Name** *(string) --*

                      The name of the categorical hyperparameter to tune.

                    - **Values** *(list) --*

                      A list of the categories for the hyperparameter.

                      - *(string) --*

              - **StaticHyperParameters** *(dict) --*

                Specifies the values of hyperparameters that do not change for the tuning job.

                - *(string) --*

                  - *(string) --*

              - **AlgorithmSpecification** *(dict) --*

                The  HyperParameterAlgorithmSpecification object that specifies the resource
                algorithm to use for the training jobs that the tuning job launches.

                - **TrainingImage** *(string) --*

                  The registry path of the Docker image that contains the training algorithm. For
                  information about Docker registry paths for built-in algorithms, see `Algorithms
                  Provided by Amazon SageMaker\\: Common Parameters
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                  . Amazon SageMaker supports both ``registry/repository[:tag]`` and
                  ``registry/repository[@digest]`` image path formats. For more information, see
                  `Using Your Own Algorithms with Amazon SageMaker
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

                - **TrainingInputMode** *(string) --*

                  The input mode that the algorithm supports: File or Pipe. In File input mode,
                  Amazon SageMaker downloads the training data from Amazon S3 to the storage volume
                  that is attached to the training instance and mounts the directory to the Docker
                  volume for the training container. In Pipe input mode, Amazon SageMaker streams
                  data directly from Amazon S3 to the container.

                  If you specify File mode, make sure that you provision the storage volume that is
                  attached to the training instance with enough capacity to accommodate the training
                  data downloaded from Amazon S3, the model artifacts, and intermediate information.

                  For more information about input modes, see `Algorithms
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

                - **AlgorithmName** *(string) --*

                  The name of the resource algorithm to use for the hyperparameter tuning job. If
                  you specify a value for this parameter, do not specify a value for
                  ``TrainingImage`` .

                - **MetricDefinitions** *(list) --*

                  An array of  MetricDefinition objects that specify the metrics that the algorithm
                  emits.

                  - *(dict) --*

                    Specifies a metric that the training algorithm writes to ``stderr`` or
                    ``stdout`` . Amazon SageMakerhyperparameter tuning captures all defined metrics.
                    You specify one metric that a hyperparameter tuning job uses as its objective
                    metric to choose the best training job.

                    - **Name** *(string) --*

                      The name of the metric.

                    - **Regex** *(string) --*

                      A regular expression that searches the output of a training job and gets the
                      value of the metric. For more information about using regular expressions to
                      define metrics, see `Defining Objective Metrics
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                      .

              - **RoleArn** *(string) --*

                The Amazon Resource Name (ARN) of the IAM role associated with the training jobs
                that the tuning job launches.

              - **InputDataConfig** *(list) --*

                An array of  Channel objects that specify the input for the training jobs that the
                tuning job launches.

                - *(dict) --*

                  A channel is a named input source that training algorithms can consume.

                  - **ChannelName** *(string) --*

                    The name of the channel.

                  - **DataSource** *(dict) --*

                    The location of the channel data.

                    - **S3DataSource** *(dict) --*

                      The S3 location of the data source that is associated with a channel.

                      - **S3DataType** *(string) --*

                        If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                        SageMaker uses all objects that match the specified key name prefix for
                        model training.

                        If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                        manifest file containing a list of object keys that you want Amazon
                        SageMaker to use for model training.

                        If you choose ``AugmentedManifestFile`` , S3Uri identifies an object that is
                        an augmented manifest file in JSON lines format. This file contains the data
                        you want to use for model training. ``AugmentedManifestFile`` can only be
                        used if the Channel's input mode is ``Pipe`` .

                      - **S3Uri** *(string) --*

                        Depending on the value specified for the ``S3DataType`` , identifies either
                        a key name prefix or a manifest. For example:

                        * A key name prefix might look like this: ``s3://bucketname/exampleprefix``
                        .

                        * A manifest might look like this: ``s3://bucketname/example.manifest``
                        The manifest is an S3 object which is a JSON file with the following format:
                        The preceding JSON matches the following ``s3Uris`` :   ``[ {"prefix":
                        "s3://customer_bucket/some/prefix/"},``
                        ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                        ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                        matches the following ``s3Uris`` :
                        ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                        ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                        ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete
                        set of ``s3uris`` in this manifest is the input data for the channel for
                        this datasource. The object that each ``s3uris`` points to must be readable
                        by the IAM role that Amazon SageMaker uses to perform tasks on your behalf.

                      - **S3DataDistributionType** *(string) --*

                        If you want Amazon SageMaker to replicate the entire dataset on each ML
                        compute instance that is launched for model training, specify
                        ``FullyReplicated`` .

                        If you want Amazon SageMaker to replicate a subset of data on each ML
                        compute instance that is launched for model training, specify
                        ``ShardedByS3Key`` . If there are *n* ML compute instances launched for a
                        training job, each instance gets approximately 1/*n* of the number of S3
                        objects. In this case, model training on each machine uses only the subset
                        of training data.

                        Don't choose more ML compute instances for training than available S3
                        objects. If you do, some nodes won't get any data and you will pay for nodes
                        that aren't getting any training data. This applies in both File and Pipe
                        modes. Keep this in mind when developing algorithms.

                        In distributed training, where you use multiple ML compute EC2 instances,
                        you might choose ``ShardedByS3Key`` . If the algorithm requires copying
                        training data to the ML storage volume (when ``TrainingInputMode`` is set to
                        ``File`` ), this copies 1/*n* of the number of objects.

                      - **AttributeNames** *(list) --*

                        A list of one or more attribute names to use that are found in a specified
                        augmented manifest file.

                        - *(string) --*

                    - **FileSystemDataSource** *(dict) --*

                      The file system that is associated with a channel.

                      - **FileSystemId** *(string) --*

                        The file system id.

                      - **FileSystemAccessMode** *(string) --*

                        The access mode of the mount of the directory associated with the channel. A
                        directory can be mounted either in ``ro`` (read-only) or ``rw`` (read-write)
                        mode.

                      - **FileSystemType** *(string) --*

                        The file system type.

                      - **DirectoryPath** *(string) --*

                        The full path to the directory to associate with the channel.

                  - **ContentType** *(string) --*

                    The MIME type of the data.

                  - **CompressionType** *(string) --*

                    If training data is compressed, the compression type. The default value is
                    ``None`` . ``CompressionType`` is used only in Pipe input mode. In File mode,
                    leave this field unset or set it to None.

                  - **RecordWrapperType** *(string) --*

                    Specify RecordIO as the value when input data is in raw format but the training
                    algorithm requires the RecordIO format. In this case, Amazon SageMaker wraps
                    each individual S3 object in a RecordIO record. If the input data is already in
                    RecordIO format, you don't need to set this attribute. For more information, see
                    `Create a Dataset Using RecordIO
                    <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__ .

                    In File mode, leave this field unset or set it to None.

                  - **InputMode** *(string) --*

                    (Optional) The input mode to use for the data channel in a training job. If you
                    don't set a value for ``InputMode`` , Amazon SageMaker uses the value set for
                    ``TrainingInputMode`` . Use this parameter to override the ``TrainingInputMode``
                    setting in a  AlgorithmSpecification request when you have a channel that needs
                    a different input mode from the training job's general setting. To download the
                    data from Amazon Simple Storage Service (Amazon S3) to the provisioned ML
                    storage volume, and mount the directory to a Docker volume, use ``File`` input
                    mode. To stream data directly from Amazon S3 to the container, choose ``Pipe``
                    input mode.

                    To use a model for incremental training, choose ``File`` input model.

                  - **ShuffleConfig** *(dict) --*

                    A configuration for a shuffle option for input data in a channel. If you use
                    ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key prefix
                    matches. If you use ``ManifestFile`` , the order of the S3 object references in
                    the ``ManifestFile`` is shuffled. If you use ``AugmentedManifestFile`` , the
                    order of the JSON lines in the ``AugmentedManifestFile`` is shuffled. The
                    shuffling order is determined using the ``Seed`` value.

                    For Pipe input mode, shuffling is done at the start of every epoch. With large
                    datasets this ensures that the order of the training data is different for each
                    epoch, it helps reduce bias and possible overfitting. In a multi-node training
                    job when ShuffleConfig is combined with ``S3DataDistributionType`` of
                    ``ShardedByS3Key`` , the data is shuffled across nodes so that the content sent
                    to a particular node on the first epoch might be sent to a different node on the
                    second epoch.

                    - **Seed** *(integer) --*

                      Determines the shuffling order in ``ShuffleConfig`` value.

              - **VpcConfig** *(dict) --*

                The  VpcConfig object that specifies the VPC that you want the training jobs that
                this hyperparameter tuning job launches to connect to. Control access to and from
                your training container by configuring the VPC. For more information, see `Protect
                Training Jobs by Using an Amazon Virtual Private Cloud
                <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                - **SecurityGroupIds** *(list) --*

                  The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups
                  for the VPC that is specified in the ``Subnets`` field.

                  - *(string) --*

                - **Subnets** *(list) --*

                  The ID of the subnets in the VPC to which you want to connect your training job or
                  model.

                  .. note::

                    Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                    availability zones of region us-east-1. If you want to create endpoints with P3
                    instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                    zones instead.

                  - *(string) --*

              - **OutputDataConfig** *(dict) --*

                Specifies the path to the Amazon S3 bucket where you store model artifacts from the
                training jobs that the tuning job launches.

                - **KmsKeyId** *(string) --*

                  The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                  the model artifacts at rest using Amazon S3 server-side encryption. The
                  ``KmsKeyId`` can be any of the following formats:

                  * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                  * // Amazon Resource Name (ARN) of a KMS Key
                  ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                  * // KMS Key Alias  ``"alias/ExampleAlias"``

                  * // Amazon Resource Name (ARN) of a KMS Key Alias
                  ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                  If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                  execution role must include permissions to call ``kms:Encrypt`` . If you don't
                  provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3 for
                  your role's account. Amazon SageMaker uses server-side encryption with KMS-managed
                  keys for ``OutputDataConfig`` . If you use a bucket policy with an
                  ``s3:PutObject`` permission that only allows objects with server-side encryption,
                  set the condition key of ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` .
                  For more information, see `KMS-Managed Encryption Keys
                  <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in
                  the *Amazon Simple Storage Service Developer Guide.*

                  The KMS key policy must grant permission to the IAM role that you specify in your
                  ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                  ``CreateHyperParameterTuningJob`` requests. For more information, see `Using Key
                  Policies in AWS KMS
                  <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the
                  *AWS Key Management Service Developer Guide* .

                - **S3OutputPath** *(string) --*

                  Identifies the S3 path where you want Amazon SageMaker to store the model
                  artifacts. For example, ``s3://bucket-name/key-name-prefix`` .

              - **ResourceConfig** *(dict) --*

                The resources, including the compute instances and storage volumes, to use for the
                training jobs that the tuning job launches.

                Storage volumes store model artifacts and incremental states. Training algorithms
                might also use storage volumes for scratch space. If you want Amazon SageMaker to
                use the storage volume to store the training data, choose ``File`` as the
                ``TrainingInputMode`` in the algorithm specification. For distributed training
                algorithms, specify an instance count greater than 1.

                - **InstanceType** *(string) --*

                  The ML compute instance type.

                - **InstanceCount** *(integer) --*

                  The number of ML compute instances to use. For distributed training, provide a
                  value greater than 1.

                - **VolumeSizeInGB** *(integer) --*

                  The size of the ML storage volume that you want to provision.

                  ML storage volumes store model artifacts and incremental states. Training
                  algorithms might also use the ML storage volume for scratch space. If you want to
                  store the training data in the ML storage volume, choose ``File`` as the
                  ``TrainingInputMode`` in the algorithm specification.

                  You must specify sufficient ML storage for your scenario.

                  .. note::

                    Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage volume
                    type.

                  .. note::

                    Certain Nitro-based instances include local storage with a fixed total size,
                    dependent on the instance type. When using these instances for training, Amazon
                    SageMaker mounts the local instance storage instead of Amazon EBS gp2 storage.
                    You can't request a ``VolumeSizeInGB`` greater than the total size of the local
                    instance storage.

                    For a list of instance types that support local instance storage, including the
                    total size per instance type, see `Instance Store Volumes
                    <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                    .

                - **VolumeKmsKeyId** *(string) --*

                  The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume
                  attached to the ML compute instance(s) that run the training job.

                  .. note::

                    Certain Nitro-based instances include local storage, dependent on the instance
                    type. Local storage volumes are encrypted using a hardware module on the
                    instance. You can't request a ``VolumeKmsKeyId`` when using an instance type
                    with local storage.

                    For a list of instance types that support local instance storage, see `Instance
                    Store Volumes
                    <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                    .

                    For more information about local instance storage encryption, see `SSD Instance
                    Store Volumes
                    <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__
                    .

                  The ``VolumeKmsKeyId`` can be in any of the following formats:

                  * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                  * // Amazon Resource Name (ARN) of a KMS Key
                  ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

              - **StoppingCondition** *(dict) --*

                Specifies a limit to how long a model hyperparameter training job can run. It also
                specifies how long you are willing to wait for a managed spot training job to
                complete. When the job reaches the a limit, Amazon SageMaker ends the training job.
                Use this API to cap model training costs.

                - **MaxRuntimeInSeconds** *(integer) --*

                  The maximum length of time, in seconds, that the training or compilation job can
                  run. If job does not complete during this time, Amazon SageMaker ends the job. If
                  value is not specified, default value is 1 day. The maximum value is 28 days.

                - **MaxWaitTimeInSeconds** *(integer) --*

                  The maximum length of time, in seconds, how long you are willing to wait for a
                  managed spot training job to complete. It is the amount of time spent waiting for
                  Spot capacity plus the amount of time the training job runs. It must be equal to
                  or greater than ``MaxRuntimeInSeconds`` .

              - **EnableNetworkIsolation** *(boolean) --*

                Isolates the training container. No inbound or outbound network calls can be made,
                except for calls between peers within a training cluster for distributed training.
                If network isolation is used for training jobs that are configured to use a VPC,
                Amazon SageMaker downloads and uploads customer data and model artifacts through the
                specified VPC, but the training container does not have network access.

                .. note::

                  The Semantic Segmentation built-in algorithm does not support network isolation.

              - **EnableInterContainerTrafficEncryption** *(boolean) --*

                To encrypt all communications between ML compute instances in distributed training,
                choose ``True`` . Encryption provides greater security for distributed training, but
                training might take longer. How long it takes depends on the amount of communication
                between compute instances, especially if you use a deep learning algorithm in
                distributed training.

              - **EnableManagedSpotTraining** *(boolean) --*

                A Boolean indicating whether managed spot training is enabled (``True`` ) or not
                (``False`` ).

              - **CheckpointConfig** *(dict) --*

                Contains information about the output location for managed spot training checkpoint
                data.

                - **S3Uri** *(string) --*

                  Identifies the S3 path where you want Amazon SageMaker to store checkpoints. For
                  example, ``s3://bucket-name/key-name-prefix`` .

                - **LocalPath** *(string) --*

                  (Optional) The local directory where checkpoints are written. The default
                  directory is ``/opt/ml/checkpoints/`` .

            - **TrainingJobDefinitions** *(list) --*

              - *(dict) --*

                Defines the training jobs launched by a hyperparameter tuning job.

                - **DefinitionName** *(string) --*

                  The job definition name.

                - **TuningObjective** *(dict) --*

                  Defines the objective metric for a hyperparameter tuning job. Hyperparameter
                  tuning uses the value of this metric to evaluate the training jobs it launches,
                  and returns the training job that results in either the highest or lowest value
                  for this metric, depending on the value you specify for the ``Type`` parameter.

                  - **Type** *(string) --*

                    Whether to minimize or maximize the objective metric.

                  - **MetricName** *(string) --*

                    The name of the metric to use for the objective metric.

                - **HyperParameterRanges** *(dict) --*

                  Specifies ranges of integer, continuous, and categorical hyperparameters that a
                  hyperparameter tuning job searches. The hyperparameter tuning job launches
                  training jobs with hyperparameter values within these ranges to find the
                  combination of values that result in the training job with the best performance as
                  measured by the objective metric of the hyperparameter tuning job.

                  .. note::

                    You can specify a maximum of 20 hyperparameters that a hyperparameter tuning job
                    can search over. Every possible value of a categorical parameter range counts
                    against this limit.

                  - **IntegerParameterRanges** *(list) --*

                    The array of  IntegerParameterRange objects that specify ranges of integer
                    hyperparameters that a hyperparameter tuning job searches.

                    - *(dict) --*

                      For a hyperparameter of the integer type, specifies the range that a
                      hyperparameter tuning job searches.

                      - **Name** *(string) --*

                        The name of the hyperparameter to search.

                      - **MinValue** *(string) --*

                        The minimum value of the hyperparameter to search.

                      - **MaxValue** *(string) --*

                        The maximum value of the hyperparameter to search.

                      - **ScalingType** *(string) --*

                        The scale that hyperparameter tuning uses to search the hyperparameter
                        range. For information about choosing a hyperparameter scale, see
                        `Hyperparameter Scaling
                        <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                        . One of the following values:

                          Auto

                        Amazon SageMaker hyperparameter tuning chooses the best scale for the
                        hyperparameter.

                          Linear

                        Hyperparameter tuning searches the values in the hyperparameter range by
                        using a linear scale.

                          Logarithmic

                        Hyperparameter tuning searches the values in the hyperparameter range by
                        using a logarithmic scale.

                        Logarithmic scaling works only for ranges that have only values greater than
                        0.

                  - **ContinuousParameterRanges** *(list) --*

                    The array of  ContinuousParameterRange objects that specify ranges of continuous
                    hyperparameters that a hyperparameter tuning job searches.

                    - *(dict) --*

                      A list of continuous hyperparameters to tune.

                      - **Name** *(string) --*

                        The name of the continuous hyperparameter to tune.

                      - **MinValue** *(string) --*

                        The minimum value for the hyperparameter. The tuning job uses floating-point
                        values between this value and ``MaxValue`` for tuning.

                      - **MaxValue** *(string) --*

                        The maximum value for the hyperparameter. The tuning job uses floating-point
                        values between ``MinValue`` value and this value for tuning.

                      - **ScalingType** *(string) --*

                        The scale that hyperparameter tuning uses to search the hyperparameter
                        range. For information about choosing a hyperparameter scale, see
                        `Hyperparameter Scaling
                        <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-ranges.html#scaling-type>`__
                        . One of the following values:

                          Auto

                        Amazon SageMaker hyperparameter tuning chooses the best scale for the
                        hyperparameter.

                          Linear

                        Hyperparameter tuning searches the values in the hyperparameter range by
                        using a linear scale.

                          Logarithmic

                        Hyperparameter tuning searches the values in the hyperparameter range by
                        using a logarithmic scale.

                        Logarithmic scaling works only for ranges that have only values greater than
                        0.

                          ReverseLogarithmic

                        Hyperparameter tuning searches the values in the hyperparameter range by
                        using a reverse logarithmic scale.

                        Reverse logarithmic scaling works only for ranges that are entirely within
                        the range 0<=x<1.0.

                  - **CategoricalParameterRanges** *(list) --*

                    The array of  CategoricalParameterRange objects that specify ranges of
                    categorical hyperparameters that a hyperparameter tuning job searches.

                    - *(dict) --*

                      A list of categorical hyperparameters to tune.

                      - **Name** *(string) --*

                        The name of the categorical hyperparameter to tune.

                      - **Values** *(list) --*

                        A list of the categories for the hyperparameter.

                        - *(string) --*

                - **StaticHyperParameters** *(dict) --*

                  Specifies the values of hyperparameters that do not change for the tuning job.

                  - *(string) --*

                    - *(string) --*

                - **AlgorithmSpecification** *(dict) --*

                  The  HyperParameterAlgorithmSpecification object that specifies the resource
                  algorithm to use for the training jobs that the tuning job launches.

                  - **TrainingImage** *(string) --*

                    The registry path of the Docker image that contains the training algorithm. For
                    information about Docker registry paths for built-in algorithms, see `Algorithms
                    Provided by Amazon SageMaker\\: Common Parameters
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                    . Amazon SageMaker supports both ``registry/repository[:tag]`` and
                    ``registry/repository[@digest]`` image path formats. For more information, see
                    `Using Your Own Algorithms with Amazon SageMaker
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

                  - **TrainingInputMode** *(string) --*

                    The input mode that the algorithm supports: File or Pipe. In File input mode,
                    Amazon SageMaker downloads the training data from Amazon S3 to the storage
                    volume that is attached to the training instance and mounts the directory to the
                    Docker volume for the training container. In Pipe input mode, Amazon SageMaker
                    streams data directly from Amazon S3 to the container.

                    If you specify File mode, make sure that you provision the storage volume that
                    is attached to the training instance with enough capacity to accommodate the
                    training data downloaded from Amazon S3, the model artifacts, and intermediate
                    information.

                    For more information about input modes, see `Algorithms
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ .

                  - **AlgorithmName** *(string) --*

                    The name of the resource algorithm to use for the hyperparameter tuning job. If
                    you specify a value for this parameter, do not specify a value for
                    ``TrainingImage`` .

                  - **MetricDefinitions** *(list) --*

                    An array of  MetricDefinition objects that specify the metrics that the
                    algorithm emits.

                    - *(dict) --*

                      Specifies a metric that the training algorithm writes to ``stderr`` or
                      ``stdout`` . Amazon SageMakerhyperparameter tuning captures all defined
                      metrics. You specify one metric that a hyperparameter tuning job uses as its
                      objective metric to choose the best training job.

                      - **Name** *(string) --*

                        The name of the metric.

                      - **Regex** *(string) --*

                        A regular expression that searches the output of a training job and gets the
                        value of the metric. For more information about using regular expressions to
                        define metrics, see `Defining Objective Metrics
                        <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                        .

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the IAM role associated with the training jobs
                  that the tuning job launches.

                - **InputDataConfig** *(list) --*

                  An array of  Channel objects that specify the input for the training jobs that the
                  tuning job launches.

                  - *(dict) --*

                    A channel is a named input source that training algorithms can consume.

                    - **ChannelName** *(string) --*

                      The name of the channel.

                    - **DataSource** *(dict) --*

                      The location of the channel data.

                      - **S3DataSource** *(dict) --*

                        The S3 location of the data source that is associated with a channel.

                        - **S3DataType** *(string) --*

                          If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix.
                          Amazon SageMaker uses all objects that match the specified key name prefix
                          for model training.

                          If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                          manifest file containing a list of object keys that you want Amazon
                          SageMaker to use for model training.

                          If you choose ``AugmentedManifestFile`` , S3Uri identifies an object that
                          is an augmented manifest file in JSON lines format. This file contains the
                          data you want to use for model training. ``AugmentedManifestFile`` can
                          only be used if the Channel's input mode is ``Pipe`` .

                        - **S3Uri** *(string) --*

                          Depending on the value specified for the ``S3DataType`` , identifies
                          either a key name prefix or a manifest. For example:

                          * A key name prefix might look like this:
                          ``s3://bucketname/exampleprefix`` .

                          * A manifest might look like this: ``s3://bucketname/example.manifest``
                          The manifest is an S3 object which is a JSON file with the following
                          format:  The preceding JSON matches the following ``s3Uris`` :   ``[
                          {"prefix": "s3://customer_bucket/some/prefix/"},``
                          ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                          ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                          matches the following ``s3Uris`` :
                          ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                          ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                          ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The
                          complete set of ``s3uris`` in this manifest is the input data for the
                          channel for this datasource. The object that each ``s3uris`` points to
                          must be readable by the IAM role that Amazon SageMaker uses to perform
                          tasks on your behalf.

                        - **S3DataDistributionType** *(string) --*

                          If you want Amazon SageMaker to replicate the entire dataset on each ML
                          compute instance that is launched for model training, specify
                          ``FullyReplicated`` .

                          If you want Amazon SageMaker to replicate a subset of data on each ML
                          compute instance that is launched for model training, specify
                          ``ShardedByS3Key`` . If there are *n* ML compute instances launched for a
                          training job, each instance gets approximately 1/*n* of the number of S3
                          objects. In this case, model training on each machine uses only the subset
                          of training data.

                          Don't choose more ML compute instances for training than available S3
                          objects. If you do, some nodes won't get any data and you will pay for
                          nodes that aren't getting any training data. This applies in both File and
                          Pipe modes. Keep this in mind when developing algorithms.

                          In distributed training, where you use multiple ML compute EC2 instances,
                          you might choose ``ShardedByS3Key`` . If the algorithm requires copying
                          training data to the ML storage volume (when ``TrainingInputMode`` is set
                          to ``File`` ), this copies 1/*n* of the number of objects.

                        - **AttributeNames** *(list) --*

                          A list of one or more attribute names to use that are found in a specified
                          augmented manifest file.

                          - *(string) --*

                      - **FileSystemDataSource** *(dict) --*

                        The file system that is associated with a channel.

                        - **FileSystemId** *(string) --*

                          The file system id.

                        - **FileSystemAccessMode** *(string) --*

                          The access mode of the mount of the directory associated with the channel.
                          A directory can be mounted either in ``ro`` (read-only) or ``rw``
                          (read-write) mode.

                        - **FileSystemType** *(string) --*

                          The file system type.

                        - **DirectoryPath** *(string) --*

                          The full path to the directory to associate with the channel.

                    - **ContentType** *(string) --*

                      The MIME type of the data.

                    - **CompressionType** *(string) --*

                      If training data is compressed, the compression type. The default value is
                      ``None`` . ``CompressionType`` is used only in Pipe input mode. In File mode,
                      leave this field unset or set it to None.

                    - **RecordWrapperType** *(string) --*

                      Specify RecordIO as the value when input data is in raw format but the
                      training algorithm requires the RecordIO format. In this case, Amazon
                      SageMaker wraps each individual S3 object in a RecordIO record. If the input
                      data is already in RecordIO format, you don't need to set this attribute. For
                      more information, see `Create a Dataset Using RecordIO
                      <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__ .

                      In File mode, leave this field unset or set it to None.

                    - **InputMode** *(string) --*

                      (Optional) The input mode to use for the data channel in a training job. If
                      you don't set a value for ``InputMode`` , Amazon SageMaker uses the value set
                      for ``TrainingInputMode`` . Use this parameter to override the
                      ``TrainingInputMode`` setting in a  AlgorithmSpecification request when you
                      have a channel that needs a different input mode from the training job's
                      general setting. To download the data from Amazon Simple Storage Service
                      (Amazon S3) to the provisioned ML storage volume, and mount the directory to a
                      Docker volume, use ``File`` input mode. To stream data directly from Amazon S3
                      to the container, choose ``Pipe`` input mode.

                      To use a model for incremental training, choose ``File`` input model.

                    - **ShuffleConfig** *(dict) --*

                      A configuration for a shuffle option for input data in a channel. If you use
                      ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key
                      prefix matches. If you use ``ManifestFile`` , the order of the S3 object
                      references in the ``ManifestFile`` is shuffled. If you use
                      ``AugmentedManifestFile`` , the order of the JSON lines in the
                      ``AugmentedManifestFile`` is shuffled. The shuffling order is determined using
                      the ``Seed`` value.

                      For Pipe input mode, shuffling is done at the start of every epoch. With large
                      datasets this ensures that the order of the training data is different for
                      each epoch, it helps reduce bias and possible overfitting. In a multi-node
                      training job when ShuffleConfig is combined with ``S3DataDistributionType`` of
                      ``ShardedByS3Key`` , the data is shuffled across nodes so that the content
                      sent to a particular node on the first epoch might be sent to a different node
                      on the second epoch.

                      - **Seed** *(integer) --*

                        Determines the shuffling order in ``ShuffleConfig`` value.

                - **VpcConfig** *(dict) --*

                  The  VpcConfig object that specifies the VPC that you want the training jobs that
                  this hyperparameter tuning job launches to connect to. Control access to and from
                  your training container by configuring the VPC. For more information, see `Protect
                  Training Jobs by Using an Amazon Virtual Private Cloud
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                  - **SecurityGroupIds** *(list) --*

                    The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups
                    for the VPC that is specified in the ``Subnets`` field.

                    - *(string) --*

                  - **Subnets** *(list) --*

                    The ID of the subnets in the VPC to which you want to connect your training job
                    or model.

                    .. note::

                      Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                      availability zones of region us-east-1. If you want to create endpoints with
                      P3 instances in VPC mode in region us-east-1, create subnets in a/b/f
                      availability zones instead.

                    - *(string) --*

                - **OutputDataConfig** *(dict) --*

                  Specifies the path to the Amazon S3 bucket where you store model artifacts from
                  the training jobs that the tuning job launches.

                  - **KmsKeyId** *(string) --*

                    The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                    encrypt the model artifacts at rest using Amazon S3 server-side encryption. The
                    ``KmsKeyId`` can be any of the following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // KMS Key Alias  ``"alias/ExampleAlias"``

                    * // Amazon Resource Name (ARN) of a KMS Key Alias
                    ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                    If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                    execution role must include permissions to call ``kms:Encrypt`` . If you don't
                    provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3
                    for your role's account. Amazon SageMaker uses server-side encryption with
                    KMS-managed keys for ``OutputDataConfig`` . If you use a bucket policy with an
                    ``s3:PutObject`` permission that only allows objects with server-side
                    encryption, set the condition key of ``s3:x-amz-server-side-encryption`` to
                    ``"aws:kms"`` . For more information, see `KMS-Managed Encryption Keys
                    <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in
                    the *Amazon Simple Storage Service Developer Guide.*

                    The KMS key policy must grant permission to the IAM role that you specify in
                    your ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                    ``CreateHyperParameterTuningJob`` requests. For more information, see `Using Key
                    Policies in AWS KMS
                    <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in
                    the *AWS Key Management Service Developer Guide* .

                  - **S3OutputPath** *(string) --*

                    Identifies the S3 path where you want Amazon SageMaker to store the model
                    artifacts. For example, ``s3://bucket-name/key-name-prefix`` .

                - **ResourceConfig** *(dict) --*

                  The resources, including the compute instances and storage volumes, to use for the
                  training jobs that the tuning job launches.

                  Storage volumes store model artifacts and incremental states. Training algorithms
                  might also use storage volumes for scratch space. If you want Amazon SageMaker to
                  use the storage volume to store the training data, choose ``File`` as the
                  ``TrainingInputMode`` in the algorithm specification. For distributed training
                  algorithms, specify an instance count greater than 1.

                  - **InstanceType** *(string) --*

                    The ML compute instance type.

                  - **InstanceCount** *(integer) --*

                    The number of ML compute instances to use. For distributed training, provide a
                    value greater than 1.

                  - **VolumeSizeInGB** *(integer) --*

                    The size of the ML storage volume that you want to provision.

                    ML storage volumes store model artifacts and incremental states. Training
                    algorithms might also use the ML storage volume for scratch space. If you want
                    to store the training data in the ML storage volume, choose ``File`` as the
                    ``TrainingInputMode`` in the algorithm specification.

                    You must specify sufficient ML storage for your scenario.

                    .. note::

                      Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage volume
                      type.

                    .. note::

                      Certain Nitro-based instances include local storage with a fixed total size,
                      dependent on the instance type. When using these instances for training,
                      Amazon SageMaker mounts the local instance storage instead of Amazon EBS gp2
                      storage. You can't request a ``VolumeSizeInGB`` greater than the total size of
                      the local instance storage.

                      For a list of instance types that support local instance storage, including
                      the total size per instance type, see `Instance Store Volumes
                      <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                      .

                  - **VolumeKmsKeyId** *(string) --*

                    The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume
                    attached to the ML compute instance(s) that run the training job.

                    .. note::

                      Certain Nitro-based instances include local storage, dependent on the instance
                      type. Local storage volumes are encrypted using a hardware module on the
                      instance. You can't request a ``VolumeKmsKeyId`` when using an instance type
                      with local storage.

                      For a list of instance types that support local instance storage, see
                      `Instance Store Volumes
                      <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                      .

                      For more information about local instance storage encryption, see `SSD
                      Instance Store Volumes
                      <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__
                      .

                    The ``VolumeKmsKeyId`` can be in any of the following formats:

                    * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                    * // Amazon Resource Name (ARN) of a KMS Key
                    ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                - **StoppingCondition** *(dict) --*

                  Specifies a limit to how long a model hyperparameter training job can run. It also
                  specifies how long you are willing to wait for a managed spot training job to
                  complete. When the job reaches the a limit, Amazon SageMaker ends the training
                  job. Use this API to cap model training costs.

                  - **MaxRuntimeInSeconds** *(integer) --*

                    The maximum length of time, in seconds, that the training or compilation job can
                    run. If job does not complete during this time, Amazon SageMaker ends the job.
                    If value is not specified, default value is 1 day. The maximum value is 28 days.

                  - **MaxWaitTimeInSeconds** *(integer) --*

                    The maximum length of time, in seconds, how long you are willing to wait for a
                    managed spot training job to complete. It is the amount of time spent waiting
                    for Spot capacity plus the amount of time the training job runs. It must be
                    equal to or greater than ``MaxRuntimeInSeconds`` .

                - **EnableNetworkIsolation** *(boolean) --*

                  Isolates the training container. No inbound or outbound network calls can be made,
                  except for calls between peers within a training cluster for distributed training.
                  If network isolation is used for training jobs that are configured to use a VPC,
                  Amazon SageMaker downloads and uploads customer data and model artifacts through
                  the specified VPC, but the training container does not have network access.

                  .. note::

                    The Semantic Segmentation built-in algorithm does not support network isolation.

                - **EnableInterContainerTrafficEncryption** *(boolean) --*

                  To encrypt all communications between ML compute instances in distributed
                  training, choose ``True`` . Encryption provides greater security for distributed
                  training, but training might take longer. How long it takes depends on the amount
                  of communication between compute instances, especially if you use a deep learning
                  algorithm in distributed training.

                - **EnableManagedSpotTraining** *(boolean) --*

                  A Boolean indicating whether managed spot training is enabled (``True`` ) or not
                  (``False`` ).

                - **CheckpointConfig** *(dict) --*

                  Contains information about the output location for managed spot training
                  checkpoint data.

                  - **S3Uri** *(string) --*

                    Identifies the S3 path where you want Amazon SageMaker to store checkpoints. For
                    example, ``s3://bucket-name/key-name-prefix`` .

                  - **LocalPath** *(string) --*

                    (Optional) The local directory where checkpoints are written. The default
                    directory is ``/opt/ml/checkpoints/`` .

            - **HyperParameterTuningJobStatus** *(string) --*

              The status of the tuning job: InProgress, Completed, Failed, Stopping, or Stopped.

            - **CreationTime** *(datetime) --*

              The date and time that the tuning job started.

            - **HyperParameterTuningEndTime** *(datetime) --*

              The date and time that the tuning job ended.

            - **LastModifiedTime** *(datetime) --*

              The date and time that the status of the tuning job was modified.

            - **TrainingJobStatusCounters** *(dict) --*

              The  TrainingJobStatusCounters object that specifies the number of training jobs,
              categorized by status, that this tuning job launched.

              - **Completed** *(integer) --*

                The number of completed training jobs launched by the hyperparameter tuning job.

              - **InProgress** *(integer) --*

                The number of in-progress training jobs launched by a hyperparameter tuning job.

              - **RetryableError** *(integer) --*

                The number of training jobs that failed, but can be retried. A failed training job
                can be retried only if it failed because an internal service error occurred.

              - **NonRetryableError** *(integer) --*

                The number of training jobs that failed and can't be retried. A failed training job
                can't be retried if it failed because a client error occurred.

              - **Stopped** *(integer) --*

                The number of training jobs launched by a hyperparameter tuning job that were
                manually stopped.

            - **ObjectiveStatusCounters** *(dict) --*

              The  ObjectiveStatusCounters object that specifies the number of training jobs,
              categorized by the status of their final objective metric, that this tuning job
              launched.

              - **Succeeded** *(integer) --*

                The number of training jobs whose final objective metric was evaluated by the
                hyperparameter tuning job and used in the hyperparameter tuning process.

              - **Pending** *(integer) --*

                The number of training jobs that are in progress and pending evaluation of their
                final objective metric.

              - **Failed** *(integer) --*

                The number of training jobs whose final objective metric was not evaluated and used
                in the hyperparameter tuning process. This typically occurs when the training job
                failed or did not emit an objective metric.

            - **BestTrainingJob** *(dict) --*

              A  TrainingJobSummary object that describes the training job that completed with the
              best current  HyperParameterTuningJobObjective .

              - **TrainingJobDefinitionName** *(string) --*

                The training job definition name.

              - **TrainingJobName** *(string) --*

                The name of the training job.

              - **TrainingJobArn** *(string) --*

                The Amazon Resource Name (ARN) of the training job.

              - **TuningJobName** *(string) --*

                The HyperParameter tuning job that launched the training job.

              - **CreationTime** *(datetime) --*

                The date and time that the training job was created.

              - **TrainingStartTime** *(datetime) --*

                The date and time that the training job started.

              - **TrainingEndTime** *(datetime) --*

                Specifies the time when the training job ends on training instances. You are billed
                for the time interval between the value of ``TrainingStartTime`` and this time. For
                successful jobs and stopped jobs, this is the time after model artifacts are
                uploaded. For failed jobs, this is the time when Amazon SageMaker detects a job
                failure.

              - **TrainingJobStatus** *(string) --*

                The status of the training job.

              - **TunedHyperParameters** *(dict) --*

                A list of the hyperparameters for which you specified ranges to search.

                - *(string) --*

                  - *(string) --*

              - **FailureReason** *(string) --*

                The reason that the training job failed.

              - **FinalHyperParameterTuningJobObjectiveMetric** *(dict) --*

                The  FinalHyperParameterTuningJobObjectiveMetric object that specifies the value of
                the objective metric of the tuning job that launched this training job.

                - **Type** *(string) --*

                  Whether to minimize or maximize the objective metric. Valid values are Minimize
                  and Maximize.

                - **MetricName** *(string) --*

                  The name of the objective metric.

                - **Value** *(float) --*

                  The value of the objective metric.

              - **ObjectiveStatus** *(string) --*

                The status of the objective metric for the training job:

                * Succeeded: The final objective metric for the training job was evaluated by the
                hyperparameter tuning job and used in the hyperparameter tuning process.

                * Pending: The training job is in progress and evaluation of its final objective
                metric is pending.

                * Failed: The final objective metric for the training job was not evaluated, and was
                not used in the hyperparameter tuning process. This typically occurs when the
                training job failed or did not emit an objective metric.

            - **OverallBestTrainingJob** *(dict) --*

              If the hyperparameter tuning job is an warm start tuning job with a ``WarmStartType``
              of ``IDENTICAL_DATA_AND_ALGORITHM`` , this is the  TrainingJobSummary for the training
              job with the best objective metric value of all training jobs launched by this tuning
              job and all parent jobs specified for the warm start tuning job.

              - **TrainingJobDefinitionName** *(string) --*

                The training job definition name.

              - **TrainingJobName** *(string) --*

                The name of the training job.

              - **TrainingJobArn** *(string) --*

                The Amazon Resource Name (ARN) of the training job.

              - **TuningJobName** *(string) --*

                The HyperParameter tuning job that launched the training job.

              - **CreationTime** *(datetime) --*

                The date and time that the training job was created.

              - **TrainingStartTime** *(datetime) --*

                The date and time that the training job started.

              - **TrainingEndTime** *(datetime) --*

                Specifies the time when the training job ends on training instances. You are billed
                for the time interval between the value of ``TrainingStartTime`` and this time. For
                successful jobs and stopped jobs, this is the time after model artifacts are
                uploaded. For failed jobs, this is the time when Amazon SageMaker detects a job
                failure.

              - **TrainingJobStatus** *(string) --*

                The status of the training job.

              - **TunedHyperParameters** *(dict) --*

                A list of the hyperparameters for which you specified ranges to search.

                - *(string) --*

                  - *(string) --*

              - **FailureReason** *(string) --*

                The reason that the training job failed.

              - **FinalHyperParameterTuningJobObjectiveMetric** *(dict) --*

                The  FinalHyperParameterTuningJobObjectiveMetric object that specifies the value of
                the objective metric of the tuning job that launched this training job.

                - **Type** *(string) --*

                  Whether to minimize or maximize the objective metric. Valid values are Minimize
                  and Maximize.

                - **MetricName** *(string) --*

                  The name of the objective metric.

                - **Value** *(float) --*

                  The value of the objective metric.

              - **ObjectiveStatus** *(string) --*

                The status of the objective metric for the training job:

                * Succeeded: The final objective metric for the training job was evaluated by the
                hyperparameter tuning job and used in the hyperparameter tuning process.

                * Pending: The training job is in progress and evaluation of its final objective
                metric is pending.

                * Failed: The final objective metric for the training job was not evaluated, and was
                not used in the hyperparameter tuning process. This typically occurs when the
                training job failed or did not emit an objective metric.

            - **WarmStartConfig** *(dict) --*

              The configuration for starting the hyperparameter parameter tuning job using one or
              more previous tuning jobs as a starting point. The results of previous tuning jobs are
              used to inform which combinations of hyperparameters to search over in the new tuning
              job.

              - **ParentHyperParameterTuningJobs** *(list) --*

                An array of hyperparameter tuning jobs that are used as the starting point for the
                new hyperparameter tuning job. For more information about warm starting a
                hyperparameter tuning job, see `Using a Previous Hyperparameter Tuning Job as a
                Starting Point
                <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-warm-start.html>`__
                .

                Hyperparameter tuning jobs created before October 1, 2018 cannot be used as parent
                jobs for warm start tuning jobs.

                - *(dict) --*

                  A previously completed or stopped hyperparameter tuning job to be used as a
                  starting point for a new hyperparameter tuning job.

                  - **HyperParameterTuningJobName** *(string) --*

                    The name of the hyperparameter tuning job to be used as a starting point for a
                    new hyperparameter tuning job.

              - **WarmStartType** *(string) --*

                Specifies one of the following:

                  IDENTICAL_DATA_AND_ALGORITHM

                The new hyperparameter tuning job uses the same input data and training image as the
                parent tuning jobs. You can change the hyperparameter ranges to search and the
                maximum number of training jobs that the hyperparameter tuning job launches. You
                cannot use a new version of the training algorithm, unless the changes in the new
                version do not affect the algorithm itself. For example, changes that improve
                logging or adding support for a different data format are allowed. You can also
                change hyperparameters from tunable to static, and from static to tunable, but the
                total number of static plus tunable hyperparameters must remain the same as it is in
                all parent jobs. The objective metric for the new tuning job must be the same as for
                all parent jobs.

                  TRANSFER_LEARNING

                The new hyperparameter tuning job can include input data, hyperparameter ranges,
                maximum number of concurrent training jobs, and maximum number of training jobs that
                are different than those of its parent hyperparameter tuning jobs. The training
                image can also be a different version from the version used in the parent
                hyperparameter tuning job. You can also change hyperparameters from tunable to
                static, and from static to tunable, but the total number of static plus tunable
                hyperparameters must remain the same as it is in all parent jobs. The objective
                metric for the new tuning job must be the same as for all parent jobs.

            - **FailureReason** *(string) --*

              If the tuning job failed, the reason it failed.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_labeling_job(
        self, LabelingJobName: str
    ) -> ClientDescribeLabelingJobResponseTypeDef:
        """
        Gets information about a labeling job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeLabelingJob>`_

        **Request Syntax**
        ::

          response = client.describe_labeling_job(
              LabelingJobName='string'
          )
        :type LabelingJobName: string
        :param LabelingJobName: **[REQUIRED]**

          The name of the labeling job to return information for.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'LabelingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                'LabelCounters': {
                    'TotalLabeled': 123,
                    'HumanLabeled': 123,
                    'MachineLabeled': 123,
                    'FailedNonRetryableError': 123,
                    'Unlabeled': 123
                },
                'FailureReason': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'JobReferenceCode': 'string',
                'LabelingJobName': 'string',
                'LabelingJobArn': 'string',
                'LabelAttributeName': 'string',
                'InputConfig': {
                    'DataSource': {
                        'S3DataSource': {
                            'ManifestS3Uri': 'string'
                        }
                    },
                    'DataAttributes': {
                        'ContentClassifiers': [
                            'FreeOfPersonallyIdentifiableInformation'|'FreeOfAdultContent',
                        ]
                    }
                },
                'OutputConfig': {
                    'S3OutputPath': 'string',
                    'KmsKeyId': 'string'
                },
                'RoleArn': 'string',
                'LabelCategoryConfigS3Uri': 'string',
                'StoppingConditions': {
                    'MaxHumanLabeledObjectCount': 123,
                    'MaxPercentageOfInputDatasetLabeled': 123
                },
                'LabelingJobAlgorithmsConfig': {
                    'LabelingJobAlgorithmSpecificationArn': 'string',
                    'InitialActiveLearningModelArn': 'string',
                    'LabelingJobResourceConfig': {
                        'VolumeKmsKeyId': 'string'
                    }
                },
                'HumanTaskConfig': {
                    'WorkteamArn': 'string',
                    'UiConfig': {
                        'UiTemplateS3Uri': 'string'
                    },
                    'PreHumanTaskLambdaArn': 'string',
                    'TaskKeywords': [
                        'string',
                    ],
                    'TaskTitle': 'string',
                    'TaskDescription': 'string',
                    'NumberOfHumanWorkersPerDataObject': 123,
                    'TaskTimeLimitInSeconds': 123,
                    'TaskAvailabilityLifetimeInSeconds': 123,
                    'MaxConcurrentTaskCount': 123,
                    'AnnotationConsolidationConfig': {
                        'AnnotationConsolidationLambdaArn': 'string'
                    },
                    'PublicWorkforceTaskPrice': {
                        'AmountInUsd': {
                            'Dollars': 123,
                            'Cents': 123,
                            'TenthFractionsOfACent': 123
                        }
                    }
                },
                'Tags': [
                    {
                        'Key': 'string',
                        'Value': 'string'
                    },
                ],
                'LabelingJobOutput': {
                    'OutputDatasetS3Uri': 'string',
                    'FinalActiveLearningModelArn': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **LabelingJobStatus** *(string) --*

              The processing status of the labeling job.

            - **LabelCounters** *(dict) --*

              Provides a breakdown of the number of data objects labeled by humans, the number of
              objects labeled by machine, the number of objects than couldn't be labeled, and the
              total number of objects labeled.

              - **TotalLabeled** *(integer) --*

                The total number of objects labeled.

              - **HumanLabeled** *(integer) --*

                The total number of objects labeled by a human worker.

              - **MachineLabeled** *(integer) --*

                The total number of objects labeled by automated data labeling.

              - **FailedNonRetryableError** *(integer) --*

                The total number of objects that could not be labeled due to an error.

              - **Unlabeled** *(integer) --*

                The total number of objects not yet labeled.

            - **FailureReason** *(string) --*

              If the job failed, the reason that it failed.

            - **CreationTime** *(datetime) --*

              The date and time that the labeling job was created.

            - **LastModifiedTime** *(datetime) --*

              The date and time that the labeling job was last updated.

            - **JobReferenceCode** *(string) --*

              A unique identifier for work done as part of a labeling job.

            - **LabelingJobName** *(string) --*

              The name assigned to the labeling job when it was created.

            - **LabelingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the labeling job.

            - **LabelAttributeName** *(string) --*

              The attribute used as the label in the output manifest file.

            - **InputConfig** *(dict) --*

              Input configuration information for the labeling job, such as the Amazon S3 location
              of the data objects and the location of the manifest file that describes the data
              objects.

              - **DataSource** *(dict) --*

                The location of the input data.

                - **S3DataSource** *(dict) --*

                  The Amazon S3 location of the input data objects.

                  - **ManifestS3Uri** *(string) --*

                    The Amazon S3 location of the manifest file that describes the input data
                    objects.

              - **DataAttributes** *(dict) --*

                Attributes of the data specified by the customer.

                - **ContentClassifiers** *(list) --*

                  Declares that your content is free of personally identifiable information or adult
                  content. Amazon SageMaker may restrict the Amazon Mechanical Turk workers that can
                  view your task based on this information.

                  - *(string) --*

            - **OutputConfig** *(dict) --*

              The location of the job's output data and the AWS Key Management Service key ID for
              the key used to encrypt the output data, if any.

              - **S3OutputPath** *(string) --*

                The Amazon S3 location to write output data.

              - **KmsKeyId** *(string) --*

                The AWS Key Management Service ID of the key used to encrypt the output data, if
                any.

                If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                execution role must include permissions to call ``kms:Encrypt`` . If you don't
                provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3 for
                your role's account. Amazon SageMaker uses server-side encryption with KMS-managed
                keys for ``LabelingJobOutputConfig`` . If you use a bucket policy with an
                ``s3:PutObject`` permission that only allows objects with server-side encryption,
                set the condition key of ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For
                more information, see `KMS-Managed Encryption Keys
                <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in the
                *Amazon Simple Storage Service Developer Guide.*

                The KMS key policy must grant permission to the IAM role that you specify in your
                ``CreateLabelingJob`` request. For more information, see `Using Key Policies in AWS
                KMS <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in
                the *AWS Key Management Service Developer Guide* .

            - **RoleArn** *(string) --*

              The Amazon Resource Name (ARN) that Amazon SageMaker assumes to perform tasks on your
              behalf during data labeling.

            - **LabelCategoryConfigS3Uri** *(string) --*

              The S3 location of the JSON file that defines the categories used to label data
              objects. Please note the following label-category limits:

              * Semantic segmentation labeling jobs using automated labeling: 20 labels

              * Box bounding labeling jobs (all): 10 lables

              The file is a JSON structure in the following format:

               ``{``

               ``"document-version": "2018-11-28"``

               ``"labels": [``

               ``{``

               ``"label": "*label 1* "``

               ``},``

               ``{``

               ``"label": "*label 2* "``

               ``},``

               ``...``

               ``{``

               ``"label": "*label n* "``

               ``}``

               ``]``

               ``}``

            - **StoppingConditions** *(dict) --*

              A set of conditions for stopping a labeling job. If any of the conditions are met, the
              job is automatically stopped.

              - **MaxHumanLabeledObjectCount** *(integer) --*

                The maximum number of objects that can be labeled by human workers.

              - **MaxPercentageOfInputDatasetLabeled** *(integer) --*

                The maximum number of input data objects that should be labeled.

            - **LabelingJobAlgorithmsConfig** *(dict) --*

              Configuration information for automated data labeling.

              - **LabelingJobAlgorithmSpecificationArn** *(string) --*

                Specifies the Amazon Resource Name (ARN) of the algorithm used for auto-labeling.
                You must select one of the following ARNs:

                * *Image classification*    ``arn:aws:sagemaker:*region*
                :027400017018:labeling-job-algorithm-specification/image-classification``

                * *Text classification*    ``arn:aws:sagemaker:*region*
                :027400017018:labeling-job-algorithm-specification/text-classification``

                * *Object detection*    ``arn:aws:sagemaker:*region*
                :027400017018:labeling-job-algorithm-specification/object-detection``

                * *Semantic Segmentation*    ``arn:aws:sagemaker:*region*
                :027400017018:labeling-job-algorithm-specification/semantic-segmentation``

              - **InitialActiveLearningModelArn** *(string) --*

                At the end of an auto-label job Amazon SageMaker Ground Truth sends the Amazon
                Resource Nam (ARN) of the final model used for auto-labeling. You can use this model
                as the starting point for subsequent similar jobs by providing the ARN of the model
                here.

              - **LabelingJobResourceConfig** *(dict) --*

                Provides configuration information for a labeling job.

                - **VolumeKmsKeyId** *(string) --*

                  The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                  data on the storage volume attached to the ML compute instance(s) that run the
                  training job. The ``VolumeKmsKeyId`` can be any of the following formats:

                  * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                  * // Amazon Resource Name (ARN) of a KMS Key
                  ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            - **HumanTaskConfig** *(dict) --*

              Configuration information required for human workers to complete a labeling task.

              - **WorkteamArn** *(string) --*

                The Amazon Resource Name (ARN) of the work team assigned to complete the tasks.

              - **UiConfig** *(dict) --*

                Information about the user interface that workers use to complete the labeling task.

                - **UiTemplateS3Uri** *(string) --*

                  The Amazon S3 bucket location of the UI template. For more information about the
                  contents of a UI template, see `Creating Your Custom Labeling Task Template
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-custom-templates-step2.html>`__
                  .

              - **PreHumanTaskLambdaArn** *(string) --*

                The Amazon Resource Name (ARN) of a Lambda function that is run before a data object
                is sent to a human worker. Use this function to provide input to a custom labeling
                job.

                For the built-in bounding box, image classification, semantic segmentation, and text
                classification task types, Amazon SageMaker Ground Truth provides the following
                Lambda functions:

                 **US East (Northern Virginia) (us-east-1):**

                * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-BoundingBox``

                * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:us-east-1:432418664414:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:us-east-1:432418664414:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:us-east-1:432418664414:function:PRE-AdjustmentSemanticSegmentation``

                 **US East (Ohio) (us-east-2):**

                * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-BoundingBox``

                * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:us-east-2:266458841044:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:us-east-2:266458841044:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:us-east-2:266458841044:function:PRE-AdjustmentSemanticSegmentation``

                 **US West (Oregon) (us-west-2):**

                * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-BoundingBox``

                * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:us-west-2:081040173940:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:us-west-2:081040173940:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:us-west-2:081040173940:function:PRE-AdjustmentSemanticSegmentation``

                 **Canada (Central) (ca-central-1):**

                * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-BoundingBox``

                * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:ca-central-1:918755190332:function:PRE-AdjustmentSemanticSegmentation``

                 **EU (Ireland) (eu-west-1):**

                * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-BoundingBox``

                * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:eu-west-1:568282634449:function:PRE-AdjustmentSemanticSegmentation``

                 **EU (London) (eu-west-2):**

                * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-BoundingBox``

                * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:eu-west-2:487402164563:function:PRE-AdjustmentSemanticSegmentation``

                 **EU Frankfurt (eu-central-1):**

                * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-BoundingBox``

                * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:eu-central-1:203001061592:function:PRE-AdjustmentSemanticSegmentation``

                 **Asia Pacific (Tokyo) (ap-northeast-1):**

                * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-BoundingBox``

                * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-NamedEntityRecognition``

                *
                ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:ap-northeast-1:477331159723:function:PRE-AdjustmentSemanticSegmentation``

                 **Asia Pacific (Seoul) (ap-northeast-2):**

                * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-BoundingBox``

                * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-NamedEntityRecognition``

                *
                ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:ap-northeast-2:845288260483:function:PRE-AdjustmentSemanticSegmentation``

                 **Asia Pacific (Mumbai) (ap-south-1):**

                * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-BoundingBox``

                * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-NamedEntityRecognition``

                * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:ap-south-1:565803892007:function:PRE-AdjustmentSemanticSegmentation``

                 **Asia Pacific (Singapore) (ap-southeast-1):**

                * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-BoundingBox``

                * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-NamedEntityRecognition``

                *
                ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:ap-southeast-1:377565633583:function:PRE-AdjustmentSemanticSegmentation``

                 **Asia Pacific (Sydney) (ap-southeast-2):**

                * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-BoundingBox``

                * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-ImageMultiClass``

                * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-SemanticSegmentation``

                * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-TextMultiClass``

                * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-NamedEntityRecognition``

                *
                ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-VerificationBoundingBox``

                *
                ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-VerificationSemanticSegmentation``

                * ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-AdjustmentBoundingBox``

                *
                ``arn:aws:lambda:ap-southeast-2:454466003867:function:PRE-AdjustmentSemanticSegmentation``

              - **TaskKeywords** *(list) --*

                Keywords used to describe the task so that workers on Amazon Mechanical Turk can
                discover the task.

                - *(string) --*

              - **TaskTitle** *(string) --*

                A title for the task for your human workers.

              - **TaskDescription** *(string) --*

                A description of the task for your human workers.

              - **NumberOfHumanWorkersPerDataObject** *(integer) --*

                The number of human workers that will label an object.

              - **TaskTimeLimitInSeconds** *(integer) --*

                The amount of time that a worker has to complete a task.

              - **TaskAvailabilityLifetimeInSeconds** *(integer) --*

                The length of time that a task remains available for labeling by human workers. **If
                you choose the Amazon Mechanical Turk workforce, the maximum is 12 hours (43200)** .
                For private and vendor workforces, the maximum is as listed.

              - **MaxConcurrentTaskCount** *(integer) --*

                Defines the maximum number of data objects that can be labeled by human workers at
                the same time. Also referred to as batch size. Each object may have more than one
                worker at one time.

              - **AnnotationConsolidationConfig** *(dict) --*

                Configures how labels are consolidated across human workers.

                - **AnnotationConsolidationLambdaArn** *(string) --*

                  The Amazon Resource Name (ARN) of a Lambda function implements the logic for
                  annotation consolidation.

                  For the built-in bounding box, image classification, semantic segmentation, and
                  text classification task types, Amazon SageMaker Ground Truth provides the
                  following Lambda functions:

                  * *Bounding box* - Finds the most similar boxes from different workers based on
                  the Jaccard index of the boxes.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-BoundingBox``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-BoundingBox``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-BoundingBox``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-BoundingBox``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-BoundingBox``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-BoundingBox``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-BoundingBox``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-BoundingBox``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-BoundingBox``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-BoundingBox``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-BoundingBox``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-BoundingBox``

                  * *Image classification* - Uses a variant of the Expectation Maximization approach
                  to estimate the true class of an image based on annotations from individual
                  workers.  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClass``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClass``

                  * *Semantic segmentation* - Treats each pixel in an image as a multi-class
                  classification and treats pixel annotations from workers as "votes" for the
                  correct label.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-SemanticSegmentation``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-SemanticSegmentation``

                  * *Text classification* - Uses a variant of the Expectation Maximization approach
                  to estimate the true class of text based on annotations from individual workers.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClass``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClass``

                  * *Named entity recognition* - Groups similar selections and calculates aggregate
                  boundaries, resolving to most-assigned label.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-NamedEntityRecognition``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-NamedEntityRecognition``

                  * *Bounding box verification* - Uses a variant of the Expectation Maximization
                  approach to estimate the true class of verification judgement for bounding box
                  labels based on annotations from individual workers.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationBoundingBox``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationBoundingBox``

                  * *Semantic segmentation verification* - Uses a variant of the Expectation
                  Maximization approach to estimate the true class of verification judgement for
                  semantic segmentation labels based on annotations from individual workers.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationSemanticSegmentation``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationSemanticSegmentation``

                  * *Bounding box adjustment* - Finds the most similar boxes from different workers
                  based on the Jaccard index of the adjusted annotations.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentBoundingBox``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentBoundingBox``

                  * *Semantic segmentation adjustment* - Treats each pixel in an image as a
                  multi-class classification and treats pixel adjusted annotations from workers as
                  "votes" for the correct label.
                  ``arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentSemanticSegmentation``
                  ``arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentSemanticSegmentation``

                  For more information, see `Annotation Consolidation
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-annotation-consolidation.html>`__
                  .

              - **PublicWorkforceTaskPrice** *(dict) --*

                The price that you pay for each task performed by an Amazon Mechanical Turk worker.

                - **AmountInUsd** *(dict) --*

                  Defines the amount of money paid to an Amazon Mechanical Turk worker in United
                  States dollars.

                  - **Dollars** *(integer) --*

                    The whole number of dollars in the amount.

                  - **Cents** *(integer) --*

                    The fractional portion, in cents, of the amount.

                  - **TenthFractionsOfACent** *(integer) --*

                    Fractions of a cent, in tenths.

            - **Tags** *(list) --*

              An array of key/value pairs. For more information, see `Using Cost Allocation Tags
              <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
              in the *AWS Billing and Cost Management User Guide* .

              - *(dict) --*

                Describes a tag.

                - **Key** *(string) --*

                  The tag key.

                - **Value** *(string) --*

                  The tag value.

            - **LabelingJobOutput** *(dict) --*

              The location of the output produced by the labeling job.

              - **OutputDatasetS3Uri** *(string) --*

                The Amazon S3 bucket location of the manifest file for labeled data.

              - **FinalActiveLearningModelArn** *(string) --*

                The Amazon Resource Name (ARN) for the most recent Amazon SageMaker model trained as
                part of automated data labeling.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_model(self, ModelName: str) -> ClientDescribeModelResponseTypeDef:
        """
        Describes a model that you created using the ``CreateModel`` API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeModel>`_

        **Request Syntax**
        ::

          response = client.describe_model(
              ModelName='string'
          )
        :type ModelName: string
        :param ModelName: **[REQUIRED]**

          The name of the model.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ModelName': 'string',
                'PrimaryContainer': {
                    'ContainerHostname': 'string',
                    'Image': 'string',
                    'Mode': 'SingleModel'|'MultiModel',
                    'ModelDataUrl': 'string',
                    'Environment': {
                        'string': 'string'
                    },
                    'ModelPackageName': 'string'
                },
                'Containers': [
                    {
                        'ContainerHostname': 'string',
                        'Image': 'string',
                        'Mode': 'SingleModel'|'MultiModel',
                        'ModelDataUrl': 'string',
                        'Environment': {
                            'string': 'string'
                        },
                        'ModelPackageName': 'string'
                    },
                ],
                'ExecutionRoleArn': 'string',
                'VpcConfig': {
                    'SecurityGroupIds': [
                        'string',
                    ],
                    'Subnets': [
                        'string',
                    ]
                },
                'CreationTime': datetime(2015, 1, 1),
                'ModelArn': 'string',
                'EnableNetworkIsolation': True|False
            }
          **Response Structure**

          - *(dict) --*

            - **ModelName** *(string) --*

              Name of the Amazon SageMaker model.

            - **PrimaryContainer** *(dict) --*

              The location of the primary inference code, associated artifacts, and custom
              environment map that the inference code uses when it is deployed in production.

              - **ContainerHostname** *(string) --*

                This parameter is ignored for models that contain only a ``PrimaryContainer`` .

                When a ``ContainerDefinition`` is part of an inference pipeline, the value of the
                parameter uniquely identifies the container for the purposes of logging and metrics.
                For information, see `Use Logs and Metrics to Monitor an Inference Pipeline
                <https://docs.aws.amazon.com/sagemaker/latest/dg/inference-pipeline-logs-metrics.html>`__
                . If you don't specify a value for this parameter for a ``ContainerDefinition`` that
                is part of an inference pipeline, a unique name is automatically assigned based on
                the position of the ``ContainerDefinition`` in the pipeline. If you specify a value
                for the ``ContainerHostName`` for any ``ContainerDefinition`` that is part of an
                inference pipeline, you must specify a value for the ``ContainerHostName`` parameter
                of every ``ContainerDefinition`` in that pipeline.

              - **Image** *(string) --*

                The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.
                If you are using your own custom algorithm instead of an algorithm provided by
                Amazon SageMaker, the inference code must meet Amazon SageMaker requirements. Amazon
                SageMaker supports both ``registry/repository[:tag]`` and
                ``registry/repository[@digest]`` image path formats. For more information, see
                `Using Your Own Algorithms with Amazon SageMaker
                <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__

              - **Mode** *(string) --*

                Whether the container hosts a single model or multiple models.

              - **ModelDataUrl** *(string) --*

                The S3 path where the model artifacts, which result from model training, are stored.
                This path must point to a single gzip compressed tar archive (.tar.gz suffix). The
                S3 path is required for Amazon SageMaker built-in algorithms, but not if you use
                your own algorithms. For more information on built-in algorithms, see `Common
                Parameters
                <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                .

                If you provide a value for this parameter, Amazon SageMaker uses AWS Security Token
                Service to download model artifacts from the S3 path you provide. AWS STS is
                activated in your IAM user account by default. If you previously deactivated AWS STS
                for a region, you need to reactivate AWS STS for that region. For more information,
                see `Activating and Deactivating AWS STS in an AWS Region
                <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html>`__
                in the *AWS Identity and Access Management User Guide* .

                .. warning::

                  If you use a built-in algorithm to create a model, Amazon SageMaker requires that
                  you provide a S3 path to the model artifacts in ``ModelDataUrl`` .

              - **Environment** *(dict) --*

                The environment variables to set in the Docker container. Each key and value in the
                ``Environment`` string to string map can have length of up to 1024. We support up to
                16 entries in the map.

                - *(string) --*

                  - *(string) --*

              - **ModelPackageName** *(string) --*

                The name or Amazon Resource Name (ARN) of the model package to use to create the
                model.

            - **Containers** *(list) --*

              The containers in the inference pipeline.

              - *(dict) --*

                Describes the container, as part of model definition.

                - **ContainerHostname** *(string) --*

                  This parameter is ignored for models that contain only a ``PrimaryContainer`` .

                  When a ``ContainerDefinition`` is part of an inference pipeline, the value of the
                  parameter uniquely identifies the container for the purposes of logging and
                  metrics. For information, see `Use Logs and Metrics to Monitor an Inference
                  Pipeline
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/inference-pipeline-logs-metrics.html>`__
                  . If you don't specify a value for this parameter for a ``ContainerDefinition``
                  that is part of an inference pipeline, a unique name is automatically assigned
                  based on the position of the ``ContainerDefinition`` in the pipeline. If you
                  specify a value for the ``ContainerHostName`` for any ``ContainerDefinition`` that
                  is part of an inference pipeline, you must specify a value for the
                  ``ContainerHostName`` parameter of every ``ContainerDefinition`` in that pipeline.

                - **Image** *(string) --*

                  The Amazon EC2 Container Registry (Amazon ECR) path where inference code is
                  stored. If you are using your own custom algorithm instead of an algorithm
                  provided by Amazon SageMaker, the inference code must meet Amazon SageMaker
                  requirements. Amazon SageMaker supports both ``registry/repository[:tag]`` and
                  ``registry/repository[@digest]`` image path formats. For more information, see
                  `Using Your Own Algorithms with Amazon SageMaker
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__

                - **Mode** *(string) --*

                  Whether the container hosts a single model or multiple models.

                - **ModelDataUrl** *(string) --*

                  The S3 path where the model artifacts, which result from model training, are
                  stored. This path must point to a single gzip compressed tar archive (.tar.gz
                  suffix). The S3 path is required for Amazon SageMaker built-in algorithms, but not
                  if you use your own algorithms. For more information on built-in algorithms, see
                  `Common Parameters
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                  .

                  If you provide a value for this parameter, Amazon SageMaker uses AWS Security
                  Token Service to download model artifacts from the S3 path you provide. AWS STS is
                  activated in your IAM user account by default. If you previously deactivated AWS
                  STS for a region, you need to reactivate AWS STS for that region. For more
                  information, see `Activating and Deactivating AWS STS in an AWS Region
                  <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html>`__
                  in the *AWS Identity and Access Management User Guide* .

                  .. warning::

                    If you use a built-in algorithm to create a model, Amazon SageMaker requires
                    that you provide a S3 path to the model artifacts in ``ModelDataUrl`` .

                - **Environment** *(dict) --*

                  The environment variables to set in the Docker container. Each key and value in
                  the ``Environment`` string to string map can have length of up to 1024. We support
                  up to 16 entries in the map.

                  - *(string) --*

                    - *(string) --*

                - **ModelPackageName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the model package to use to create the
                  model.

            - **ExecutionRoleArn** *(string) --*

              The Amazon Resource Name (ARN) of the IAM role that you specified for the model.

            - **VpcConfig** *(dict) --*

              A  VpcConfig object that specifies the VPC that this model has access to. For more
              information, see `Protect Endpoints by Using an Amazon Virtual Private Cloud
              <https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html>`__

              - **SecurityGroupIds** *(list) --*

                The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for
                the VPC that is specified in the ``Subnets`` field.

                - *(string) --*

              - **Subnets** *(list) --*

                The ID of the subnets in the VPC to which you want to connect your training job or
                model.

                .. note::

                  Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                  availability zones of region us-east-1. If you want to create endpoints with P3
                  instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                  zones instead.

                - *(string) --*

            - **CreationTime** *(datetime) --*

              A timestamp that shows when the model was created.

            - **ModelArn** *(string) --*

              The Amazon Resource Name (ARN) of the model.

            - **EnableNetworkIsolation** *(boolean) --*

              If ``True`` , no inbound or outbound network calls can be made to or from the model
              container.

              .. note::

                The Semantic Segmentation built-in algorithm does not support network isolation.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_model_package(
        self, ModelPackageName: str
    ) -> ClientDescribeModelPackageResponseTypeDef:
        """
        Returns a description of the specified model package, which is used to create Amazon
        SageMaker models or list them on AWS Marketplace.

        To create models in Amazon SageMaker, buyers can subscribe to model packages listed on AWS
        Marketplace.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeModelPackage>`_

        **Request Syntax**
        ::

          response = client.describe_model_package(
              ModelPackageName='string'
          )
        :type ModelPackageName: string
        :param ModelPackageName: **[REQUIRED]**

          The name of the model package to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ModelPackageName': 'string',
                'ModelPackageArn': 'string',
                'ModelPackageDescription': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'InferenceSpecification': {
                    'Containers': [
                        {
                            'ContainerHostname': 'string',
                            'Image': 'string',
                            'ImageDigest': 'string',
                            'ModelDataUrl': 'string',
                            'ProductId': 'string'
                        },
                    ],
                    'SupportedTransformInstanceTypes': [
                        'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                        |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                        |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                        |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge'
                        |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                    ],
                    'SupportedRealtimeInferenceInstanceTypes': [
                        'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'|'ml.m4.xlarge'
                        |'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'|'ml.m4.16xlarge'
                        |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.m5d.large'|'ml.m5d.xlarge'
                        |'ml.m5d.2xlarge'|'ml.m5d.4xlarge'|'ml.m5d.12xlarge'|'ml.m5d.24xlarge'
                        |'ml.c4.large'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                        |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.large'
                        |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                        |'ml.c5.18xlarge'|'ml.c5d.large'|'ml.c5d.xlarge'|'ml.c5d.2xlarge'
                        |'ml.c5d.4xlarge'|'ml.c5d.9xlarge'|'ml.c5d.18xlarge'|'ml.g4dn.xlarge'
                        |'ml.g4dn.2xlarge'|'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                        |'ml.g4dn.16xlarge'|'ml.r5.large'|'ml.r5.xlarge'|'ml.r5.2xlarge'
                        |'ml.r5.4xlarge'|'ml.r5.12xlarge'|'ml.r5.24xlarge'|'ml.r5d.large'
                        |'ml.r5d.xlarge'|'ml.r5d.2xlarge'|'ml.r5d.4xlarge'|'ml.r5d.12xlarge'
                        |'ml.r5d.24xlarge'|'ml.inf1.xlarge'|'ml.inf1.2xlarge'|'ml.inf1.6xlarge'
                        |'ml.inf1.24xlarge',
                    ],
                    'SupportedContentTypes': [
                        'string',
                    ],
                    'SupportedResponseMIMETypes': [
                        'string',
                    ]
                },
                'SourceAlgorithmSpecification': {
                    'SourceAlgorithms': [
                        {
                            'ModelDataUrl': 'string',
                            'AlgorithmName': 'string'
                        },
                    ]
                },
                'ValidationSpecification': {
                    'ValidationRole': 'string',
                    'ValidationProfiles': [
                        {
                            'ProfileName': 'string',
                            'TransformJobDefinition': {
                                'MaxConcurrentTransforms': 123,
                                'MaxPayloadInMB': 123,
                                'BatchStrategy': 'MultiRecord'|'SingleRecord',
                                'Environment': {
                                    'string': 'string'
                                },
                                'TransformInput': {
                                    'DataSource': {
                                        'S3DataSource': {
                                            'S3DataType':
                                            'ManifestFile'
                                            |'S3Prefix'
                                            |'AugmentedManifestFile',
                                            'S3Uri': 'string'
                                        }
                                    },
                                    'ContentType': 'string',
                                    'CompressionType': 'None'|'Gzip',
                                    'SplitType': 'None'|'Line'|'RecordIO'|'TFRecord'
                                },
                                'TransformOutput': {
                                    'S3OutputPath': 'string',
                                    'Accept': 'string',
                                    'AssembleWith': 'None'|'Line',
                                    'KmsKeyId': 'string'
                                },
                                'TransformResources': {
                                    'InstanceType':
                                    'ml.m4.xlarge'|'ml.m4.2xlarge'
                                    |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                    |'ml.m4.16xlarge'|'ml.c4.xlarge'
                                    |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                    |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                    |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                    |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                    |'ml.p3.16xlarge'|'ml.c5.xlarge'
                                    |'ml.c5.2xlarge'|'ml.c5.4xlarge'
                                    |'ml.c5.9xlarge'|'ml.c5.18xlarge'
                                    |'ml.m5.large'|'ml.m5.xlarge'
                                    |'ml.m5.2xlarge'|'ml.m5.4xlarge'
                                    |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                                    'InstanceCount': 123,
                                    'VolumeKmsKeyId': 'string'
                                }
                            }
                        },
                    ]
                },
                'ModelPackageStatus': 'Pending'|'InProgress'|'Completed'|'Failed'|'Deleting',
                'ModelPackageStatusDetails': {
                    'ValidationStatuses': [
                        {
                            'Name': 'string',
                            'Status': 'NotStarted'|'InProgress'|'Completed'|'Failed',
                            'FailureReason': 'string'
                        },
                    ],
                    'ImageScanStatuses': [
                        {
                            'Name': 'string',
                            'Status': 'NotStarted'|'InProgress'|'Completed'|'Failed',
                            'FailureReason': 'string'
                        },
                    ]
                },
                'CertifyForMarketplace': True|False
            }
          **Response Structure**

          - *(dict) --*

            - **ModelPackageName** *(string) --*

              The name of the model package being described.

            - **ModelPackageArn** *(string) --*

              The Amazon Resource Name (ARN) of the model package.

            - **ModelPackageDescription** *(string) --*

              A brief summary of the model package.

            - **CreationTime** *(datetime) --*

              A timestamp specifying when the model package was created.

            - **InferenceSpecification** *(dict) --*

              Details about inference jobs that can be run with models based on this model package.

              - **Containers** *(list) --*

                The Amazon ECR registry path of the Docker image that contains the inference code.

                - *(dict) --*

                  Describes the Docker container for the model package.

                  - **ContainerHostname** *(string) --*

                    The DNS host name for the Docker container.

                  - **Image** *(string) --*

                    The Amazon EC2 Container Registry (Amazon ECR) path where inference code is
                    stored.

                    If you are using your own custom algorithm instead of an algorithm provided by
                    Amazon SageMaker, the inference code must meet Amazon SageMaker requirements.
                    Amazon SageMaker supports both ``registry/repository[:tag]`` and
                    ``registry/repository[@digest]`` image path formats. For more information, see
                    `Using Your Own Algorithms with Amazon SageMaker
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

                  - **ImageDigest** *(string) --*

                    An MD5 hash of the training algorithm that identifies the Docker image used for
                    training.

                  - **ModelDataUrl** *(string) --*

                    The Amazon S3 path where the model artifacts, which result from model training,
                    are stored. This path must point to a single ``gzip`` compressed tar archive
                    (``.tar.gz`` suffix).

                  - **ProductId** *(string) --*

                    The AWS Marketplace product ID of the model package.

              - **SupportedTransformInstanceTypes** *(list) --*

                A list of the instance types on which a transformation job can be run or on which an
                endpoint can be deployed.

                - *(string) --*

              - **SupportedRealtimeInferenceInstanceTypes** *(list) --*

                A list of the instance types that are used to generate inferences in real-time.

                - *(string) --*

              - **SupportedContentTypes** *(list) --*

                The supported MIME types for the input data.

                - *(string) --*

              - **SupportedResponseMIMETypes** *(list) --*

                The supported MIME types for the output data.

                - *(string) --*

            - **SourceAlgorithmSpecification** *(dict) --*

              Details about the algorithm that was used to create the model package.

              - **SourceAlgorithms** *(list) --*

                A list of the algorithms that were used to create a model package.

                - *(dict) --*

                  Specifies an algorithm that was used to create the model package. The algorithm
                  must be either an algorithm resource in your Amazon SageMaker account or an
                  algorithm in AWS Marketplace that you are subscribed to.

                  - **ModelDataUrl** *(string) --*

                    The Amazon S3 path where the model artifacts, which result from model training,
                    are stored. This path must point to a single ``gzip`` compressed tar archive
                    (``.tar.gz`` suffix).

                  - **AlgorithmName** *(string) --*

                    The name of an algorithm that was used to create the model package. The
                    algorithm must be either an algorithm resource in your Amazon SageMaker account
                    or an algorithm in AWS Marketplace that you are subscribed to.

            - **ValidationSpecification** *(dict) --*

              Configurations for one or more transform jobs that Amazon SageMaker runs to test the
              model package.

              - **ValidationRole** *(string) --*

                The IAM roles to be used for the validation of the model package.

              - **ValidationProfiles** *(list) --*

                An array of ``ModelPackageValidationProfile`` objects, each of which specifies a
                batch transform job that Amazon SageMaker runs to validate your model package.

                - *(dict) --*

                  Contains data, such as the inputs and targeted instance types that are used in the
                  process of validating the model package.

                  The data provided in the validation profile is made available to your buyers on
                  AWS Marketplace.

                  - **ProfileName** *(string) --*

                    The name of the profile for the model package.

                  - **TransformJobDefinition** *(dict) --*

                    The ``TransformJobDefinition`` object that describes the transform job used for
                    the validation of the model package.

                    - **MaxConcurrentTransforms** *(integer) --*

                      The maximum number of parallel requests that can be sent to each instance in a
                      transform job. The default value is 1.

                    - **MaxPayloadInMB** *(integer) --*

                      The maximum payload size allowed, in MB. A payload is the data portion of a
                      record (without metadata).

                    - **BatchStrategy** *(string) --*

                      A string that determines the number of records included in a single
                      mini-batch.

                       ``SingleRecord`` means only one record is used per mini-batch.
                       ``MultiRecord`` means a mini-batch is set to contain as many records that can
                       fit within the ``MaxPayloadInMB`` limit.

                    - **Environment** *(dict) --*

                      The environment variables to set in the Docker container. We support up to 16
                      key and values entries in the map.

                      - *(string) --*

                        - *(string) --*

                    - **TransformInput** *(dict) --*

                      A description of the input source and the way the transform job consumes it.

                      - **DataSource** *(dict) --*

                        Describes the location of the channel data, which is, the S3 location of the
                        input data that the model can consume.

                        - **S3DataSource** *(dict) --*

                          The S3 location of the data source that is associated with a channel.

                          - **S3DataType** *(string) --*

                            If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix.
                            Amazon SageMaker uses all objects with the specified key name prefix for
                            batch transform.

                            If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is
                            a manifest file containing a list of object keys that you want Amazon
                            SageMaker to use for batch transform.

                            The following values are compatible: ``ManifestFile`` , ``S3Prefix``

                            The following value is not compatible: ``AugmentedManifestFile``

                          - **S3Uri** *(string) --*

                            Depending on the value specified for the ``S3DataType`` , identifies
                            either a key name prefix or a manifest. For example:

                            * A key name prefix might look like this:
                            ``s3://bucketname/exampleprefix`` .

                            * A manifest might look like this: ``s3://bucketname/example.manifest``
                            The manifest is an S3 object which is a JSON file with the following
                            format:   ``[ {"prefix": "s3://customer_bucket/some/prefix/"},``
                            ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                            ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                            matches the following ``s3Uris`` :
                            ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                            ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                            ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The
                            complete set of ``S3Uris`` in this manifest constitutes the input data
                            for the channel for this datasource. The object that each ``S3Uris``
                            points to must be readable by the IAM role that Amazon SageMaker uses to
                            perform tasks on your behalf.

                      - **ContentType** *(string) --*

                        The multipurpose internet mail extension (MIME) type of the data. Amazon
                        SageMaker uses the MIME type with each http call to transfer data to the
                        transform job.

                      - **CompressionType** *(string) --*

                        If your transform data is compressed, specify the compression type. Amazon
                        SageMaker automatically decompresses the data for the transform job
                        accordingly. The default value is ``None`` .

                      - **SplitType** *(string) --*

                        The method to use to split the transform job's data files into smaller
                        batches. Splitting is necessary when the total size of each object is too
                        large to fit in a single request. You can also use data splitting to improve
                        performance by processing multiple concurrent mini-batches. The default
                        value for ``SplitType`` is ``None`` , which indicates that input data files
                        are not split, and request payloads contain the entire contents of an input
                        object. Set the value of this parameter to ``Line`` to split records on a
                        newline character boundary. ``SplitType`` also supports a number of
                        record-oriented binary data formats.

                        When splitting is enabled, the size of a mini-batch depends on the values of
                        the ``BatchStrategy`` and ``MaxPayloadInMB`` parameters. When the value of
                        ``BatchStrategy`` is ``MultiRecord`` , Amazon SageMaker sends the maximum
                        number of records in each request, up to the ``MaxPayloadInMB`` limit. If
                        the value of ``BatchStrategy`` is ``SingleRecord`` , Amazon SageMaker sends
                        individual records in each request.

                        .. note::

                          Some data formats represent a record as a binary payload wrapped with
                          extra padding bytes. When splitting is applied to a binary data format,
                          padding is removed if the value of ``BatchStrategy`` is set to
                          ``SingleRecord`` . Padding is not removed if the value of
                          ``BatchStrategy`` is set to ``MultiRecord`` .

                          For more information about ``RecordIO`` , see `Create a Dataset Using
                          RecordIO <https://mxnet.apache.org/api/faq/recordio>`__ in the MXNet
                          documentation. For more information about ``TFRecord`` , see `Consuming
                          TFRecord data
                          <https://www.tensorflow.org/guide/datasets#consuming_tfrecord_data>`__ in
                          the TensorFlow documentation.

                    - **TransformOutput** *(dict) --*

                      Identifies the Amazon S3 location where you want Amazon SageMaker to save the
                      results from the transform job.

                      - **S3OutputPath** *(string) --*

                        The Amazon S3 path where you want Amazon SageMaker to store the results of
                        the transform job. For example, ``s3://bucket-name/key-name-prefix`` .

                        For every S3 object used as input for the transform job, batch transform
                        stores the transformed data with an .``out`` suffix in a corresponding
                        subfolder in the location in the output prefix. For example, for the input
                        data stored at ``s3://bucket-name/input-name-prefix/dataset01/data.csv`` ,
                        batch transform stores the transformed data at
                        ``s3://bucket-name/output-name-prefix/input-name-prefix/data.csv.out`` .
                        Batch transform doesn't upload partially processed objects. For an input S3
                        object that contains multiple records, it creates an .``out`` file only if
                        the transform job succeeds on the entire file. When the input contains
                        multiple S3 objects, the batch transform job processes the listed S3 objects
                        and uploads only the output for successfully processed objects. If any
                        object fails in the transform job batch transform marks the job as failed to
                        prompt investigation.

                      - **Accept** *(string) --*

                        The MIME type used to specify the output data. Amazon SageMaker uses the
                        MIME type with each http call to transfer data from the transform job.

                      - **AssembleWith** *(string) --*

                        Defines how to assemble the results of the transform job as a single S3
                        object. Choose a format that is most convenient to you. To concatenate the
                        results in binary format, specify ``None`` . To add a newline character at
                        the end of every transformed record, specify ``Line`` .

                      - **KmsKeyId** *(string) --*

                        The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                        encrypt the model artifacts at rest using Amazon S3 server-side encryption.
                        The ``KmsKeyId`` can be any of the following formats:

                        * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // Amazon Resource Name (ARN) of a KMS Key
                        ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // KMS Key Alias  ``"alias/ExampleAlias"``

                        * // Amazon Resource Name (ARN) of a KMS Key Alias
                        ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                        If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS key
                        for Amazon S3 for your role's account. For more information, see
                        `KMS-Managed Encryption Keys
                        <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__
                        in the *Amazon Simple Storage Service Developer Guide.*

                        The KMS key policy must grant permission to the IAM role that you specify in
                        your  CreateModel request. For more information, see `Using Key Policies in
                        AWS KMS
                        <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__
                        in the *AWS Key Management Service Developer Guide* .

                    - **TransformResources** *(dict) --*

                      Identifies the ML compute instances for the transform job.

                      - **InstanceType** *(string) --*

                        The ML compute instance type for the transform job. If you are using
                        built-in algorithms to transform moderately sized datasets, we recommend
                        using ml.m4.xlarge or ``ml.m5.large`` instance types.

                      - **InstanceCount** *(integer) --*

                        The number of ML compute instances to use in the transform job. For
                        distributed transform jobs, specify a value greater than 1. The default
                        value is ``1`` .

                      - **VolumeKmsKeyId** *(string) --*

                        The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                        encrypt model data on the storage volume attached to the ML compute
                        instance(s) that run the batch transform job. The ``VolumeKmsKeyId`` can be
                        any of the following formats:

                        * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                        * // Amazon Resource Name (ARN) of a KMS Key
                        ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            - **ModelPackageStatus** *(string) --*

              The current status of the model package.

            - **ModelPackageStatusDetails** *(dict) --*

              Details about the current status of the model package.

              - **ValidationStatuses** *(list) --*

                The validation status of the model package.

                - *(dict) --*

                  Represents the overall status of a model package.

                  - **Name** *(string) --*

                    The name of the model package for which the overall status is being reported.

                  - **Status** *(string) --*

                    The current status.

                  - **FailureReason** *(string) --*

                    if the overall status is ``Failed`` , the reason for the failure.

              - **ImageScanStatuses** *(list) --*

                The status of the scan of the Docker image container for the model package.

                - *(dict) --*

                  Represents the overall status of a model package.

                  - **Name** *(string) --*

                    The name of the model package for which the overall status is being reported.

                  - **Status** *(string) --*

                    The current status.

                  - **FailureReason** *(string) --*

                    if the overall status is ``Failed`` , the reason for the failure.

            - **CertifyForMarketplace** *(boolean) --*

              Whether the model package is certified for listing on AWS Marketplace.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_monitoring_schedule(
        self, MonitoringScheduleName: str
    ) -> ClientDescribeMonitoringScheduleResponseTypeDef:
        """
        Describes the schedule for a monitoring job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeMonitoringSchedule>`_

        **Request Syntax**
        ::

          response = client.describe_monitoring_schedule(
              MonitoringScheduleName='string'
          )
        :type MonitoringScheduleName: string
        :param MonitoringScheduleName: **[REQUIRED]**

          Name of a previously created monitoring schedule.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MonitoringScheduleArn': 'string',
                'MonitoringScheduleName': 'string',
                'MonitoringScheduleStatus': 'Pending'|'Failed'|'Scheduled'|'Stopped',
                'FailureReason': 'string',
                'CreationTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'MonitoringScheduleConfig': {
                    'ScheduleConfig': {
                        'ScheduleExpression': 'string'
                    },
                    'MonitoringJobDefinition': {
                        'BaselineConfig': {
                            'ConstraintsResource': {
                                'S3Uri': 'string'
                            },
                            'StatisticsResource': {
                                'S3Uri': 'string'
                            }
                        },
                        'MonitoringInputs': [
                            {
                                'EndpointInput': {
                                    'EndpointName': 'string',
                                    'LocalPath': 'string',
                                    'S3InputMode': 'Pipe'|'File',
                                    'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key'
                                }
                            },
                        ],
                        'MonitoringOutputConfig': {
                            'MonitoringOutputs': [
                                {
                                    'S3Output': {
                                        'S3Uri': 'string',
                                        'LocalPath': 'string',
                                        'S3UploadMode': 'Continuous'|'EndOfJob'
                                    }
                                },
                            ],
                            'KmsKeyId': 'string'
                        },
                        'MonitoringResources': {
                            'ClusterConfig': {
                                'InstanceCount': 123,
                                'InstanceType':
                                'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'
                                |'ml.t3.2xlarge'|'ml.m4.xlarge'
                                |'ml.m4.2xlarge'|'ml.m4.4xlarge'
                                |'ml.m4.10xlarge'|'ml.m4.16xlarge'
                                |'ml.c4.xlarge'|'ml.c4.2xlarge'
                                |'ml.c4.4xlarge'|'ml.c4.8xlarge'
                                |'ml.p2.xlarge'|'ml.p2.8xlarge'
                                |'ml.p2.16xlarge'|'ml.p3.2xlarge'
                                |'ml.p3.8xlarge'|'ml.p3.16xlarge'
                                |'ml.c5.xlarge'|'ml.c5.2xlarge'
                                |'ml.c5.4xlarge'|'ml.c5.9xlarge'
                                |'ml.c5.18xlarge'|'ml.m5.large'
                                |'ml.m5.xlarge'|'ml.m5.2xlarge'
                                |'ml.m5.4xlarge'|'ml.m5.12xlarge'
                                |'ml.m5.24xlarge'|'ml.r5.large'
                                |'ml.r5.xlarge'|'ml.r5.2xlarge'
                                |'ml.r5.4xlarge'|'ml.r5.8xlarge'
                                |'ml.r5.12xlarge'|'ml.r5.16xlarge'
                                |'ml.r5.24xlarge',
                                'VolumeSizeInGB': 123,
                                'VolumeKmsKeyId': 'string'
                            }
                        },
                        'MonitoringAppSpecification': {
                            'ImageUri': 'string',
                            'ContainerEntrypoint': [
                                'string',
                            ],
                            'ContainerArguments': [
                                'string',
                            ],
                            'RecordPreprocessorSourceUri': 'string',
                            'PostAnalyticsProcessorSourceUri': 'string'
                        },
                        'StoppingCondition': {
                            'MaxRuntimeInSeconds': 123
                        },
                        'Environment': {
                            'string': 'string'
                        },
                        'NetworkConfig': {
                            'EnableNetworkIsolation': True|False,
                            'VpcConfig': {
                                'SecurityGroupIds': [
                                    'string',
                                ],
                                'Subnets': [
                                    'string',
                                ]
                            }
                        },
                        'RoleArn': 'string'
                    }
                },
                'EndpointName': 'string',
                'LastMonitoringExecutionSummary': {
                    'MonitoringScheduleName': 'string',
                    'ScheduledTime': datetime(2015, 1, 1),
                    'CreationTime': datetime(2015, 1, 1),
                    'LastModifiedTime': datetime(2015, 1, 1),
                    'MonitoringExecutionStatus':
                    'Pending'|'Completed'|'CompletedWithViolations'|'InProgress'
                    |'Failed'|'Stopping'|'Stopped',
                    'ProcessingJobArn': 'string',
                    'EndpointName': 'string',
                    'FailureReason': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **MonitoringScheduleArn** *(string) --*

              The Amazon Resource Name (ARN) of the monitoring schedule.

            - **MonitoringScheduleName** *(string) --*

              Name of the monitoring schedule.

            - **MonitoringScheduleStatus** *(string) --*

              The status of an monitoring job.

            - **FailureReason** *(string) --*

              A string, up to one KB in size, that contains the reason a monitoring job failed, if
              it failed.

            - **CreationTime** *(datetime) --*

              The time at which the monitoring job was created.

            - **LastModifiedTime** *(datetime) --*

              The time at which the monitoring job was last modified.

            - **MonitoringScheduleConfig** *(dict) --*

              The configuration object that specifies the monitoring schedule and defines the
              monitoring job.

              - **ScheduleConfig** *(dict) --*

                Configures the monitoring schedule.

                - **ScheduleExpression** *(string) --*

                  A cron expression that describes details about the monitoring schedule.

                  Currently the only supported cron expressions are:

                  * If you want to set the job to start every hour, please use the following:
                  ``Hourly: cron(0 * ? * * *)``

                  * If you want to start the job daily:  ``cron(0 [00-23] ? * * *)``

                  For example, the following are valid cron expressions:

                  * Daily at noon UTC: ``cron(0 12 ? * * *)``

                  * Daily at midnight UTC: ``cron(0 0 ? * * *)``

                  To support running every 6, 12 hours, the following are also supported:

                   ``cron(0 [00-23]/[01-24] ? * * *)``

                  For example, the following are valid cron expressions:

                  * Every 12 hours, starting at 5pm UTC: ``cron(0 17/12 ? * * *)``

                  * Every two hours starting at midnight: ``cron(0 0/2 ? * * *)``

                  .. note::

                    * Even though the cron expression is set to start at 5PM UTC, note that there
                    could be a delay of 0-20 minutes from the actual requested time to run the
                    execution.

                    * We recommend that if you would like a daily schedule, you do not provide this
                    parameter. Amazon SageMaker will pick a time for running every day.

              - **MonitoringJobDefinition** *(dict) --*

                Defines the monitoring job.

                - **BaselineConfig** *(dict) --*

                  Baseline configuration used to validate that the data conforms to the specified
                  constraints and statistics

                  - **ConstraintsResource** *(dict) --*

                    The baseline constraint file in Amazon S3 that the current monitoring job should
                    validated against.

                    - **S3Uri** *(string) --*

                      The Amazon S3 URI for the constraints resource.

                  - **StatisticsResource** *(dict) --*

                    The baseline statistics file in Amazon S3 that the current monitoring job should
                    be validated against.

                    - **S3Uri** *(string) --*

                      The Amazon S3 URI for the statistics resource.

                - **MonitoringInputs** *(list) --*

                  The array of inputs for the monitoring job. Currently we support monitoring an
                  Amazon SageMaker Endpoint.

                  - *(dict) --*

                    The inputs for a monitoring job.

                    - **EndpointInput** *(dict) --*

                      The endpoint for a monitoring job.

                      - **EndpointName** *(string) --*

                        An endpoint in customer's account which has enabled ``DataCaptureConfig``
                        enabled.

                      - **LocalPath** *(string) --*

                        Path to the filesystem where the endpoint data is available to the
                        container.

                      - **S3InputMode** *(string) --*

                        Whether the ``Pipe`` or ``File`` is used as the input mode for transfering
                        data for the monitoring job. ``Pipe`` mode is recommended for large
                        datasets. ``File`` mode is useful for small files that fit in memory.
                        Defaults to ``File`` .

                      - **S3DataDistributionType** *(string) --*

                        Whether input data distributed in Amazon S3 is fully replicated or sharded
                        by an S3 key. Defauts to ``FullyReplicated``

                - **MonitoringOutputConfig** *(dict) --*

                  The array of outputs from the monitoring job to be uploaded to Amazon Simple
                  Storage Service (Amazon S3).

                  - **MonitoringOutputs** *(list) --*

                    Monitoring outputs for monitoring jobs. This is where the output of the periodic
                    monitoring jobs is uploaded.

                    - *(dict) --*

                      The output object for a monitoring job.

                      - **S3Output** *(dict) --*

                        The Amazon S3 storage location where the results of a monitoring job are
                        saved.

                        - **S3Uri** *(string) --*

                          A URI that identifies the Amazon S3 storage location where Amazon
                          SageMaker saves the results of a monitoring job.

                        - **LocalPath** *(string) --*

                          The local path to the Amazon S3 storage location where Amazon SageMaker
                          saves the results of a monitoring job. LocalPath is an absolute path for
                          the output data.

                        - **S3UploadMode** *(string) --*

                          Whether to upload the results of the monitoring job continuously or after
                          the job completes.

                  - **KmsKeyId** *(string) --*

                    The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                    encrypt the model artifacts at rest using Amazon S3 server-side encryption.

                - **MonitoringResources** *(dict) --*

                  Identifies the resources, ML compute instances, and ML storage volumes to deploy
                  for a monitoring job. In distributed processing, you specify more than one
                  instance.

                  - **ClusterConfig** *(dict) --*

                    The configuration for the cluster resources used to run the processing job.

                    - **InstanceCount** *(integer) --*

                      The number of ML compute instances to use in the model monitoring job. For
                      distributed processing jobs, specify a value greater than 1. The default value
                      is 1.

                    - **InstanceType** *(string) --*

                      The ML compute instance type for the processing job.

                    - **VolumeSizeInGB** *(integer) --*

                      The size of the ML storage volume, in gigabytes, that you want to provision.
                      You must specify sufficient ML storage for your scenario.

                    - **VolumeKmsKeyId** *(string) --*

                      The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                      encrypt data on the storage volume attached to the ML compute instance(s) that
                      run the model monitoring job.

                - **MonitoringAppSpecification** *(dict) --*

                  Configures the monitoring job to run a specified Docker container image.

                  - **ImageUri** *(string) --*

                    The container image to be run by the monitoring job.

                  - **ContainerEntrypoint** *(list) --*

                    Specifies the entrypoint for a container used to run the monitoring job.

                    - *(string) --*

                  - **ContainerArguments** *(list) --*

                    An array of arguments for the container used to run the monitoring job.

                    - *(string) --*

                  - **RecordPreprocessorSourceUri** *(string) --*

                    An Amazon S3 URI to a script that is called per row prior to running analysis.
                    It can base64 decode the payload and convert it into a flatted json so that the
                    built-in container can use the converted data. Applicable only for the built-in
                    (first party) containers.

                  - **PostAnalyticsProcessorSourceUri** *(string) --*

                    An Amazon S3 URI to a script that is called after analysis has been performed.
                    Applicable only for the built-in (first party) containers.

                - **StoppingCondition** *(dict) --*

                  Specifies a time limit for how long the monitoring job is allowed to run.

                  - **MaxRuntimeInSeconds** *(integer) --*

                    The maximum runtime allowed in seconds.

                - **Environment** *(dict) --*

                  Sets the environment variables in the Docker container.

                  - *(string) --*

                    - *(string) --*

                - **NetworkConfig** *(dict) --*

                  Specifies networking options for an monitoring job.

                  - **EnableNetworkIsolation** *(boolean) --*

                    Whether to allow inbound and outbound network calls to and from the containers
                    used for the processing job.

                  - **VpcConfig** *(dict) --*

                    Specifies a VPC that your training jobs and hosted models have access to.
                    Control access to and from your training and model containers by configuring the
                    VPC. For more information, see `Protect Endpoints by Using an Amazon Virtual
                    Private Cloud <https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html>`__
                    and `Protect Training Jobs by Using an Amazon Virtual Private Cloud
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                    - **SecurityGroupIds** *(list) --*

                      The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security
                      groups for the VPC that is specified in the ``Subnets`` field.

                      - *(string) --*

                    - **Subnets** *(list) --*

                      The ID of the subnets in the VPC to which you want to connect your training
                      job or model.

                      .. note::

                        Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                        availability zones of region us-east-1. If you want to create endpoints with
                        P3 instances in VPC mode in region us-east-1, create subnets in a/b/f
                        availability zones instead.

                      - *(string) --*

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to
                  perform tasks on your behalf.

            - **EndpointName** *(string) --*

              The name of the endpoint for the monitoring job.

            - **LastMonitoringExecutionSummary** *(dict) --*

              Describes metadata on the last execution to run, if there was one.

              - **MonitoringScheduleName** *(string) --*

                The name of the monitoring schedule.

              - **ScheduledTime** *(datetime) --*

                The time the monitoring job was scheduled.

              - **CreationTime** *(datetime) --*

                The time at which the monitoring job was created.

              - **LastModifiedTime** *(datetime) --*

                A timestamp that indicates the last time the monitoring job was modified.

              - **MonitoringExecutionStatus** *(string) --*

                The status of the monitoring job.

              - **ProcessingJobArn** *(string) --*

                The Amazon Resource Name (ARN) of the monitoring job.

              - **EndpointName** *(string) --*

                The name of teh endpoint used to run the monitoring job.

              - **FailureReason** *(string) --*

                Contains the reason a monitoring job failed, if it failed.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_notebook_instance(
        self, NotebookInstanceName: str
    ) -> ClientDescribeNotebookInstanceResponseTypeDef:
        """
        Returns information about a notebook instance.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeNotebookInstance>`_

        **Request Syntax**
        ::

          response = client.describe_notebook_instance(
              NotebookInstanceName='string'
          )
        :type NotebookInstanceName: string
        :param NotebookInstanceName: **[REQUIRED]**

          The name of the notebook instance that you want information about.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'NotebookInstanceArn': 'string',
                'NotebookInstanceName': 'string',
                'NotebookInstanceStatus':
                'Pending'|'InService'|'Stopping'|'Stopped'|'Failed'|'Deleting'|'Updating',
                'FailureReason': 'string',
                'Url': 'string',
                'InstanceType':
                'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'|'ml.t3.medium'
                |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'|'ml.m4.xlarge'|'ml.m4.2xlarge'
                |'ml.m4.4xlarge'|'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.xlarge'
                |'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'
                |'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'
                |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                |'ml.c5.18xlarge'|'ml.c5d.xlarge'|'ml.c5d.2xlarge'|'ml.c5d.4xlarge'
                |'ml.c5d.9xlarge'|'ml.c5d.18xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'
                |'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge',
                'SubnetId': 'string',
                'SecurityGroups': [
                    'string',
                ],
                'RoleArn': 'string',
                'KmsKeyId': 'string',
                'NetworkInterfaceId': 'string',
                'LastModifiedTime': datetime(2015, 1, 1),
                'CreationTime': datetime(2015, 1, 1),
                'NotebookInstanceLifecycleConfigName': 'string',
                'DirectInternetAccess': 'Enabled'|'Disabled',
                'VolumeSizeInGB': 123,
                'AcceleratorTypes': [
                    'ml.eia1.medium'|'ml.eia1.large'|'ml.eia1.xlarge'|'ml.eia2.medium'
                    |'ml.eia2.large'|'ml.eia2.xlarge',
                ],
                'DefaultCodeRepository': 'string',
                'AdditionalCodeRepositories': [
                    'string',
                ],
                'RootAccess': 'Enabled'|'Disabled'
            }
          **Response Structure**

          - *(dict) --*

            - **NotebookInstanceArn** *(string) --*

              The Amazon Resource Name (ARN) of the notebook instance.

            - **NotebookInstanceName** *(string) --*

              The name of the Amazon SageMaker notebook instance.

            - **NotebookInstanceStatus** *(string) --*

              The status of the notebook instance.

            - **FailureReason** *(string) --*

              If status is ``Failed`` , the reason it failed.

            - **Url** *(string) --*

              The URL that you use to connect to the Jupyter notebook that is running in your
              notebook instance.

            - **InstanceType** *(string) --*

              The type of ML compute instance running on the notebook instance.

            - **SubnetId** *(string) --*

              The ID of the VPC subnet.

            - **SecurityGroups** *(list) --*

              The IDs of the VPC security groups.

              - *(string) --*

            - **RoleArn** *(string) --*

              The Amazon Resource Name (ARN) of the IAM role associated with the instance.

            - **KmsKeyId** *(string) --*

              The AWS KMS key ID Amazon SageMaker uses to encrypt data when storing it on the ML
              storage volume attached to the instance.

            - **NetworkInterfaceId** *(string) --*

              The network interface IDs that Amazon SageMaker created at the time of creating the
              instance.

            - **LastModifiedTime** *(datetime) --*

              A timestamp. Use this parameter to retrieve the time when the notebook instance was
              last modified.

            - **CreationTime** *(datetime) --*

              A timestamp. Use this parameter to return the time when the notebook instance was
              created

            - **NotebookInstanceLifecycleConfigName** *(string) --*

              Returns the name of a notebook instance lifecycle configuration.

              For information about notebook instance lifestyle configurations, see `Step 2.1\\:
              (Optional) Customize a Notebook Instance
              <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__

            - **DirectInternetAccess** *(string) --*

              Describes whether Amazon SageMaker provides internet access to the notebook instance.
              If this value is set to *Disabled* , the notebook instance does not have internet
              access, and cannot connect to Amazon SageMaker training and endpoint services.

              For more information, see `Notebook Instances Are Internet-Enabled by Default
              <https://docs.aws.amazon.com/sagemaker/latest/dg/appendix-additional-considerations.html#appendix-notebook-and-internet-access>`__
              .

            - **VolumeSizeInGB** *(integer) --*

              The size, in GB, of the ML storage volume attached to the notebook instance.

            - **AcceleratorTypes** *(list) --*

              A list of the Elastic Inference (EI) instance types associated with this notebook
              instance. Currently only one EI instance type can be associated with a notebook
              instance. For more information, see `Using Elastic Inference in Amazon SageMaker
              <https://docs.aws.amazon.com/sagemaker/latest/dg/ei.html>`__ .

              - *(string) --*

            - **DefaultCodeRepository** *(string) --*

              The Git repository associated with the notebook instance as its default code
              repository. This can be either the name of a Git repository stored as a resource in
              your account, or the URL of a Git repository in `AWS CodeCommit
              <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in any
              other Git repository. When you open a notebook instance, it opens in the directory
              that contains this repository. For more information, see `Associating Git Repositories
              with Amazon SageMaker Notebook Instances
              <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

            - **AdditionalCodeRepositories** *(list) --*

              An array of up to three Git repositories associated with the notebook instance. These
              can be either the names of Git repositories stored as resources in your account, or
              the URL of Git repositories in `AWS CodeCommit
              <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in any
              other Git repository. These repositories are cloned at the same level as the default
              repository of your notebook instance. For more information, see `Associating Git
              Repositories with Amazon SageMaker Notebook Instances
              <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

              - *(string) --*

            - **RootAccess** *(string) --*

              Whether root access is enabled or disabled for users of the notebook instance.

              .. note::

                Lifecycle configurations need root access to be able to set up a notebook instance.
                Because of this, lifecycle configurations associated with a notebook instance always
                run with root access even if you disable root access for users.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_notebook_instance_lifecycle_config(
        self, NotebookInstanceLifecycleConfigName: str
    ) -> ClientDescribeNotebookInstanceLifecycleConfigResponseTypeDef:
        """
        Returns a description of a notebook instance lifecycle configuration.

        For information about notebook instance lifestyle configurations, see `Step 2.1\\:
        (Optional) Customize a Notebook Instance
        <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeNotebookInstanceLifecycleConfig>`_

        **Request Syntax**
        ::

          response = client.describe_notebook_instance_lifecycle_config(
              NotebookInstanceLifecycleConfigName='string'
          )
        :type NotebookInstanceLifecycleConfigName: string
        :param NotebookInstanceLifecycleConfigName: **[REQUIRED]**

          The name of the lifecycle configuration to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'NotebookInstanceLifecycleConfigArn': 'string',
                'NotebookInstanceLifecycleConfigName': 'string',
                'OnCreate': [
                    {
                        'Content': 'string'
                    },
                ],
                'OnStart': [
                    {
                        'Content': 'string'
                    },
                ],
                'LastModifiedTime': datetime(2015, 1, 1),
                'CreationTime': datetime(2015, 1, 1)
            }
          **Response Structure**

          - *(dict) --*

            - **NotebookInstanceLifecycleConfigArn** *(string) --*

              The Amazon Resource Name (ARN) of the lifecycle configuration.

            - **NotebookInstanceLifecycleConfigName** *(string) --*

              The name of the lifecycle configuration.

            - **OnCreate** *(list) --*

              The shell script that runs only once, when you create a notebook instance.

              - *(dict) --*

                Contains the notebook instance lifecycle configuration script.

                Each lifecycle configuration script has a limit of 16384 characters.

                The value of the ``$PATH`` environment variable that is available to both scripts is
                ``/sbin:bin:/usr/sbin:/usr/bin`` .

                View CloudWatch Logs for notebook instance lifecycle configurations in log group
                ``/aws/sagemaker/NotebookInstances`` in log stream
                ``[notebook-instance-name]/[LifecycleConfigHook]`` .

                Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script
                runs for longer than 5 minutes, it fails and the notebook instance is not created or
                started.

                For information about notebook instance lifestyle configurations, see `Step 2.1\\:
                (Optional) Customize a Notebook Instance
                <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__
                .

                - **Content** *(string) --*

                  A base64-encoded string that contains a shell script for a notebook instance
                  lifecycle configuration.

            - **OnStart** *(list) --*

              The shell script that runs every time you start a notebook instance, including when
              you create the notebook instance.

              - *(dict) --*

                Contains the notebook instance lifecycle configuration script.

                Each lifecycle configuration script has a limit of 16384 characters.

                The value of the ``$PATH`` environment variable that is available to both scripts is
                ``/sbin:bin:/usr/sbin:/usr/bin`` .

                View CloudWatch Logs for notebook instance lifecycle configurations in log group
                ``/aws/sagemaker/NotebookInstances`` in log stream
                ``[notebook-instance-name]/[LifecycleConfigHook]`` .

                Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script
                runs for longer than 5 minutes, it fails and the notebook instance is not created or
                started.

                For information about notebook instance lifestyle configurations, see `Step 2.1\\:
                (Optional) Customize a Notebook Instance
                <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__
                .

                - **Content** *(string) --*

                  A base64-encoded string that contains a shell script for a notebook instance
                  lifecycle configuration.

            - **LastModifiedTime** *(datetime) --*

              A timestamp that tells when the lifecycle configuration was last modified.

            - **CreationTime** *(datetime) --*

              A timestamp that tells when the lifecycle configuration was created.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_processing_job(
        self, ProcessingJobName: str
    ) -> ClientDescribeProcessingJobResponseTypeDef:
        """
        Returns a description of a processing job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeProcessingJob>`_

        **Request Syntax**
        ::

          response = client.describe_processing_job(
              ProcessingJobName='string'
          )
        :type ProcessingJobName: string
        :param ProcessingJobName: **[REQUIRED]**

          The name of the processing job. The name must be unique within an AWS Region in the AWS
          account.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ProcessingInputs': [
                    {
                        'InputName': 'string',
                        'S3Input': {
                            'S3Uri': 'string',
                            'LocalPath': 'string',
                            'S3DataType': 'ManifestFile'|'S3Prefix',
                            'S3InputMode': 'Pipe'|'File',
                            'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key',
                            'S3CompressionType': 'None'|'Gzip'
                        }
                    },
                ],
                'ProcessingOutputConfig': {
                    'Outputs': [
                        {
                            'OutputName': 'string',
                            'S3Output': {
                                'S3Uri': 'string',
                                'LocalPath': 'string',
                                'S3UploadMode': 'Continuous'|'EndOfJob'
                            }
                        },
                    ],
                    'KmsKeyId': 'string'
                },
                'ProcessingJobName': 'string',
                'ProcessingResources': {
                    'ClusterConfig': {
                        'InstanceCount': 123,
                        'InstanceType':
                        'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                        |'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'
                        |'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.c4.xlarge'
                        |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'
                        |'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'
                        |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                        |'ml.c5.9xlarge'|'ml.c5.18xlarge'|'ml.m5.large'
                        |'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.r5.large'
                        |'ml.r5.xlarge'|'ml.r5.2xlarge'|'ml.r5.4xlarge'
                        |'ml.r5.8xlarge'|'ml.r5.12xlarge'|'ml.r5.16xlarge'
                        |'ml.r5.24xlarge',
                        'VolumeSizeInGB': 123,
                        'VolumeKmsKeyId': 'string'
                    }
                },
                'StoppingCondition': {
                    'MaxRuntimeInSeconds': 123
                },
                'AppSpecification': {
                    'ImageUri': 'string',
                    'ContainerEntrypoint': [
                        'string',
                    ],
                    'ContainerArguments': [
                        'string',
                    ]
                },
                'Environment': {
                    'string': 'string'
                },
                'NetworkConfig': {
                    'EnableNetworkIsolation': True|False,
                    'VpcConfig': {
                        'SecurityGroupIds': [
                            'string',
                        ],
                        'Subnets': [
                            'string',
                        ]
                    }
                },
                'RoleArn': 'string',
                'ExperimentConfig': {
                    'ExperimentName': 'string',
                    'TrialName': 'string',
                    'TrialComponentDisplayName': 'string'
                },
                'ProcessingJobArn': 'string',
                'ProcessingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                'ExitMessage': 'string',
                'FailureReason': 'string',
                'ProcessingEndTime': datetime(2015, 1, 1),
                'ProcessingStartTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'CreationTime': datetime(2015, 1, 1),
                'MonitoringScheduleArn': 'string',
                'AutoMLJobArn': 'string',
                'TrainingJobArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ProcessingInputs** *(list) --*

              The inputs for a processing job.

              - *(dict) --*

                The inputs for a processing job.

                - **InputName** *(string) --*

                  The name of the inputs for the processing job.

                - **S3Input** *(dict) --*

                  The S3 inputs for the processing job.

                  - **S3Uri** *(string) --*

                    The URI for the Amazon S3 storage where you want Amazon SageMaker to download
                    the artifacts needed to run a processing job.

                  - **LocalPath** *(string) --*

                    The local path to the Amazon S3 bucket where you want Amazon SageMaker to
                    download the inputs to run a processing job. ``LocalPath`` is an absolute path
                    to the input data.

                  - **S3DataType** *(string) --*

                    Whether you use an ``S3Prefix`` or a ``ManifestFile`` for the data type. If you
                    choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon SageMaker
                    uses all objects with the specified key name prefix for the processing job. If
                    you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a manifest
                    file containing a list of object keys that you want Amazon SageMaker to use for
                    the processing job.

                  - **S3InputMode** *(string) --*

                    Wether to use ``File`` or ``Pipe`` input mode. In ``File`` mode, Amazon
                    SageMaker copies the data from the input source onto the local Amazon Elastic
                    Block Store (Amazon EBS) volumes before starting your training algorithm. This
                    is the most commonly used input mode. In ``Pipe`` mode, Amazon SageMaker streams
                    input data from the source directly to your algorithm without using the EBS
                    volume.

                  - **S3DataDistributionType** *(string) --*

                    Whether the data stored in Amazon S3 is ``FullyReplicated`` or
                    ``ShardedByS3Key`` .

                  - **S3CompressionType** *(string) --*

                    Whether to use ``Gzip`` compresion for Amazon S3 storage.

            - **ProcessingOutputConfig** *(dict) --*

              Output configuration for the processing job.

              - **Outputs** *(list) --*

                Output configuration information for a processing job.

                - *(dict) --*

                  Describes the results of a processing job.

                  - **OutputName** *(string) --*

                    The name for the processing job output.

                  - **S3Output** *(dict) --*

                    Configuration for processing job outputs in Amazon S3.

                    - **S3Uri** *(string) --*

                      A URI that identifies the Amazon S3 bucket where you want Amazon SageMaker to
                      save the results of a processing job.

                    - **LocalPath** *(string) --*

                      The local path to the Amazon S3 bucket where you want Amazon SageMaker to save
                      the results of an processing job. ``LocalPath`` is an absolute path to the
                      input data.

                    - **S3UploadMode** *(string) --*

                      Whether to upload the results of the processing job continuously or after the
                      job completes.

              - **KmsKeyId** *(string) --*

                The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                the processing job output. ``KmsKeyId`` can be an ID of a KMS key, ARN of a KMS key,
                alias of a KMS key, or alias of a KMS key. The ``KmsKeyId`` is applied to all
                outputs.

            - **ProcessingJobName** *(string) --*

              The name of the processing job. The name must be unique within an AWS Region in the
              AWS account.

            - **ProcessingResources** *(dict) --*

              Identifies the resources, ML compute instances, and ML storage volumes to deploy for a
              processing job. In distributed training, you specify more than one instance.

              - **ClusterConfig** *(dict) --*

                The configuration for the resources in a cluster used to run the processing job.

                - **InstanceCount** *(integer) --*

                  The number of ML compute instances to use in the processing job. For distributed
                  processing jobs, specify a value greater than 1. The default value is 1.

                - **InstanceType** *(string) --*

                  The ML compute instance type for the processing job.

                - **VolumeSizeInGB** *(integer) --*

                  The size of the ML storage volume in gigabytes that you want to provision. You
                  must specify sufficient ML storage for your scenario.

                - **VolumeKmsKeyId** *(string) --*

                  The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                  data on the storage volume attached to the ML compute instance(s) that run the
                  processing job.

            - **StoppingCondition** *(dict) --*

              The time limit for how long the processing job is allowed to run.

              - **MaxRuntimeInSeconds** *(integer) --*

                Specifies the maximum runtime in seconds.

            - **AppSpecification** *(dict) --*

              Configures the processing job to run a specified container image.

              - **ImageUri** *(string) --*

                The container image to be run by the processing job.

              - **ContainerEntrypoint** *(list) --*

                The entrypoint for a container used to run a processing job.

                - *(string) --*

              - **ContainerArguments** *(list) --*

                The arguments for a container used to run a processing job.

                - *(string) --*

            - **Environment** *(dict) --*

              The environment variables set in the Docker container.

              - *(string) --*

                - *(string) --*

            - **NetworkConfig** *(dict) --*

              Networking options for a processing job.

              - **EnableNetworkIsolation** *(boolean) --*

                Whether to allow inbound and outbound network calls to and from the containers used
                for the processing job.

              - **VpcConfig** *(dict) --*

                Specifies a VPC that your training jobs and hosted models have access to. Control
                access to and from your training and model containers by configuring the VPC. For
                more information, see `Protect Endpoints by Using an Amazon Virtual Private Cloud
                <https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html>`__ and `Protect
                Training Jobs by Using an Amazon Virtual Private Cloud
                <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                - **SecurityGroupIds** *(list) --*

                  The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups
                  for the VPC that is specified in the ``Subnets`` field.

                  - *(string) --*

                - **Subnets** *(list) --*

                  The ID of the subnets in the VPC to which you want to connect your training job or
                  model.

                  .. note::

                    Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                    availability zones of region us-east-1. If you want to create endpoints with P3
                    instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                    zones instead.

                  - *(string) --*

            - **RoleArn** *(string) --*

              The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to
              perform tasks on your behalf.

            - **ExperimentConfig** *(dict) --*

              The configuration information used to create an experiment.

              - **ExperimentName** *(string) --*

                The name of the experiment.

              - **TrialName** *(string) --*

                The name of the trial.

              - **TrialComponentDisplayName** *(string) --*

                Display name for the trial component.

            - **ProcessingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the processing job.

            - **ProcessingJobStatus** *(string) --*

              Provides the status of a processing job.

            - **ExitMessage** *(string) --*

              An optional string, up to one KB in size, that contains metadata from the processing
              container when the processing job exits.

            - **FailureReason** *(string) --*

              A string, up to one KB in size, that contains the reason a processing job failed, if
              it failed.

            - **ProcessingEndTime** *(datetime) --*

              The time at which the processing job completed.

            - **ProcessingStartTime** *(datetime) --*

              The time at which the processing job started.

            - **LastModifiedTime** *(datetime) --*

              The time at which the processing job was last modified.

            - **CreationTime** *(datetime) --*

              The time at which the processing job was created.

            - **MonitoringScheduleArn** *(string) --*

              The ARN of a monitoring schedule for an endpoint associated with this processing job.

            - **AutoMLJobArn** *(string) --*

              The ARN of an AutoML job associated with this processing job.

            - **TrainingJobArn** *(string) --*

              The ARN of a training job associated with this processing job.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_subscribed_workteam(
        self, WorkteamArn: str
    ) -> ClientDescribeSubscribedWorkteamResponseTypeDef:
        """
        Gets information about a work team provided by a vendor. It returns details about the
        subscription with a vendor in the AWS Marketplace.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeSubscribedWorkteam>`_

        **Request Syntax**
        ::

          response = client.describe_subscribed_workteam(
              WorkteamArn='string'
          )
        :type WorkteamArn: string
        :param WorkteamArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the subscribed work team to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SubscribedWorkteam': {
                    'WorkteamArn': 'string',
                    'MarketplaceTitle': 'string',
                    'SellerName': 'string',
                    'MarketplaceDescription': 'string',
                    'ListingId': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **SubscribedWorkteam** *(dict) --*

              A ``Workteam`` instance that contains information about the work team.

              - **WorkteamArn** *(string) --*

                The Amazon Resource Name (ARN) of the vendor that you have subscribed.

              - **MarketplaceTitle** *(string) --*

                The title of the service provided by the vendor in the Amazon Marketplace.

              - **SellerName** *(string) --*

                The name of the vendor in the Amazon Marketplace.

              - **MarketplaceDescription** *(string) --*

                The description of the vendor from the Amazon Marketplace.

              - **ListingId** *(string) --*
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_training_job(
        self, TrainingJobName: str
    ) -> ClientDescribeTrainingJobResponseTypeDef:
        """
        Returns information about a training job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeTrainingJob>`_

        **Request Syntax**
        ::

          response = client.describe_training_job(
              TrainingJobName='string'
          )
        :type TrainingJobName: string
        :param TrainingJobName: **[REQUIRED]**

          The name of the training job.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrainingJobName': 'string',
                'TrainingJobArn': 'string',
                'TuningJobArn': 'string',
                'LabelingJobArn': 'string',
                'AutoMLJobArn': 'string',
                'ModelArtifacts': {
                    'S3ModelArtifacts': 'string'
                },
                'TrainingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                'SecondaryStatus':
                'Starting'|'LaunchingMLInstances'|'PreparingTrainingStack'|'Downloading'
                |'DownloadingTrainingImage'|'Training'|'Uploading'|'Stopping'|'Stopped'
                |'MaxRuntimeExceeded'|'Completed'|'Failed'|'Interrupted'
                |'MaxWaitTimeExceeded',
                'FailureReason': 'string',
                'HyperParameters': {
                    'string': 'string'
                },
                'AlgorithmSpecification': {
                    'TrainingImage': 'string',
                    'AlgorithmName': 'string',
                    'TrainingInputMode': 'Pipe'|'File',
                    'MetricDefinitions': [
                        {
                            'Name': 'string',
                            'Regex': 'string'
                        },
                    ],
                    'EnableSageMakerMetricsTimeSeries': True|False
                },
                'RoleArn': 'string',
                'InputDataConfig': [
                    {
                        'ChannelName': 'string',
                        'DataSource': {
                            'S3DataSource': {
                                'S3DataType': 'ManifestFile'|'S3Prefix'|'AugmentedManifestFile',
                                'S3Uri': 'string',
                                'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key',
                                'AttributeNames': [
                                    'string',
                                ]
                            },
                            'FileSystemDataSource': {
                                'FileSystemId': 'string',
                                'FileSystemAccessMode': 'rw'|'ro',
                                'FileSystemType': 'EFS'|'FSxLustre',
                                'DirectoryPath': 'string'
                            }
                        },
                        'ContentType': 'string',
                        'CompressionType': 'None'|'Gzip',
                        'RecordWrapperType': 'None'|'RecordIO',
                        'InputMode': 'Pipe'|'File',
                        'ShuffleConfig': {
                            'Seed': 123
                        }
                    },
                ],
                'OutputDataConfig': {
                    'KmsKeyId': 'string',
                    'S3OutputPath': 'string'
                },
                'ResourceConfig': {
                    'InstanceType':
                    'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                    |'ml.m4.16xlarge'|'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                    |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'
                    |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'
                    |'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                    |'ml.p3.16xlarge'|'ml.p3dn.24xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                    |'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge',
                    'InstanceCount': 123,
                    'VolumeSizeInGB': 123,
                    'VolumeKmsKeyId': 'string'
                },
                'VpcConfig': {
                    'SecurityGroupIds': [
                        'string',
                    ],
                    'Subnets': [
                        'string',
                    ]
                },
                'StoppingCondition': {
                    'MaxRuntimeInSeconds': 123,
                    'MaxWaitTimeInSeconds': 123
                },
                'CreationTime': datetime(2015, 1, 1),
                'TrainingStartTime': datetime(2015, 1, 1),
                'TrainingEndTime': datetime(2015, 1, 1),
                'LastModifiedTime': datetime(2015, 1, 1),
                'SecondaryStatusTransitions': [
                    {
                        'Status':
                        'Starting'|'LaunchingMLInstances'|'PreparingTrainingStack'
                        |'Downloading'|'DownloadingTrainingImage'|'Training'
                        |'Uploading'|'Stopping'|'Stopped'|'MaxRuntimeExceeded'
                        |'Completed'|'Failed'|'Interrupted'|'MaxWaitTimeExceeded',
                        'StartTime': datetime(2015, 1, 1),
                        'EndTime': datetime(2015, 1, 1),
                        'StatusMessage': 'string'
                    },
                ],
                'FinalMetricDataList': [
                    {
                        'MetricName': 'string',
                        'Value': ...,
                        'Timestamp': datetime(2015, 1, 1)
                    },
                ],
                'EnableNetworkIsolation': True|False,
                'EnableInterContainerTrafficEncryption': True|False,
                'EnableManagedSpotTraining': True|False,
                'CheckpointConfig': {
                    'S3Uri': 'string',
                    'LocalPath': 'string'
                },
                'TrainingTimeInSeconds': 123,
                'BillableTimeInSeconds': 123,
                'DebugHookConfig': {
                    'LocalPath': 'string',
                    'S3OutputPath': 'string',
                    'HookParameters': {
                        'string': 'string'
                    },
                    'CollectionConfigurations': [
                        {
                            'CollectionName': 'string',
                            'CollectionParameters': {
                                'string': 'string'
                            }
                        },
                    ]
                },
                'ExperimentConfig': {
                    'ExperimentName': 'string',
                    'TrialName': 'string',
                    'TrialComponentDisplayName': 'string'
                },
                'DebugRuleConfigurations': [
                    {
                        'RuleConfigurationName': 'string',
                        'LocalPath': 'string',
                        'S3OutputPath': 'string',
                        'RuleEvaluatorImage': 'string',
                        'InstanceType':
                        'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                        |'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'
                        |'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.c4.xlarge'
                        |'ml.c4.2xlarge'|'ml.c4.4xlarge'|'ml.c4.8xlarge'
                        |'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'
                        |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                        |'ml.c5.9xlarge'|'ml.c5.18xlarge'|'ml.m5.large'
                        |'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                        |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.r5.large'
                        |'ml.r5.xlarge'|'ml.r5.2xlarge'|'ml.r5.4xlarge'
                        |'ml.r5.8xlarge'|'ml.r5.12xlarge'|'ml.r5.16xlarge'
                        |'ml.r5.24xlarge',
                        'VolumeSizeInGB': 123,
                        'RuleParameters': {
                            'string': 'string'
                        }
                    },
                ],
                'TensorBoardOutputConfig': {
                    'LocalPath': 'string',
                    'S3OutputPath': 'string'
                },
                'DebugRuleEvaluationStatuses': [
                    {
                        'RuleConfigurationName': 'string',
                        'RuleEvaluationJobArn': 'string',
                        'RuleEvaluationStatus':
                        'InProgress'|'NoIssuesFound'|'IssuesFound'|'Error'
                        |'Stopping'|'Stopped',
                        'StatusDetails': 'string',
                        'LastModifiedTime': datetime(2015, 1, 1)
                    },
                ]
            }
          **Response Structure**

          - *(dict) --*

            - **TrainingJobName** *(string) --*

              Name of the model training job.

            - **TrainingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the training job.

            - **TuningJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the associated hyperparameter tuning job if the
              training job was launched by a hyperparameter tuning job.

            - **LabelingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the Amazon SageMaker Ground Truth labeling job that
              created the transform or training job.

            - **AutoMLJobArn** *(string) --*

            - **ModelArtifacts** *(dict) --*

              Information about the Amazon S3 location that is configured for storing model
              artifacts.

              - **S3ModelArtifacts** *(string) --*

                The path of the S3 object that contains the model artifacts. For example,
                ``s3://bucket-name/keynameprefix/model.tar.gz`` .

            - **TrainingJobStatus** *(string) --*

              The status of the training job.

              Amazon SageMaker provides the following training job statuses:

              * ``InProgress`` - The training is in progress.

              * ``Completed`` - The training job has completed.

              * ``Failed`` - The training job has failed. To see the reason for the failure, see the
              ``FailureReason`` field in the response to a ``DescribeTrainingJobResponse`` call.

              * ``Stopping`` - The training job is stopping.

              * ``Stopped`` - The training job has stopped.

              For more detailed information, see ``SecondaryStatus`` .

            - **SecondaryStatus** *(string) --*

              Provides detailed information about the state of the training job. For detailed
              information on the secondary status of the training job, see ``StatusMessage`` under
              SecondaryStatusTransition .

              Amazon SageMaker provides primary statuses and secondary statuses that apply to each
              of them:

                InProgress

              * ``Starting`` - Starting the training job.

              * ``Downloading`` - An optional stage for algorithms that support ``File`` training
              input mode. It indicates that data is being downloaded to the ML storage volumes.

              * ``Training`` - Training is in progress.

              * ``Interrupted`` - The job stopped because the managed spot training instances were
              interrupted.

              * ``Uploading`` - Training is complete and the model artifacts are being uploaded to
              the S3 location.

                Completed

              * ``Completed`` - The training job has completed.

                Failed

              * ``Failed`` - The training job has failed. The reason for the failure is returned in
              the ``FailureReason`` field of ``DescribeTrainingJobResponse`` .

                Stopped

              * ``MaxRuntimeExceeded`` - The job stopped because it exceeded the maximum allowed
              runtime.

              * ``MaxWaitTmeExceeded`` - The job stopped because it exceeded the maximum allowed
              wait time.

              * ``Stopped`` - The training job has stopped.

                Stopping

              * ``Stopping`` - Stopping the training job.

              .. warning::

                Valid values for ``SecondaryStatus`` are subject to change.

              We no longer support the following secondary statuses:

              * ``LaunchingMLInstances``

              * ``PreparingTrainingStack``

              * ``DownloadingTrainingImage``

            - **FailureReason** *(string) --*

              If the training job failed, the reason it failed.

            - **HyperParameters** *(dict) --*

              Algorithm-specific parameters.

              - *(string) --*

                - *(string) --*

            - **AlgorithmSpecification** *(dict) --*

              Information about the algorithm used for training, and algorithm metadata.

              - **TrainingImage** *(string) --*

                The registry path of the Docker image that contains the training algorithm. For
                information about docker registry paths for built-in algorithms, see `Algorithms
                Provided by Amazon SageMaker\\: Common Parameters
                <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                . Amazon SageMaker supports both ``registry/repository[:tag]`` and
                ``registry/repository[@digest]`` image path formats. For more information, see
                `Using Your Own Algorithms with Amazon SageMaker
                <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

              - **AlgorithmName** *(string) --*

                The name of the algorithm resource to use for the training job. This must be an
                algorithm resource that you created or subscribe to on AWS Marketplace. If you
                specify a value for this parameter, you can't specify a value for ``TrainingImage``
                .

              - **TrainingInputMode** *(string) --*

                The input mode that the algorithm supports. For the input modes that Amazon
                SageMaker algorithms support, see `Algorithms
                <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ . If an algorithm
                supports the ``File`` input mode, Amazon SageMaker downloads the training data from
                S3 to the provisioned ML storage Volume, and mounts the directory to docker volume
                for training container. If an algorithm supports the ``Pipe`` input mode, Amazon
                SageMaker streams data directly from S3 to the container.

                In File mode, make sure you provision ML storage volume with sufficient capacity to
                accommodate the data download from S3. In addition to the training data, the ML
                storage volume also stores the output model. The algorithm container use ML storage
                volume to also store intermediate information, if any.

                For distributed algorithms using File mode, training data is distributed uniformly,
                and your training duration is predictable if the input data objects size is
                approximately same. Amazon SageMaker does not split the files any further for model
                training. If the object sizes are skewed, training won't be optimal as the data
                distribution is also skewed where one host in a training cluster is overloaded, thus
                becoming bottleneck in training.

              - **MetricDefinitions** *(list) --*

                A list of metric definition objects. Each object specifies the metric name and
                regular expressions used to parse algorithm logs. Amazon SageMaker publishes each
                metric to Amazon CloudWatch.

                - *(dict) --*

                  Specifies a metric that the training algorithm writes to ``stderr`` or ``stdout``
                  . Amazon SageMakerhyperparameter tuning captures all defined metrics. You specify
                  one metric that a hyperparameter tuning job uses as its objective metric to choose
                  the best training job.

                  - **Name** *(string) --*

                    The name of the metric.

                  - **Regex** *(string) --*

                    A regular expression that searches the output of a training job and gets the
                    value of the metric. For more information about using regular expressions to
                    define metrics, see `Defining Objective Metrics
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                    .

              - **EnableSageMakerMetricsTimeSeries** *(boolean) --*

                To generate and save time-series metrics during training, set to ``true`` . The
                default is ``false`` and time-series metrics aren't generated except in the
                following cases:

                * You use one of the Amazon SageMaker built-in algorithms

                * You use one of the following prebuilt Amazon SageMaker Docker images:

                  * Tensorflow

                  * MXNet

                  * PyTorch

                * You specify at least one  MetricDefinition

            - **RoleArn** *(string) --*

              The AWS Identity and Access Management (IAM) role configured for the training job.

            - **InputDataConfig** *(list) --*

              An array of ``Channel`` objects that describes each data input channel.

              - *(dict) --*

                A channel is a named input source that training algorithms can consume.

                - **ChannelName** *(string) --*

                  The name of the channel.

                - **DataSource** *(dict) --*

                  The location of the channel data.

                  - **S3DataSource** *(dict) --*

                    The S3 location of the data source that is associated with a channel.

                    - **S3DataType** *(string) --*

                      If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                      SageMaker uses all objects that match the specified key name prefix for model
                      training.

                      If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                      manifest file containing a list of object keys that you want Amazon SageMaker
                      to use for model training.

                      If you choose ``AugmentedManifestFile`` , S3Uri identifies an object that is
                      an augmented manifest file in JSON lines format. This file contains the data
                      you want to use for model training. ``AugmentedManifestFile`` can only be used
                      if the Channel's input mode is ``Pipe`` .

                    - **S3Uri** *(string) --*

                      Depending on the value specified for the ``S3DataType`` , identifies either a
                      key name prefix or a manifest. For example:

                      * A key name prefix might look like this: ``s3://bucketname/exampleprefix`` .

                      * A manifest might look like this: ``s3://bucketname/example.manifest``   The
                      manifest is an S3 object which is a JSON file with the following format:  The
                      preceding JSON matches the following ``s3Uris`` :   ``[ {"prefix":
                      "s3://customer_bucket/some/prefix/"},``    ``"relative/path/to/custdata-1",``
                      ``"relative/path/custdata-2",``    ``...``    ``"relative/path/custdata-N"``
                      ``]``   The preceding JSON matches the following ``s3Uris`` :
                      ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                      ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                      ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete
                      set of ``s3uris`` in this manifest is the input data for the channel for this
                      datasource. The object that each ``s3uris`` points to must be readable by the
                      IAM role that Amazon SageMaker uses to perform tasks on your behalf.

                    - **S3DataDistributionType** *(string) --*

                      If you want Amazon SageMaker to replicate the entire dataset on each ML
                      compute instance that is launched for model training, specify
                      ``FullyReplicated`` .

                      If you want Amazon SageMaker to replicate a subset of data on each ML compute
                      instance that is launched for model training, specify ``ShardedByS3Key`` . If
                      there are *n* ML compute instances launched for a training job, each instance
                      gets approximately 1/*n* of the number of S3 objects. In this case, model
                      training on each machine uses only the subset of training data.

                      Don't choose more ML compute instances for training than available S3 objects.
                      If you do, some nodes won't get any data and you will pay for nodes that
                      aren't getting any training data. This applies in both File and Pipe modes.
                      Keep this in mind when developing algorithms.

                      In distributed training, where you use multiple ML compute EC2 instances, you
                      might choose ``ShardedByS3Key`` . If the algorithm requires copying training
                      data to the ML storage volume (when ``TrainingInputMode`` is set to ``File``
                      ), this copies 1/*n* of the number of objects.

                    - **AttributeNames** *(list) --*

                      A list of one or more attribute names to use that are found in a specified
                      augmented manifest file.

                      - *(string) --*

                  - **FileSystemDataSource** *(dict) --*

                    The file system that is associated with a channel.

                    - **FileSystemId** *(string) --*

                      The file system id.

                    - **FileSystemAccessMode** *(string) --*

                      The access mode of the mount of the directory associated with the channel. A
                      directory can be mounted either in ``ro`` (read-only) or ``rw`` (read-write)
                      mode.

                    - **FileSystemType** *(string) --*

                      The file system type.

                    - **DirectoryPath** *(string) --*

                      The full path to the directory to associate with the channel.

                - **ContentType** *(string) --*

                  The MIME type of the data.

                - **CompressionType** *(string) --*

                  If training data is compressed, the compression type. The default value is
                  ``None`` . ``CompressionType`` is used only in Pipe input mode. In File mode,
                  leave this field unset or set it to None.

                - **RecordWrapperType** *(string) --*

                  Specify RecordIO as the value when input data is in raw format but the training
                  algorithm requires the RecordIO format. In this case, Amazon SageMaker wraps each
                  individual S3 object in a RecordIO record. If the input data is already in
                  RecordIO format, you don't need to set this attribute. For more information, see
                  `Create a Dataset Using RecordIO
                  <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__ .

                  In File mode, leave this field unset or set it to None.

                - **InputMode** *(string) --*

                  (Optional) The input mode to use for the data channel in a training job. If you
                  don't set a value for ``InputMode`` , Amazon SageMaker uses the value set for
                  ``TrainingInputMode`` . Use this parameter to override the ``TrainingInputMode``
                  setting in a  AlgorithmSpecification request when you have a channel that needs a
                  different input mode from the training job's general setting. To download the data
                  from Amazon Simple Storage Service (Amazon S3) to the provisioned ML storage
                  volume, and mount the directory to a Docker volume, use ``File`` input mode. To
                  stream data directly from Amazon S3 to the container, choose ``Pipe`` input mode.

                  To use a model for incremental training, choose ``File`` input model.

                - **ShuffleConfig** *(dict) --*

                  A configuration for a shuffle option for input data in a channel. If you use
                  ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key prefix
                  matches. If you use ``ManifestFile`` , the order of the S3 object references in
                  the ``ManifestFile`` is shuffled. If you use ``AugmentedManifestFile`` , the order
                  of the JSON lines in the ``AugmentedManifestFile`` is shuffled. The shuffling
                  order is determined using the ``Seed`` value.

                  For Pipe input mode, shuffling is done at the start of every epoch. With large
                  datasets this ensures that the order of the training data is different for each
                  epoch, it helps reduce bias and possible overfitting. In a multi-node training job
                  when ShuffleConfig is combined with ``S3DataDistributionType`` of
                  ``ShardedByS3Key`` , the data is shuffled across nodes so that the content sent to
                  a particular node on the first epoch might be sent to a different node on the
                  second epoch.

                  - **Seed** *(integer) --*

                    Determines the shuffling order in ``ShuffleConfig`` value.

            - **OutputDataConfig** *(dict) --*

              The S3 path where model artifacts that you configured when creating the job are
              stored. Amazon SageMaker creates subfolders for model artifacts.

              - **KmsKeyId** *(string) --*

                The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                the model artifacts at rest using Amazon S3 server-side encryption. The ``KmsKeyId``
                can be any of the following formats:

                * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // Amazon Resource Name (ARN) of a KMS Key
                ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // KMS Key Alias  ``"alias/ExampleAlias"``

                * // Amazon Resource Name (ARN) of a KMS Key Alias
                ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                execution role must include permissions to call ``kms:Encrypt`` . If you don't
                provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3 for
                your role's account. Amazon SageMaker uses server-side encryption with KMS-managed
                keys for ``OutputDataConfig`` . If you use a bucket policy with an ``s3:PutObject``
                permission that only allows objects with server-side encryption, set the condition
                key of ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For more information,
                see `KMS-Managed Encryption Keys
                <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in the
                *Amazon Simple Storage Service Developer Guide.*

                The KMS key policy must grant permission to the IAM role that you specify in your
                ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                ``CreateHyperParameterTuningJob`` requests. For more information, see `Using Key
                Policies in AWS KMS
                <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the
                *AWS Key Management Service Developer Guide* .

              - **S3OutputPath** *(string) --*

                Identifies the S3 path where you want Amazon SageMaker to store the model artifacts.
                For example, ``s3://bucket-name/key-name-prefix`` .

            - **ResourceConfig** *(dict) --*

              Resources, including ML compute instances and ML storage volumes, that are configured
              for model training.

              - **InstanceType** *(string) --*

                The ML compute instance type.

              - **InstanceCount** *(integer) --*

                The number of ML compute instances to use. For distributed training, provide a value
                greater than 1.

              - **VolumeSizeInGB** *(integer) --*

                The size of the ML storage volume that you want to provision.

                ML storage volumes store model artifacts and incremental states. Training algorithms
                might also use the ML storage volume for scratch space. If you want to store the
                training data in the ML storage volume, choose ``File`` as the ``TrainingInputMode``
                in the algorithm specification.

                You must specify sufficient ML storage for your scenario.

                .. note::

                  Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage volume
                  type.

                .. note::

                  Certain Nitro-based instances include local storage with a fixed total size,
                  dependent on the instance type. When using these instances for training, Amazon
                  SageMaker mounts the local instance storage instead of Amazon EBS gp2 storage. You
                  can't request a ``VolumeSizeInGB`` greater than the total size of the local
                  instance storage.

                  For a list of instance types that support local instance storage, including the
                  total size per instance type, see `Instance Store Volumes
                  <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                  .

              - **VolumeKmsKeyId** *(string) --*

                The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume
                attached to the ML compute instance(s) that run the training job.

                .. note::

                  Certain Nitro-based instances include local storage, dependent on the instance
                  type. Local storage volumes are encrypted using a hardware module on the instance.
                  You can't request a ``VolumeKmsKeyId`` when using an instance type with local
                  storage.

                  For a list of instance types that support local instance storage, see `Instance
                  Store Volumes
                  <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                  .

                  For more information about local instance storage encryption, see `SSD Instance
                  Store Volumes
                  <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__ .

                The ``VolumeKmsKeyId`` can be in any of the following formats:

                * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // Amazon Resource Name (ARN) of a KMS Key
                ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            - **VpcConfig** *(dict) --*

              A  VpcConfig object that specifies the VPC that this training job has access to. For
              more information, see `Protect Training Jobs by Using an Amazon Virtual Private Cloud
              <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

              - **SecurityGroupIds** *(list) --*

                The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for
                the VPC that is specified in the ``Subnets`` field.

                - *(string) --*

              - **Subnets** *(list) --*

                The ID of the subnets in the VPC to which you want to connect your training job or
                model.

                .. note::

                  Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                  availability zones of region us-east-1. If you want to create endpoints with P3
                  instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                  zones instead.

                - *(string) --*

            - **StoppingCondition** *(dict) --*

              Specifies a limit to how long a model training job can run. It also specifies the
              maximum time to wait for a spot instance. When the job reaches the time limit, Amazon
              SageMaker ends the training job. Use this API to cap model training costs.

              To stop a job, Amazon SageMaker sends the algorithm the ``SIGTERM`` signal, which
              delays job termination for 120 seconds. Algorithms can use this 120-second window to
              save the model artifacts, so the results of training are not lost.

              - **MaxRuntimeInSeconds** *(integer) --*

                The maximum length of time, in seconds, that the training or compilation job can
                run. If job does not complete during this time, Amazon SageMaker ends the job. If
                value is not specified, default value is 1 day. The maximum value is 28 days.

              - **MaxWaitTimeInSeconds** *(integer) --*

                The maximum length of time, in seconds, how long you are willing to wait for a
                managed spot training job to complete. It is the amount of time spent waiting for
                Spot capacity plus the amount of time the training job runs. It must be equal to or
                greater than ``MaxRuntimeInSeconds`` .

            - **CreationTime** *(datetime) --*

              A timestamp that indicates when the training job was created.

            - **TrainingStartTime** *(datetime) --*

              Indicates the time when the training job starts on training instances. You are billed
              for the time interval between this time and the value of ``TrainingEndTime`` . The
              start time in CloudWatch Logs might be later than this time. The difference is due to
              the time it takes to download the training data and to the size of the training
              container.

            - **TrainingEndTime** *(datetime) --*

              Indicates the time when the training job ends on training instances. You are billed
              for the time interval between the value of ``TrainingStartTime`` and this time. For
              successful jobs and stopped jobs, this is the time after model artifacts are uploaded.
              For failed jobs, this is the time when Amazon SageMaker detects a job failure.

            - **LastModifiedTime** *(datetime) --*

              A timestamp that indicates when the status of the training job was last modified.

            - **SecondaryStatusTransitions** *(list) --*

              A history of all of the secondary statuses that the training job has transitioned
              through.

              - *(dict) --*

                An array element of  DescribeTrainingJobResponse$SecondaryStatusTransitions . It
                provides additional details about a status that the training job has transitioned
                through. A training job can be in one of several states, for example, starting,
                downloading, training, or uploading. Within each state, there are a number of
                intermediate states. For example, within the starting state, Amazon SageMaker could
                be starting the training job or launching the ML instances. These transitional
                states are referred to as the job's secondary status.

                - **Status** *(string) --*

                  Contains a secondary status information from a training job.

                  Status might be one of the following secondary statuses:

                    InProgress

                  * ``Starting`` - Starting the training job.

                  * ``Downloading`` - An optional stage for algorithms that support ``File``
                  training input mode. It indicates that data is being downloaded to the ML storage
                  volumes.

                  * ``Training`` - Training is in progress.

                  * ``Uploading`` - Training is complete and the model artifacts are being uploaded
                  to the S3 location.

                    Completed

                  * ``Completed`` - The training job has completed.

                    Failed

                  * ``Failed`` - The training job has failed. The reason for the failure is returned
                  in the ``FailureReason`` field of ``DescribeTrainingJobResponse`` .

                    Stopped

                  * ``MaxRuntimeExceeded`` - The job stopped because it exceeded the maximum allowed
                  runtime.

                  * ``Stopped`` - The training job has stopped.

                    Stopping

                  * ``Stopping`` - Stopping the training job.

                  We no longer support the following secondary statuses:

                  * ``LaunchingMLInstances``

                  * ``PreparingTrainingStack``

                  * ``DownloadingTrainingImage``

                - **StartTime** *(datetime) --*

                  A timestamp that shows when the training job transitioned to the current secondary
                  status state.

                - **EndTime** *(datetime) --*

                  A timestamp that shows when the training job transitioned out of this secondary
                  status state into another secondary status state or when the training job has
                  ended.

                - **StatusMessage** *(string) --*

                  A detailed description of the progress within a secondary status.

                  Amazon SageMaker provides secondary statuses and status messages that apply to
                  each of them:

                    Starting

                  * Starting the training job.

                  * Launching requested ML instances.

                  * Insufficient capacity error from EC2 while launching instances, retrying!

                  * Launched instance was unhealthy, replacing it!

                  * Preparing the instances for training.

                    Training

                  * Downloading the training image.

                  * Training image download completed. Training in progress.

                  .. warning::

                    Status messages are subject to change. Therefore, we recommend not including
                    them in code that programmatically initiates actions. For examples, don't use
                    status messages in if statements.

                  To have an overview of your training job's progress, view ``TrainingJobStatus``
                  and ``SecondaryStatus`` in  DescribeTrainingJob , and ``StatusMessage`` together.
                  For example, at the start of a training job, you might see the following:

                  * ``TrainingJobStatus`` - InProgress

                  * ``SecondaryStatus`` - Training

                  * ``StatusMessage`` - Downloading the training image

            - **FinalMetricDataList** *(list) --*

              A collection of ``MetricData`` objects that specify the names, values, and dates and
              times that the training algorithm emitted to Amazon CloudWatch.

              - *(dict) --*

                The name, value, and date and time of a metric that was emitted to Amazon
                CloudWatch.

                - **MetricName** *(string) --*

                  The name of the metric.

                - **Value** *(float) --*

                  The value of the metric.

                - **Timestamp** *(datetime) --*

                  The date and time that the algorithm emitted the metric.

            - **EnableNetworkIsolation** *(boolean) --*

              If you want to allow inbound or outbound network calls, except for calls between peers
              within a training cluster for distributed training, choose ``True`` . If you enable
              network isolation for training jobs that are configured to use a VPC, Amazon SageMaker
              downloads and uploads customer data and model artifacts through the specified VPC, but
              the training container does not have network access.

              .. note::

                The Semantic Segmentation built-in algorithm does not support network isolation.

            - **EnableInterContainerTrafficEncryption** *(boolean) --*

              To encrypt all communications between ML compute instances in distributed training,
              choose ``True`` . Encryption provides greater security for distributed training, but
              training might take longer. How long it takes depends on the amount of communication
              between compute instances, especially if you use a deep learning algorithms in
              distributed training.

            - **EnableManagedSpotTraining** *(boolean) --*

              A Boolean indicating whether managed spot training is enabled (``True`` ) or not
              (``False`` ).

            - **CheckpointConfig** *(dict) --*

              Contains information about the output location for managed spot training checkpoint
              data.

              - **S3Uri** *(string) --*

                Identifies the S3 path where you want Amazon SageMaker to store checkpoints. For
                example, ``s3://bucket-name/key-name-prefix`` .

              - **LocalPath** *(string) --*

                (Optional) The local directory where checkpoints are written. The default directory
                is ``/opt/ml/checkpoints/`` .

            - **TrainingTimeInSeconds** *(integer) --*

              The training time in seconds.

            - **BillableTimeInSeconds** *(integer) --*

              The billable time in seconds.

              You can calculate the savings from using managed spot training using the formula ``(1
              - BillableTimeInSeconds / TrainingTimeInSeconds) * 100`` . For example, if
              ``BillableTimeInSeconds`` is 100 and ``TrainingTimeInSeconds`` is 500, the savings is
              80%.

            - **DebugHookConfig** *(dict) --*

              Configuration information for the debug hook parameters, collection configuration, and
              storage paths.

              - **LocalPath** *(string) --*

                Path to local storage location for tensors. Defaults to ``/opt/ml/output/tensors/``
                .

              - **S3OutputPath** *(string) --*

                Path to Amazon S3 storage location for tensors.

              - **HookParameters** *(dict) --*

                Configuration information for the debug hook parameters.

                - *(string) --*

                  - *(string) --*

              - **CollectionConfigurations** *(list) --*

                Configuration information for tensor collections.

                - *(dict) --*

                  Configuration information for tensor collections.

                  - **CollectionName** *(string) --*

                    The name of the tensor collection.

                  - **CollectionParameters** *(dict) --*

                    Parameter values for the tensor collection. The allowed parameters are
                    ``"name"`` , ``"include_regex"`` , ``"reduction_config"`` , ``"save_config"`` ,
                    ``"tensor_names"`` , and ``"save_histogram"`` .

                    - *(string) --*

                      - *(string) --*

            - **ExperimentConfig** *(dict) --*

              Configuration for the experiment.

              - **ExperimentName** *(string) --*

                The name of the experiment.

              - **TrialName** *(string) --*

                The name of the trial.

              - **TrialComponentDisplayName** *(string) --*

                Display name for the trial component.

            - **DebugRuleConfigurations** *(list) --*

              Configuration information for debugging rules.

              - *(dict) --*

                Configuration information for debugging rules.

                - **RuleConfigurationName** *(string) --*

                  The name of the rule configuration. It must be unique relative to other rule
                  configuration names.

                - **LocalPath** *(string) --*

                  Path to local storage location for rules. Defaults to
                  ``/opt/ml/processing/output/rule/`` .

                - **S3OutputPath** *(string) --*

                  Path to Amazon S3 storage location for rules.

                - **RuleEvaluatorImage** *(string) --*

                  The Amazon Elastic Container (ECR) Image for the managed rule evaluation.

                - **InstanceType** *(string) --*

                  The instance type to deploy for a training job.

                - **VolumeSizeInGB** *(integer) --*

                  The size, in GB, of the ML storage volume attached to the notebook instance.

                - **RuleParameters** *(dict) --*

                  Runtime configuration for rule container.

                  - *(string) --*

                    - *(string) --*

            - **TensorBoardOutputConfig** *(dict) --*

              Configuration of storage locations for TensorBoard output.

              - **LocalPath** *(string) --*

                Path to local storage location for tensorBoard output. Defaults to
                ``/opt/ml/output/tensorboard`` .

              - **S3OutputPath** *(string) --*

                Path to Amazon S3 storage location for TensorBoard output.

            - **DebugRuleEvaluationStatuses** *(list) --*

              Status about the debug rule evaluation.

              - *(dict) --*

                Information about the status of the rule evaluation.

                - **RuleConfigurationName** *(string) --*

                  The name of the rule configuration

                - **RuleEvaluationJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the rule evaluation job.

                - **RuleEvaluationStatus** *(string) --*

                  Status of the rule evaluation.

                - **StatusDetails** *(string) --*

                  Details from the rule evaluation.

                - **LastModifiedTime** *(datetime) --*

                  Timestamp when the rule evaluation status was last modified.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_transform_job(
        self, TransformJobName: str
    ) -> ClientDescribeTransformJobResponseTypeDef:
        """
        Returns information about a transform job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeTransformJob>`_

        **Request Syntax**
        ::

          response = client.describe_transform_job(
              TransformJobName='string'
          )
        :type TransformJobName: string
        :param TransformJobName: **[REQUIRED]**

          The name of the transform job that you want to view details of.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TransformJobName': 'string',
                'TransformJobArn': 'string',
                'TransformJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                'FailureReason': 'string',
                'ModelName': 'string',
                'MaxConcurrentTransforms': 123,
                'MaxPayloadInMB': 123,
                'BatchStrategy': 'MultiRecord'|'SingleRecord',
                'Environment': {
                    'string': 'string'
                },
                'TransformInput': {
                    'DataSource': {
                        'S3DataSource': {
                            'S3DataType': 'ManifestFile'|'S3Prefix'|'AugmentedManifestFile',
                            'S3Uri': 'string'
                        }
                    },
                    'ContentType': 'string',
                    'CompressionType': 'None'|'Gzip',
                    'SplitType': 'None'|'Line'|'RecordIO'|'TFRecord'
                },
                'TransformOutput': {
                    'S3OutputPath': 'string',
                    'Accept': 'string',
                    'AssembleWith': 'None'|'Line',
                    'KmsKeyId': 'string'
                },
                'TransformResources': {
                    'InstanceType':
                    'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'|'ml.m4.10xlarge'
                    |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'|'ml.c4.4xlarge'
                    |'ml.c4.8xlarge'|'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                    |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge'|'ml.c5.xlarge'
                    |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'|'ml.c5.18xlarge'
                    |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'|'ml.m5.4xlarge'
                    |'ml.m5.12xlarge'|'ml.m5.24xlarge',
                    'InstanceCount': 123,
                    'VolumeKmsKeyId': 'string'
                },
                'CreationTime': datetime(2015, 1, 1),
                'TransformStartTime': datetime(2015, 1, 1),
                'TransformEndTime': datetime(2015, 1, 1),
                'LabelingJobArn': 'string',
                'AutoMLJobArn': 'string',
                'DataProcessing': {
                    'InputFilter': 'string',
                    'OutputFilter': 'string',
                    'JoinSource': 'Input'|'None'
                },
                'ExperimentConfig': {
                    'ExperimentName': 'string',
                    'TrialName': 'string',
                    'TrialComponentDisplayName': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **TransformJobName** *(string) --*

              The name of the transform job.

            - **TransformJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the transform job.

            - **TransformJobStatus** *(string) --*

              The status of the transform job. If the transform job failed, the reason is returned
              in the ``FailureReason`` field.

            - **FailureReason** *(string) --*

              If the transform job failed, ``FailureReason`` describes why it failed. A transform
              job creates a log file, which includes error messages, and stores it as an Amazon S3
              object. For more information, see `Log Amazon SageMaker Events with Amazon CloudWatch
              <https://docs.aws.amazon.com/sagemaker/latest/dg/logging-cloudwatch.html>`__ .

            - **ModelName** *(string) --*

              The name of the model used in the transform job.

            - **MaxConcurrentTransforms** *(integer) --*

              The maximum number of parallel requests on each instance node that can be launched in
              a transform job. The default value is 1.

            - **MaxPayloadInMB** *(integer) --*

              The maximum payload size, in MB, used in the transform job.

            - **BatchStrategy** *(string) --*

              Specifies the number of records to include in a mini-batch for an HTTP inference
              request. A *record*  is a single unit of input data that inference can be made on. For
              example, a single line in a CSV file is a record.

              To enable the batch strategy, you must set ``SplitType`` to ``Line`` , ``RecordIO`` ,
              or ``TFRecord`` .

            - **Environment** *(dict) --*

              The environment variables to set in the Docker container. We support up to 16 key and
              values entries in the map.

              - *(string) --*

                - *(string) --*

            - **TransformInput** *(dict) --*

              Describes the dataset to be transformed and the Amazon S3 location where it is stored.

              - **DataSource** *(dict) --*

                Describes the location of the channel data, which is, the S3 location of the input
                data that the model can consume.

                - **S3DataSource** *(dict) --*

                  The S3 location of the data source that is associated with a channel.

                  - **S3DataType** *(string) --*

                    If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix. Amazon
                    SageMaker uses all objects with the specified key name prefix for batch
                    transform.

                    If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is a
                    manifest file containing a list of object keys that you want Amazon SageMaker to
                    use for batch transform.

                    The following values are compatible: ``ManifestFile`` , ``S3Prefix``

                    The following value is not compatible: ``AugmentedManifestFile``

                  - **S3Uri** *(string) --*

                    Depending on the value specified for the ``S3DataType`` , identifies either a
                    key name prefix or a manifest. For example:

                    * A key name prefix might look like this: ``s3://bucketname/exampleprefix`` .

                    * A manifest might look like this: ``s3://bucketname/example.manifest``   The
                    manifest is an S3 object which is a JSON file with the following format:   ``[
                    {"prefix": "s3://customer_bucket/some/prefix/"},``
                    ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``    ``...``
                    ``"relative/path/custdata-N"``    ``]``   The preceding JSON matches the
                    following ``s3Uris`` :
                    ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                    ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                    ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The complete set
                    of ``S3Uris`` in this manifest constitutes the input data for the channel for
                    this datasource. The object that each ``S3Uris`` points to must be readable by
                    the IAM role that Amazon SageMaker uses to perform tasks on your behalf.

              - **ContentType** *(string) --*

                The multipurpose internet mail extension (MIME) type of the data. Amazon SageMaker
                uses the MIME type with each http call to transfer data to the transform job.

              - **CompressionType** *(string) --*

                If your transform data is compressed, specify the compression type. Amazon SageMaker
                automatically decompresses the data for the transform job accordingly. The default
                value is ``None`` .

              - **SplitType** *(string) --*

                The method to use to split the transform job's data files into smaller batches.
                Splitting is necessary when the total size of each object is too large to fit in a
                single request. You can also use data splitting to improve performance by processing
                multiple concurrent mini-batches. The default value for ``SplitType`` is ``None`` ,
                which indicates that input data files are not split, and request payloads contain
                the entire contents of an input object. Set the value of this parameter to ``Line``
                to split records on a newline character boundary. ``SplitType`` also supports a
                number of record-oriented binary data formats.

                When splitting is enabled, the size of a mini-batch depends on the values of the
                ``BatchStrategy`` and ``MaxPayloadInMB`` parameters. When the value of
                ``BatchStrategy`` is ``MultiRecord`` , Amazon SageMaker sends the maximum number of
                records in each request, up to the ``MaxPayloadInMB`` limit. If the value of
                ``BatchStrategy`` is ``SingleRecord`` , Amazon SageMaker sends individual records in
                each request.

                .. note::

                  Some data formats represent a record as a binary payload wrapped with extra
                  padding bytes. When splitting is applied to a binary data format, padding is
                  removed if the value of ``BatchStrategy`` is set to ``SingleRecord`` . Padding is
                  not removed if the value of ``BatchStrategy`` is set to ``MultiRecord`` .

                  For more information about ``RecordIO`` , see `Create a Dataset Using RecordIO
                  <https://mxnet.apache.org/api/faq/recordio>`__ in the MXNet documentation. For
                  more information about ``TFRecord`` , see `Consuming TFRecord data
                  <https://www.tensorflow.org/guide/datasets#consuming_tfrecord_data>`__ in the
                  TensorFlow documentation.

            - **TransformOutput** *(dict) --*

              Identifies the Amazon S3 location where you want Amazon SageMaker to save the results
              from the transform job.

              - **S3OutputPath** *(string) --*

                The Amazon S3 path where you want Amazon SageMaker to store the results of the
                transform job. For example, ``s3://bucket-name/key-name-prefix`` .

                For every S3 object used as input for the transform job, batch transform stores the
                transformed data with an .``out`` suffix in a corresponding subfolder in the
                location in the output prefix. For example, for the input data stored at
                ``s3://bucket-name/input-name-prefix/dataset01/data.csv`` , batch transform stores
                the transformed data at
                ``s3://bucket-name/output-name-prefix/input-name-prefix/data.csv.out`` . Batch
                transform doesn't upload partially processed objects. For an input S3 object that
                contains multiple records, it creates an .``out`` file only if the transform job
                succeeds on the entire file. When the input contains multiple S3 objects, the batch
                transform job processes the listed S3 objects and uploads only the output for
                successfully processed objects. If any object fails in the transform job batch
                transform marks the job as failed to prompt investigation.

              - **Accept** *(string) --*

                The MIME type used to specify the output data. Amazon SageMaker uses the MIME type
                with each http call to transfer data from the transform job.

              - **AssembleWith** *(string) --*

                Defines how to assemble the results of the transform job as a single S3 object.
                Choose a format that is most convenient to you. To concatenate the results in binary
                format, specify ``None`` . To add a newline character at the end of every
                transformed record, specify ``Line`` .

              - **KmsKeyId** *(string) --*

                The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                the model artifacts at rest using Amazon S3 server-side encryption. The ``KmsKeyId``
                can be any of the following formats:

                * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // Amazon Resource Name (ARN) of a KMS Key
                ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // KMS Key Alias  ``"alias/ExampleAlias"``

                * // Amazon Resource Name (ARN) of a KMS Key Alias
                ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS key for
                Amazon S3 for your role's account. For more information, see `KMS-Managed Encryption
                Keys <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__ in
                the *Amazon Simple Storage Service Developer Guide.*

                The KMS key policy must grant permission to the IAM role that you specify in your
                CreateModel request. For more information, see `Using Key Policies in AWS KMS
                <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in the
                *AWS Key Management Service Developer Guide* .

            - **TransformResources** *(dict) --*

              Describes the resources, including ML instance types and ML instance count, to use for
              the transform job.

              - **InstanceType** *(string) --*

                The ML compute instance type for the transform job. If you are using built-in
                algorithms to transform moderately sized datasets, we recommend using ml.m4.xlarge
                or ``ml.m5.large`` instance types.

              - **InstanceCount** *(integer) --*

                The number of ML compute instances to use in the transform job. For distributed
                transform jobs, specify a value greater than 1. The default value is ``1`` .

              - **VolumeKmsKeyId** *(string) --*

                The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                model data on the storage volume attached to the ML compute instance(s) that run the
                batch transform job. The ``VolumeKmsKeyId`` can be any of the following formats:

                * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                * // Amazon Resource Name (ARN) of a KMS Key
                ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

            - **CreationTime** *(datetime) --*

              A timestamp that shows when the transform Job was created.

            - **TransformStartTime** *(datetime) --*

              Indicates when the transform job starts on ML instances. You are billed for the time
              interval between this time and the value of ``TransformEndTime`` .

            - **TransformEndTime** *(datetime) --*

              Indicates when the transform job has been completed, or has stopped or failed. You are
              billed for the time interval between this time and the value of ``TransformStartTime``
              .

            - **LabelingJobArn** *(string) --*

              The Amazon Resource Name (ARN) of the Amazon SageMaker Ground Truth labeling job that
              created the transform or training job.

            - **AutoMLJobArn** *(string) --*

            - **DataProcessing** *(dict) --*

              The data structure used to specify the data to be used for inference in a batch
              transform job and to associate the data that is relevant to the prediction results in
              the output. The input filter provided allows you to exclude input data that is not
              needed for inference in a batch transform job. The output filter provided allows you
              to include input data relevant to interpreting the predictions in the output from the
              job. For more information, see `Associate Prediction Results with their Corresponding
              Input Records
              <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html>`__
              .

              - **InputFilter** *(string) --*

                A `JSONPath
                <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html#data-processing-operators>`__
                expression used to select a portion of the input data to pass to the algorithm. Use
                the ``InputFilter`` parameter to exclude fields, such as an ID column, from the
                input. If you want Amazon SageMaker to pass the entire input dataset to the
                algorithm, accept the default value ``$`` .

                Examples: ``"$"`` , ``"$[1:]"`` , ``"$.features"``

              - **OutputFilter** *(string) --*

                A `JSONPath
                <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html#data-processing-operators>`__
                expression used to select a portion of the joined dataset to save in the output file
                for a batch transform job. If you want Amazon SageMaker to store the entire input
                dataset in the output file, leave the default value, ``$`` . If you specify indexes
                that aren't within the dimension size of the joined dataset, you get an error.

                Examples: ``"$"`` , ``"$[0,5:]"`` , ``"$['id','SageMakerOutput']"``

              - **JoinSource** *(string) --*

                Specifies the source of the data to join with the transformed data. The valid values
                are ``None`` and ``Input`` . The default value is ``None`` , which specifies not to
                join the input with the transformed data. If you want the batch transform job to
                join the original input data with the transformed data, set ``JoinSource`` to
                ``Input`` .

                For JSON or JSONLines objects, such as a JSON array, Amazon SageMaker adds the
                transformed data to the input JSON object in an attribute called ``SageMakerOutput``
                . The joined result for JSON must be a key-value pair object. If the input is not a
                key-value pair object, Amazon SageMaker creates a new JSON file. In the new JSON
                file, and the input data is stored under the ``SageMakerInput`` key and the results
                are stored in ``SageMakerOutput`` .

                For CSV files, Amazon SageMaker combines the transformed data with the input data at
                the end of the input data and stores it in the output file. The joined data has the
                joined input data followed by the transformed data and the output is a CSV file.

            - **ExperimentConfig** *(dict) --*

              Configuration for the experiment.

              - **ExperimentName** *(string) --*

                The name of the experiment.

              - **TrialName** *(string) --*

                The name of the trial.

              - **TrialComponentDisplayName** *(string) --*

                Display name for the trial component.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_trial(self, TrialName: str) -> ClientDescribeTrialResponseTypeDef:
        """
        Provides a list of a trial's properties.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeTrial>`_

        **Request Syntax**
        ::

          response = client.describe_trial(
              TrialName='string'
          )
        :type TrialName: string
        :param TrialName: **[REQUIRED]**

          The name of the trial to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialName': 'string',
                'TrialArn': 'string',
                'DisplayName': 'string',
                'ExperimentName': 'string',
                'Source': {
                    'SourceArn': 'string',
                    'SourceType': 'string'
                },
                'CreationTime': datetime(2015, 1, 1),
                'CreatedBy': {
                    'UserProfileArn': 'string',
                    'UserProfileName': 'string',
                    'DomainId': 'string'
                },
                'LastModifiedTime': datetime(2015, 1, 1),
                'LastModifiedBy': {
                    'UserProfileArn': 'string',
                    'UserProfileName': 'string',
                    'DomainId': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **TrialName** *(string) --*

              The name of the trial.

            - **TrialArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial.

            - **DisplayName** *(string) --*

              The name of the trial as displayed. If ``DisplayName`` isn't specified, ``TrialName``
              is displayed.

            - **ExperimentName** *(string) --*

              The name of the experiment the trial is part of.

            - **Source** *(dict) --*

              The Amazon Resource Name (ARN) of the source and, optionally, the job type.

              - **SourceArn** *(string) --*

                The Amazon Resource Name (ARN) of the source.

              - **SourceType** *(string) --*

                The source job type.

            - **CreationTime** *(datetime) --*

              When the trial was created.

            - **CreatedBy** *(dict) --*

              Who created the trial.

              - **UserProfileArn** *(string) --*

                The Amazon Resource Name (ARN) of the user's profile.

              - **UserProfileName** *(string) --*

                The name of the user's profile.

              - **DomainId** *(string) --*

                The domain associated with the user.

            - **LastModifiedTime** *(datetime) --*

              When the trial was last modified.

            - **LastModifiedBy** *(dict) --*

              Who last modified the trial.

              - **UserProfileArn** *(string) --*

                The Amazon Resource Name (ARN) of the user's profile.

              - **UserProfileName** *(string) --*

                The name of the user's profile.

              - **DomainId** *(string) --*

                The domain associated with the user.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_trial_component(
        self, TrialComponentName: str
    ) -> ClientDescribeTrialComponentResponseTypeDef:
        """
        Provides a list of a trials component's properties.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeTrialComponent>`_

        **Request Syntax**
        ::

          response = client.describe_trial_component(
              TrialComponentName='string'
          )
        :type TrialComponentName: string
        :param TrialComponentName: **[REQUIRED]**

          The name of the trial component to describe.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialComponentName': 'string',
                'TrialComponentArn': 'string',
                'DisplayName': 'string',
                'Source': {
                    'SourceArn': 'string',
                    'SourceType': 'string'
                },
                'Status': {
                    'PrimaryStatus': 'InProgress'|'Completed'|'Failed',
                    'Message': 'string'
                },
                'StartTime': datetime(2015, 1, 1),
                'EndTime': datetime(2015, 1, 1),
                'CreationTime': datetime(2015, 1, 1),
                'CreatedBy': {
                    'UserProfileArn': 'string',
                    'UserProfileName': 'string',
                    'DomainId': 'string'
                },
                'LastModifiedTime': datetime(2015, 1, 1),
                'LastModifiedBy': {
                    'UserProfileArn': 'string',
                    'UserProfileName': 'string',
                    'DomainId': 'string'
                },
                'Parameters': {
                    'string': {
                        'StringValue': 'string',
                        'NumberValue': 123.0
                    }
                },
                'InputArtifacts': {
                    'string': {
                        'MediaType': 'string',
                        'Value': 'string'
                    }
                },
                'OutputArtifacts': {
                    'string': {
                        'MediaType': 'string',
                        'Value': 'string'
                    }
                },
                'Metrics': [
                    {
                        'MetricName': 'string',
                        'SourceArn': 'string',
                        'TimeStamp': datetime(2015, 1, 1),
                        'Max': 123.0,
                        'Min': 123.0,
                        'Last': 123.0,
                        'Count': 123,
                        'Avg': 123.0,
                        'StdDev': 123.0
                    },
                ]
            }
          **Response Structure**

          - *(dict) --*

            - **TrialComponentName** *(string) --*

              The name of the trial component.

            - **TrialComponentArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial component.

            - **DisplayName** *(string) --*

              The name of the component as displayed. If ``DisplayName`` isn't specified,
              ``TrialComponentName`` is displayed.

            - **Source** *(dict) --*

              The Amazon Resource Name (ARN) of the source and, optionally, the job type.

              - **SourceArn** *(string) --*

                The Amazon Resource Name (ARN) of the source.

              - **SourceType** *(string) --*

                The source job type.

            - **Status** *(dict) --*

              The status of the component. States include:

              * InProgress

              * Completed

              * Failed

              - **PrimaryStatus** *(string) --*

                The status of the trial component.

              - **Message** *(string) --*

                If the component failed, a message describing why.

            - **StartTime** *(datetime) --*

              When the component started.

            - **EndTime** *(datetime) --*

              When the component ended.

            - **CreationTime** *(datetime) --*

              When the component was created.

            - **CreatedBy** *(dict) --*

              Who created the component.

              - **UserProfileArn** *(string) --*

                The Amazon Resource Name (ARN) of the user's profile.

              - **UserProfileName** *(string) --*

                The name of the user's profile.

              - **DomainId** *(string) --*

                The domain associated with the user.

            - **LastModifiedTime** *(datetime) --*

              When the component was last modified.

            - **LastModifiedBy** *(dict) --*

              Who last modified the component.

              - **UserProfileArn** *(string) --*

                The Amazon Resource Name (ARN) of the user's profile.

              - **UserProfileName** *(string) --*

                The name of the user's profile.

              - **DomainId** *(string) --*

                The domain associated with the user.

            - **Parameters** *(dict) --*

              The hyperparameters of the component.

              - *(string) --*

                - *(dict) --*

                  The value of a hyperparameter. Only one of ``NumberValue`` or ``StringValue`` can
                  be specified.

                  This object is specified in the  CreateTrialComponent request.

                  - **StringValue** *(string) --*

                    The string value of a categorical hyperparameter. If you specify a value for
                    this parameter, you can't specify the ``NumberValue`` parameter.

                  - **NumberValue** *(float) --*

                    The numeric value of a numeric hyperparameter. If you specify a value for this
                    parameter, you can't specify the ``StringValue`` parameter.

            - **InputArtifacts** *(dict) --*

              The input artifacts of the component.

              - *(string) --*

                - *(dict) --*

                  Represents an input or output artifact of a trial component. You specify
                  ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and
                  ``OutputArtifacts`` parameters in the  CreateTrialComponent request.

                  Examples of input artifacts are datasets, algorithms, hyperparameters, source
                  code, and instance types. Examples of output artifacts are metrics, snapshots,
                  logs, and images.

                  - **MediaType** *(string) --*

                    The media type of the artifact, which indicates the type of data in the artifact
                    file. The media type consists of a *type* and a *subtype* concatenated with a
                    slash (/) character, for example, text/csv, image/jpeg, and s3/uri. The type
                    specifies the category of the media. The subtype specifies the kind of data.

                  - **Value** *(string) --*

                    The location of the artifact.

            - **OutputArtifacts** *(dict) --*

              The output artifacts of the component.

              - *(string) --*

                - *(dict) --*

                  Represents an input or output artifact of a trial component. You specify
                  ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and
                  ``OutputArtifacts`` parameters in the  CreateTrialComponent request.

                  Examples of input artifacts are datasets, algorithms, hyperparameters, source
                  code, and instance types. Examples of output artifacts are metrics, snapshots,
                  logs, and images.

                  - **MediaType** *(string) --*

                    The media type of the artifact, which indicates the type of data in the artifact
                    file. The media type consists of a *type* and a *subtype* concatenated with a
                    slash (/) character, for example, text/csv, image/jpeg, and s3/uri. The type
                    specifies the category of the media. The subtype specifies the kind of data.

                  - **Value** *(string) --*

                    The location of the artifact.

            - **Metrics** *(list) --*

              The metrics for the component.

              - *(dict) --*

                A summary of the metrics of a trial component.

                - **MetricName** *(string) --*

                  The name of the metric.

                - **SourceArn** *(string) --*

                  The Amazon Resource Name (ARN) of the source.

                - **TimeStamp** *(datetime) --*

                  When the metric was last updated.

                - **Max** *(float) --*

                  The maximum value of the metric.

                - **Min** *(float) --*

                  The minimum value of the metric.

                - **Last** *(float) --*

                  The most recent value of the metric.

                - **Count** *(integer) --*

                  The number of samples used to generate the metric.

                - **Avg** *(float) --*

                  The average value of the metric.

                - **StdDev** *(float) --*

                  The standard deviation of the metric.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_user_profile(
        self, DomainId: str, UserProfileName: str
    ) -> ClientDescribeUserProfileResponseTypeDef:
        """
        Describes the user profile.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeUserProfile>`_

        **Request Syntax**
        ::

          response = client.describe_user_profile(
              DomainId='string',
              UserProfileName='string'
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          The user profile name.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'DomainId': 'string',
                'UserProfileArn': 'string',
                'UserProfileName': 'string',
                'HomeEfsFileSystemUid': 'string',
                'Status': 'Deleting'|'Failed'|'InService'|'Pending',
                'LastModifiedTime': datetime(2015, 1, 1),
                'CreationTime': datetime(2015, 1, 1),
                'FailureReason': 'string',
                'SingleSignOnUserIdentifier': 'string',
                'SingleSignOnUserValue': 'string',
                'UserSettings': {
                    'ExecutionRole': 'string',
                    'SecurityGroups': [
                        'string',
                    ],
                    'SharingSettings': {
                        'NotebookOutputOption': 'Allowed'|'Disabled',
                        'S3OutputPath': 'string',
                        'S3KmsKeyId': 'string'
                    },
                    'JupyterServerAppSettings': {
                        'DefaultResourceSpec': {
                            'EnvironmentArn': 'string',
                            'InstanceType':
                            'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                            |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                            |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                            |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                            |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                            |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                            |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                            |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                            |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                            |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                            |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'
                        }
                    },
                    'KernelGatewayAppSettings': {
                        'DefaultResourceSpec': {
                            'EnvironmentArn': 'string',
                            'InstanceType':
                            'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                            |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                            |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                            |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                            |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                            |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                            |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                            |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                            |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                            |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                            |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'
                        }
                    },
                    'TensorBoardAppSettings': {
                        'DefaultResourceSpec': {
                            'EnvironmentArn': 'string',
                            'InstanceType':
                            'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                            |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                            |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                            |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                            |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                            |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                            |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                            |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                            |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                            |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'
                            |'ml.g4dn.12xlarge'|'ml.g4dn.16xlarge'
                        }
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            - **DomainId** *(string) --*

              The domain ID.

            - **UserProfileArn** *(string) --*

              The user profile Amazon Resource Name (ARN).

            - **UserProfileName** *(string) --*

              The user profile name.

            - **HomeEfsFileSystemUid** *(string) --*

              The homa Amazon Elastic File System (EFS) Uid.

            - **Status** *(string) --*

              The status.

            - **LastModifiedTime** *(datetime) --*

              The last modified time.

            - **CreationTime** *(datetime) --*

              The creation time.

            - **FailureReason** *(string) --*

              The failure reason.

            - **SingleSignOnUserIdentifier** *(string) --*

              The SSO user identifier.

            - **SingleSignOnUserValue** *(string) --*

              The SSO user value.

            - **UserSettings** *(dict) --*

              A collection of settings.

              - **ExecutionRole** *(string) --*

                The execution role for the user.

              - **SecurityGroups** *(list) --*

                The security groups.

                - *(string) --*

              - **SharingSettings** *(dict) --*

                The sharing settings.

                - **NotebookOutputOption** *(string) --*

                  The notebook output option.

                - **S3OutputPath** *(string) --*

                  The Amazon S3 output path.

                - **S3KmsKeyId** *(string) --*

                  The AWS Key Management Service encryption key ID.

              - **JupyterServerAppSettings** *(dict) --*

                The Jupyter server's app settings.

                - **DefaultResourceSpec** *(dict) --*

                  The instance type and quantity.

                  - **EnvironmentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the environment.

                  - **InstanceType** *(string) --*

                    The instance type.

              - **KernelGatewayAppSettings** *(dict) --*

                The kernel gateway app settings.

                - **DefaultResourceSpec** *(dict) --*

                  The instance type and quantity.

                  - **EnvironmentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the environment.

                  - **InstanceType** *(string) --*

                    The instance type.

              - **TensorBoardAppSettings** *(dict) --*

                The TensorBoard app settings.

                - **DefaultResourceSpec** *(dict) --*

                  The instance type and quantity.

                  - **EnvironmentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the environment.

                  - **InstanceType** *(string) --*

                    The instance type.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_workteam(self, WorkteamName: str) -> ClientDescribeWorkteamResponseTypeDef:
        """
        Gets information about a specific work team. You can see information such as the create
        date, the last updated date, membership information, and the work team's Amazon Resource
        Name (ARN).

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DescribeWorkteam>`_

        **Request Syntax**
        ::

          response = client.describe_workteam(
              WorkteamName='string'
          )
        :type WorkteamName: string
        :param WorkteamName: **[REQUIRED]**

          The name of the work team to return a description of.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Workteam': {
                    'WorkteamName': 'string',
                    'MemberDefinitions': [
                        {
                            'CognitoMemberDefinition': {
                                'UserPool': 'string',
                                'UserGroup': 'string',
                                'ClientId': 'string'
                            }
                        },
                    ],
                    'WorkteamArn': 'string',
                    'ProductListingIds': [
                        'string',
                    ],
                    'Description': 'string',
                    'SubDomain': 'string',
                    'CreateDate': datetime(2015, 1, 1),
                    'LastUpdatedDate': datetime(2015, 1, 1),
                    'NotificationConfiguration': {
                        'NotificationTopicArn': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            - **Workteam** *(dict) --*

              A ``Workteam`` instance that contains information about the work team.

              - **WorkteamName** *(string) --*

                The name of the work team.

              - **MemberDefinitions** *(list) --*

                The Amazon Cognito user groups that make up the work team.

                - *(dict) --*

                  Defines the Amazon Cognito user group that is part of a work team.

                  - **CognitoMemberDefinition** *(dict) --*

                    The Amazon Cognito user group that is part of the work team.

                    - **UserPool** *(string) --*

                      An identifier for a user pool. The user pool must be in the same region as the
                      service that you are calling.

                    - **UserGroup** *(string) --*

                      An identifier for a user group.

                    - **ClientId** *(string) --*

                      An identifier for an application client. You must create the app client ID
                      using Amazon Cognito.

              - **WorkteamArn** *(string) --*

                The Amazon Resource Name (ARN) that identifies the work team.

              - **ProductListingIds** *(list) --*

                The Amazon Marketplace identifier for a vendor's work team.

                - *(string) --*

              - **Description** *(string) --*

                A description of the work team.

              - **SubDomain** *(string) --*

                The URI of the labeling job's user interface. Workers open this URI to start
                labeling your data objects.

              - **CreateDate** *(datetime) --*

                The date and time that the work team was created (timestamp).

              - **LastUpdatedDate** *(datetime) --*

                The date and time that the work team was last updated (timestamp).

              - **NotificationConfiguration** *(dict) --*

                Configures SNS notifications of available or expiring work items for work teams.

                - **NotificationTopicArn** *(string) --*

                  The ARN for the SNS topic to which notifications should be published.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def disassociate_trial_component(
        self, TrialComponentName: str, TrialName: str
    ) -> ClientDisassociateTrialComponentResponseTypeDef:
        """
        Disassociates a trial component from a trial. This doesn't effect other trials the component
        is associated with. Before you can delete a component, you must disassociate the component
        from all trials it is associated with. To associate a trial component with a trial, call the
        AssociateTrialComponent API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/DisassociateTrialComponent>`_

        **Request Syntax**
        ::

          response = client.disassociate_trial_component(
              TrialComponentName='string',
              TrialName='string'
          )
        :type TrialComponentName: string
        :param TrialComponentName: **[REQUIRED]**

          The name of the component to disassociate from the trial.

        :type TrialName: string
        :param TrialName: **[REQUIRED]**

          The name of the trial to disassociate from.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialComponentArn': 'string',
                'TrialArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialComponentArn** *(string) --*

              The ARN of the trial component.

            - **TrialArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> None:
        """
        Generate a presigned url given a client, its method, and arguments

        :type ClientMethod: string
        :param ClientMethod: The client method to presign for

        :type Params: dict
        :param Params: The parameters normally passed to
            ``ClientMethod``.

        :type ExpiresIn: int
        :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

        :type HttpMethod: string
        :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

        :returns: The presigned url
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_search_suggestions(
        self,
        Resource: Literal[
            "TrainingJob", "Experiment", "ExperimentTrial", "ExperimentTrialComponent"
        ],
        SuggestionQuery: ClientGetSearchSuggestionsSuggestionQueryTypeDef = None,
    ) -> ClientGetSearchSuggestionsResponseTypeDef:
        """
        An auto-complete API for the search functionality in the Amazon SageMaker console. It
        returns suggestions of possible matches for the property name to use in ``Search`` queries.
        Provides suggestions for ``HyperParameters`` , ``Tags`` , and ``Metrics`` .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/GetSearchSuggestions>`_

        **Request Syntax**
        ::

          response = client.get_search_suggestions(
              Resource='TrainingJob'|'Experiment'|'ExperimentTrial'|'ExperimentTrialComponent',
              SuggestionQuery={
                  'PropertyNameQuery': {
                      'PropertyNameHint': 'string'
                  }
              }
          )
        :type Resource: string
        :param Resource: **[REQUIRED]**

          The name of the Amazon SageMaker resource to Search for. The only valid ``Resource`` value
          is ``TrainingJob`` .

        :type SuggestionQuery: dict
        :param SuggestionQuery:

          Limits the property names that are included in the response.

          - **PropertyNameQuery** *(dict) --*

            A type of ``SuggestionQuery`` . Defines a property name hint. Only property names that
            match the specified hint are included in the response.

            - **PropertyNameHint** *(string) --* **[REQUIRED]**

              Text that is part of a property's name. The property names of hyperparameter, metric,
              and tag key names that begin with the specified text in the ``PropertyNameHint`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'PropertyNameSuggestions': [
                    {
                        'PropertyName': 'string'
                    },
                ]
            }
          **Response Structure**

          - *(dict) --*

            - **PropertyNameSuggestions** *(list) --*

              A list of property names for a ``Resource`` that match a ``SuggestionQuery`` .

              - *(dict) --*

                A property name returned from a ``GetSearchSuggestions`` call that specifies a value
                in the ``PropertyNameQuery`` field.

                - **PropertyName** *(string) --*

                  A suggested property name based on what you entered in the search textbox in the
                  Amazon SageMaker console.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_algorithms(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        MaxResults: int = None,
        NameContains: str = None,
        NextToken: str = None,
        SortBy: Literal["Name", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
    ) -> ClientListAlgorithmsResponseTypeDef:
        """
        Lists the machine learning algorithms that have been created.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListAlgorithms>`_

        **Request Syntax**
        ::

          response = client.list_algorithms(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              MaxResults=123,
              NameContains='string',
              NextToken='string',
              SortBy='Name'|'CreationTime',
              SortOrder='Ascending'|'Descending'
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only algorithms created after the specified time (timestamp).

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only algorithms created before the specified time (timestamp).

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of algorithms to return in the response.

        :type NameContains: string
        :param NameContains:

          A string in the algorithm name. This filter returns only algorithms whose name contains
          the specified string.

        :type NextToken: string
        :param NextToken:

          If the response to a previous ``ListAlgorithms`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of algorithms, use the token in the
          next request.

        :type SortBy: string
        :param SortBy:

          The parameter by which to sort the results. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for the results. The default is ``Ascending`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AlgorithmSummaryList': [
                    {
                        'AlgorithmName': 'string',
                        'AlgorithmArn': 'string',
                        'AlgorithmDescription': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'AlgorithmStatus': 'Pending'|'InProgress'|'Completed'|'Failed'|'Deleting'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **AlgorithmSummaryList** *(list) --*

              >An array of ``AlgorithmSummary`` objects, each of which lists an algorithm.

              - *(dict) --*

                Provides summary information about an algorithm.

                - **AlgorithmName** *(string) --*

                  The name of the algorithm that is described by the summary.

                - **AlgorithmArn** *(string) --*

                  The Amazon Resource Name (ARN) of the algorithm.

                - **AlgorithmDescription** *(string) --*

                  A brief description of the algorithm.

                - **CreationTime** *(datetime) --*

                  A timestamp that shows when the algorithm was created.

                - **AlgorithmStatus** *(string) --*

                  The overall status of the algorithm.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of algorithms, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_apps(
        self,
        NextToken: str = None,
        MaxResults: int = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        SortBy: str = None,
        DomainIdEquals: str = None,
        UserProfileNameEquals: str = None,
    ) -> ClientListAppsResponseTypeDef:
        """
        Lists apps.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListApps>`_

        **Request Syntax**
        ::

          response = client.list_apps(
              NextToken='string',
              MaxResults=123,
              SortOrder='Ascending'|'Descending',
              SortBy='CreationTime',
              DomainIdEquals='string',
              UserProfileNameEquals='string'
          )
        :type NextToken: string
        :param NextToken:

          If the previous response was truncated, you will receive this token. Use it in your next
          request to receive the next set of results.

        :type MaxResults: integer
        :param MaxResults:

          Returns a list up to a specified limit.

        :type SortOrder: string
        :param SortOrder:

          The sort order for the results. The default is Ascending.

        :type SortBy: string
        :param SortBy:

          The parameter by which to sort the results. The default is CreationTime.

        :type DomainIdEquals: string
        :param DomainIdEquals:

          A parameter to search for the domain ID.

        :type UserProfileNameEquals: string
        :param UserProfileNameEquals:

          A parameter to search by user profile name.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Apps': [
                    {
                        'DomainId': 'string',
                        'UserProfileName': 'string',
                        'AppType': 'JupyterServer'|'KernelGateway'|'TensorBoard',
                        'AppName': 'string',
                        'Status': 'Deleted'|'Deleting'|'Failed'|'InService'|'Pending',
                        'CreationTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Apps** *(list) --*

              The list of apps.

              - *(dict) --*

                The app's details.

                - **DomainId** *(string) --*

                  The domain ID.

                - **UserProfileName** *(string) --*

                  The user profile name.

                - **AppType** *(string) --*

                  The type of app.

                - **AppName** *(string) --*

                  The name of the app.

                - **Status** *(string) --*

                  The status.

                - **CreationTime** *(datetime) --*

                  The creation time.

            - **NextToken** *(string) --*

              If the previous response was truncated, you will receive this token. Use it in your
              next request to receive the next set of results.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_auto_ml_jobs(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        NameContains: str = None,
        StatusEquals: Literal["Completed", "InProgress", "Failed", "Stopped", "Stopping"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        MaxResults: int = None,
        NextToken: str = None,
    ) -> ClientListAutoMlJobsResponseTypeDef:
        """
        Request a list of jobs.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListAutoMLJobs>`_

        **Request Syntax**
        ::

          response = client.list_auto_ml_jobs(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              NameContains='string',
              StatusEquals='Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
              SortOrder='Ascending'|'Descending',
              SortBy='Name'|'CreationTime'|'Status',
              MaxResults=123,
              NextToken='string'
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          Request a list of jobs, using a filter for time.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          Request a list of jobs, using a filter for time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          Request a list of jobs, using a filter for time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          Request a list of jobs, using a filter for time.

        :type NameContains: string
        :param NameContains:

          Request a list of jobs, using a search filter for name.

        :type StatusEquals: string
        :param StatusEquals:

          Request a list of jobs, using a filter for status.

        :type SortOrder: string
        :param SortOrder:

          The sort order for the results. The default is Descending.

        :type SortBy: string
        :param SortBy:

          The parameter by which to sort the results. The default is AutoMLJobName.

        :type MaxResults: integer
        :param MaxResults:

          Request a list of jobs up to a specified limit.

        :type NextToken: string
        :param NextToken:

          If the previous response was truncated, you will receive this token. Use it in your next
          request to receive the next set of results.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AutoMLJobSummaries': [
                    {
                        'AutoMLJobName': 'string',
                        'AutoMLJobArn': 'string',
                        'AutoMLJobStatus': 'Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
                        'AutoMLJobSecondaryStatus':
                        'Starting'|'AnalyzingData'|'FeatureEngineering'
                        |'ModelTuning'|'MaxCandidatesReached'|'Failed'|'Stopped'
                        |'MaxAutoMLJobRuntimeReached'|'Stopping'
                        |'CandidateDefinitionsGenerated',
                        'CreationTime': datetime(2015, 1, 1),
                        'EndTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'FailureReason': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **AutoMLJobSummaries** *(list) --*

              Returns a summary list of jobs.

              - *(dict) --*

                Provides a summary about a job.

                - **AutoMLJobName** *(string) --*

                  The name of the object you are requesting.

                - **AutoMLJobArn** *(string) --*

                  The ARN of the job.

                - **AutoMLJobStatus** *(string) --*

                  The job's status.

                - **AutoMLJobSecondaryStatus** *(string) --*

                  The job's secondary status.

                - **CreationTime** *(datetime) --*

                  When the job was created.

                - **EndTime** *(datetime) --*

                  The end time.

                - **LastModifiedTime** *(datetime) --*

                  When the job was last modified.

                - **FailureReason** *(string) --*

                  The failure reason.

            - **NextToken** *(string) --*

              If the previous response was truncated, you will receive this token. Use it in your
              next request to receive the next set of results.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_candidates_for_auto_ml_job(
        self,
        AutoMLJobName: str,
        StatusEquals: Literal["Completed", "InProgress", "Failed", "Stopped", "Stopping"] = None,
        CandidateNameEquals: str = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        SortBy: Literal["CreationTime", "Status", "FinalObjectiveMetricValue"] = None,
        MaxResults: int = None,
        NextToken: str = None,
    ) -> ClientListCandidatesForAutoMlJobResponseTypeDef:
        """
        List the Candidates created for the job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListCandidatesForAutoMLJob>`_

        **Request Syntax**
        ::

          response = client.list_candidates_for_auto_ml_job(
              AutoMLJobName='string',
              StatusEquals='Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
              CandidateNameEquals='string',
              SortOrder='Ascending'|'Descending',
              SortBy='CreationTime'|'Status'|'FinalObjectiveMetricValue',
              MaxResults=123,
              NextToken='string'
          )
        :type AutoMLJobName: string
        :param AutoMLJobName: **[REQUIRED]**

          List the Candidates created for the job by providing the job's name.

        :type StatusEquals: string
        :param StatusEquals:

          List the Candidates for the job and filter by status.

        :type CandidateNameEquals: string
        :param CandidateNameEquals:

          List the Candidates for the job and filter by candidate name.

        :type SortOrder: string
        :param SortOrder:

          The sort order for the results. The default is Ascending.

        :type SortBy: string
        :param SortBy:

          The parameter by which to sort the results. The default is Descending.

        :type MaxResults: integer
        :param MaxResults:

          List the job's Candidates up to a specified limit.

        :type NextToken: string
        :param NextToken:

          If the previous response was truncated, you will receive this token. Use it in your next
          request to receive the next set of results.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Candidates': [
                    {
                        'CandidateName': 'string',
                        'FinalAutoMLJobObjectiveMetric': {
                            'Type': 'Maximize'|'Minimize',
                            'MetricName': 'Accuracy'|'MSE'|'F1'|'F1macro',
                            'Value': ...
                        },
                        'ObjectiveStatus': 'Succeeded'|'Pending'|'Failed',
                        'CandidateSteps': [
                            {
                                'CandidateStepType':
                                'AWS::SageMaker::TrainingJob'
                                |'AWS::SageMaker::TransformJob'
                                |'AWS::SageMaker::ProcessingJob',
                                'CandidateStepArn': 'string',
                                'CandidateStepName': 'string'
                            },
                        ],
                        'CandidateStatus': 'Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
                        'InferenceContainers': [
                            {
                                'Image': 'string',
                                'ModelDataUrl': 'string',
                                'Environment': {
                                    'string': 'string'
                                }
                            },
                        ],
                        'CreationTime': datetime(2015, 1, 1),
                        'EndTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'FailureReason': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Candidates** *(list) --*

              Summaries about the Candidates.

              - *(dict) --*

                An AutoPilot job will return recommendations, or candidates. Each candidate has
                futher details about the steps involed, and the status.

                - **CandidateName** *(string) --*

                  The candidate name.

                - **FinalAutoMLJobObjectiveMetric** *(dict) --*

                  The candidate result from a job.

                  - **Type** *(string) --*

                    The metric type used.

                  - **MetricName** *(string) --*

                    The name of the metric.

                  - **Value** *(float) --*

                    The value of the metric.

                - **ObjectiveStatus** *(string) --*

                  The objective status.

                - **CandidateSteps** *(list) --*

                  The candidate's steps.

                  - *(dict) --*

                    Information about the steps for a Candidate, and what step it is working on.

                    - **CandidateStepType** *(string) --*

                      Whether the Candidate is at the transform, training, or processing step.

                    - **CandidateStepArn** *(string) --*

                      The ARN for the Candidate's step.

                    - **CandidateStepName** *(string) --*

                      The name for the Candidate's step.

                - **CandidateStatus** *(string) --*

                  The candidate's status.

                - **InferenceContainers** *(list) --*

                  The inference containers.

                  - *(dict) --*

                    A list of container definitions that describe the different containers that make
                    up one AutoML candidate. Refer to ContainerDefinition for more details.

                    - **Image** *(string) --*

                      The ECR path of the container. Refer to ContainerDefinition for more details.

                    - **ModelDataUrl** *(string) --*

                      The location of the model artifacts. Refer to ContainerDefinition for more
                      details.

                    - **Environment** *(dict) --*

                      Environment variables to set in the container. Refer to ContainerDefinition
                      for more details.

                      - *(string) --*

                        - *(string) --*

                - **CreationTime** *(datetime) --*

                  The creation time.

                - **EndTime** *(datetime) --*

                  The end time.

                - **LastModifiedTime** *(datetime) --*

                  The last modified time.

                - **FailureReason** *(string) --*

                  The failure reason.

            - **NextToken** *(string) --*

              If the previous response was truncated, you will receive this token. Use it in your
              next request to receive the next set of results.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_code_repositories(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        MaxResults: int = None,
        NameContains: str = None,
        NextToken: str = None,
        SortBy: Literal["Name", "CreationTime", "LastModifiedTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
    ) -> ClientListCodeRepositoriesResponseTypeDef:
        """
        Gets a list of the Git repositories in your account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListCodeRepositories>`_

        **Request Syntax**
        ::

          response = client.list_code_repositories(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              MaxResults=123,
              NameContains='string',
              NextToken='string',
              SortBy='Name'|'CreationTime'|'LastModifiedTime',
              SortOrder='Ascending'|'Descending'
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only Git repositories that were created after the specified time.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only Git repositories that were created before the specified time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only Git repositories that were last modified after the specified
          time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only Git repositories that were last modified before the specified
          time.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of Git repositories to return in the response.

        :type NameContains: string
        :param NameContains:

          A string in the Git repositories name. This filter returns only repositories whose name
          contains the specified string.

        :type NextToken: string
        :param NextToken:

          If the result of a ``ListCodeRepositoriesOutput`` request was truncated, the response
          includes a ``NextToken`` . To get the next set of Git repositories, use the token in the
          next request.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``Name`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CodeRepositorySummaryList': [
                    {
                        'CodeRepositoryName': 'string',
                        'CodeRepositoryArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'GitConfig': {
                            'RepositoryUrl': 'string',
                            'Branch': 'string',
                            'SecretArn': 'string'
                        }
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **CodeRepositorySummaryList** *(list) --*

              Gets a list of summaries of the Git repositories. Each summary specifies the following
              values for the repository:

              * Name

              * Amazon Resource Name (ARN)

              * Creation time

              * Last modified time

              * Configuration information, including the URL location of the repository and the ARN
              of the AWS Secrets Manager secret that contains the credentials used to access the
              repository.

              - *(dict) --*

                Specifies summary information about a Git repository.

                - **CodeRepositoryName** *(string) --*

                  The name of the Git repository.

                - **CodeRepositoryArn** *(string) --*

                  The Amazon Resource Name (ARN) of the Git repository.

                - **CreationTime** *(datetime) --*

                  The date and time that the Git repository was created.

                - **LastModifiedTime** *(datetime) --*

                  The date and time that the Git repository was last modified.

                - **GitConfig** *(dict) --*

                  Configuration details for the Git repository, including the URL where it is
                  located and the ARN of the AWS Secrets Manager secret that contains the
                  credentials used to access the repository.

                  - **RepositoryUrl** *(string) --*

                    The URL where the Git repository is located.

                  - **Branch** *(string) --*

                    The default branch for the Git repository.

                  - **SecretArn** *(string) --*

                    The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains
                    the credentials used to access the git repository. The secret must have a
                    staging label of ``AWSCURRENT`` and must be in the following format:

                     ``{"username": *UserName* , "password": *Password* }``

            - **NextToken** *(string) --*

              If the result of a ``ListCodeRepositoriesOutput`` request was truncated, the response
              includes a ``NextToken`` . To get the next set of Git repositories, use the token in
              the next request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_compilation_jobs(
        self,
        NextToken: str = None,
        MaxResults: int = None,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        NameContains: str = None,
        StatusEquals: Literal[
            "INPROGRESS", "COMPLETED", "FAILED", "STARTING", "STOPPING", "STOPPED"
        ] = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
    ) -> ClientListCompilationJobsResponseTypeDef:
        """
        Lists model compilation jobs that satisfy various filters.

        To create a model compilation job, use  CreateCompilationJob . To get information about a
        particular model compilation job you have created, use  DescribeCompilationJob .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListCompilationJobs>`_

        **Request Syntax**
        ::

          response = client.list_compilation_jobs(
              NextToken='string',
              MaxResults=123,
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              NameContains='string',
              StatusEquals='INPROGRESS'|'COMPLETED'|'FAILED'|'STARTING'|'STOPPING'|'STOPPED',
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending'
          )
        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListCompilationJobs`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of model compilation jobs, use the
          token in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of model compilation jobs to return in the response.

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns the model compilation jobs that were created after a specified time.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns the model compilation jobs that were created before a specified
          time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns the model compilation jobs that were modified after a specified
          time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns the model compilation jobs that were modified before a specified
          time.

        :type NameContains: string
        :param NameContains:

          A filter that returns the model compilation jobs whose name contains a specified string.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that retrieves model compilation jobs with a specific
          DescribeCompilationJobResponse$CompilationJobStatus status.

        :type SortBy: string
        :param SortBy:

          The field by which to sort results. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CompilationJobSummaries': [
                    {
                        'CompilationJobName': 'string',
                        'CompilationJobArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'CompilationStartTime': datetime(2015, 1, 1),
                        'CompilationEndTime': datetime(2015, 1, 1),
                        'CompilationTargetDevice':
                        'lambda'|'ml_m4'|'ml_m5'|'ml_c4'|'ml_c5'|'ml_p2'|'ml_p3'
                        |'ml_inf1'|'jetson_tx1'|'jetson_tx2'|'jetson_nano'|'rasp3b'
                        |'deeplens'|'rk3399'|'rk3288'|'aisage'|'sbe_c'|'qcs605'
                        |'qcs603',
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'CompilationJobStatus':
                        'INPROGRESS'|'COMPLETED'|'FAILED'|'STARTING'|'STOPPING'
                        |'STOPPED'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **CompilationJobSummaries** *(list) --*

              An array of  CompilationJobSummary objects, each describing a model compilation job.

              - *(dict) --*

                A summary of a model compilation job.

                - **CompilationJobName** *(string) --*

                  The name of the model compilation job that you want a summary for.

                - **CompilationJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the model compilation job.

                - **CreationTime** *(datetime) --*

                  The time when the model compilation job was created.

                - **CompilationStartTime** *(datetime) --*

                  The time when the model compilation job started.

                - **CompilationEndTime** *(datetime) --*

                  The time when the model compilation job completed.

                - **CompilationTargetDevice** *(string) --*

                  The type of device that the model will run on after compilation has completed.

                - **LastModifiedTime** *(datetime) --*

                  The time when the model compilation job was last modified.

                - **CompilationJobStatus** *(string) --*

                  The status of the model compilation job.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this ``NextToken`` . To
              retrieve the next set of model compilation jobs, use this token in the next request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_domains(
        self, NextToken: str = None, MaxResults: int = None
    ) -> ClientListDomainsResponseTypeDef:
        """
        Lists the domains.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListDomains>`_

        **Request Syntax**
        ::

          response = client.list_domains(
              NextToken='string',
              MaxResults=123
          )
        :type NextToken: string
        :param NextToken:

          If the previous response was truncated, you will receive this token. Use it in your next
          request to receive the next set of results.

        :type MaxResults: integer
        :param MaxResults:

          Returns a list up to a specified limit.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Domains': [
                    {
                        'DomainArn': 'string',
                        'DomainId': 'string',
                        'DomainName': 'string',
                        'Status': 'Deleting'|'Failed'|'InService'|'Pending',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'Url': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Domains** *(list) --*

              The list of domains.

              - *(dict) --*

                The domain's details.

                - **DomainArn** *(string) --*

                  The domain's Amazon Resource Name (ARN).

                - **DomainId** *(string) --*

                  The domain ID.

                - **DomainName** *(string) --*

                  The domain name.

                - **Status** *(string) --*

                  The status.

                - **CreationTime** *(datetime) --*

                  The creation time.

                - **LastModifiedTime** *(datetime) --*

                  The last modified time.

                - **Url** *(string) --*

                  The domain's URL.

            - **NextToken** *(string) --*

              If the previous response was truncated, you will receive this token. Use it in your
              next request to receive the next set of results.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_endpoint_configs(
        self,
        SortBy: Literal["Name", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
        NameContains: str = None,
        CreationTimeBefore: datetime = None,
        CreationTimeAfter: datetime = None,
    ) -> ClientListEndpointConfigsResponseTypeDef:
        """
        Lists endpoint configurations.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListEndpointConfigs>`_

        **Request Syntax**
        ::

          response = client.list_endpoint_configs(
              SortBy='Name'|'CreationTime',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123,
              NameContains='string',
              CreationTimeBefore=datetime(2015, 1, 1),
              CreationTimeAfter=datetime(2015, 1, 1)
          )
        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Descending`` .

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListEndpointConfig`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of endpoint configurations, use the
          token in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of training jobs to return in the response.

        :type NameContains: string
        :param NameContains:

          A string in the endpoint configuration name. This filter returns only endpoint
          configurations whose name contains the specified string.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only endpoint configurations created before the specified time
          (timestamp).

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only endpoint configurations with a creation time greater than or
          equal to the specified time (timestamp).

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointConfigs': [
                    {
                        'EndpointConfigName': 'string',
                        'EndpointConfigArn': 'string',
                        'CreationTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **EndpointConfigs** *(list) --*

              An array of endpoint configurations.

              - *(dict) --*

                Provides summary information for an endpoint configuration.

                - **EndpointConfigName** *(string) --*

                  The name of the endpoint configuration.

                - **EndpointConfigArn** *(string) --*

                  The Amazon Resource Name (ARN) of the endpoint configuration.

                - **CreationTime** *(datetime) --*

                  A timestamp that shows when the endpoint configuration was created.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of endpoint configurations, use it in the subsequent request
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_endpoints(
        self,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
        NameContains: str = None,
        CreationTimeBefore: datetime = None,
        CreationTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        StatusEquals: Literal[
            "OutOfService",
            "Creating",
            "Updating",
            "SystemUpdating",
            "RollingBack",
            "InService",
            "Deleting",
            "Failed",
        ] = None,
    ) -> ClientListEndpointsResponseTypeDef:
        """
        Lists endpoints.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListEndpoints>`_

        **Request Syntax**
        ::

          response = client.list_endpoints(
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123,
              NameContains='string',
              CreationTimeBefore=datetime(2015, 1, 1),
              CreationTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              StatusEquals=
                  'OutOfService'|'Creating'|'Updating'|'SystemUpdating'|'RollingBack'|'InService'
                  |'Deleting'|'Failed'
          )
        :type SortBy: string
        :param SortBy:

          Sorts the list of results. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Descending`` .

        :type NextToken: string
        :param NextToken:

          If the result of a ``ListEndpoints`` request was truncated, the response includes a
          ``NextToken`` . To retrieve the next set of endpoints, use the token in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of endpoints to return in the response.

        :type NameContains: string
        :param NameContains:

          A string in endpoint names. This filter returns only endpoints whose name contains the
          specified string.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only endpoints that were created before the specified time
          (timestamp).

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only endpoints with a creation time greater than or equal to the
          specified time (timestamp).

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only endpoints that were modified before the specified timestamp.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only endpoints that were modified after the specified timestamp.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that returns only endpoints with the specified status.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Endpoints': [
                    {
                        'EndpointName': 'string',
                        'EndpointArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'EndpointStatus':
                        'OutOfService'|'Creating'|'Updating'|'SystemUpdating'
                        |'RollingBack'|'InService'|'Deleting'|'Failed'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Endpoints** *(list) --*

              An array or endpoint objects.

              - *(dict) --*

                Provides summary information for an endpoint.

                - **EndpointName** *(string) --*

                  The name of the endpoint.

                - **EndpointArn** *(string) --*

                  The Amazon Resource Name (ARN) of the endpoint.

                - **CreationTime** *(datetime) --*

                  A timestamp that shows when the endpoint was created.

                - **LastModifiedTime** *(datetime) --*

                  A timestamp that shows when the endpoint was last modified.

                - **EndpointStatus** *(string) --*

                  The status of the endpoint.

                  * ``OutOfService`` : Endpoint is not available to take incoming requests.

                  * ``Creating`` :  CreateEndpoint is executing.

                  * ``Updating`` :  UpdateEndpoint or  UpdateEndpointWeightsAndCapacities is
                  executing.

                  * ``SystemUpdating`` : Endpoint is undergoing maintenance and cannot be updated or
                  deleted or re-scaled until it has completed. This maintenance operation does not
                  change any customer-specified values such as VPC config, KMS encryption, model,
                  instance type, or instance count.

                  * ``RollingBack`` : Endpoint fails to scale up or down or change its variant
                  weight and is in the process of rolling back to its previous configuration. Once
                  the rollback completes, endpoint returns to an ``InService`` status. This
                  transitional status only applies to an endpoint that has autoscaling enabled and
                  is undergoing variant weight or capacity changes as part of an
                  UpdateEndpointWeightsAndCapacities call or when the
                  UpdateEndpointWeightsAndCapacities operation is called explicitly.

                  * ``InService`` : Endpoint is available to process incoming requests.

                  * ``Deleting`` :  DeleteEndpoint is executing.

                  * ``Failed`` : Endpoint could not be created, updated, or re-scaled. Use
                  DescribeEndpointOutput$FailureReason for information about the failure.
                  DeleteEndpoint is the only operation that can be performed on a failed endpoint.

                  To get a list of endpoints with a specified status, use the
                  ListEndpointsInput$StatusEquals filter.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of training jobs, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_experiments(
        self,
        CreatedAfter: datetime = None,
        CreatedBefore: datetime = None,
        SortBy: Literal["Name", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListExperimentsResponseTypeDef:
        """
        Lists all the experiments in your account. The list can be filtered to show only experiments
        that were created in a specific time range. The list can be sorted by experiment name or
        creation time.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListExperiments>`_

        **Request Syntax**
        ::

          response = client.list_experiments(
              CreatedAfter=datetime(2015, 1, 1),
              CreatedBefore=datetime(2015, 1, 1),
              SortBy='Name'|'CreationTime',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123
          )
        :type CreatedAfter: datetime
        :param CreatedAfter:

          A filter that returns only experiments created after the specified time.

        :type CreatedBefore: datetime
        :param CreatedBefore:

          A filter that returns only experiments created before the specified time.

        :type SortBy: string
        :param SortBy:

          The property used to sort results. The default value is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order. The default value is ``Descending`` .

        :type NextToken: string
        :param NextToken:

          If the previous call to ``ListExperiments`` didn't return the full set of experiments, the
          call returns a token for getting the next set of experiments.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of experiments to return in the response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExperimentSummaries': [
                    {
                        'ExperimentArn': 'string',
                        'ExperimentName': 'string',
                        'DisplayName': 'string',
                        'ExperimentSource': {
                            'SourceArn': 'string',
                            'SourceType': 'string'
                        },
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ExperimentSummaries** *(list) --*

              A list of the summaries of your experiments.

              - *(dict) --*

                A summary of the properties of an experiment. To get the complete set of properties,
                call the  DescribeExperiment API and provide the ``ExperimentName`` .

                - **ExperimentArn** *(string) --*

                  The Amazon Resource Name (ARN) of the experiment.

                - **ExperimentName** *(string) --*

                  The name of the experiment.

                - **DisplayName** *(string) --*

                  The name of the experiment as displayed. If ``DisplayName`` isn't specified,
                  ``ExperimentName`` is displayed.

                - **ExperimentSource** *(dict) --*

                  The source of the experiment.

                  - **SourceArn** *(string) --*

                    The Amazon Resource Name (ARN) of the source.

                  - **SourceType** *(string) --*

                    The source type.

                - **CreationTime** *(datetime) --*

                  When the experiment was created.

                - **LastModifiedTime** *(datetime) --*

                  When the experiment was last modified.

            - **NextToken** *(string) --*

              A token for getting the next set of experiments, if there are any.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_flow_definitions(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListFlowDefinitionsResponseTypeDef:
        """
        Returns information about the flow definitions in your account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListFlowDefinitions>`_

        **Request Syntax**
        ::

          response = client.list_flow_definitions(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only flow definitions with a creation time greater than or equal to
          the specified timestamp.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only flow definitions that were created before the specified
          timestamp.

        :type SortOrder: string
        :param SortOrder:

          An optional value that specifies whether you want the results sorted in ``Ascending`` or
          ``Descending`` order.

        :type NextToken: string
        :param NextToken:

          A token to resume pagination.

        :type MaxResults: integer
        :param MaxResults:

          The total number of items to return. If the total number of available items is more than
          the value specified in ``MaxResults`` , then a ``NextToken`` will be provided in the
          output that you can use to resume pagination.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'FlowDefinitionSummaries': [
                    {
                        'FlowDefinitionName': 'string',
                        'FlowDefinitionArn': 'string',
                        'FlowDefinitionStatus':
                        'Initializing'|'Active'|'Failed'|'Deleting'|'Deleted',
                        'CreationTime': datetime(2015, 1, 1),
                        'FailureReason': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **FlowDefinitionSummaries** *(list) --*

              An array of objects describing the flow definitions.

              - *(dict) --*

                Contains summary information about the flow definition.

                - **FlowDefinitionName** *(string) --*

                  The name of the flow definition.

                - **FlowDefinitionArn** *(string) --*

                  The Amazon Resource Name (ARN) of the flow definition.

                - **FlowDefinitionStatus** *(string) --*

                  The status of the flow definition. Valid values:

                - **CreationTime** *(datetime) --*

                  The timestamp when SageMaker created the flow definition.

                - **FailureReason** *(string) --*

                  The reason why the flow definition creation failed. A failure reason is returned
                  only when the flow definition status is ``Failed`` .

            - **NextToken** *(string) --*

              A token to resume pagination.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_human_task_uis(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListHumanTaskUisResponseTypeDef:
        """
        Returns information about the human task user interfaces in your account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListHumanTaskUis>`_

        **Request Syntax**
        ::

          response = client.list_human_task_uis(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only human task user interfaces with a creation time greater than or
          equal to the specified timestamp.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only human task user interfaces that were created before the
          specified timestamp.

        :type SortOrder: string
        :param SortOrder:

          An optional value that specifies whether you want the results sorted in ``Ascending`` or
          ``Descending`` order.

        :type NextToken: string
        :param NextToken:

          A token to resume pagination.

        :type MaxResults: integer
        :param MaxResults:

          The total number of items to return. If the total number of available items is more than
          the value specified in ``MaxResults`` , then a ``NextToken`` will be provided in the
          output that you can use to resume pagination.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'HumanTaskUiSummaries': [
                    {
                        'HumanTaskUiName': 'string',
                        'HumanTaskUiArn': 'string',
                        'CreationTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **HumanTaskUiSummaries** *(list) --*

              An array of objects describing the human task user interfaces.

              - *(dict) --*

                Container for human task user interface information.

                - **HumanTaskUiName** *(string) --*

                  The name of the human task user interface.

                - **HumanTaskUiArn** *(string) --*

                  The Amazon Resource Name (ARN) of the human task user interface.

                - **CreationTime** *(datetime) --*

                  A timestamp when SageMaker created the human task user interface.

            - **NextToken** *(string) --*

              A token to resume pagination.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_hyper_parameter_tuning_jobs(
        self,
        NextToken: str = None,
        MaxResults: int = None,
        SortBy: Literal["Name", "Status", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NameContains: str = None,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        StatusEquals: Literal["Completed", "InProgress", "Failed", "Stopped", "Stopping"] = None,
    ) -> ClientListHyperParameterTuningJobsResponseTypeDef:
        """
        Gets a list of  HyperParameterTuningJobSummary objects that describe the hyperparameter
        tuning jobs launched in your account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListHyperParameterTuningJobs>`_

        **Request Syntax**
        ::

          response = client.list_hyper_parameter_tuning_jobs(
              NextToken='string',
              MaxResults=123,
              SortBy='Name'|'Status'|'CreationTime',
              SortOrder='Ascending'|'Descending',
              NameContains='string',
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              StatusEquals='Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping'
          )
        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListHyperParameterTuningJobs`` request was truncated, the
          response includes a ``NextToken`` . To retrieve the next set of tuning jobs, use the token
          in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of tuning jobs to return. The default value is 10.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``Name`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :type NameContains: string
        :param NameContains:

          A string in the tuning job name. This filter returns only tuning jobs whose name contains
          the specified string.

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only tuning jobs that were created after the specified time.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only tuning jobs that were created before the specified time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only tuning jobs that were modified after the specified time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only tuning jobs that were modified before the specified time.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that returns only tuning jobs with the specified status.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'HyperParameterTuningJobSummaries': [
                    {
                        'HyperParameterTuningJobName': 'string',
                        'HyperParameterTuningJobArn': 'string',
                        'HyperParameterTuningJobStatus':
                        'Completed'|'InProgress'|'Failed'|'Stopped'|'Stopping',
                        'Strategy': 'Bayesian'|'Random',
                        'CreationTime': datetime(2015, 1, 1),
                        'HyperParameterTuningEndTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'TrainingJobStatusCounters': {
                            'Completed': 123,
                            'InProgress': 123,
                            'RetryableError': 123,
                            'NonRetryableError': 123,
                            'Stopped': 123
                        },
                        'ObjectiveStatusCounters': {
                            'Succeeded': 123,
                            'Pending': 123,
                            'Failed': 123
                        },
                        'ResourceLimits': {
                            'MaxNumberOfTrainingJobs': 123,
                            'MaxParallelTrainingJobs': 123
                        }
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **HyperParameterTuningJobSummaries** *(list) --*

              A list of  HyperParameterTuningJobSummary objects that describe the tuning jobs that
              the ``ListHyperParameterTuningJobs`` request returned.

              - *(dict) --*

                Provides summary information about a hyperparameter tuning job.

                - **HyperParameterTuningJobName** *(string) --*

                  The name of the tuning job.

                - **HyperParameterTuningJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the tuning job.

                - **HyperParameterTuningJobStatus** *(string) --*

                  The status of the tuning job.

                - **Strategy** *(string) --*

                  Specifies the search strategy hyperparameter tuning uses to choose which
                  hyperparameters to use for each iteration. Currently, the only valid value is
                  Bayesian.

                - **CreationTime** *(datetime) --*

                  The date and time that the tuning job was created.

                - **HyperParameterTuningEndTime** *(datetime) --*

                  The date and time that the tuning job ended.

                - **LastModifiedTime** *(datetime) --*

                  The date and time that the tuning job was modified.

                - **TrainingJobStatusCounters** *(dict) --*

                  The  TrainingJobStatusCounters object that specifies the numbers of training jobs,
                  categorized by status, that this tuning job launched.

                  - **Completed** *(integer) --*

                    The number of completed training jobs launched by the hyperparameter tuning job.

                  - **InProgress** *(integer) --*

                    The number of in-progress training jobs launched by a hyperparameter tuning job.

                  - **RetryableError** *(integer) --*

                    The number of training jobs that failed, but can be retried. A failed training
                    job can be retried only if it failed because an internal service error occurred.

                  - **NonRetryableError** *(integer) --*

                    The number of training jobs that failed and can't be retried. A failed training
                    job can't be retried if it failed because a client error occurred.

                  - **Stopped** *(integer) --*

                    The number of training jobs launched by a hyperparameter tuning job that were
                    manually stopped.

                - **ObjectiveStatusCounters** *(dict) --*

                  The  ObjectiveStatusCounters object that specifies the numbers of training jobs,
                  categorized by objective metric status, that this tuning job launched.

                  - **Succeeded** *(integer) --*

                    The number of training jobs whose final objective metric was evaluated by the
                    hyperparameter tuning job and used in the hyperparameter tuning process.

                  - **Pending** *(integer) --*

                    The number of training jobs that are in progress and pending evaluation of their
                    final objective metric.

                  - **Failed** *(integer) --*

                    The number of training jobs whose final objective metric was not evaluated and
                    used in the hyperparameter tuning process. This typically occurs when the
                    training job failed or did not emit an objective metric.

                - **ResourceLimits** *(dict) --*

                  The  ResourceLimits object that specifies the maximum number of training jobs and
                  parallel training jobs allowed for this tuning job.

                  - **MaxNumberOfTrainingJobs** *(integer) --*

                    The maximum number of training jobs that a hyperparameter tuning job can launch.

                  - **MaxParallelTrainingJobs** *(integer) --*

                    The maximum number of concurrent training jobs that a hyperparameter tuning job
                    can launch.

            - **NextToken** *(string) --*

              If the result of this ``ListHyperParameterTuningJobs`` request was truncated, the
              response includes a ``NextToken`` . To retrieve the next set of tuning jobs, use the
              token in the next request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_labeling_jobs(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        MaxResults: int = None,
        NextToken: str = None,
        NameContains: str = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        StatusEquals: Literal["InProgress", "Completed", "Failed", "Stopping", "Stopped"] = None,
    ) -> ClientListLabelingJobsResponseTypeDef:
        """
        Gets a list of labeling jobs.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListLabelingJobs>`_

        **Request Syntax**
        ::

          response = client.list_labeling_jobs(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              MaxResults=123,
              NextToken='string',
              NameContains='string',
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending',
              StatusEquals='InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped'
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only labeling jobs created after the specified time (timestamp).

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only labeling jobs created before the specified time (timestamp).

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only labeling jobs modified after the specified time (timestamp).

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only labeling jobs modified before the specified time (timestamp).

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of labeling jobs to return in each page of the response.

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListLabelingJobs`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of labeling jobs, use the token in the
          next request.

        :type NameContains: string
        :param NameContains:

          A string in the labeling job name. This filter returns only labeling jobs whose name
          contains the specified string.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :type StatusEquals: string
        :param StatusEquals:

          A filter that retrieves only labeling jobs with a specific status.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'LabelingJobSummaryList': [
                    {
                        'LabelingJobName': 'string',
                        'LabelingJobArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'LabelingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                        'LabelCounters': {
                            'TotalLabeled': 123,
                            'HumanLabeled': 123,
                            'MachineLabeled': 123,
                            'FailedNonRetryableError': 123,
                            'Unlabeled': 123
                        },
                        'WorkteamArn': 'string',
                        'PreHumanTaskLambdaArn': 'string',
                        'AnnotationConsolidationLambdaArn': 'string',
                        'FailureReason': 'string',
                        'LabelingJobOutput': {
                            'OutputDatasetS3Uri': 'string',
                            'FinalActiveLearningModelArn': 'string'
                        },
                        'InputConfig': {
                            'DataSource': {
                                'S3DataSource': {
                                    'ManifestS3Uri': 'string'
                                }
                            },
                            'DataAttributes': {
                                'ContentClassifiers': [
                                    'FreeOfPersonallyIdentifiableInformation'|'FreeOfAdultContent',
                                ]
                            }
                        }
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **LabelingJobSummaryList** *(list) --*

              An array of ``LabelingJobSummary`` objects, each describing a labeling job.

              - *(dict) --*

                Provides summary information about a labeling job.

                - **LabelingJobName** *(string) --*

                  The name of the labeling job.

                - **LabelingJobArn** *(string) --*

                  The Amazon Resource Name (ARN) assigned to the labeling job when it was created.

                - **CreationTime** *(datetime) --*

                  The date and time that the job was created (timestamp).

                - **LastModifiedTime** *(datetime) --*

                  The date and time that the job was last modified (timestamp).

                - **LabelingJobStatus** *(string) --*

                  The current status of the labeling job.

                - **LabelCounters** *(dict) --*

                  Counts showing the progress of the labeling job.

                  - **TotalLabeled** *(integer) --*

                    The total number of objects labeled.

                  - **HumanLabeled** *(integer) --*

                    The total number of objects labeled by a human worker.

                  - **MachineLabeled** *(integer) --*

                    The total number of objects labeled by automated data labeling.

                  - **FailedNonRetryableError** *(integer) --*

                    The total number of objects that could not be labeled due to an error.

                  - **Unlabeled** *(integer) --*

                    The total number of objects not yet labeled.

                - **WorkteamArn** *(string) --*

                  The Amazon Resource Name (ARN) of the work team assigned to the job.

                - **PreHumanTaskLambdaArn** *(string) --*

                  The Amazon Resource Name (ARN) of a Lambda function. The function is run before
                  each data object is sent to a worker.

                - **AnnotationConsolidationLambdaArn** *(string) --*

                  The Amazon Resource Name (ARN) of the Lambda function used to consolidate the
                  annotations from individual workers into a label for a data object. For more
                  information, see `Annotation Consolidation
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-annotation-consolidation.html>`__
                  .

                - **FailureReason** *(string) --*

                  If the ``LabelingJobStatus`` field is ``Failed`` , this field contains a
                  description of the error.

                - **LabelingJobOutput** *(dict) --*

                  The location of the output produced by the labeling job.

                  - **OutputDatasetS3Uri** *(string) --*

                    The Amazon S3 bucket location of the manifest file for labeled data.

                  - **FinalActiveLearningModelArn** *(string) --*

                    The Amazon Resource Name (ARN) for the most recent Amazon SageMaker model
                    trained as part of automated data labeling.

                - **InputConfig** *(dict) --*

                  Input configuration for the labeling job.

                  - **DataSource** *(dict) --*

                    The location of the input data.

                    - **S3DataSource** *(dict) --*

                      The Amazon S3 location of the input data objects.

                      - **ManifestS3Uri** *(string) --*

                        The Amazon S3 location of the manifest file that describes the input data
                        objects.

                  - **DataAttributes** *(dict) --*

                    Attributes of the data specified by the customer.

                    - **ContentClassifiers** *(list) --*

                      Declares that your content is free of personally identifiable information or
                      adult content. Amazon SageMaker may restrict the Amazon Mechanical Turk
                      workers that can view your task based on this information.

                      - *(string) --*

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of labeling jobs, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_labeling_jobs_for_workteam(
        self,
        WorkteamArn: str,
        MaxResults: int = None,
        NextToken: str = None,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        JobReferenceCodeContains: str = None,
        SortBy: str = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
    ) -> ClientListLabelingJobsForWorkteamResponseTypeDef:
        """
        Gets a list of labeling jobs assigned to a specified work team.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListLabelingJobsForWorkteam>`_

        **Request Syntax**
        ::

          response = client.list_labeling_jobs_for_workteam(
              WorkteamArn='string',
              MaxResults=123,
              NextToken='string',
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              JobReferenceCodeContains='string',
              SortBy='CreationTime',
              SortOrder='Ascending'|'Descending'
          )
        :type WorkteamArn: string
        :param WorkteamArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the work team for which you want to see labeling jobs
          for.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of labeling jobs to return in each page of the response.

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListLabelingJobsForWorkteam`` request was truncated, the
          response includes a ``NextToken`` . To retrieve the next set of labeling jobs, use the
          token in the next request.

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only labeling jobs created after the specified time (timestamp).

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only labeling jobs created before the specified time (timestamp).

        :type JobReferenceCodeContains: string
        :param JobReferenceCodeContains:

          A filter the limits jobs to only the ones whose job reference code contains the specified
          string.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'LabelingJobSummaryList': [
                    {
                        'LabelingJobName': 'string',
                        'JobReferenceCode': 'string',
                        'WorkRequesterAccountId': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'LabelCounters': {
                            'HumanLabeled': 123,
                            'PendingHuman': 123,
                            'Total': 123
                        },
                        'NumberOfHumanWorkersPerDataObject': 123
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **LabelingJobSummaryList** *(list) --*

              An array of ``LabelingJobSummary`` objects, each describing a labeling job.

              - *(dict) --*

                Provides summary information for a work team.

                - **LabelingJobName** *(string) --*

                  The name of the labeling job that the work team is assigned to.

                - **JobReferenceCode** *(string) --*

                  A unique identifier for a labeling job. You can use this to refer to a specific
                  labeling job.

                - **WorkRequesterAccountId** *(string) --*

                - **CreationTime** *(datetime) --*

                  The date and time that the labeling job was created.

                - **LabelCounters** *(dict) --*

                  Provides information about the progress of a labeling job.

                  - **HumanLabeled** *(integer) --*

                    The total number of data objects labeled by a human worker.

                  - **PendingHuman** *(integer) --*

                    The total number of data objects that need to be labeled by a human worker.

                  - **Total** *(integer) --*

                    The total number of tasks in the labeling job.

                - **NumberOfHumanWorkersPerDataObject** *(integer) --*

                  The configured number of workers per data object.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of labeling jobs, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_model_packages(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        MaxResults: int = None,
        NameContains: str = None,
        NextToken: str = None,
        SortBy: Literal["Name", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
    ) -> ClientListModelPackagesResponseTypeDef:
        """
        Lists the model packages that have been created.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListModelPackages>`_

        **Request Syntax**
        ::

          response = client.list_model_packages(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              MaxResults=123,
              NameContains='string',
              NextToken='string',
              SortBy='Name'|'CreationTime',
              SortOrder='Ascending'|'Descending'
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only model packages created after the specified time (timestamp).

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only model packages created before the specified time (timestamp).

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of model packages to return in the response.

        :type NameContains: string
        :param NameContains:

          A string in the model package name. This filter returns only model packages whose name
          contains the specified string.

        :type NextToken: string
        :param NextToken:

          If the response to a previous ``ListModelPackages`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of model packages, use the token in
          the next request.

        :type SortBy: string
        :param SortBy:

          The parameter by which to sort the results. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for the results. The default is ``Ascending`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ModelPackageSummaryList': [
                    {
                        'ModelPackageName': 'string',
                        'ModelPackageArn': 'string',
                        'ModelPackageDescription': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'ModelPackageStatus': 'Pending'|'InProgress'|'Completed'|'Failed'|'Deleting'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ModelPackageSummaryList** *(list) --*

              An array of ``ModelPackageSummary`` objects, each of which lists a model package.

              - *(dict) --*

                Provides summary information about a model package.

                - **ModelPackageName** *(string) --*

                  The name of the model package.

                - **ModelPackageArn** *(string) --*

                  The Amazon Resource Name (ARN) of the model package.

                - **ModelPackageDescription** *(string) --*

                  A brief description of the model package.

                - **CreationTime** *(datetime) --*

                  A timestamp that shows when the model package was created.

                - **ModelPackageStatus** *(string) --*

                  The overall status of the model package.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of model packages, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_models(
        self,
        SortBy: Literal["Name", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
        NameContains: str = None,
        CreationTimeBefore: datetime = None,
        CreationTimeAfter: datetime = None,
    ) -> ClientListModelsResponseTypeDef:
        """
        Lists models created with the `CreateModel
        <https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateModel.html>`__ API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListModels>`_

        **Request Syntax**
        ::

          response = client.list_models(
              SortBy='Name'|'CreationTime',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123,
              NameContains='string',
              CreationTimeBefore=datetime(2015, 1, 1),
              CreationTimeAfter=datetime(2015, 1, 1)
          )
        :type SortBy: string
        :param SortBy:

          Sorts the list of results. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Descending`` .

        :type NextToken: string
        :param NextToken:

          If the response to a previous ``ListModels`` request was truncated, the response includes
          a ``NextToken`` . To retrieve the next set of models, use the token in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of models to return in the response.

        :type NameContains: string
        :param NameContains:

          A string in the training job name. This filter returns only models in the training job
          whose name contains the specified string.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only models created before the specified time (timestamp).

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only models with a creation time greater than or equal to the
          specified time (timestamp).

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Models': [
                    {
                        'ModelName': 'string',
                        'ModelArn': 'string',
                        'CreationTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Models** *(list) --*

              An array of ``ModelSummary`` objects, each of which lists a model.

              - *(dict) --*

                Provides summary information about a model.

                - **ModelName** *(string) --*

                  The name of the model that you want a summary for.

                - **ModelArn** *(string) --*

                  The Amazon Resource Name (ARN) of the model.

                - **CreationTime** *(datetime) --*

                  A timestamp that indicates when the model was created.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of models, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_monitoring_executions(
        self,
        MonitoringScheduleName: str = None,
        EndpointName: str = None,
        SortBy: Literal["CreationTime", "ScheduledTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
        ScheduledTimeBefore: datetime = None,
        ScheduledTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        CreationTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        StatusEquals: Literal[
            "Pending",
            "Completed",
            "CompletedWithViolations",
            "InProgress",
            "Failed",
            "Stopping",
            "Stopped",
        ] = None,
    ) -> ClientListMonitoringExecutionsResponseTypeDef:
        """
        Returns list of all monitoring job executions.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListMonitoringExecutions>`_

        **Request Syntax**
        ::

          response = client.list_monitoring_executions(
              MonitoringScheduleName='string',
              EndpointName='string',
              SortBy='CreationTime'|'ScheduledTime'|'Status',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123,
              ScheduledTimeBefore=datetime(2015, 1, 1),
              ScheduledTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              CreationTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              StatusEquals=
                  'Pending'|'Completed'|'CompletedWithViolations'|'InProgress'|'Failed'|'Stopping'
                  |'Stopped'
          )
        :type MonitoringScheduleName: string
        :param MonitoringScheduleName:

          Name of a specific schedule to fetch jobs for.

        :type EndpointName: string
        :param EndpointName:

          Name of a specific endpoint to fetch jobs for.

        :type SortBy: string
        :param SortBy:

          Whether to sort results by ``Status`` , ``CreationTime`` , ``ScheduledTime`` field. The
          default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          Whether to sort the results in ``Ascending`` or ``Descending`` order. The default is
          ``Descending`` .

        :type NextToken: string
        :param NextToken:

          The token returned if the response is truncated. To retrieve the next set of job
          executions, use it in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of jobs to return in the response. The default value is 10.

        :type ScheduledTimeBefore: datetime
        :param ScheduledTimeBefore:

          Filter for jobs scheduled before a specified time.

        :type ScheduledTimeAfter: datetime
        :param ScheduledTimeAfter:

          Filter for jobs scheduled after a specified time.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only jobs created before a specified time.

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only jobs created after a specified time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only jobs modified after a specified time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only jobs modified before a specified time.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that retrieves only jobs with a specific status.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MonitoringExecutionSummaries': [
                    {
                        'MonitoringScheduleName': 'string',
                        'ScheduledTime': datetime(2015, 1, 1),
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'MonitoringExecutionStatus':
                        'Pending'|'Completed'|'CompletedWithViolations'|'InProgress'
                        |'Failed'|'Stopping'|'Stopped',
                        'ProcessingJobArn': 'string',
                        'EndpointName': 'string',
                        'FailureReason': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **MonitoringExecutionSummaries** *(list) --*

              A JSON array in which each element is a summary for a monitoring execution.

              - *(dict) --*

                Summary of information about the last monitoring job to run.

                - **MonitoringScheduleName** *(string) --*

                  The name of the monitoring schedule.

                - **ScheduledTime** *(datetime) --*

                  The time the monitoring job was scheduled.

                - **CreationTime** *(datetime) --*

                  The time at which the monitoring job was created.

                - **LastModifiedTime** *(datetime) --*

                  A timestamp that indicates the last time the monitoring job was modified.

                - **MonitoringExecutionStatus** *(string) --*

                  The status of the monitoring job.

                - **ProcessingJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the monitoring job.

                - **EndpointName** *(string) --*

                  The name of teh endpoint used to run the monitoring job.

                - **FailureReason** *(string) --*

                  Contains the reason a monitoring job failed, if it failed.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of jobs, use it in the subsequent reques
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_monitoring_schedules(
        self,
        EndpointName: str = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
        NameContains: str = None,
        CreationTimeBefore: datetime = None,
        CreationTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        StatusEquals: Literal["Pending", "Failed", "Scheduled", "Stopped"] = None,
    ) -> ClientListMonitoringSchedulesResponseTypeDef:
        """
        Returns list of all monitoring schedules.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListMonitoringSchedules>`_

        **Request Syntax**
        ::

          response = client.list_monitoring_schedules(
              EndpointName='string',
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123,
              NameContains='string',
              CreationTimeBefore=datetime(2015, 1, 1),
              CreationTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              StatusEquals='Pending'|'Failed'|'Scheduled'|'Stopped'
          )
        :type EndpointName: string
        :param EndpointName:

          Name of a specific endpoint to fetch schedules for.

        :type SortBy: string
        :param SortBy:

          Whether to sort results by ``Status`` , ``CreationTime`` , ``ScheduledTime`` field. The
          default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          Whether to sort the results in ``Ascending`` or ``Descending`` order. The default is
          ``Descending`` .

        :type NextToken: string
        :param NextToken:

          The token returned if the response is truncated. To retrieve the next set of job
          executions, use it in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of jobs to return in the response. The default value is 10.

        :type NameContains: string
        :param NameContains:

          Filter for monitoring schedules whose name contains a specified string.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only monitoring schedules created before a specified time.

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only monitoring schedules created after a specified time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only monitoring schedules modified before a specified time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only monitoring schedules modified after a specified time.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that returns only monitoring schedules modified before a specified time.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MonitoringScheduleSummaries': [
                    {
                        'MonitoringScheduleName': 'string',
                        'MonitoringScheduleArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'MonitoringScheduleStatus': 'Pending'|'Failed'|'Scheduled'|'Stopped',
                        'EndpointName': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **MonitoringScheduleSummaries** *(list) --*

              A JSON array in which each element is a summary for a monitoring schedule.

              - *(dict) --*

                Summarizes the monitoring schedule.

                - **MonitoringScheduleName** *(string) --*

                  The name of the monitoring schedule.

                - **MonitoringScheduleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the monitoring schedule.

                - **CreationTime** *(datetime) --*

                  The creation time of the monitoring schedule.

                - **LastModifiedTime** *(datetime) --*

                  The last time the monitoring schedule was modified.

                - **MonitoringScheduleStatus** *(string) --*

                  The status of the monitoring schedule.

                - **EndpointName** *(string) --*

                  The name of the endpoint using the monitoring schedule.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of jobs, use it in the subsequent reques
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_notebook_instance_lifecycle_configs(
        self,
        NextToken: str = None,
        MaxResults: int = None,
        SortBy: Literal["Name", "CreationTime", "LastModifiedTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NameContains: str = None,
        CreationTimeBefore: datetime = None,
        CreationTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
    ) -> ClientListNotebookInstanceLifecycleConfigsResponseTypeDef:
        """
        Lists notebook instance lifestyle configurations created with the
        CreateNotebookInstanceLifecycleConfig API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListNotebookInstanceLifecycleConfigs>`_

        **Request Syntax**
        ::

          response = client.list_notebook_instance_lifecycle_configs(
              NextToken='string',
              MaxResults=123,
              SortBy='Name'|'CreationTime'|'LastModifiedTime',
              SortOrder='Ascending'|'Descending',
              NameContains='string',
              CreationTimeBefore=datetime(2015, 1, 1),
              CreationTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1)
          )
        :type NextToken: string
        :param NextToken:

          If the result of a ``ListNotebookInstanceLifecycleConfigs`` request was truncated, the
          response includes a ``NextToken`` . To get the next set of lifecycle configurations, use
          the token in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of lifecycle configurations to return in the response.

        :type SortBy: string
        :param SortBy:

          Sorts the list of results. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results.

        :type NameContains: string
        :param NameContains:

          A string in the lifecycle configuration name. This filter returns only lifecycle
          configurations whose name contains the specified string.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only lifecycle configurations that were created before the specified
          time (timestamp).

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only lifecycle configurations that were created after the specified
          time (timestamp).

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only lifecycle configurations that were modified before the
          specified time (timestamp).

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only lifecycle configurations that were modified after the specified
          time (timestamp).

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'NextToken': 'string',
                'NotebookInstanceLifecycleConfigs': [
                    {
                        'NotebookInstanceLifecycleConfigName': 'string',
                        'NotebookInstanceLifecycleConfigArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1)
                    },
                ]
            }
          **Response Structure**

          - *(dict) --*

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To get the next set
              of lifecycle configurations, use it in the next request.

            - **NotebookInstanceLifecycleConfigs** *(list) --*

              An array of ``NotebookInstanceLifecycleConfiguration`` objects, each listing a
              lifecycle configuration.

              - *(dict) --*

                Provides a summary of a notebook instance lifecycle configuration.

                - **NotebookInstanceLifecycleConfigName** *(string) --*

                  The name of the lifecycle configuration.

                - **NotebookInstanceLifecycleConfigArn** *(string) --*

                  The Amazon Resource Name (ARN) of the lifecycle configuration.

                - **CreationTime** *(datetime) --*

                  A timestamp that tells when the lifecycle configuration was created.

                - **LastModifiedTime** *(datetime) --*

                  A timestamp that tells when the lifecycle configuration was last modified.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_notebook_instances(
        self,
        NextToken: str = None,
        MaxResults: int = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NameContains: str = None,
        CreationTimeBefore: datetime = None,
        CreationTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        StatusEquals: Literal[
            "Pending", "InService", "Stopping", "Stopped", "Failed", "Deleting", "Updating"
        ] = None,
        NotebookInstanceLifecycleConfigNameContains: str = None,
        DefaultCodeRepositoryContains: str = None,
        AdditionalCodeRepositoryEquals: str = None,
    ) -> ClientListNotebookInstancesResponseTypeDef:
        """
        Returns a list of the Amazon SageMaker notebook instances in the requester's account in an
        AWS Region.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListNotebookInstances>`_

        **Request Syntax**
        ::

          response = client.list_notebook_instances(
              NextToken='string',
              MaxResults=123,
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending',
              NameContains='string',
              CreationTimeBefore=datetime(2015, 1, 1),
              CreationTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              StatusEquals=
                  'Pending'|'InService'|'Stopping'|'Stopped'|'Failed'|'Deleting'|'Updating',
              NotebookInstanceLifecycleConfigNameContains='string',
              DefaultCodeRepositoryContains='string',
              AdditionalCodeRepositoryEquals='string'
          )
        :type NextToken: string
        :param NextToken:

          If the previous call to the ``ListNotebookInstances`` is truncated, the response includes
          a ``NextToken`` . You can use this token in your subsequent ``ListNotebookInstances``
          request to fetch the next set of notebook instances.

          .. note::

            You might specify a filter or a sort order in your request. When response is truncated,
            you must use the same values for the filer and sort order in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of notebook instances to return.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``Name`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results.

        :type NameContains: string
        :param NameContains:

          A string in the notebook instances' name. This filter returns only notebook instances
          whose name contains the specified string.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only notebook instances that were created before the specified time
          (timestamp).

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only notebook instances that were created after the specified time
          (timestamp).

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only notebook instances that were modified before the specified time
          (timestamp).

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only notebook instances that were modified after the specified time
          (timestamp).

        :type StatusEquals: string
        :param StatusEquals:

          A filter that returns only notebook instances with the specified status.

        :type NotebookInstanceLifecycleConfigNameContains: string
        :param NotebookInstanceLifecycleConfigNameContains:

          A string in the name of a notebook instances lifecycle configuration associated with this
          notebook instance. This filter returns only notebook instances associated with a lifecycle
          configuration with a name that contains the specified string.

        :type DefaultCodeRepositoryContains: string
        :param DefaultCodeRepositoryContains:

          A string in the name or URL of a Git repository associated with this notebook instance.
          This filter returns only notebook instances associated with a git repository with a name
          that contains the specified string.

        :type AdditionalCodeRepositoryEquals: string
        :param AdditionalCodeRepositoryEquals:

          A filter that returns only notebook instances with associated with the specified git
          repository.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'NextToken': 'string',
                'NotebookInstances': [
                    {
                        'NotebookInstanceName': 'string',
                        'NotebookInstanceArn': 'string',
                        'NotebookInstanceStatus':
                        'Pending'|'InService'|'Stopping'|'Stopped'|'Failed'
                        |'Deleting'|'Updating',
                        'Url': 'string',
                        'InstanceType':
                        'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'
                        |'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                        |'ml.m4.xlarge'|'ml.m4.2xlarge'|'ml.m4.4xlarge'
                        |'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.xlarge'
                        |'ml.m5.2xlarge'|'ml.m5.4xlarge'|'ml.m5.12xlarge'
                        |'ml.m5.24xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'
                        |'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.c5.xlarge'
                        |'ml.c5.2xlarge'|'ml.c5.4xlarge'|'ml.c5.9xlarge'
                        |'ml.c5.18xlarge'|'ml.c5d.xlarge'|'ml.c5d.2xlarge'
                        |'ml.c5d.4xlarge'|'ml.c5d.9xlarge'|'ml.c5d.18xlarge'
                        |'ml.p2.xlarge'|'ml.p2.8xlarge'|'ml.p2.16xlarge'
                        |'ml.p3.2xlarge'|'ml.p3.8xlarge'|'ml.p3.16xlarge',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'NotebookInstanceLifecycleConfigName': 'string',
                        'DefaultCodeRepository': 'string',
                        'AdditionalCodeRepositories': [
                            'string',
                        ]
                    },
                ]
            }
          **Response Structure**

          - *(dict) --*

            - **NextToken** *(string) --*

              If the response to the previous ``ListNotebookInstances`` request was truncated,
              Amazon SageMaker returns this token. To retrieve the next set of notebook instances,
              use the token in the next request.

            - **NotebookInstances** *(list) --*

              An array of ``NotebookInstanceSummary`` objects, one for each notebook instance.

              - *(dict) --*

                Provides summary information for an Amazon SageMaker notebook instance.

                - **NotebookInstanceName** *(string) --*

                  The name of the notebook instance that you want a summary for.

                - **NotebookInstanceArn** *(string) --*

                  The Amazon Resource Name (ARN) of the notebook instance.

                - **NotebookInstanceStatus** *(string) --*

                  The status of the notebook instance.

                - **Url** *(string) --*

                  The URL that you use to connect to the Jupyter instance running in your notebook
                  instance.

                - **InstanceType** *(string) --*

                  The type of ML compute instance that the notebook instance is running on.

                - **CreationTime** *(datetime) --*

                  A timestamp that shows when the notebook instance was created.

                - **LastModifiedTime** *(datetime) --*

                  A timestamp that shows when the notebook instance was last modified.

                - **NotebookInstanceLifecycleConfigName** *(string) --*

                  The name of a notebook instance lifecycle configuration associated with this
                  notebook instance.

                  For information about notebook instance lifestyle configurations, see `Step 2.1\\:
                  (Optional) Customize a Notebook Instance
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__
                  .

                - **DefaultCodeRepository** *(string) --*

                  The Git repository associated with the notebook instance as its default code
                  repository. This can be either the name of a Git repository stored as a resource
                  in your account, or the URL of a Git repository in `AWS CodeCommit
                  <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in
                  any other Git repository. When you open a notebook instance, it opens in the
                  directory that contains this repository. For more information, see `Associating
                  Git Repositories with Amazon SageMaker Notebook Instances
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

                - **AdditionalCodeRepositories** *(list) --*

                  An array of up to three Git repositories associated with the notebook instance.
                  These can be either the names of Git repositories stored as resources in your
                  account, or the URL of Git repositories in `AWS CodeCommit
                  <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in
                  any other Git repository. These repositories are cloned at the same level as the
                  default repository of your notebook instance. For more information, see
                  `Associating Git Repositories with Amazon SageMaker Notebook Instances
                  <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

                  - *(string) --*
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_processing_jobs(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        NameContains: str = None,
        StatusEquals: Literal["InProgress", "Completed", "Failed", "Stopping", "Stopped"] = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListProcessingJobsResponseTypeDef:
        """
        Lists processing jobs that satisfy various filters.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListProcessingJobs>`_

        **Request Syntax**
        ::

          response = client.list_processing_jobs(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              NameContains='string',
              StatusEquals='InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only processing jobs created after the specified time.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only processing jobs created after the specified time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only processing jobs modified after the specified time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only processing jobs modified before the specified time.

        :type NameContains: string
        :param NameContains:

          A string in the processing job name. This filter returns only processing jobs whose name
          contains the specified string.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that retrieves only processing jobs with a specific status.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListProcessingJobs`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of processing jobs, use the token in
          the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of processing jobs to return in the response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ProcessingJobSummaries': [
                    {
                        'ProcessingJobName': 'string',
                        'ProcessingJobArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'ProcessingEndTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'ProcessingJobStatus':
                        'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                        'FailureReason': 'string',
                        'ExitMessage': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ProcessingJobSummaries** *(list) --*

              An array of ``ProcessingJobSummary`` objects, each listing a processing job.

              - *(dict) --*

                Summary of information about a processing job.

                - **ProcessingJobName** *(string) --*

                  The name of the processing job.

                - **ProcessingJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the processing job..

                - **CreationTime** *(datetime) --*

                  The time at which the processing job was created.

                - **ProcessingEndTime** *(datetime) --*

                  The time at which the processing job completed.

                - **LastModifiedTime** *(datetime) --*

                  A timestamp that indicates the last time the processing job was modified.

                - **ProcessingJobStatus** *(string) --*

                  The status of the processing job.

                - **FailureReason** *(string) --*

                  A string, up to one KB in size, that contains the reason a processing job failed,
                  if it failed.

                - **ExitMessage** *(string) --*

                  An optional string, up to one KB in size, that contains metadata from the
                  processing container when the processing job exits.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of processing jobs, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_subscribed_workteams(
        self, NameContains: str = None, NextToken: str = None, MaxResults: int = None
    ) -> ClientListSubscribedWorkteamsResponseTypeDef:
        """
        Gets a list of the work teams that you are subscribed to in the AWS Marketplace. The list
        may be empty if no work team satisfies the filter specified in the ``NameContains``
        parameter.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListSubscribedWorkteams>`_

        **Request Syntax**
        ::

          response = client.list_subscribed_workteams(
              NameContains='string',
              NextToken='string',
              MaxResults=123
          )
        :type NameContains: string
        :param NameContains:

          A string in the work team name. This filter returns only work teams whose name contains
          the specified string.

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListSubscribedWorkteams`` request was truncated, the
          response includes a ``NextToken`` . To retrieve the next set of labeling jobs, use the
          token in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of work teams to return in each page of the response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SubscribedWorkteams': [
                    {
                        'WorkteamArn': 'string',
                        'MarketplaceTitle': 'string',
                        'SellerName': 'string',
                        'MarketplaceDescription': 'string',
                        'ListingId': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **SubscribedWorkteams** *(list) --*

              An array of ``Workteam`` objects, each describing a work team.

              - *(dict) --*

                Describes a work team of a vendor that does the a labelling job.

                - **WorkteamArn** *(string) --*

                  The Amazon Resource Name (ARN) of the vendor that you have subscribed.

                - **MarketplaceTitle** *(string) --*

                  The title of the service provided by the vendor in the Amazon Marketplace.

                - **SellerName** *(string) --*

                  The name of the vendor in the Amazon Marketplace.

                - **MarketplaceDescription** *(string) --*

                  The description of the vendor from the Amazon Marketplace.

                - **ListingId** *(string) --*

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of work teams, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_tags(
        self, ResourceArn: str, NextToken: str = None, MaxResults: int = None
    ) -> ClientListTagsResponseTypeDef:
        """
        Returns the tags for the specified Amazon SageMaker resource.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListTags>`_

        **Request Syntax**
        ::

          response = client.list_tags(
              ResourceArn='string',
              NextToken='string',
              MaxResults=123
          )
        :type ResourceArn: string
        :param ResourceArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the resource whose tags you want to retrieve.

        :type NextToken: string
        :param NextToken:

          If the response to the previous ``ListTags`` request is truncated, Amazon SageMaker
          returns this token. To retrieve the next set of tags, use it in the subsequent request.

        :type MaxResults: integer
        :param MaxResults:

          Maximum number of tags to return.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Tags': [
                    {
                        'Key': 'string',
                        'Value': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Tags** *(list) --*

              An array of ``Tag`` objects, each with a tag key and a value.

              - *(dict) --*

                Describes a tag.

                - **Key** *(string) --*

                  The tag key.

                - **Value** *(string) --*

                  The tag value.

            - **NextToken** *(string) --*

              If response is truncated, Amazon SageMaker includes a token in the response. You can
              use this token in your subsequent request to fetch next set of tokens.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_training_jobs(
        self,
        NextToken: str = None,
        MaxResults: int = None,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        NameContains: str = None,
        StatusEquals: Literal["InProgress", "Completed", "Failed", "Stopping", "Stopped"] = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
    ) -> ClientListTrainingJobsResponseTypeDef:
        """
        Lists training jobs.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListTrainingJobs>`_

        **Request Syntax**
        ::

          response = client.list_training_jobs(
              NextToken='string',
              MaxResults=123,
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              NameContains='string',
              StatusEquals='InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending'
          )
        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListTrainingJobs`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of training jobs, use the token in the
          next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of training jobs to return in the response.

        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only training jobs created after the specified time (timestamp).

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only training jobs created before the specified time (timestamp).

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only training jobs modified after the specified time (timestamp).

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only training jobs modified before the specified time (timestamp).

        :type NameContains: string
        :param NameContains:

          A string in the training job name. This filter returns only training jobs whose name
          contains the specified string.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that retrieves only training jobs with a specific status.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrainingJobSummaries': [
                    {
                        'TrainingJobName': 'string',
                        'TrainingJobArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'TrainingEndTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'TrainingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrainingJobSummaries** *(list) --*

              An array of ``TrainingJobSummary`` objects, each listing a training job.

              - *(dict) --*

                Provides summary information about a training job.

                - **TrainingJobName** *(string) --*

                  The name of the training job that you want a summary for.

                - **TrainingJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the training job.

                - **CreationTime** *(datetime) --*

                  A timestamp that shows when the training job was created.

                - **TrainingEndTime** *(datetime) --*

                  A timestamp that shows when the training job ended. This field is set only if the
                  training job has one of the terminal statuses (``Completed`` , ``Failed`` , or
                  ``Stopped`` ).

                - **LastModifiedTime** *(datetime) --*

                  Timestamp when the training job was last modified.

                - **TrainingJobStatus** *(string) --*

                  The status of the training job.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of training jobs, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_training_jobs_for_hyper_parameter_tuning_job(
        self,
        HyperParameterTuningJobName: str,
        NextToken: str = None,
        MaxResults: int = None,
        StatusEquals: Literal["InProgress", "Completed", "Failed", "Stopping", "Stopped"] = None,
        SortBy: Literal["Name", "CreationTime", "Status", "FinalObjectiveMetricValue"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
    ) -> ClientListTrainingJobsForHyperParameterTuningJobResponseTypeDef:
        """
        Gets a list of  TrainingJobSummary objects that describe the training jobs that a
        hyperparameter tuning job launched.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListTrainingJobsForHyperParameterTuningJob>`_

        **Request Syntax**
        ::

          response = client.list_training_jobs_for_hyper_parameter_tuning_job(
              HyperParameterTuningJobName='string',
              NextToken='string',
              MaxResults=123,
              StatusEquals='InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
              SortBy='Name'|'CreationTime'|'Status'|'FinalObjectiveMetricValue',
              SortOrder='Ascending'|'Descending'
          )
        :type HyperParameterTuningJobName: string
        :param HyperParameterTuningJobName: **[REQUIRED]**

          The name of the tuning job whose training jobs you want to list.

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListTrainingJobsForHyperParameterTuningJob`` request was
          truncated, the response includes a ``NextToken`` . To retrieve the next set of training
          jobs, use the token in the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of training jobs to return. The default value is 10.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that returns only training jobs with the specified status.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``Name`` .

          If the value of this field is ``FinalObjectiveMetricValue`` , any training jobs that did
          not return an objective metric are not listed.

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrainingJobSummaries': [
                    {
                        'TrainingJobDefinitionName': 'string',
                        'TrainingJobName': 'string',
                        'TrainingJobArn': 'string',
                        'TuningJobName': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'TrainingStartTime': datetime(2015, 1, 1),
                        'TrainingEndTime': datetime(2015, 1, 1),
                        'TrainingJobStatus': 'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                        'TunedHyperParameters': {
                            'string': 'string'
                        },
                        'FailureReason': 'string',
                        'FinalHyperParameterTuningJobObjectiveMetric': {
                            'Type': 'Maximize'|'Minimize',
                            'MetricName': 'string',
                            'Value': ...
                        },
                        'ObjectiveStatus': 'Succeeded'|'Pending'|'Failed'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrainingJobSummaries** *(list) --*

              A list of  TrainingJobSummary objects that describe the training jobs that the
              ``ListTrainingJobsForHyperParameterTuningJob`` request returned.

              - *(dict) --*

                Specifies summary information about a training job.

                - **TrainingJobDefinitionName** *(string) --*

                  The training job definition name.

                - **TrainingJobName** *(string) --*

                  The name of the training job.

                - **TrainingJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the training job.

                - **TuningJobName** *(string) --*

                  The HyperParameter tuning job that launched the training job.

                - **CreationTime** *(datetime) --*

                  The date and time that the training job was created.

                - **TrainingStartTime** *(datetime) --*

                  The date and time that the training job started.

                - **TrainingEndTime** *(datetime) --*

                  Specifies the time when the training job ends on training instances. You are
                  billed for the time interval between the value of ``TrainingStartTime`` and this
                  time. For successful jobs and stopped jobs, this is the time after model artifacts
                  are uploaded. For failed jobs, this is the time when Amazon SageMaker detects a
                  job failure.

                - **TrainingJobStatus** *(string) --*

                  The status of the training job.

                - **TunedHyperParameters** *(dict) --*

                  A list of the hyperparameters for which you specified ranges to search.

                  - *(string) --*

                    - *(string) --*

                - **FailureReason** *(string) --*

                  The reason that the training job failed.

                - **FinalHyperParameterTuningJobObjectiveMetric** *(dict) --*

                  The  FinalHyperParameterTuningJobObjectiveMetric object that specifies the value
                  of the objective metric of the tuning job that launched this training job.

                  - **Type** *(string) --*

                    Whether to minimize or maximize the objective metric. Valid values are Minimize
                    and Maximize.

                  - **MetricName** *(string) --*

                    The name of the objective metric.

                  - **Value** *(float) --*

                    The value of the objective metric.

                - **ObjectiveStatus** *(string) --*

                  The status of the objective metric for the training job:

                  * Succeeded: The final objective metric for the training job was evaluated by the
                  hyperparameter tuning job and used in the hyperparameter tuning process.

                  * Pending: The training job is in progress and evaluation of its final objective
                  metric is pending.

                  * Failed: The final objective metric for the training job was not evaluated, and
                  was not used in the hyperparameter tuning process. This typically occurs when the
                  training job failed or did not emit an objective metric.

            - **NextToken** *(string) --*

              If the result of this ``ListTrainingJobsForHyperParameterTuningJob`` request was
              truncated, the response includes a ``NextToken`` . To retrieve the next set of
              training jobs, use the token in the next request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_transform_jobs(
        self,
        CreationTimeAfter: datetime = None,
        CreationTimeBefore: datetime = None,
        LastModifiedTimeAfter: datetime = None,
        LastModifiedTimeBefore: datetime = None,
        NameContains: str = None,
        StatusEquals: Literal["InProgress", "Completed", "Failed", "Stopping", "Stopped"] = None,
        SortBy: Literal["Name", "CreationTime", "Status"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListTransformJobsResponseTypeDef:
        """
        Lists transform jobs.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListTransformJobs>`_

        **Request Syntax**
        ::

          response = client.list_transform_jobs(
              CreationTimeAfter=datetime(2015, 1, 1),
              CreationTimeBefore=datetime(2015, 1, 1),
              LastModifiedTimeAfter=datetime(2015, 1, 1),
              LastModifiedTimeBefore=datetime(2015, 1, 1),
              NameContains='string',
              StatusEquals='InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
              SortBy='Name'|'CreationTime'|'Status',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123
          )
        :type CreationTimeAfter: datetime
        :param CreationTimeAfter:

          A filter that returns only transform jobs created after the specified time.

        :type CreationTimeBefore: datetime
        :param CreationTimeBefore:

          A filter that returns only transform jobs created before the specified time.

        :type LastModifiedTimeAfter: datetime
        :param LastModifiedTimeAfter:

          A filter that returns only transform jobs modified after the specified time.

        :type LastModifiedTimeBefore: datetime
        :param LastModifiedTimeBefore:

          A filter that returns only transform jobs modified before the specified time.

        :type NameContains: string
        :param NameContains:

          A string in the transform job name. This filter returns only transform jobs whose name
          contains the specified string.

        :type StatusEquals: string
        :param StatusEquals:

          A filter that retrieves only transform jobs with a specific status.

        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Descending`` .

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListTransformJobs`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of transform jobs, use the token in
          the next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of transform jobs to return in the response. The default value is
          ``10`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TransformJobSummaries': [
                    {
                        'TransformJobName': 'string',
                        'TransformJobArn': 'string',
                        'CreationTime': datetime(2015, 1, 1),
                        'TransformEndTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'TransformJobStatus':
                        'InProgress'|'Completed'|'Failed'|'Stopping'|'Stopped',
                        'FailureReason': 'string'
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TransformJobSummaries** *(list) --*

              An array of ``TransformJobSummary`` objects.

              - *(dict) --*

                Provides a summary of a transform job. Multiple ``TransformJobSummary`` objects are
                returned as a list after in response to a  ListTransformJobs call.

                - **TransformJobName** *(string) --*

                  The name of the transform job.

                - **TransformJobArn** *(string) --*

                  The Amazon Resource Name (ARN) of the transform job.

                - **CreationTime** *(datetime) --*

                  A timestamp that shows when the transform Job was created.

                - **TransformEndTime** *(datetime) --*

                  Indicates when the transform job ends on compute instances. For successful jobs
                  and stopped jobs, this is the exact time recorded after the results are uploaded.
                  For failed jobs, this is when Amazon SageMaker detected that the job failed.

                - **LastModifiedTime** *(datetime) --*

                  Indicates when the transform job was last modified.

                - **TransformJobStatus** *(string) --*

                  The status of the transform job.

                - **FailureReason** *(string) --*

                  If the transform job failed, the reason it failed.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of transform jobs, use it in the next request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_trial_components(
        self,
        SourceArn: str = None,
        CreatedAfter: datetime = None,
        CreatedBefore: datetime = None,
        SortBy: Literal["Name", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        MaxResults: int = None,
        NextToken: str = None,
    ) -> ClientListTrialComponentsResponseTypeDef:
        """
        Lists the trial components in your account. You can filter the list to show only components
        that were created in a specific time range. You can sort the list by trial component name or
        creation time.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListTrialComponents>`_

        **Request Syntax**
        ::

          response = client.list_trial_components(
              SourceArn='string',
              CreatedAfter=datetime(2015, 1, 1),
              CreatedBefore=datetime(2015, 1, 1),
              SortBy='Name'|'CreationTime',
              SortOrder='Ascending'|'Descending',
              MaxResults=123,
              NextToken='string'
          )
        :type SourceArn: string
        :param SourceArn:

          A filter that returns only components that have the specified source Amazon Resource Name
          (ARN).

        :type CreatedAfter: datetime
        :param CreatedAfter:

          A filter that returns only components created after the specified time.

        :type CreatedBefore: datetime
        :param CreatedBefore:

          A filter that returns only components created before the specified time.

        :type SortBy: string
        :param SortBy:

          The property used to sort results. The default value is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order. The default value is ``Descending`` .

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of components to return in the response.

        :type NextToken: string
        :param NextToken:

          If the previous call to ``ListTrialComponents`` didn't return the full set of components,
          the call returns a token for getting the next set of components.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialComponentSummaries': [
                    {
                        'TrialComponentName': 'string',
                        'TrialComponentArn': 'string',
                        'DisplayName': 'string',
                        'TrialComponentSource': {
                            'SourceArn': 'string',
                            'SourceType': 'string'
                        },
                        'Status': {
                            'PrimaryStatus': 'InProgress'|'Completed'|'Failed',
                            'Message': 'string'
                        },
                        'StartTime': datetime(2015, 1, 1),
                        'EndTime': datetime(2015, 1, 1),
                        'CreationTime': datetime(2015, 1, 1),
                        'CreatedBy': {
                            'UserProfileArn': 'string',
                            'UserProfileName': 'string',
                            'DomainId': 'string'
                        },
                        'LastModifiedTime': datetime(2015, 1, 1),
                        'LastModifiedBy': {
                            'UserProfileArn': 'string',
                            'UserProfileName': 'string',
                            'DomainId': 'string'
                        }
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialComponentSummaries** *(list) --*

              A list of the summaries of your trial components.

              - *(dict) --*

                A summary of the properties of a trial component. To get all the properties, call
                the  DescribeTrialComponent API and provide the ``TrialComponentName`` .

                - **TrialComponentName** *(string) --*

                  The name of the trial component.

                - **TrialComponentArn** *(string) --*

                  The ARN of the trial component.

                - **DisplayName** *(string) --*

                  The name of the component as displayed. If ``DisplayName`` isn't specified,
                  ``TrialComponentName`` is displayed.

                - **TrialComponentSource** *(dict) --*

                  The source of the trial component.

                  - **SourceArn** *(string) --*

                    The Amazon Resource Name (ARN) of the source.

                  - **SourceType** *(string) --*

                    The source job type.

                - **Status** *(dict) --*

                  The status of the component. States include:

                  * InProgress

                  * Completed

                  * Failed

                  - **PrimaryStatus** *(string) --*

                    The status of the trial component.

                  - **Message** *(string) --*

                    If the component failed, a message describing why.

                - **StartTime** *(datetime) --*

                  When the component started.

                - **EndTime** *(datetime) --*

                  When the component ended.

                - **CreationTime** *(datetime) --*

                  When the component was created.

                - **CreatedBy** *(dict) --*

                  Who created the component.

                  - **UserProfileArn** *(string) --*

                    The Amazon Resource Name (ARN) of the user's profile.

                  - **UserProfileName** *(string) --*

                    The name of the user's profile.

                  - **DomainId** *(string) --*

                    The domain associated with the user.

                - **LastModifiedTime** *(datetime) --*

                  When the component was last modified.

                - **LastModifiedBy** *(dict) --*

                  Who last modified the component.

                  - **UserProfileArn** *(string) --*

                    The Amazon Resource Name (ARN) of the user's profile.

                  - **UserProfileName** *(string) --*

                    The name of the user's profile.

                  - **DomainId** *(string) --*

                    The domain associated with the user.

            - **NextToken** *(string) --*

              A token for getting the next set of components, if there are any.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_trials(
        self,
        ExperimentName: str = None,
        CreatedAfter: datetime = None,
        CreatedBefore: datetime = None,
        SortBy: Literal["Name", "CreationTime"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        MaxResults: int = None,
        NextToken: str = None,
    ) -> ClientListTrialsResponseTypeDef:
        """
        Lists the trials in your account. Specify an experiment name to limit the list to the trials
        that are part of that experiment. The list can be filtered to show only trials that were
        created in a specific time range. The list can be sorted by trial name or creation time.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListTrials>`_

        **Request Syntax**
        ::

          response = client.list_trials(
              ExperimentName='string',
              CreatedAfter=datetime(2015, 1, 1),
              CreatedBefore=datetime(2015, 1, 1),
              SortBy='Name'|'CreationTime',
              SortOrder='Ascending'|'Descending',
              MaxResults=123,
              NextToken='string'
          )
        :type ExperimentName: string
        :param ExperimentName:

          A filter that returns only trials that are part of the specified experiment.

        :type CreatedAfter: datetime
        :param CreatedAfter:

          A filter that returns only trials created after the specified time.

        :type CreatedBefore: datetime
        :param CreatedBefore:

          A filter that returns only trials created before the specified time.

        :type SortBy: string
        :param SortBy:

          The property used to sort results. The default value is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order. The default value is ``Descending`` .

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of trials to return in the response.

        :type NextToken: string
        :param NextToken:

          If the previous call to ``ListTrials`` didn't return the full set of trials, the call
          returns a token for getting the next set of trials.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialSummaries': [
                    {
                        'TrialArn': 'string',
                        'TrialName': 'string',
                        'DisplayName': 'string',
                        'TrialSource': {
                            'SourceArn': 'string',
                            'SourceType': 'string'
                        },
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialSummaries** *(list) --*

              A list of the summaries of your trials.

              - *(dict) --*

                A summary of the properties of a trial. To get the complete set of properties, call
                the  DescribeTrial API and provide the ``TrialName`` .

                - **TrialArn** *(string) --*

                  The Amazon Resource Name (ARN) of the trial.

                - **TrialName** *(string) --*

                  The name of the trial.

                - **DisplayName** *(string) --*

                  The name of the trial as displayed. If ``DisplayName`` isn't specified,
                  ``TrialName`` is displayed.

                - **TrialSource** *(dict) --*

                  The source of the trial.

                  - **SourceArn** *(string) --*

                    The Amazon Resource Name (ARN) of the source.

                  - **SourceType** *(string) --*

                    The source job type.

                - **CreationTime** *(datetime) --*

                  When the trial was created.

                - **LastModifiedTime** *(datetime) --*

                  When the trial was last modified.

            - **NextToken** *(string) --*

              A token for getting the next set of trials, if there are any.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_user_profiles(
        self,
        NextToken: str = None,
        MaxResults: int = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        SortBy: Literal["CreationTime", "LastModifiedTime"] = None,
        DomainIdEquals: str = None,
        UserProfileNameContains: str = None,
    ) -> ClientListUserProfilesResponseTypeDef:
        """
        Lists user profiles.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListUserProfiles>`_

        **Request Syntax**
        ::

          response = client.list_user_profiles(
              NextToken='string',
              MaxResults=123,
              SortOrder='Ascending'|'Descending',
              SortBy='CreationTime'|'LastModifiedTime',
              DomainIdEquals='string',
              UserProfileNameContains='string'
          )
        :type NextToken: string
        :param NextToken:

          If the previous response was truncated, you will receive this token. Use it in your next
          request to receive the next set of results.

        :type MaxResults: integer
        :param MaxResults:

          Returns a list up to a specified limit.

        :type SortOrder: string
        :param SortOrder:

          The sort order for the results. The default is Ascending.

        :type SortBy: string
        :param SortBy:

          The parameter by which to sort the results. The default is CreationTime.

        :type DomainIdEquals: string
        :param DomainIdEquals:

          A parameter by which to filter the results.

        :type UserProfileNameContains: string
        :param UserProfileNameContains:

          A parameter by which to filter the results.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'UserProfiles': [
                    {
                        'DomainId': 'string',
                        'UserProfileName': 'string',
                        'Status': 'Deleting'|'Failed'|'InService'|'Pending',
                        'CreationTime': datetime(2015, 1, 1),
                        'LastModifiedTime': datetime(2015, 1, 1)
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **UserProfiles** *(list) --*

              The list of user profiles.

              - *(dict) --*

                The user profile details.

                - **DomainId** *(string) --*

                  The domain ID.

                - **UserProfileName** *(string) --*

                  The user profile name.

                - **Status** *(string) --*

                  The status.

                - **CreationTime** *(datetime) --*

                  The creation time.

                - **LastModifiedTime** *(datetime) --*

                  The last modified time.

            - **NextToken** *(string) --*

              If the previous response was truncated, you will receive this token. Use it in your
              next request to receive the next set of results.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_workteams(
        self,
        SortBy: Literal["Name", "CreateDate"] = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NameContains: str = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListWorkteamsResponseTypeDef:
        """
        Gets a list of work teams that you have defined in a region. The list may be empty if no
        work team satisfies the filter specified in the ``NameContains`` parameter.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ListWorkteams>`_

        **Request Syntax**
        ::

          response = client.list_workteams(
              SortBy='Name'|'CreateDate',
              SortOrder='Ascending'|'Descending',
              NameContains='string',
              NextToken='string',
              MaxResults=123
          )
        :type SortBy: string
        :param SortBy:

          The field to sort results by. The default is ``CreationTime`` .

        :type SortOrder: string
        :param SortOrder:

          The sort order for results. The default is ``Ascending`` .

        :type NameContains: string
        :param NameContains:

          A string in the work team's name. This filter returns only work teams whose name contains
          the specified string.

        :type NextToken: string
        :param NextToken:

          If the result of the previous ``ListWorkteams`` request was truncated, the response
          includes a ``NextToken`` . To retrieve the next set of labeling jobs, use the token in the
          next request.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of work teams to return in each page of the response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Workteams': [
                    {
                        'WorkteamName': 'string',
                        'MemberDefinitions': [
                            {
                                'CognitoMemberDefinition': {
                                    'UserPool': 'string',
                                    'UserGroup': 'string',
                                    'ClientId': 'string'
                                }
                            },
                        ],
                        'WorkteamArn': 'string',
                        'ProductListingIds': [
                            'string',
                        ],
                        'Description': 'string',
                        'SubDomain': 'string',
                        'CreateDate': datetime(2015, 1, 1),
                        'LastUpdatedDate': datetime(2015, 1, 1),
                        'NotificationConfiguration': {
                            'NotificationTopicArn': 'string'
                        }
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Workteams** *(list) --*

              An array of ``Workteam`` objects, each describing a work team.

              - *(dict) --*

                Provides details about a labeling work team.

                - **WorkteamName** *(string) --*

                  The name of the work team.

                - **MemberDefinitions** *(list) --*

                  The Amazon Cognito user groups that make up the work team.

                  - *(dict) --*

                    Defines the Amazon Cognito user group that is part of a work team.

                    - **CognitoMemberDefinition** *(dict) --*

                      The Amazon Cognito user group that is part of the work team.

                      - **UserPool** *(string) --*

                        An identifier for a user pool. The user pool must be in the same region as
                        the service that you are calling.

                      - **UserGroup** *(string) --*

                        An identifier for a user group.

                      - **ClientId** *(string) --*

                        An identifier for an application client. You must create the app client ID
                        using Amazon Cognito.

                - **WorkteamArn** *(string) --*

                  The Amazon Resource Name (ARN) that identifies the work team.

                - **ProductListingIds** *(list) --*

                  The Amazon Marketplace identifier for a vendor's work team.

                  - *(string) --*

                - **Description** *(string) --*

                  A description of the work team.

                - **SubDomain** *(string) --*

                  The URI of the labeling job's user interface. Workers open this URI to start
                  labeling your data objects.

                - **CreateDate** *(datetime) --*

                  The date and time that the work team was created (timestamp).

                - **LastUpdatedDate** *(datetime) --*

                  The date and time that the work team was last updated (timestamp).

                - **NotificationConfiguration** *(dict) --*

                  Configures SNS notifications of available or expiring work items for work teams.

                  - **NotificationTopicArn** *(string) --*

                    The ARN for the SNS topic to which notifications should be published.

            - **NextToken** *(string) --*

              If the response is truncated, Amazon SageMaker returns this token. To retrieve the
              next set of work teams, use it in the subsequent request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def render_ui_template(
        self,
        UiTemplate: ClientRenderUiTemplateUiTemplateTypeDef,
        Task: ClientRenderUiTemplateTaskTypeDef,
        RoleArn: str,
    ) -> ClientRenderUiTemplateResponseTypeDef:
        """
        Renders the UI template so that you can preview the worker's experience.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/RenderUiTemplate>`_

        **Request Syntax**
        ::

          response = client.render_ui_template(
              UiTemplate={
                  'Content': 'string'
              },
              Task={
                  'Input': 'string'
              },
              RoleArn='string'
          )
        :type UiTemplate: dict
        :param UiTemplate: **[REQUIRED]**

          A ``Template`` object containing the worker UI template to render.

          - **Content** *(string) --* **[REQUIRED]**

            The content of the Liquid template for the worker user interface.

        :type Task: dict
        :param Task: **[REQUIRED]**

          A ``RenderableTask`` object containing a representative task to render.

          - **Input** *(string) --* **[REQUIRED]**

            A JSON object that contains values for the variables defined in the template. It is made
            available to the template under the substitution variable ``task.input`` . For example,
            if you define a variable ``task.input.text`` in your template, you can supply the
            variable in the JSON object as ``"text": "sample text"`` .

        :type RoleArn: string
        :param RoleArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) that has access to the S3 objects that are used by the
          template.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'RenderedContent': 'string',
                'Errors': [
                    {
                        'Code': 'string',
                        'Message': 'string'
                    },
                ]
            }
          **Response Structure**

          - *(dict) --*

            - **RenderedContent** *(string) --*

              A Liquid template that renders the HTML for the worker UI.

            - **Errors** *(list) --*

              A list of one or more ``RenderingError`` objects if any were encountered while
              rendering the template. If there were no errors, the list is empty.

              - *(dict) --*

                A description of an error that occurred while rendering the template.

                - **Code** *(string) --*

                  A unique identifier for a specific class of errors.

                - **Message** *(string) --*

                  A human-readable message describing the error.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def search(
        self,
        Resource: Literal[
            "TrainingJob", "Experiment", "ExperimentTrial", "ExperimentTrialComponent"
        ],
        SearchExpression: ClientSearchSearchExpressionTypeDef = None,
        SortBy: str = None,
        SortOrder: Literal["Ascending", "Descending"] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientSearchResponseTypeDef:
        """
        Finds Amazon SageMaker resources that match a search query. Matching resource objects are
        returned as a list of ``SearchResult`` objects in the response. You can sort the search
        results by any resource property in a ascending or descending order.

        You can query against the following value types: numerical, text, Booleans, and timestamps.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/Search>`_

        **Request Syntax**
        ::

          response = client.search(
              Resource='TrainingJob'|'Experiment'|'ExperimentTrial'|'ExperimentTrialComponent',
              SearchExpression={
                  'Filters': [
                      {
                          'Name': 'string',
                          'Operator':
                          'Equals'|'NotEquals'|'GreaterThan'
                          |'GreaterThanOrEqualTo'|'LessThan'|'LessThanOrEqualTo'
                          |'Contains'|'Exists'|'NotExists',
                          'Value': 'string'
                      },
                  ],
                  'NestedFilters': [
                      {
                          'NestedPropertyName': 'string',
                          'Filters': [
                              {
                                  'Name': 'string',
                                  'Operator':
                                  'Equals'|'NotEquals'|'GreaterThan'
                                  |'GreaterThanOrEqualTo'|'LessThan'
                                  |'LessThanOrEqualTo'|'Contains'|'Exists'
                                  |'NotExists',
                                  'Value': 'string'
                              },
                          ]
                      },
                  ],
                  'SubExpressions': [
                      {'... recursive ...'},
                  ],
                  'Operator': 'And'|'Or'
              },
              SortBy='string',
              SortOrder='Ascending'|'Descending',
              NextToken='string',
              MaxResults=123
          )
        :type Resource: string
        :param Resource: **[REQUIRED]**

          The name of the Amazon SageMaker resource to search for. Currently, the only valid
          ``Resource`` value is ``TrainingJob`` .

        :type SearchExpression: dict
        :param SearchExpression:

          A Boolean conditional statement. Resource objects must satisfy this condition to be
          included in search results. You must provide at least one subexpression, filter, or nested
          filter. The maximum number of recursive ``SubExpressions`` , ``NestedFilters`` , and
          ``Filters`` that can be included in a ``SearchExpression`` object is 50.

          - **Filters** *(list) --*

            A list of filter objects.

            - *(dict) --*

              A conditional statement for a search expression that includes a resource property, a
              Boolean operator, and a value.

              If you don't specify an ``Operator`` and a ``Value`` , the filter searches for only
              the specified property. For example, defining a ``Filter`` for the ``FailureReason``
              for the ``TrainingJob``  ``Resource`` searches for training job objects that have a
              value in the ``FailureReason`` field.

              If you specify a ``Value`` , but not an ``Operator`` , Amazon SageMaker uses the
              equals operator as the default.

              In search, there are several property types:

                Metrics

              To define a metric filter, enter a value using the form ``"Metrics.<name>"`` , where
              ``<name>`` is a metric name. For example, the following filter searches for training
              jobs with an ``"accuracy"`` metric greater than ``"0.9"`` :

               ``{``

               ``"Name": "Metrics.accuracy",``

               ``"Operator": "GREATER_THAN",``

               ``"Value": "0.9"``

               ``}``

                HyperParameters

              To define a hyperparameter filter, enter a value with the form
              ``"HyperParameters.<name>"`` . Decimal hyperparameter values are treated as a decimal
              in a comparison if the specified ``Value`` is also a decimal value. If the specified
              ``Value`` is an integer, the decimal hyperparameter values are treated as integers.
              For example, the following filter is satisfied by training jobs with a
              ``"learning_rate"`` hyperparameter that is less than ``"0.5"`` :

               ``{``

               ``"Name": "HyperParameters.learning_rate",``

               ``"Operator": "LESS_THAN",``

               ``"Value": "0.5"``

               ``}``

                Tags

              To define a tag filter, enter a value with the form ``"Tags.<key>"`` .

              - **Name** *(string) --* **[REQUIRED]**

                A property name. For example, ``TrainingJobName`` . For the list of valid property
                names returned in a search result for each supported resource, see  TrainingJob
                properties. You must specify a valid property name for the resource.

              - **Operator** *(string) --*

                A Boolean binary operator that is used to evaluate the filter. The operator field
                contains one of the following values:

                  Equals

                The specified resource in ``Name`` equals the specified ``Value`` .

                  NotEquals

                The specified resource in ``Name`` does not equal the specified ``Value`` .

                  GreaterThan

                The specified resource in ``Name`` is greater than the specified ``Value`` . Not
                supported for text-based properties.

                  GreaterThanOrEqualTo

                The specified resource in ``Name`` is greater than or equal to the specified
                ``Value`` . Not supported for text-based properties.

                  LessThan

                The specified resource in ``Name`` is less than the specified ``Value`` . Not
                supported for text-based properties.

                  LessThanOrEqualTo

                The specified resource in ``Name`` is less than or equal to the specified ``Value``
                . Not supported for text-based properties.

                  Contains

                Only supported for text-based properties. The word-list of the property contains the
                specified ``Value`` . A ``SearchExpression`` can include only one ``Contains``
                operator.

                If you have specified a filter ``Value`` , the default is ``Equals`` .

              - **Value** *(string) --*

                A value used with ``Resource`` and ``Operator`` to determine if objects satisfy the
                filter's condition. For numerical properties, ``Value`` must be an integer or
                floating-point decimal. For timestamp properties, ``Value`` must be an ISO 8601
                date-time string of the following format: ``YYYY-mm-dd'T'HH:MM:SS`` .

          - **NestedFilters** *(list) --*

            A list of nested filter objects.

            - *(dict) --*

              Defines a list of ``NestedFilters`` objects. To satisfy the conditions specified in
              the ``NestedFilters`` call, a resource must satisfy the conditions of all of the
              filters.

              For example, you could define a ``NestedFilters`` using the training job's
              ``InputDataConfig`` property to filter on ``Channel`` objects.

              A ``NestedFilters`` object contains multiple filters. For example, to find all
              training jobs whose name contains ``train`` and that have ``cat/data`` in their
              ``S3Uri`` (specified in ``InputDataConfig`` ), you need to create a ``NestedFilters``
              object that specifies the ``InputDataConfig`` property with the following ``Filter``
              objects:

              * ``'{Name:"InputDataConfig.ChannelName", "Operator":"EQUALS", "Value":"train"}',``

              * ``'{Name:"InputDataConfig.DataSource.S3DataSource.S3Uri", "Operator":"CONTAINS",
              "Value":"cat/data"}'``

              - **NestedPropertyName** *(string) --* **[REQUIRED]**

                The name of the property to use in the nested filters. The value must match a listed
                property name, such as ``InputDataConfig`` .

              - **Filters** *(list) --* **[REQUIRED]**

                A list of filters. Each filter acts on a property. Filters must contain at least one
                ``Filters`` value. For example, a ``NestedFilters`` call might include a filter on
                the ``PropertyName`` parameter of the ``InputDataConfig`` property:
                ``InputDataConfig.DataSource.S3DataSource.S3Uri`` .

                - *(dict) --*

                  A conditional statement for a search expression that includes a resource property,
                  a Boolean operator, and a value.

                  If you don't specify an ``Operator`` and a ``Value`` , the filter searches for
                  only the specified property. For example, defining a ``Filter`` for the
                  ``FailureReason`` for the ``TrainingJob``  ``Resource`` searches for training job
                  objects that have a value in the ``FailureReason`` field.

                  If you specify a ``Value`` , but not an ``Operator`` , Amazon SageMaker uses the
                  equals operator as the default.

                  In search, there are several property types:

                    Metrics

                  To define a metric filter, enter a value using the form ``"Metrics.<name>"`` ,
                  where ``<name>`` is a metric name. For example, the following filter searches for
                  training jobs with an ``"accuracy"`` metric greater than ``"0.9"`` :

                   ``{``

                   ``"Name": "Metrics.accuracy",``

                   ``"Operator": "GREATER_THAN",``

                   ``"Value": "0.9"``

                   ``}``

                    HyperParameters

                  To define a hyperparameter filter, enter a value with the form
                  ``"HyperParameters.<name>"`` . Decimal hyperparameter values are treated as a
                  decimal in a comparison if the specified ``Value`` is also a decimal value. If the
                  specified ``Value`` is an integer, the decimal hyperparameter values are treated
                  as integers. For example, the following filter is satisfied by training jobs with
                  a ``"learning_rate"`` hyperparameter that is less than ``"0.5"`` :

                   ``{``

                   ``"Name": "HyperParameters.learning_rate",``

                   ``"Operator": "LESS_THAN",``

                   ``"Value": "0.5"``

                   ``}``

                    Tags

                  To define a tag filter, enter a value with the form ``"Tags.<key>"`` .

                  - **Name** *(string) --* **[REQUIRED]**

                    A property name. For example, ``TrainingJobName`` . For the list of valid
                    property names returned in a search result for each supported resource, see
                    TrainingJob properties. You must specify a valid property name for the resource.

                  - **Operator** *(string) --*

                    A Boolean binary operator that is used to evaluate the filter. The operator
                    field contains one of the following values:

                      Equals

                    The specified resource in ``Name`` equals the specified ``Value`` .

                      NotEquals

                    The specified resource in ``Name`` does not equal the specified ``Value`` .

                      GreaterThan

                    The specified resource in ``Name`` is greater than the specified ``Value`` . Not
                    supported for text-based properties.

                      GreaterThanOrEqualTo

                    The specified resource in ``Name`` is greater than or equal to the specified
                    ``Value`` . Not supported for text-based properties.

                      LessThan

                    The specified resource in ``Name`` is less than the specified ``Value`` . Not
                    supported for text-based properties.

                      LessThanOrEqualTo

                    The specified resource in ``Name`` is less than or equal to the specified
                    ``Value`` . Not supported for text-based properties.

                      Contains

                    Only supported for text-based properties. The word-list of the property contains
                    the specified ``Value`` . A ``SearchExpression`` can include only one
                    ``Contains`` operator.

                    If you have specified a filter ``Value`` , the default is ``Equals`` .

                  - **Value** *(string) --*

                    A value used with ``Resource`` and ``Operator`` to determine if objects satisfy
                    the filter's condition. For numerical properties, ``Value`` must be an integer
                    or floating-point decimal. For timestamp properties, ``Value`` must be an ISO
                    8601 date-time string of the following format: ``YYYY-mm-dd'T'HH:MM:SS`` .

          - **SubExpressions** *(list) --*

            A list of search expression objects.

            - *(dict) --*

              A multi-expression that searches for the specified resource or resources in a search.
              All resource objects that satisfy the expression's condition are included in the
              search results. You must specify at least one subexpression, filter, or nested filter.
              A ``SearchExpression`` can contain up to twenty elements.

              A ``SearchExpression`` contains the following components:

              * A list of ``Filter`` objects. Each filter defines a simple Boolean expression
              comprised of a resource property name, Boolean operator, and value. A
              ``SearchExpression`` can include only one ``Contains`` operator.

              * A list of ``NestedFilter`` objects. Each nested filter defines a list of Boolean
              expressions using a list of resource properties. A nested filter is satisfied if a
              single object in the list satisfies all Boolean expressions.

              * A list of ``SearchExpression`` objects. A search expression object can be nested in
              a list of search expression objects.

              * A Boolean operator: ``And`` or ``Or`` .

          - **Operator** *(string) --*

            A Boolean operator used to evaluate the search expression. If you want every conditional
            statement in all lists to be satisfied for the entire search expression to be true,
            specify ``And`` . If only a single conditional statement needs to be true for the entire
            search expression to be true, specify ``Or`` . The default value is ``And`` .

        :type SortBy: string
        :param SortBy:

          The name of the resource property used to sort the ``SearchResults`` . The default is
          ``LastModifiedTime`` .

        :type SortOrder: string
        :param SortOrder:

          How ``SearchResults`` are ordered. Valid values are ``Ascending`` or ``Descending`` . The
          default is ``Descending`` .

        :type NextToken: string
        :param NextToken:

          If more than ``MaxResults`` resource objects match the specified ``SearchExpression`` ,
          the ``SearchResponse`` includes a ``NextToken`` . The ``NextToken`` can be passed to the
          next ``SearchRequest`` to continue retrieving results for the specified
          ``SearchExpression`` and ``Sort`` parameters.

        :type MaxResults: integer
        :param MaxResults:

          The maximum number of results to return in a ``SearchResponse`` .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Results': [
                    {
                        'TrainingJob': {
                            'TrainingJobName': 'string',
                            'TrainingJobArn': 'string',
                            'TuningJobArn': 'string',
                            'LabelingJobArn': 'string',
                            'AutoMLJobArn': 'string',
                            'ModelArtifacts': {
                                'S3ModelArtifacts': 'string'
                            },
                            'TrainingJobStatus':
                            'InProgress'|'Completed'|'Failed'|'Stopping'
                            |'Stopped',
                            'SecondaryStatus':
                            'Starting'|'LaunchingMLInstances'
                            |'PreparingTrainingStack'|'Downloading'
                            |'DownloadingTrainingImage'|'Training'|'Uploading'
                            |'Stopping'|'Stopped'|'MaxRuntimeExceeded'
                            |'Completed'|'Failed'|'Interrupted'
                            |'MaxWaitTimeExceeded',
                            'FailureReason': 'string',
                            'HyperParameters': {
                                'string': 'string'
                            },
                            'AlgorithmSpecification': {
                                'TrainingImage': 'string',
                                'AlgorithmName': 'string',
                                'TrainingInputMode': 'Pipe'|'File',
                                'MetricDefinitions': [
                                    {
                                        'Name': 'string',
                                        'Regex': 'string'
                                    },
                                ],
                                'EnableSageMakerMetricsTimeSeries': True|False
                            },
                            'RoleArn': 'string',
                            'InputDataConfig': [
                                {
                                    'ChannelName': 'string',
                                    'DataSource': {
                                        'S3DataSource': {
                                            'S3DataType':
                                            'ManifestFile'
                                            |'S3Prefix'
                                            |'AugmentedManifestFile',
                                            'S3Uri': 'string',
                                            'S3DataDistributionType':
                                            'FullyReplicated'
                                            |'ShardedByS3Key',
                                            'AttributeNames': [
                                                'string',
                                            ]
                                        },
                                        'FileSystemDataSource': {
                                            'FileSystemId': 'string',
                                            'FileSystemAccessMode': 'rw'|'ro',
                                            'FileSystemType': 'EFS'|'FSxLustre',
                                            'DirectoryPath': 'string'
                                        }
                                    },
                                    'ContentType': 'string',
                                    'CompressionType': 'None'|'Gzip',
                                    'RecordWrapperType': 'None'|'RecordIO',
                                    'InputMode': 'Pipe'|'File',
                                    'ShuffleConfig': {
                                        'Seed': 123
                                    }
                                },
                            ],
                            'OutputDataConfig': {
                                'KmsKeyId': 'string',
                                'S3OutputPath': 'string'
                            },
                            'ResourceConfig': {
                                'InstanceType':
                                'ml.m4.xlarge'|'ml.m4.2xlarge'
                                |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                |'ml.m4.16xlarge'|'ml.m5.large'
                                |'ml.m5.xlarge'|'ml.m5.2xlarge'
                                |'ml.m5.4xlarge'|'ml.m5.12xlarge'
                                |'ml.m5.24xlarge'|'ml.c4.xlarge'
                                |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                |'ml.p3.16xlarge'|'ml.p3dn.24xlarge'
                                |'ml.c5.xlarge'|'ml.c5.2xlarge'
                                |'ml.c5.4xlarge'|'ml.c5.9xlarge'
                                |'ml.c5.18xlarge',
                                'InstanceCount': 123,
                                'VolumeSizeInGB': 123,
                                'VolumeKmsKeyId': 'string'
                            },
                            'VpcConfig': {
                                'SecurityGroupIds': [
                                    'string',
                                ],
                                'Subnets': [
                                    'string',
                                ]
                            },
                            'StoppingCondition': {
                                'MaxRuntimeInSeconds': 123,
                                'MaxWaitTimeInSeconds': 123
                            },
                            'CreationTime': datetime(2015, 1, 1),
                            'TrainingStartTime': datetime(2015, 1, 1),
                            'TrainingEndTime': datetime(2015, 1, 1),
                            'LastModifiedTime': datetime(2015, 1, 1),
                            'SecondaryStatusTransitions': [
                                {
                                    'Status':
                                    'Starting'|'LaunchingMLInstances'
                                    |'PreparingTrainingStack'
                                    |'Downloading'
                                    |'DownloadingTrainingImage'
                                    |'Training'|'Uploading'|'Stopping'
                                    |'Stopped'|'MaxRuntimeExceeded'
                                    |'Completed'|'Failed'|'Interrupted'
                                    |'MaxWaitTimeExceeded',
                                    'StartTime': datetime(2015, 1, 1),
                                    'EndTime': datetime(2015, 1, 1),
                                    'StatusMessage': 'string'
                                },
                            ],
                            'FinalMetricDataList': [
                                {
                                    'MetricName': 'string',
                                    'Value': ...,
                                    'Timestamp': datetime(2015, 1, 1)
                                },
                            ],
                            'EnableNetworkIsolation': True|False,
                            'EnableInterContainerTrafficEncryption': True|False,
                            'EnableManagedSpotTraining': True|False,
                            'CheckpointConfig': {
                                'S3Uri': 'string',
                                'LocalPath': 'string'
                            },
                            'TrainingTimeInSeconds': 123,
                            'BillableTimeInSeconds': 123,
                            'DebugHookConfig': {
                                'LocalPath': 'string',
                                'S3OutputPath': 'string',
                                'HookParameters': {
                                    'string': 'string'
                                },
                                'CollectionConfigurations': [
                                    {
                                        'CollectionName': 'string',
                                        'CollectionParameters': {
                                            'string': 'string'
                                        }
                                    },
                                ]
                            },
                            'ExperimentConfig': {
                                'ExperimentName': 'string',
                                'TrialName': 'string',
                                'TrialComponentDisplayName': 'string'
                            },
                            'DebugRuleConfigurations': [
                                {
                                    'RuleConfigurationName': 'string',
                                    'LocalPath': 'string',
                                    'S3OutputPath': 'string',
                                    'RuleEvaluatorImage': 'string',
                                    'InstanceType':
                                    'ml.t3.medium'|'ml.t3.large'
                                    |'ml.t3.xlarge'|'ml.t3.2xlarge'
                                    |'ml.m4.xlarge'|'ml.m4.2xlarge'
                                    |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                                    |'ml.m4.16xlarge'|'ml.c4.xlarge'
                                    |'ml.c4.2xlarge'|'ml.c4.4xlarge'
                                    |'ml.c4.8xlarge'|'ml.p2.xlarge'
                                    |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                                    |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                                    |'ml.p3.16xlarge'|'ml.c5.xlarge'
                                    |'ml.c5.2xlarge'|'ml.c5.4xlarge'
                                    |'ml.c5.9xlarge'|'ml.c5.18xlarge'
                                    |'ml.m5.large'|'ml.m5.xlarge'
                                    |'ml.m5.2xlarge'|'ml.m5.4xlarge'
                                    |'ml.m5.12xlarge'|'ml.m5.24xlarge'
                                    |'ml.r5.large'|'ml.r5.xlarge'
                                    |'ml.r5.2xlarge'|'ml.r5.4xlarge'
                                    |'ml.r5.8xlarge'|'ml.r5.12xlarge'
                                    |'ml.r5.16xlarge'|'ml.r5.24xlarge',
                                    'VolumeSizeInGB': 123,
                                    'RuleParameters': {
                                        'string': 'string'
                                    }
                                },
                            ],
                            'TensorBoardOutputConfig': {
                                'LocalPath': 'string',
                                'S3OutputPath': 'string'
                            },
                            'DebugRuleEvaluationStatuses': [
                                {
                                    'RuleConfigurationName': 'string',
                                    'RuleEvaluationJobArn': 'string',
                                    'RuleEvaluationStatus':
                                    'InProgress'|'NoIssuesFound'
                                    |'IssuesFound'|'Error'|'Stopping'
                                    |'Stopped',
                                    'StatusDetails': 'string',
                                    'LastModifiedTime': datetime(2015, 1, 1)
                                },
                            ],
                            'Tags': [
                                {
                                    'Key': 'string',
                                    'Value': 'string'
                                },
                            ]
                        },
                        'Experiment': {
                            'ExperimentName': 'string',
                            'ExperimentArn': 'string',
                            'DisplayName': 'string',
                            'Source': {
                                'SourceArn': 'string',
                                'SourceType': 'string'
                            },
                            'Description': 'string',
                            'CreationTime': datetime(2015, 1, 1),
                            'CreatedBy': {
                                'UserProfileArn': 'string',
                                'UserProfileName': 'string',
                                'DomainId': 'string'
                            },
                            'LastModifiedTime': datetime(2015, 1, 1),
                            'LastModifiedBy': {
                                'UserProfileArn': 'string',
                                'UserProfileName': 'string',
                                'DomainId': 'string'
                            },
                            'Tags': [
                                {
                                    'Key': 'string',
                                    'Value': 'string'
                                },
                            ]
                        },
                        'Trial': {
                            'TrialName': 'string',
                            'TrialArn': 'string',
                            'DisplayName': 'string',
                            'ExperimentName': 'string',
                            'Source': {
                                'SourceArn': 'string',
                                'SourceType': 'string'
                            },
                            'CreationTime': datetime(2015, 1, 1),
                            'CreatedBy': {
                                'UserProfileArn': 'string',
                                'UserProfileName': 'string',
                                'DomainId': 'string'
                            },
                            'LastModifiedTime': datetime(2015, 1, 1),
                            'LastModifiedBy': {
                                'UserProfileArn': 'string',
                                'UserProfileName': 'string',
                                'DomainId': 'string'
                            },
                            'Tags': [
                                {
                                    'Key': 'string',
                                    'Value': 'string'
                                },
                            ],
                            'TrialComponentSummaries': [
                                {
                                    'TrialComponentName': 'string',
                                    'TrialComponentArn': 'string',
                                    'TrialComponentSource': {
                                        'SourceArn': 'string',
                                        'SourceType': 'string'
                                    },
                                    'CreationTime': datetime(2015, 1, 1),
                                    'CreatedBy': {
                                        'UserProfileArn': 'string',
                                        'UserProfileName': 'string',
                                        'DomainId': 'string'
                                    }
                                },
                            ]
                        },
                        'TrialComponent': {
                            'TrialComponentName': 'string',
                            'DisplayName': 'string',
                            'TrialComponentArn': 'string',
                            'Source': {
                                'SourceArn': 'string',
                                'SourceType': 'string'
                            },
                            'Status': {
                                'PrimaryStatus': 'InProgress'|'Completed'|'Failed',
                                'Message': 'string'
                            },
                            'StartTime': datetime(2015, 1, 1),
                            'EndTime': datetime(2015, 1, 1),
                            'CreationTime': datetime(2015, 1, 1),
                            'CreatedBy': {
                                'UserProfileArn': 'string',
                                'UserProfileName': 'string',
                                'DomainId': 'string'
                            },
                            'LastModifiedTime': datetime(2015, 1, 1),
                            'LastModifiedBy': {
                                'UserProfileArn': 'string',
                                'UserProfileName': 'string',
                                'DomainId': 'string'
                            },
                            'Parameters': {
                                'string': {
                                    'StringValue': 'string',
                                    'NumberValue': 123.0
                                }
                            },
                            'InputArtifacts': {
                                'string': {
                                    'MediaType': 'string',
                                    'Value': 'string'
                                }
                            },
                            'OutputArtifacts': {
                                'string': {
                                    'MediaType': 'string',
                                    'Value': 'string'
                                }
                            },
                            'Metrics': [
                                {
                                    'MetricName': 'string',
                                    'SourceArn': 'string',
                                    'TimeStamp': datetime(2015, 1, 1),
                                    'Max': 123.0,
                                    'Min': 123.0,
                                    'Last': 123.0,
                                    'Count': 123,
                                    'Avg': 123.0,
                                    'StdDev': 123.0
                                },
                            ],
                            'SourceDetail': {
                                'SourceArn': 'string',
                                'TrainingJob': {
                                    'TrainingJobName': 'string',
                                    'TrainingJobArn': 'string',
                                    'TuningJobArn': 'string',
                                    'LabelingJobArn': 'string',
                                    'AutoMLJobArn': 'string',
                                    'ModelArtifacts': {
                                        'S3ModelArtifacts': 'string'
                                    },
                                    'TrainingJobStatus':
                                    'InProgress'|'Completed'|'Failed'
                                    |'Stopping'|'Stopped',
                                    'SecondaryStatus':
                                    'Starting'|'LaunchingMLInstances'
                                    |'PreparingTrainingStack'
                                    |'Downloading'
                                    |'DownloadingTrainingImage'
                                    |'Training'|'Uploading'|'Stopping'
                                    |'Stopped'|'MaxRuntimeExceeded'
                                    |'Completed'|'Failed'|'Interrupted'
                                    |'MaxWaitTimeExceeded',
                                    'FailureReason': 'string',
                                    'HyperParameters': {
                                        'string': 'string'
                                    },
                                    'AlgorithmSpecification': {
                                        'TrainingImage': 'string',
                                        'AlgorithmName': 'string',
                                        'TrainingInputMode': 'Pipe'|'File',
                                        'MetricDefinitions': [
                                            {
                                                'Name': 'string',
                                                'Regex': 'string'
                                            },
                                        ],
                                        'EnableSageMakerMetricsTimeSeries': True|False
                                    },
                                    'RoleArn': 'string',
                                    'InputDataConfig': [
                                        {
                                            'ChannelName': 'string',
                                            'DataSource': {
                                                'S3DataSource': {
                                                    'S3DataType':
                                                    'ManifestFile'|'S3Prefix'
                                                    |'AugmentedManifestFile',
                                                    'S3Uri': 'string',
                                                    'S3DataDistributionType':
                                                    'FullyReplicated'
                                                    |'ShardedByS3Key',
                                                    'AttributeNames': [
                                                        'string',
                                                    ]
                                                },
                                                'FileSystemDataSource': {
                                                    'FileSystemId': 'string',
                                                    'FileSystemAccessMode': 'rw'|'ro',
                                                    'FileSystemType': 'EFS'|'FSxLustre',
                                                    'DirectoryPath': 'string'
                                                }
                                            },
                                            'ContentType': 'string',
                                            'CompressionType': 'None'|'Gzip',
                                            'RecordWrapperType': 'None'|'RecordIO',
                                            'InputMode': 'Pipe'|'File',
                                            'ShuffleConfig': {
                                                'Seed': 123
                                            }
                                        },
                                    ],
                                    'OutputDataConfig': {
                                        'KmsKeyId': 'string',
                                        'S3OutputPath': 'string'
                                    },
                                    'ResourceConfig': {
                                        'InstanceType':
                                        'ml.m4.xlarge'
                                        |'ml.m4.2xlarge'
                                        |'ml.m4.4xlarge'
                                        |'ml.m4.10xlarge'
                                        |'ml.m4.16xlarge'
                                        |'ml.m5.large'
                                        |'ml.m5.xlarge'
                                        |'ml.m5.2xlarge'
                                        |'ml.m5.4xlarge'
                                        |'ml.m5.12xlarge'
                                        |'ml.m5.24xlarge'
                                        |'ml.c4.xlarge'
                                        |'ml.c4.2xlarge'
                                        |'ml.c4.4xlarge'
                                        |'ml.c4.8xlarge'
                                        |'ml.p2.xlarge'
                                        |'ml.p2.8xlarge'
                                        |'ml.p2.16xlarge'
                                        |'ml.p3.2xlarge'
                                        |'ml.p3.8xlarge'
                                        |'ml.p3.16xlarge'
                                        |'ml.p3dn.24xlarge'
                                        |'ml.c5.xlarge'
                                        |'ml.c5.2xlarge'
                                        |'ml.c5.4xlarge'
                                        |'ml.c5.9xlarge'
                                        |'ml.c5.18xlarge',
                                        'InstanceCount': 123,
                                        'VolumeSizeInGB': 123,
                                        'VolumeKmsKeyId': 'string'
                                    },
                                    'VpcConfig': {
                                        'SecurityGroupIds': [
                                            'string',
                                        ],
                                        'Subnets': [
                                            'string',
                                        ]
                                    },
                                    'StoppingCondition': {
                                        'MaxRuntimeInSeconds': 123,
                                        'MaxWaitTimeInSeconds': 123
                                    },
                                    'CreationTime': datetime(2015, 1, 1),
                                    'TrainingStartTime': datetime(2015, 1, 1),
                                    'TrainingEndTime': datetime(2015, 1, 1),
                                    'LastModifiedTime': datetime(2015, 1, 1),
                                    'SecondaryStatusTransitions': [
                                        {
                                            'Status':
                                            'Starting'
                                            |'LaunchingMLInstances'|'PreparingTrainingStack'|'Downloading'|'DownloadingTrainingImage'|'Training'|'Uploading'|'Stopping'|'Stopped'|'MaxRuntimeExceeded'|'Completed'|'Failed'|'Interrupted'
                                            |'MaxWaitTimeExceeded',
                                            'StartTime': datetime(2015, 1, 1),
                                            'EndTime': datetime(2015, 1, 1),
                                            'StatusMessage': 'string'
                                        },
                                    ],
                                    'FinalMetricDataList': [
                                        {
                                            'MetricName': 'string',
                                            'Value': ...,
                                            'Timestamp': datetime(2015, 1, 1)
                                        },
                                    ],
                                    'EnableNetworkIsolation': True|False,
                                    'EnableInterContainerTrafficEncryption': True|False,
                                    'EnableManagedSpotTraining': True|False,
                                    'CheckpointConfig': {
                                        'S3Uri': 'string',
                                        'LocalPath': 'string'
                                    },
                                    'TrainingTimeInSeconds': 123,
                                    'BillableTimeInSeconds': 123,
                                    'DebugHookConfig': {
                                        'LocalPath': 'string',
                                        'S3OutputPath': 'string',
                                        'HookParameters': {
                                            'string': 'string'
                                        },
                                        'CollectionConfigurations': [
                                            {
                                                'CollectionName': 'string',
                                                'CollectionParameters': {
                                                    'string': 'string'
                                                }
                                            },
                                        ]
                                    },
                                    'ExperimentConfig': {
                                        'ExperimentName': 'string',
                                        'TrialName': 'string',
                                        'TrialComponentDisplayName': 'string'
                                    },
                                    'DebugRuleConfigurations': [
                                        {
                                            'RuleConfigurationName': 'string',
                                            'LocalPath': 'string',
                                            'S3OutputPath': 'string',
                                            'RuleEvaluatorImage': 'string',
                                            'InstanceType':
                                            'ml.t3.medium'
                                            |'ml.t3.large'
                                            |'ml.t3.xlarge'
                                            |'ml.t3.2xlarge'
                                            |'ml.m4.xlarge'
                                            |'ml.m4.2xlarge'
                                            |'ml.m4.4xlarge'
                                            |'ml.m4.10xlarge'
                                            |'ml.m4.16xlarge'
                                            |'ml.c4.xlarge'
                                            |'ml.c4.2xlarge'
                                            |'ml.c4.4xlarge'
                                            |'ml.c4.8xlarge'
                                            |'ml.p2.xlarge'
                                            |'ml.p2.8xlarge'
                                            |'ml.p2.16xlarge'
                                            |'ml.p3.2xlarge'
                                            |'ml.p3.8xlarge'
                                            |'ml.p3.16xlarge'
                                            |'ml.c5.xlarge'
                                            |'ml.c5.2xlarge'
                                            |'ml.c5.4xlarge'
                                            |'ml.c5.9xlarge'
                                            |'ml.c5.18xlarge'
                                            |'ml.m5.large'
                                            |'ml.m5.xlarge'
                                            |'ml.m5.2xlarge'
                                            |'ml.m5.4xlarge'
                                            |'ml.m5.12xlarge'
                                            |'ml.m5.24xlarge'
                                            |'ml.r5.large'
                                            |'ml.r5.xlarge'
                                            |'ml.r5.2xlarge'
                                            |'ml.r5.4xlarge'
                                            |'ml.r5.8xlarge'
                                            |'ml.r5.12xlarge'
                                            |'ml.r5.16xlarge'
                                            |'ml.r5.24xlarge',
                                            'VolumeSizeInGB': 123,
                                            'RuleParameters': {
                                                'string': 'string'
                                            }
                                        },
                                    ],
                                    'TensorBoardOutputConfig': {
                                        'LocalPath': 'string',
                                        'S3OutputPath': 'string'
                                    },
                                    'DebugRuleEvaluationStatuses': [
                                        {
                                            'RuleConfigurationName': 'string',
                                            'RuleEvaluationJobArn': 'string',
                                            'RuleEvaluationStatus':
                                            'InProgress'
                                            |'NoIssuesFound'
                                            |'IssuesFound'
                                            |'Error'|'Stopping'
                                            |'Stopped',
                                            'StatusDetails': 'string',
                                            'LastModifiedTime': datetime(2015, 1, 1)
                                        },
                                    ],
                                    'Tags': [
                                        {
                                            'Key': 'string',
                                            'Value': 'string'
                                        },
                                    ]
                                }
                            },
                            'Tags': [
                                {
                                    'Key': 'string',
                                    'Value': 'string'
                                },
                            ],
                            'Parents': [
                                {
                                    'TrialName': 'string',
                                    'ExperimentName': 'string'
                                },
                            ]
                        }
                    },
                ],
                'NextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **Results** *(list) --*

              A list of ``SearchResult`` objects.

              - *(dict) --*

                An individual search result record that contains a single resource object.

                - **TrainingJob** *(dict) --*

                  A ``TrainingJob`` object that is returned as part of a ``Search`` request.

                  - **TrainingJobName** *(string) --*

                    The name of the training job.

                  - **TrainingJobArn** *(string) --*

                    The Amazon Resource Name (ARN) of the training job.

                  - **TuningJobArn** *(string) --*

                    The Amazon Resource Name (ARN) of the associated hyperparameter tuning job if
                    the training job was launched by a hyperparameter tuning job.

                  - **LabelingJobArn** *(string) --*

                    The Amazon Resource Name (ARN) of the labeling job.

                  - **AutoMLJobArn** *(string) --*

                    The Amazon Resource Name (ARN) of the job.

                  - **ModelArtifacts** *(dict) --*

                    Information about the Amazon S3 location that is configured for storing model
                    artifacts.

                    - **S3ModelArtifacts** *(string) --*

                      The path of the S3 object that contains the model artifacts. For example,
                      ``s3://bucket-name/keynameprefix/model.tar.gz`` .

                  - **TrainingJobStatus** *(string) --*

                    The status of the training job.

                    Training job statuses are:

                    * ``InProgress`` - The training is in progress.

                    * ``Completed`` - The training job has completed.

                    * ``Failed`` - The training job has failed. To see the reason for the failure,
                    see the ``FailureReason`` field in the response to a
                    ``DescribeTrainingJobResponse`` call.

                    * ``Stopping`` - The training job is stopping.

                    * ``Stopped`` - The training job has stopped.

                    For more detailed information, see ``SecondaryStatus`` .

                  - **SecondaryStatus** *(string) --*

                    Provides detailed information about the state of the training job. For detailed
                    information about the secondary status of the training job, see
                    ``StatusMessage`` under  SecondaryStatusTransition .

                    Amazon SageMaker provides primary statuses and secondary statuses that apply to
                    each of them:

                      InProgress

                    * ``Starting`` - Starting the training job.

                    * ``Downloading`` - An optional stage for algorithms that support ``File``
                    training input mode. It indicates that data is being downloaded to the ML
                    storage volumes.

                    * ``Training`` - Training is in progress.

                    * ``Uploading`` - Training is complete and the model artifacts are being
                    uploaded to the S3 location.

                      Completed

                    * ``Completed`` - The training job has completed.

                      Failed

                    * ``Failed`` - The training job has failed. The reason for the failure is
                    returned in the ``FailureReason`` field of ``DescribeTrainingJobResponse`` .

                      Stopped

                    * ``MaxRuntimeExceeded`` - The job stopped because it exceeded the maximum
                    allowed runtime.

                    * ``Stopped`` - The training job has stopped.

                      Stopping

                    * ``Stopping`` - Stopping the training job.

                    .. warning::

                      Valid values for ``SecondaryStatus`` are subject to change.

                    We no longer support the following secondary statuses:

                    * ``LaunchingMLInstances``

                    * ``PreparingTrainingStack``

                    * ``DownloadingTrainingImage``

                  - **FailureReason** *(string) --*

                    If the training job failed, the reason it failed.

                  - **HyperParameters** *(dict) --*

                    Algorithm-specific parameters.

                    - *(string) --*

                      - *(string) --*

                  - **AlgorithmSpecification** *(dict) --*

                    Information about the algorithm used for training, and algorithm metadata.

                    - **TrainingImage** *(string) --*

                      The registry path of the Docker image that contains the training algorithm.
                      For information about docker registry paths for built-in algorithms, see
                      `Algorithms Provided by Amazon SageMaker\\: Common Parameters
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                      . Amazon SageMaker supports both ``registry/repository[:tag]`` and
                      ``registry/repository[@digest]`` image path formats. For more information, see
                      `Using Your Own Algorithms with Amazon SageMaker
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__ .

                    - **AlgorithmName** *(string) --*

                      The name of the algorithm resource to use for the training job. This must be
                      an algorithm resource that you created or subscribe to on AWS Marketplace. If
                      you specify a value for this parameter, you can't specify a value for
                      ``TrainingImage`` .

                    - **TrainingInputMode** *(string) --*

                      The input mode that the algorithm supports. For the input modes that Amazon
                      SageMaker algorithms support, see `Algorithms
                      <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ . If an
                      algorithm supports the ``File`` input mode, Amazon SageMaker downloads the
                      training data from S3 to the provisioned ML storage Volume, and mounts the
                      directory to docker volume for training container. If an algorithm supports
                      the ``Pipe`` input mode, Amazon SageMaker streams data directly from S3 to the
                      container.

                      In File mode, make sure you provision ML storage volume with sufficient
                      capacity to accommodate the data download from S3. In addition to the training
                      data, the ML storage volume also stores the output model. The algorithm
                      container use ML storage volume to also store intermediate information, if
                      any.

                      For distributed algorithms using File mode, training data is distributed
                      uniformly, and your training duration is predictable if the input data objects
                      size is approximately same. Amazon SageMaker does not split the files any
                      further for model training. If the object sizes are skewed, training won't be
                      optimal as the data distribution is also skewed where one host in a training
                      cluster is overloaded, thus becoming bottleneck in training.

                    - **MetricDefinitions** *(list) --*

                      A list of metric definition objects. Each object specifies the metric name and
                      regular expressions used to parse algorithm logs. Amazon SageMaker publishes
                      each metric to Amazon CloudWatch.

                      - *(dict) --*

                        Specifies a metric that the training algorithm writes to ``stderr`` or
                        ``stdout`` . Amazon SageMakerhyperparameter tuning captures all defined
                        metrics. You specify one metric that a hyperparameter tuning job uses as its
                        objective metric to choose the best training job.

                        - **Name** *(string) --*

                          The name of the metric.

                        - **Regex** *(string) --*

                          A regular expression that searches the output of a training job and gets
                          the value of the metric. For more information about using regular
                          expressions to define metrics, see `Defining Objective Metrics
                          <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                          .

                    - **EnableSageMakerMetricsTimeSeries** *(boolean) --*

                      To generate and save time-series metrics during training, set to ``true`` .
                      The default is ``false`` and time-series metrics aren't generated except in
                      the following cases:

                      * You use one of the Amazon SageMaker built-in algorithms

                      * You use one of the following prebuilt Amazon SageMaker Docker images:

                        * Tensorflow

                        * MXNet

                        * PyTorch

                      * You specify at least one  MetricDefinition

                  - **RoleArn** *(string) --*

                    The AWS Identity and Access Management (IAM) role configured for the training
                    job.

                  - **InputDataConfig** *(list) --*

                    An array of ``Channel`` objects that describes each data input channel.

                    - *(dict) --*

                      A channel is a named input source that training algorithms can consume.

                      - **ChannelName** *(string) --*

                        The name of the channel.

                      - **DataSource** *(dict) --*

                        The location of the channel data.

                        - **S3DataSource** *(dict) --*

                          The S3 location of the data source that is associated with a channel.

                          - **S3DataType** *(string) --*

                            If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix.
                            Amazon SageMaker uses all objects that match the specified key name
                            prefix for model training.

                            If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that is
                            a manifest file containing a list of object keys that you want Amazon
                            SageMaker to use for model training.

                            If you choose ``AugmentedManifestFile`` , S3Uri identifies an object
                            that is an augmented manifest file in JSON lines format. This file
                            contains the data you want to use for model training.
                            ``AugmentedManifestFile`` can only be used if the Channel's input mode
                            is ``Pipe`` .

                          - **S3Uri** *(string) --*

                            Depending on the value specified for the ``S3DataType`` , identifies
                            either a key name prefix or a manifest. For example:

                            * A key name prefix might look like this:
                            ``s3://bucketname/exampleprefix`` .

                            * A manifest might look like this: ``s3://bucketname/example.manifest``
                            The manifest is an S3 object which is a JSON file with the following
                            format:  The preceding JSON matches the following ``s3Uris`` :   ``[
                            {"prefix": "s3://customer_bucket/some/prefix/"},``
                            ``"relative/path/to/custdata-1",``    ``"relative/path/custdata-2",``
                            ``...``    ``"relative/path/custdata-N"``    ``]``   The preceding JSON
                            matches the following ``s3Uris`` :
                            ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                            ``s3://customer_bucket/some/prefix/relative/path/custdata-2``    ``...``
                            ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The
                            complete set of ``s3uris`` in this manifest is the input data for the
                            channel for this datasource. The object that each ``s3uris`` points to
                            must be readable by the IAM role that Amazon SageMaker uses to perform
                            tasks on your behalf.

                          - **S3DataDistributionType** *(string) --*

                            If you want Amazon SageMaker to replicate the entire dataset on each ML
                            compute instance that is launched for model training, specify
                            ``FullyReplicated`` .

                            If you want Amazon SageMaker to replicate a subset of data on each ML
                            compute instance that is launched for model training, specify
                            ``ShardedByS3Key`` . If there are *n* ML compute instances launched for
                            a training job, each instance gets approximately 1/*n* of the number of
                            S3 objects. In this case, model training on each machine uses only the
                            subset of training data.

                            Don't choose more ML compute instances for training than available S3
                            objects. If you do, some nodes won't get any data and you will pay for
                            nodes that aren't getting any training data. This applies in both File
                            and Pipe modes. Keep this in mind when developing algorithms.

                            In distributed training, where you use multiple ML compute EC2
                            instances, you might choose ``ShardedByS3Key`` . If the algorithm
                            requires copying training data to the ML storage volume (when
                            ``TrainingInputMode`` is set to ``File`` ), this copies 1/*n* of the
                            number of objects.

                          - **AttributeNames** *(list) --*

                            A list of one or more attribute names to use that are found in a
                            specified augmented manifest file.

                            - *(string) --*

                        - **FileSystemDataSource** *(dict) --*

                          The file system that is associated with a channel.

                          - **FileSystemId** *(string) --*

                            The file system id.

                          - **FileSystemAccessMode** *(string) --*

                            The access mode of the mount of the directory associated with the
                            channel. A directory can be mounted either in ``ro`` (read-only) or
                            ``rw`` (read-write) mode.

                          - **FileSystemType** *(string) --*

                            The file system type.

                          - **DirectoryPath** *(string) --*

                            The full path to the directory to associate with the channel.

                      - **ContentType** *(string) --*

                        The MIME type of the data.

                      - **CompressionType** *(string) --*

                        If training data is compressed, the compression type. The default value is
                        ``None`` . ``CompressionType`` is used only in Pipe input mode. In File
                        mode, leave this field unset or set it to None.

                      - **RecordWrapperType** *(string) --*

                        Specify RecordIO as the value when input data is in raw format but the
                        training algorithm requires the RecordIO format. In this case, Amazon
                        SageMaker wraps each individual S3 object in a RecordIO record. If the input
                        data is already in RecordIO format, you don't need to set this attribute.
                        For more information, see `Create a Dataset Using RecordIO
                        <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__
                        .

                        In File mode, leave this field unset or set it to None.

                      - **InputMode** *(string) --*

                        (Optional) The input mode to use for the data channel in a training job. If
                        you don't set a value for ``InputMode`` , Amazon SageMaker uses the value
                        set for ``TrainingInputMode`` . Use this parameter to override the
                        ``TrainingInputMode`` setting in a  AlgorithmSpecification request when you
                        have a channel that needs a different input mode from the training job's
                        general setting. To download the data from Amazon Simple Storage Service
                        (Amazon S3) to the provisioned ML storage volume, and mount the directory to
                        a Docker volume, use ``File`` input mode. To stream data directly from
                        Amazon S3 to the container, choose ``Pipe`` input mode.

                        To use a model for incremental training, choose ``File`` input model.

                      - **ShuffleConfig** *(dict) --*

                        A configuration for a shuffle option for input data in a channel. If you use
                        ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the S3 key
                        prefix matches. If you use ``ManifestFile`` , the order of the S3 object
                        references in the ``ManifestFile`` is shuffled. If you use
                        ``AugmentedManifestFile`` , the order of the JSON lines in the
                        ``AugmentedManifestFile`` is shuffled. The shuffling order is determined
                        using the ``Seed`` value.

                        For Pipe input mode, shuffling is done at the start of every epoch. With
                        large datasets this ensures that the order of the training data is different
                        for each epoch, it helps reduce bias and possible overfitting. In a
                        multi-node training job when ShuffleConfig is combined with
                        ``S3DataDistributionType`` of ``ShardedByS3Key`` , the data is shuffled
                        across nodes so that the content sent to a particular node on the first
                        epoch might be sent to a different node on the second epoch.

                        - **Seed** *(integer) --*

                          Determines the shuffling order in ``ShuffleConfig`` value.

                  - **OutputDataConfig** *(dict) --*

                    The S3 path where model artifacts that you configured when creating the job are
                    stored. Amazon SageMaker creates subfolders for model artifacts.

                    - **KmsKeyId** *(string) --*

                      The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                      encrypt the model artifacts at rest using Amazon S3 server-side encryption.
                      The ``KmsKeyId`` can be any of the following formats:

                      * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                      * // Amazon Resource Name (ARN) of a KMS Key
                      ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                      * // KMS Key Alias  ``"alias/ExampleAlias"``

                      * // Amazon Resource Name (ARN) of a KMS Key Alias
                      ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                      If you use a KMS key ID or an alias of your master key, the Amazon SageMaker
                      execution role must include permissions to call ``kms:Encrypt`` . If you don't
                      provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3
                      for your role's account. Amazon SageMaker uses server-side encryption with
                      KMS-managed keys for ``OutputDataConfig`` . If you use a bucket policy with an
                      ``s3:PutObject`` permission that only allows objects with server-side
                      encryption, set the condition key of ``s3:x-amz-server-side-encryption`` to
                      ``"aws:kms"`` . For more information, see `KMS-Managed Encryption Keys
                      <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__
                      in the *Amazon Simple Storage Service Developer Guide.*

                      The KMS key policy must grant permission to the IAM role that you specify in
                      your ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                      ``CreateHyperParameterTuningJob`` requests. For more information, see `Using
                      Key Policies in AWS KMS
                      <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__ in
                      the *AWS Key Management Service Developer Guide* .

                    - **S3OutputPath** *(string) --*

                      Identifies the S3 path where you want Amazon SageMaker to store the model
                      artifacts. For example, ``s3://bucket-name/key-name-prefix`` .

                  - **ResourceConfig** *(dict) --*

                    Resources, including ML compute instances and ML storage volumes, that are
                    configured for model training.

                    - **InstanceType** *(string) --*

                      The ML compute instance type.

                    - **InstanceCount** *(integer) --*

                      The number of ML compute instances to use. For distributed training, provide a
                      value greater than 1.

                    - **VolumeSizeInGB** *(integer) --*

                      The size of the ML storage volume that you want to provision.

                      ML storage volumes store model artifacts and incremental states. Training
                      algorithms might also use the ML storage volume for scratch space. If you want
                      to store the training data in the ML storage volume, choose ``File`` as the
                      ``TrainingInputMode`` in the algorithm specification.

                      You must specify sufficient ML storage for your scenario.

                      .. note::

                        Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage
                        volume type.

                      .. note::

                        Certain Nitro-based instances include local storage with a fixed total size,
                        dependent on the instance type. When using these instances for training,
                        Amazon SageMaker mounts the local instance storage instead of Amazon EBS gp2
                        storage. You can't request a ``VolumeSizeInGB`` greater than the total size
                        of the local instance storage.

                        For a list of instance types that support local instance storage, including
                        the total size per instance type, see `Instance Store Volumes
                        <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                        .

                    - **VolumeKmsKeyId** *(string) --*

                      The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage
                      volume attached to the ML compute instance(s) that run the training job.

                      .. note::

                        Certain Nitro-based instances include local storage, dependent on the
                        instance type. Local storage volumes are encrypted using a hardware module
                        on the instance. You can't request a ``VolumeKmsKeyId`` when using an
                        instance type with local storage.

                        For a list of instance types that support local instance storage, see
                        `Instance Store Volumes
                        <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                        .

                        For more information about local instance storage encryption, see `SSD
                        Instance Store Volumes
                        <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__
                        .

                      The ``VolumeKmsKeyId`` can be in any of the following formats:

                      * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                      * // Amazon Resource Name (ARN) of a KMS Key
                      ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                  - **VpcConfig** *(dict) --*

                    A  VpcConfig object that specifies the VPC that this training job has access to.
                    For more information, see `Protect Training Jobs by Using an Amazon Virtual
                    Private Cloud
                    <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                    - **SecurityGroupIds** *(list) --*

                      The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security
                      groups for the VPC that is specified in the ``Subnets`` field.

                      - *(string) --*

                    - **Subnets** *(list) --*

                      The ID of the subnets in the VPC to which you want to connect your training
                      job or model.

                      .. note::

                        Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                        availability zones of region us-east-1. If you want to create endpoints with
                        P3 instances in VPC mode in region us-east-1, create subnets in a/b/f
                        availability zones instead.

                      - *(string) --*

                  - **StoppingCondition** *(dict) --*

                    Specifies a limit to how long a model training job can run. When the job reaches
                    the time limit, Amazon SageMaker ends the training job. Use this API to cap
                    model training costs.

                    To stop a job, Amazon SageMaker sends the algorithm the ``SIGTERM`` signal,
                    which delays job termination for 120 seconds. Algorithms can use this 120-second
                    window to save the model artifacts, so the results of training are not lost.

                    - **MaxRuntimeInSeconds** *(integer) --*

                      The maximum length of time, in seconds, that the training or compilation job
                      can run. If job does not complete during this time, Amazon SageMaker ends the
                      job. If value is not specified, default value is 1 day. The maximum value is
                      28 days.

                    - **MaxWaitTimeInSeconds** *(integer) --*

                      The maximum length of time, in seconds, how long you are willing to wait for a
                      managed spot training job to complete. It is the amount of time spent waiting
                      for Spot capacity plus the amount of time the training job runs. It must be
                      equal to or greater than ``MaxRuntimeInSeconds`` .

                  - **CreationTime** *(datetime) --*

                    A timestamp that indicates when the training job was created.

                  - **TrainingStartTime** *(datetime) --*

                    Indicates the time when the training job starts on training instances. You are
                    billed for the time interval between this time and the value of
                    ``TrainingEndTime`` . The start time in CloudWatch Logs might be later than this
                    time. The difference is due to the time it takes to download the training data
                    and to the size of the training container.

                  - **TrainingEndTime** *(datetime) --*

                    Indicates the time when the training job ends on training instances. You are
                    billed for the time interval between the value of ``TrainingStartTime`` and this
                    time. For successful jobs and stopped jobs, this is the time after model
                    artifacts are uploaded. For failed jobs, this is the time when Amazon SageMaker
                    detects a job failure.

                  - **LastModifiedTime** *(datetime) --*

                    A timestamp that indicates when the status of the training job was last
                    modified.

                  - **SecondaryStatusTransitions** *(list) --*

                    A history of all of the secondary statuses that the training job has
                    transitioned through.

                    - *(dict) --*

                      An array element of  DescribeTrainingJobResponse$SecondaryStatusTransitions .
                      It provides additional details about a status that the training job has
                      transitioned through. A training job can be in one of several states, for
                      example, starting, downloading, training, or uploading. Within each state,
                      there are a number of intermediate states. For example, within the starting
                      state, Amazon SageMaker could be starting the training job or launching the ML
                      instances. These transitional states are referred to as the job's secondary
                      status.

                      - **Status** *(string) --*

                        Contains a secondary status information from a training job.

                        Status might be one of the following secondary statuses:

                          InProgress

                        * ``Starting`` - Starting the training job.

                        * ``Downloading`` - An optional stage for algorithms that support ``File``
                        training input mode. It indicates that data is being downloaded to the ML
                        storage volumes.

                        * ``Training`` - Training is in progress.

                        * ``Uploading`` - Training is complete and the model artifacts are being
                        uploaded to the S3 location.

                          Completed

                        * ``Completed`` - The training job has completed.

                          Failed

                        * ``Failed`` - The training job has failed. The reason for the failure is
                        returned in the ``FailureReason`` field of ``DescribeTrainingJobResponse`` .

                          Stopped

                        * ``MaxRuntimeExceeded`` - The job stopped because it exceeded the maximum
                        allowed runtime.

                        * ``Stopped`` - The training job has stopped.

                          Stopping

                        * ``Stopping`` - Stopping the training job.

                        We no longer support the following secondary statuses:

                        * ``LaunchingMLInstances``

                        * ``PreparingTrainingStack``

                        * ``DownloadingTrainingImage``

                      - **StartTime** *(datetime) --*

                        A timestamp that shows when the training job transitioned to the current
                        secondary status state.

                      - **EndTime** *(datetime) --*

                        A timestamp that shows when the training job transitioned out of this
                        secondary status state into another secondary status state or when the
                        training job has ended.

                      - **StatusMessage** *(string) --*

                        A detailed description of the progress within a secondary status.

                        Amazon SageMaker provides secondary statuses and status messages that apply
                        to each of them:

                          Starting

                        * Starting the training job.

                        * Launching requested ML instances.

                        * Insufficient capacity error from EC2 while launching instances, retrying!

                        * Launched instance was unhealthy, replacing it!

                        * Preparing the instances for training.

                          Training

                        * Downloading the training image.

                        * Training image download completed. Training in progress.

                        .. warning::

                          Status messages are subject to change. Therefore, we recommend not
                          including them in code that programmatically initiates actions. For
                          examples, don't use status messages in if statements.

                        To have an overview of your training job's progress, view
                        ``TrainingJobStatus`` and ``SecondaryStatus`` in  DescribeTrainingJob , and
                        ``StatusMessage`` together. For example, at the start of a training job, you
                        might see the following:

                        * ``TrainingJobStatus`` - InProgress

                        * ``SecondaryStatus`` - Training

                        * ``StatusMessage`` - Downloading the training image

                  - **FinalMetricDataList** *(list) --*

                    A list of final metric values that are set when the training job completes. Used
                    only if the training job was configured to use metrics.

                    - *(dict) --*

                      The name, value, and date and time of a metric that was emitted to Amazon
                      CloudWatch.

                      - **MetricName** *(string) --*

                        The name of the metric.

                      - **Value** *(float) --*

                        The value of the metric.

                      - **Timestamp** *(datetime) --*

                        The date and time that the algorithm emitted the metric.

                  - **EnableNetworkIsolation** *(boolean) --*

                    If the ``TrainingJob`` was created with network isolation, the value is set to
                    ``true`` . If network isolation is enabled, nodes can't communicate beyond the
                    VPC they run in.

                  - **EnableInterContainerTrafficEncryption** *(boolean) --*

                    To encrypt all communications between ML compute instances in distributed
                    training, choose ``True`` . Encryption provides greater security for distributed
                    training, but training might take longer. How long it takes depends on the
                    amount of communication between compute instances, especially if you use a deep
                    learning algorithm in distributed training.

                  - **EnableManagedSpotTraining** *(boolean) --*

                    When true, enables managed spot training using Amazon EC2 Spot instances to run
                    training jobs instead of on-demand instances. For more information, see
                    model-managed-spot-training .

                  - **CheckpointConfig** *(dict) --*

                    Contains information about the output location for managed spot training
                    checkpoint data.

                    - **S3Uri** *(string) --*

                      Identifies the S3 path where you want Amazon SageMaker to store checkpoints.
                      For example, ``s3://bucket-name/key-name-prefix`` .

                    - **LocalPath** *(string) --*

                      (Optional) The local directory where checkpoints are written. The default
                      directory is ``/opt/ml/checkpoints/`` .

                  - **TrainingTimeInSeconds** *(integer) --*

                    The training time in seconds.

                  - **BillableTimeInSeconds** *(integer) --*

                    The billable time in seconds.

                  - **DebugHookConfig** *(dict) --*

                    Configuration information for the debug hook parameters, collection
                    configuration, and storage paths.

                    - **LocalPath** *(string) --*

                      Path to local storage location for tensors. Defaults to
                      ``/opt/ml/output/tensors/`` .

                    - **S3OutputPath** *(string) --*

                      Path to Amazon S3 storage location for tensors.

                    - **HookParameters** *(dict) --*

                      Configuration information for the debug hook parameters.

                      - *(string) --*

                        - *(string) --*

                    - **CollectionConfigurations** *(list) --*

                      Configuration information for tensor collections.

                      - *(dict) --*

                        Configuration information for tensor collections.

                        - **CollectionName** *(string) --*

                          The name of the tensor collection.

                        - **CollectionParameters** *(dict) --*

                          Parameter values for the tensor collection. The allowed parameters are
                          ``"name"`` , ``"include_regex"`` , ``"reduction_config"`` ,
                          ``"save_config"`` , ``"tensor_names"`` , and ``"save_histogram"`` .

                          - *(string) --*

                            - *(string) --*

                  - **ExperimentConfig** *(dict) --*

                    Configuration for the experiment.

                    - **ExperimentName** *(string) --*

                      The name of the experiment.

                    - **TrialName** *(string) --*

                      The name of the trial.

                    - **TrialComponentDisplayName** *(string) --*

                      Display name for the trial component.

                  - **DebugRuleConfigurations** *(list) --*

                    Information about the debug rule configuration.

                    - *(dict) --*

                      Configuration information for debugging rules.

                      - **RuleConfigurationName** *(string) --*

                        The name of the rule configuration. It must be unique relative to other rule
                        configuration names.

                      - **LocalPath** *(string) --*

                        Path to local storage location for rules. Defaults to
                        ``/opt/ml/processing/output/rule/`` .

                      - **S3OutputPath** *(string) --*

                        Path to Amazon S3 storage location for rules.

                      - **RuleEvaluatorImage** *(string) --*

                        The Amazon Elastic Container (ECR) Image for the managed rule evaluation.

                      - **InstanceType** *(string) --*

                        The instance type to deploy for a training job.

                      - **VolumeSizeInGB** *(integer) --*

                        The size, in GB, of the ML storage volume attached to the notebook instance.

                      - **RuleParameters** *(dict) --*

                        Runtime configuration for rule container.

                        - *(string) --*

                          - *(string) --*

                  - **TensorBoardOutputConfig** *(dict) --*

                    Configuration of storage locations for TensorBoard output.

                    - **LocalPath** *(string) --*

                      Path to local storage location for tensorBoard output. Defaults to
                      ``/opt/ml/output/tensorboard`` .

                    - **S3OutputPath** *(string) --*

                      Path to Amazon S3 storage location for TensorBoard output.

                  - **DebugRuleEvaluationStatuses** *(list) --*

                    Information about the evaluation status of the rules for the training job.

                    - *(dict) --*

                      Information about the status of the rule evaluation.

                      - **RuleConfigurationName** *(string) --*

                        The name of the rule configuration

                      - **RuleEvaluationJobArn** *(string) --*

                        The Amazon Resource Name (ARN) of the rule evaluation job.

                      - **RuleEvaluationStatus** *(string) --*

                        Status of the rule evaluation.

                      - **StatusDetails** *(string) --*

                        Details from the rule evaluation.

                      - **LastModifiedTime** *(datetime) --*

                        Timestamp when the rule evaluation status was last modified.

                  - **Tags** *(list) --*

                    An array of key-value pairs. For more information, see `Using Cost Allocation
                    Tags
                    <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
                    in the *AWS Billing and Cost Management User Guide* .

                    - *(dict) --*

                      Describes a tag.

                      - **Key** *(string) --*

                        The tag key.

                      - **Value** *(string) --*

                        The tag value.

                - **Experiment** *(dict) --*

                  A summary of the properties of an experiment.

                  - **ExperimentName** *(string) --*

                    The name of the experiment.

                  - **ExperimentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the experiment.

                  - **DisplayName** *(string) --*

                    The name of the experiment as displayed. If ``DisplayName`` isn't specified,
                    ``ExperimentName`` is displayed.

                  - **Source** *(dict) --*

                    The source of the experiment.

                    - **SourceArn** *(string) --*

                      The Amazon Resource Name (ARN) of the source.

                    - **SourceType** *(string) --*

                      The source type.

                  - **Description** *(string) --*

                    The description of the experiment.

                  - **CreationTime** *(datetime) --*

                    When the experiment was created.

                  - **CreatedBy** *(dict) --*

                    Information about the user who created or modified an experiment, trial, or
                    trial component.

                    - **UserProfileArn** *(string) --*

                      The Amazon Resource Name (ARN) of the user's profile.

                    - **UserProfileName** *(string) --*

                      The name of the user's profile.

                    - **DomainId** *(string) --*

                      The domain associated with the user.

                  - **LastModifiedTime** *(datetime) --*

                    When the experiment was last modified.

                  - **LastModifiedBy** *(dict) --*

                    Information about the user who created or modified an experiment, trial, or
                    trial component.

                    - **UserProfileArn** *(string) --*

                      The Amazon Resource Name (ARN) of the user's profile.

                    - **UserProfileName** *(string) --*

                      The name of the user's profile.

                    - **DomainId** *(string) --*

                      The domain associated with the user.

                  - **Tags** *(list) --*

                    The list of tags that are associated with the experiment. You can use  Search
                    API to search on the tags.

                    - *(dict) --*

                      Describes a tag.

                      - **Key** *(string) --*

                        The tag key.

                      - **Value** *(string) --*

                        The tag value.

                - **Trial** *(dict) --*

                  A summary of the properties of a trial.

                  - **TrialName** *(string) --*

                    The name of the trial.

                  - **TrialArn** *(string) --*

                    The Amazon Resource Name (ARN) of the trial.

                  - **DisplayName** *(string) --*

                    The name of the trial as displayed. If ``DisplayName`` isn't specified,
                    ``TrialName`` is displayed.

                  - **ExperimentName** *(string) --*

                    The name of the experiment the trial is part of.

                  - **Source** *(dict) --*

                    The source of the trial.

                    - **SourceArn** *(string) --*

                      The Amazon Resource Name (ARN) of the source.

                    - **SourceType** *(string) --*

                      The source job type.

                  - **CreationTime** *(datetime) --*

                    When the trial was created.

                  - **CreatedBy** *(dict) --*

                    Information about the user who created or modified an experiment, trial, or
                    trial component.

                    - **UserProfileArn** *(string) --*

                      The Amazon Resource Name (ARN) of the user's profile.

                    - **UserProfileName** *(string) --*

                      The name of the user's profile.

                    - **DomainId** *(string) --*

                      The domain associated with the user.

                  - **LastModifiedTime** *(datetime) --*

                    Who last modified the trial.

                  - **LastModifiedBy** *(dict) --*

                    Information about the user who created or modified an experiment, trial, or
                    trial component.

                    - **UserProfileArn** *(string) --*

                      The Amazon Resource Name (ARN) of the user's profile.

                    - **UserProfileName** *(string) --*

                      The name of the user's profile.

                    - **DomainId** *(string) --*

                      The domain associated with the user.

                  - **Tags** *(list) --*

                    The list of tags that are associated with the trial. You can use  Search API to
                    search on the tags.

                    - *(dict) --*

                      Describes a tag.

                      - **Key** *(string) --*

                        The tag key.

                      - **Value** *(string) --*

                        The tag value.

                  - **TrialComponentSummaries** *(list) --*

                    A list of the components associated with the trial. For each component, a
                    summary of the component's properties is included.

                    - *(dict) --*

                      A short summary of a trial component.

                      - **TrialComponentName** *(string) --*

                        The name of the trial component.

                      - **TrialComponentArn** *(string) --*

                        The Amazon Resource Name (ARN) of the trial component.

                      - **TrialComponentSource** *(dict) --*

                        The source of the trial component.

                        - **SourceArn** *(string) --*

                          The Amazon Resource Name (ARN) of the source.

                        - **SourceType** *(string) --*

                          The source job type.

                      - **CreationTime** *(datetime) --*

                        When the component was created.

                      - **CreatedBy** *(dict) --*

                        Information about the user who created or modified an experiment, trial, or
                        trial component.

                        - **UserProfileArn** *(string) --*

                          The Amazon Resource Name (ARN) of the user's profile.

                        - **UserProfileName** *(string) --*

                          The name of the user's profile.

                        - **DomainId** *(string) --*

                          The domain associated with the user.

                - **TrialComponent** *(dict) --*

                  A summary of the properties of a trial component.

                  - **TrialComponentName** *(string) --*

                    The name of the trial component.

                  - **DisplayName** *(string) --*

                    The name of the component as displayed. If ``DisplayName`` isn't specified,
                    ``TrialComponentName`` is displayed.

                  - **TrialComponentArn** *(string) --*

                    The Amazon Resource Name (ARN) of the trial component.

                  - **Source** *(dict) --*

                    The source of the trial component.

                    - **SourceArn** *(string) --*

                      The Amazon Resource Name (ARN) of the source.

                    - **SourceType** *(string) --*

                      The source job type.

                  - **Status** *(dict) --*

                    The status of the trial component.

                    - **PrimaryStatus** *(string) --*

                      The status of the trial component.

                    - **Message** *(string) --*

                      If the component failed, a message describing why.

                  - **StartTime** *(datetime) --*

                    When the component started.

                  - **EndTime** *(datetime) --*

                    When the component ended.

                  - **CreationTime** *(datetime) --*

                    When the component was created.

                  - **CreatedBy** *(dict) --*

                    Information about the user who created or modified an experiment, trial, or
                    trial component.

                    - **UserProfileArn** *(string) --*

                      The Amazon Resource Name (ARN) of the user's profile.

                    - **UserProfileName** *(string) --*

                      The name of the user's profile.

                    - **DomainId** *(string) --*

                      The domain associated with the user.

                  - **LastModifiedTime** *(datetime) --*

                    When the component was last modified.

                  - **LastModifiedBy** *(dict) --*

                    Information about the user who created or modified an experiment, trial, or
                    trial component.

                    - **UserProfileArn** *(string) --*

                      The Amazon Resource Name (ARN) of the user's profile.

                    - **UserProfileName** *(string) --*

                      The name of the user's profile.

                    - **DomainId** *(string) --*

                      The domain associated with the user.

                  - **Parameters** *(dict) --*

                    The hyperparameters of the component.

                    - *(string) --*

                      - *(dict) --*

                        The value of a hyperparameter. Only one of ``NumberValue`` or
                        ``StringValue`` can be specified.

                        This object is specified in the  CreateTrialComponent request.

                        - **StringValue** *(string) --*

                          The string value of a categorical hyperparameter. If you specify a value
                          for this parameter, you can't specify the ``NumberValue`` parameter.

                        - **NumberValue** *(float) --*

                          The numeric value of a numeric hyperparameter. If you specify a value for
                          this parameter, you can't specify the ``StringValue`` parameter.

                  - **InputArtifacts** *(dict) --*

                    The input artifacts of the component.

                    - *(string) --*

                      - *(dict) --*

                        Represents an input or output artifact of a trial component. You specify
                        ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and
                        ``OutputArtifacts`` parameters in the  CreateTrialComponent request.

                        Examples of input artifacts are datasets, algorithms, hyperparameters,
                        source code, and instance types. Examples of output artifacts are metrics,
                        snapshots, logs, and images.

                        - **MediaType** *(string) --*

                          The media type of the artifact, which indicates the type of data in the
                          artifact file. The media type consists of a *type* and a *subtype*
                          concatenated with a slash (/) character, for example, text/csv,
                          image/jpeg, and s3/uri. The type specifies the category of the media. The
                          subtype specifies the kind of data.

                        - **Value** *(string) --*

                          The location of the artifact.

                  - **OutputArtifacts** *(dict) --*

                    The output artifacts of the component.

                    - *(string) --*

                      - *(dict) --*

                        Represents an input or output artifact of a trial component. You specify
                        ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and
                        ``OutputArtifacts`` parameters in the  CreateTrialComponent request.

                        Examples of input artifacts are datasets, algorithms, hyperparameters,
                        source code, and instance types. Examples of output artifacts are metrics,
                        snapshots, logs, and images.

                        - **MediaType** *(string) --*

                          The media type of the artifact, which indicates the type of data in the
                          artifact file. The media type consists of a *type* and a *subtype*
                          concatenated with a slash (/) character, for example, text/csv,
                          image/jpeg, and s3/uri. The type specifies the category of the media. The
                          subtype specifies the kind of data.

                        - **Value** *(string) --*

                          The location of the artifact.

                  - **Metrics** *(list) --*

                    The metrics for the component.

                    - *(dict) --*

                      A summary of the metrics of a trial component.

                      - **MetricName** *(string) --*

                        The name of the metric.

                      - **SourceArn** *(string) --*

                        The Amazon Resource Name (ARN) of the source.

                      - **TimeStamp** *(datetime) --*

                        When the metric was last updated.

                      - **Max** *(float) --*

                        The maximum value of the metric.

                      - **Min** *(float) --*

                        The minimum value of the metric.

                      - **Last** *(float) --*

                        The most recent value of the metric.

                      - **Count** *(integer) --*

                        The number of samples used to generate the metric.

                      - **Avg** *(float) --*

                        The average value of the metric.

                      - **StdDev** *(float) --*

                        The standard deviation of the metric.

                  - **SourceDetail** *(dict) --*

                    The source of the trial component.>

                    - **SourceArn** *(string) --*

                      The Amazon Resource Name (ARN) of the source.

                    - **TrainingJob** *(dict) --*

                      Contains information about a training job.

                      - **TrainingJobName** *(string) --*

                        The name of the training job.

                      - **TrainingJobArn** *(string) --*

                        The Amazon Resource Name (ARN) of the training job.

                      - **TuningJobArn** *(string) --*

                        The Amazon Resource Name (ARN) of the associated hyperparameter tuning job
                        if the training job was launched by a hyperparameter tuning job.

                      - **LabelingJobArn** *(string) --*

                        The Amazon Resource Name (ARN) of the labeling job.

                      - **AutoMLJobArn** *(string) --*

                        The Amazon Resource Name (ARN) of the job.

                      - **ModelArtifacts** *(dict) --*

                        Information about the Amazon S3 location that is configured for storing
                        model artifacts.

                        - **S3ModelArtifacts** *(string) --*

                          The path of the S3 object that contains the model artifacts. For example,
                          ``s3://bucket-name/keynameprefix/model.tar.gz`` .

                      - **TrainingJobStatus** *(string) --*

                        The status of the training job.

                        Training job statuses are:

                        * ``InProgress`` - The training is in progress.

                        * ``Completed`` - The training job has completed.

                        * ``Failed`` - The training job has failed. To see the reason for the
                        failure, see the ``FailureReason`` field in the response to a
                        ``DescribeTrainingJobResponse`` call.

                        * ``Stopping`` - The training job is stopping.

                        * ``Stopped`` - The training job has stopped.

                        For more detailed information, see ``SecondaryStatus`` .

                      - **SecondaryStatus** *(string) --*

                        Provides detailed information about the state of the training job. For
                        detailed information about the secondary status of the training job, see
                        ``StatusMessage`` under  SecondaryStatusTransition .

                        Amazon SageMaker provides primary statuses and secondary statuses that apply
                        to each of them:

                          InProgress

                        * ``Starting`` - Starting the training job.

                        * ``Downloading`` - An optional stage for algorithms that support ``File``
                        training input mode. It indicates that data is being downloaded to the ML
                        storage volumes.

                        * ``Training`` - Training is in progress.

                        * ``Uploading`` - Training is complete and the model artifacts are being
                        uploaded to the S3 location.

                          Completed

                        * ``Completed`` - The training job has completed.

                          Failed

                        * ``Failed`` - The training job has failed. The reason for the failure is
                        returned in the ``FailureReason`` field of ``DescribeTrainingJobResponse`` .

                          Stopped

                        * ``MaxRuntimeExceeded`` - The job stopped because it exceeded the maximum
                        allowed runtime.

                        * ``Stopped`` - The training job has stopped.

                          Stopping

                        * ``Stopping`` - Stopping the training job.

                        .. warning::

                          Valid values for ``SecondaryStatus`` are subject to change.

                        We no longer support the following secondary statuses:

                        * ``LaunchingMLInstances``

                        * ``PreparingTrainingStack``

                        * ``DownloadingTrainingImage``

                      - **FailureReason** *(string) --*

                        If the training job failed, the reason it failed.

                      - **HyperParameters** *(dict) --*

                        Algorithm-specific parameters.

                        - *(string) --*

                          - *(string) --*

                      - **AlgorithmSpecification** *(dict) --*

                        Information about the algorithm used for training, and algorithm metadata.

                        - **TrainingImage** *(string) --*

                          The registry path of the Docker image that contains the training
                          algorithm. For information about docker registry paths for built-in
                          algorithms, see `Algorithms Provided by Amazon SageMaker\\: Common
                          Parameters
                          <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-algo-docker-registry-paths.html>`__
                          . Amazon SageMaker supports both ``registry/repository[:tag]`` and
                          ``registry/repository[@digest]`` image path formats. For more information,
                          see `Using Your Own Algorithms with Amazon SageMaker
                          <https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html>`__
                          .

                        - **AlgorithmName** *(string) --*

                          The name of the algorithm resource to use for the training job. This must
                          be an algorithm resource that you created or subscribe to on AWS
                          Marketplace. If you specify a value for this parameter, you can't specify
                          a value for ``TrainingImage`` .

                        - **TrainingInputMode** *(string) --*

                          The input mode that the algorithm supports. For the input modes that
                          Amazon SageMaker algorithms support, see `Algorithms
                          <https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html>`__ . If an
                          algorithm supports the ``File`` input mode, Amazon SageMaker downloads the
                          training data from S3 to the provisioned ML storage Volume, and mounts the
                          directory to docker volume for training container. If an algorithm
                          supports the ``Pipe`` input mode, Amazon SageMaker streams data directly
                          from S3 to the container.

                          In File mode, make sure you provision ML storage volume with sufficient
                          capacity to accommodate the data download from S3. In addition to the
                          training data, the ML storage volume also stores the output model. The
                          algorithm container use ML storage volume to also store intermediate
                          information, if any.

                          For distributed algorithms using File mode, training data is distributed
                          uniformly, and your training duration is predictable if the input data
                          objects size is approximately same. Amazon SageMaker does not split the
                          files any further for model training. If the object sizes are skewed,
                          training won't be optimal as the data distribution is also skewed where
                          one host in a training cluster is overloaded, thus becoming bottleneck in
                          training.

                        - **MetricDefinitions** *(list) --*

                          A list of metric definition objects. Each object specifies the metric name
                          and regular expressions used to parse algorithm logs. Amazon SageMaker
                          publishes each metric to Amazon CloudWatch.

                          - *(dict) --*

                            Specifies a metric that the training algorithm writes to ``stderr`` or
                            ``stdout`` . Amazon SageMakerhyperparameter tuning captures all defined
                            metrics. You specify one metric that a hyperparameter tuning job uses as
                            its objective metric to choose the best training job.

                            - **Name** *(string) --*

                              The name of the metric.

                            - **Regex** *(string) --*

                              A regular expression that searches the output of a training job and
                              gets the value of the metric. For more information about using regular
                              expressions to define metrics, see `Defining Objective Metrics
                              <https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics.html>`__
                              .

                        - **EnableSageMakerMetricsTimeSeries** *(boolean) --*

                          To generate and save time-series metrics during training, set to ``true``
                          . The default is ``false`` and time-series metrics aren't generated except
                          in the following cases:

                          * You use one of the Amazon SageMaker built-in algorithms

                          * You use one of the following prebuilt Amazon SageMaker Docker images:

                            * Tensorflow

                            * MXNet

                            * PyTorch

                          * You specify at least one  MetricDefinition

                      - **RoleArn** *(string) --*

                        The AWS Identity and Access Management (IAM) role configured for the
                        training job.

                      - **InputDataConfig** *(list) --*

                        An array of ``Channel`` objects that describes each data input channel.

                        - *(dict) --*

                          A channel is a named input source that training algorithms can consume.

                          - **ChannelName** *(string) --*

                            The name of the channel.

                          - **DataSource** *(dict) --*

                            The location of the channel data.

                            - **S3DataSource** *(dict) --*

                              The S3 location of the data source that is associated with a channel.

                              - **S3DataType** *(string) --*

                                If you choose ``S3Prefix`` , ``S3Uri`` identifies a key name prefix.
                                Amazon SageMaker uses all objects that match the specified key name
                                prefix for model training.

                                If you choose ``ManifestFile`` , ``S3Uri`` identifies an object that
                                is a manifest file containing a list of object keys that you want
                                Amazon SageMaker to use for model training.

                                If you choose ``AugmentedManifestFile`` , S3Uri identifies an object
                                that is an augmented manifest file in JSON lines format. This file
                                contains the data you want to use for model training.
                                ``AugmentedManifestFile`` can only be used if the Channel's input
                                mode is ``Pipe`` .

                              - **S3Uri** *(string) --*

                                Depending on the value specified for the ``S3DataType`` , identifies
                                either a key name prefix or a manifest. For example:

                                * A key name prefix might look like this:
                                ``s3://bucketname/exampleprefix`` .

                                * A manifest might look like this:
                                ``s3://bucketname/example.manifest``   The manifest is an S3 object
                                which is a JSON file with the following format:  The preceding JSON
                                matches the following ``s3Uris`` :   ``[ {"prefix":
                                "s3://customer_bucket/some/prefix/"},``
                                ``"relative/path/to/custdata-1",``
                                ``"relative/path/custdata-2",``    ``...``
                                ``"relative/path/custdata-N"``    ``]``   The preceding JSON matches
                                the following ``s3Uris`` :
                                ``s3://customer_bucket/some/prefix/relative/path/to/custdata-1``
                                ``s3://customer_bucket/some/prefix/relative/path/custdata-2``
                                ``...``
                                ``s3://customer_bucket/some/prefix/relative/path/custdata-N``   The
                                complete set of ``s3uris`` in this manifest is the input data for
                                the channel for this datasource. The object that each ``s3uris``
                                points to must be readable by the IAM role that Amazon SageMaker
                                uses to perform tasks on your behalf.

                              - **S3DataDistributionType** *(string) --*

                                If you want Amazon SageMaker to replicate the entire dataset on each
                                ML compute instance that is launched for model training, specify
                                ``FullyReplicated`` .

                                If you want Amazon SageMaker to replicate a subset of data on each
                                ML compute instance that is launched for model training, specify
                                ``ShardedByS3Key`` . If there are *n* ML compute instances launched
                                for a training job, each instance gets approximately 1/*n* of the
                                number of S3 objects. In this case, model training on each machine
                                uses only the subset of training data.

                                Don't choose more ML compute instances for training than available
                                S3 objects. If you do, some nodes won't get any data and you will
                                pay for nodes that aren't getting any training data. This applies in
                                both File and Pipe modes. Keep this in mind when developing
                                algorithms.

                                In distributed training, where you use multiple ML compute EC2
                                instances, you might choose ``ShardedByS3Key`` . If the algorithm
                                requires copying training data to the ML storage volume (when
                                ``TrainingInputMode`` is set to ``File`` ), this copies 1/*n* of the
                                number of objects.

                              - **AttributeNames** *(list) --*

                                A list of one or more attribute names to use that are found in a
                                specified augmented manifest file.

                                - *(string) --*

                            - **FileSystemDataSource** *(dict) --*

                              The file system that is associated with a channel.

                              - **FileSystemId** *(string) --*

                                The file system id.

                              - **FileSystemAccessMode** *(string) --*

                                The access mode of the mount of the directory associated with the
                                channel. A directory can be mounted either in ``ro`` (read-only) or
                                ``rw`` (read-write) mode.

                              - **FileSystemType** *(string) --*

                                The file system type.

                              - **DirectoryPath** *(string) --*

                                The full path to the directory to associate with the channel.

                          - **ContentType** *(string) --*

                            The MIME type of the data.

                          - **CompressionType** *(string) --*

                            If training data is compressed, the compression type. The default value
                            is ``None`` . ``CompressionType`` is used only in Pipe input mode. In
                            File mode, leave this field unset or set it to None.

                          - **RecordWrapperType** *(string) --*

                            Specify RecordIO as the value when input data is in raw format but the
                            training algorithm requires the RecordIO format. In this case, Amazon
                            SageMaker wraps each individual S3 object in a RecordIO record. If the
                            input data is already in RecordIO format, you don't need to set this
                            attribute. For more information, see `Create a Dataset Using RecordIO
                            <https://mxnet.apache.org/api/architecture/note_data_loading#data-format>`__
                            .

                            In File mode, leave this field unset or set it to None.

                          - **InputMode** *(string) --*

                            (Optional) The input mode to use for the data channel in a training job.
                            If you don't set a value for ``InputMode`` , Amazon SageMaker uses the
                            value set for ``TrainingInputMode`` . Use this parameter to override the
                            ``TrainingInputMode`` setting in a  AlgorithmSpecification request when
                            you have a channel that needs a different input mode from the training
                            job's general setting. To download the data from Amazon Simple Storage
                            Service (Amazon S3) to the provisioned ML storage volume, and mount the
                            directory to a Docker volume, use ``File`` input mode. To stream data
                            directly from Amazon S3 to the container, choose ``Pipe`` input mode.

                            To use a model for incremental training, choose ``File`` input model.

                          - **ShuffleConfig** *(dict) --*

                            A configuration for a shuffle option for input data in a channel. If you
                            use ``S3Prefix`` for ``S3DataType`` , this shuffles the results of the
                            S3 key prefix matches. If you use ``ManifestFile`` , the order of the S3
                            object references in the ``ManifestFile`` is shuffled. If you use
                            ``AugmentedManifestFile`` , the order of the JSON lines in the
                            ``AugmentedManifestFile`` is shuffled. The shuffling order is determined
                            using the ``Seed`` value.

                            For Pipe input mode, shuffling is done at the start of every epoch. With
                            large datasets this ensures that the order of the training data is
                            different for each epoch, it helps reduce bias and possible overfitting.
                            In a multi-node training job when ShuffleConfig is combined with
                            ``S3DataDistributionType`` of ``ShardedByS3Key`` , the data is shuffled
                            across nodes so that the content sent to a particular node on the first
                            epoch might be sent to a different node on the second epoch.

                            - **Seed** *(integer) --*

                              Determines the shuffling order in ``ShuffleConfig`` value.

                      - **OutputDataConfig** *(dict) --*

                        The S3 path where model artifacts that you configured when creating the job
                        are stored. Amazon SageMaker creates subfolders for model artifacts.

                        - **KmsKeyId** *(string) --*

                          The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to
                          encrypt the model artifacts at rest using Amazon S3 server-side
                          encryption. The ``KmsKeyId`` can be any of the following formats:

                          * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                          * // Amazon Resource Name (ARN) of a KMS Key
                          ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                          * // KMS Key Alias  ``"alias/ExampleAlias"``

                          * // Amazon Resource Name (ARN) of a KMS Key Alias
                          ``"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"``

                          If you use a KMS key ID or an alias of your master key, the Amazon
                          SageMaker execution role must include permissions to call ``kms:Encrypt``
                          . If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS
                          key for Amazon S3 for your role's account. Amazon SageMaker uses
                          server-side encryption with KMS-managed keys for ``OutputDataConfig`` . If
                          you use a bucket policy with an ``s3:PutObject`` permission that only
                          allows objects with server-side encryption, set the condition key of
                          ``s3:x-amz-server-side-encryption`` to ``"aws:kms"`` . For more
                          information, see `KMS-Managed Encryption Keys
                          <https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html>`__
                          in the *Amazon Simple Storage Service Developer Guide.*

                          The KMS key policy must grant permission to the IAM role that you specify
                          in your ``CreateTrainingJob`` , ``CreateTransformJob`` , or
                          ``CreateHyperParameterTuningJob`` requests. For more information, see
                          `Using Key Policies in AWS KMS
                          <http://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html>`__
                          in the *AWS Key Management Service Developer Guide* .

                        - **S3OutputPath** *(string) --*

                          Identifies the S3 path where you want Amazon SageMaker to store the model
                          artifacts. For example, ``s3://bucket-name/key-name-prefix`` .

                      - **ResourceConfig** *(dict) --*

                        Resources, including ML compute instances and ML storage volumes, that are
                        configured for model training.

                        - **InstanceType** *(string) --*

                          The ML compute instance type.

                        - **InstanceCount** *(integer) --*

                          The number of ML compute instances to use. For distributed training,
                          provide a value greater than 1.

                        - **VolumeSizeInGB** *(integer) --*

                          The size of the ML storage volume that you want to provision.

                          ML storage volumes store model artifacts and incremental states. Training
                          algorithms might also use the ML storage volume for scratch space. If you
                          want to store the training data in the ML storage volume, choose ``File``
                          as the ``TrainingInputMode`` in the algorithm specification.

                          You must specify sufficient ML storage for your scenario.

                          .. note::

                            Amazon SageMaker supports only the General Purpose SSD (gp2) ML storage
                            volume type.

                          .. note::

                            Certain Nitro-based instances include local storage with a fixed total
                            size, dependent on the instance type. When using these instances for
                            training, Amazon SageMaker mounts the local instance storage instead of
                            Amazon EBS gp2 storage. You can't request a ``VolumeSizeInGB`` greater
                            than the total size of the local instance storage.

                            For a list of instance types that support local instance storage,
                            including the total size per instance type, see `Instance Store Volumes
                            <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                            .

                        - **VolumeKmsKeyId** *(string) --*

                          The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage
                          volume attached to the ML compute instance(s) that run the training job.

                          .. note::

                            Certain Nitro-based instances include local storage, dependent on the
                            instance type. Local storage volumes are encrypted using a hardware
                            module on the instance. You can't request a ``VolumeKmsKeyId`` when
                            using an instance type with local storage.

                            For a list of instance types that support local instance storage, see
                            `Instance Store Volumes
                            <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes>`__
                            .

                            For more information about local instance storage encryption, see `SSD
                            Instance Store Volumes
                            <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html>`__
                            .

                          The ``VolumeKmsKeyId`` can be in any of the following formats:

                          * // KMS Key ID  ``"1234abcd-12ab-34cd-56ef-1234567890ab"``

                          * // Amazon Resource Name (ARN) of a KMS Key
                          ``"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"``

                      - **VpcConfig** *(dict) --*

                        A  VpcConfig object that specifies the VPC that this training job has access
                        to. For more information, see `Protect Training Jobs by Using an Amazon
                        Virtual Private Cloud
                        <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                        - **SecurityGroupIds** *(list) --*

                          The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security
                          groups for the VPC that is specified in the ``Subnets`` field.

                          - *(string) --*

                        - **Subnets** *(list) --*

                          The ID of the subnets in the VPC to which you want to connect your
                          training job or model.

                          .. note::

                            Amazon EC2 P3 accelerated computing instances are not available in the
                            c/d/e availability zones of region us-east-1. If you want to create
                            endpoints with P3 instances in VPC mode in region us-east-1, create
                            subnets in a/b/f availability zones instead.

                          - *(string) --*

                      - **StoppingCondition** *(dict) --*

                        Specifies a limit to how long a model training job can run. When the job
                        reaches the time limit, Amazon SageMaker ends the training job. Use this API
                        to cap model training costs.

                        To stop a job, Amazon SageMaker sends the algorithm the ``SIGTERM`` signal,
                        which delays job termination for 120 seconds. Algorithms can use this
                        120-second window to save the model artifacts, so the results of training
                        are not lost.

                        - **MaxRuntimeInSeconds** *(integer) --*

                          The maximum length of time, in seconds, that the training or compilation
                          job can run. If job does not complete during this time, Amazon SageMaker
                          ends the job. If value is not specified, default value is 1 day. The
                          maximum value is 28 days.

                        - **MaxWaitTimeInSeconds** *(integer) --*

                          The maximum length of time, in seconds, how long you are willing to wait
                          for a managed spot training job to complete. It is the amount of time
                          spent waiting for Spot capacity plus the amount of time the training job
                          runs. It must be equal to or greater than ``MaxRuntimeInSeconds`` .

                      - **CreationTime** *(datetime) --*

                        A timestamp that indicates when the training job was created.

                      - **TrainingStartTime** *(datetime) --*

                        Indicates the time when the training job starts on training instances. You
                        are billed for the time interval between this time and the value of
                        ``TrainingEndTime`` . The start time in CloudWatch Logs might be later than
                        this time. The difference is due to the time it takes to download the
                        training data and to the size of the training container.

                      - **TrainingEndTime** *(datetime) --*

                        Indicates the time when the training job ends on training instances. You are
                        billed for the time interval between the value of ``TrainingStartTime`` and
                        this time. For successful jobs and stopped jobs, this is the time after
                        model artifacts are uploaded. For failed jobs, this is the time when Amazon
                        SageMaker detects a job failure.

                      - **LastModifiedTime** *(datetime) --*

                        A timestamp that indicates when the status of the training job was last
                        modified.

                      - **SecondaryStatusTransitions** *(list) --*

                        A history of all of the secondary statuses that the training job has
                        transitioned through.

                        - *(dict) --*

                          An array element of
                          DescribeTrainingJobResponse$SecondaryStatusTransitions . It provides
                          additional details about a status that the training job has transitioned
                          through. A training job can be in one of several states, for example,
                          starting, downloading, training, or uploading. Within each state, there
                          are a number of intermediate states. For example, within the starting
                          state, Amazon SageMaker could be starting the training job or launching
                          the ML instances. These transitional states are referred to as the job's
                          secondary status.

                          - **Status** *(string) --*

                            Contains a secondary status information from a training job.

                            Status might be one of the following secondary statuses:

                              InProgress

                            * ``Starting`` - Starting the training job.

                            * ``Downloading`` - An optional stage for algorithms that support
                            ``File`` training input mode. It indicates that data is being downloaded
                            to the ML storage volumes.

                            * ``Training`` - Training is in progress.

                            * ``Uploading`` - Training is complete and the model artifacts are being
                            uploaded to the S3 location.

                              Completed

                            * ``Completed`` - The training job has completed.

                              Failed

                            * ``Failed`` - The training job has failed. The reason for the failure
                            is returned in the ``FailureReason`` field of
                            ``DescribeTrainingJobResponse`` .

                              Stopped

                            * ``MaxRuntimeExceeded`` - The job stopped because it exceeded the
                            maximum allowed runtime.

                            * ``Stopped`` - The training job has stopped.

                              Stopping

                            * ``Stopping`` - Stopping the training job.

                            We no longer support the following secondary statuses:

                            * ``LaunchingMLInstances``

                            * ``PreparingTrainingStack``

                            * ``DownloadingTrainingImage``

                          - **StartTime** *(datetime) --*

                            A timestamp that shows when the training job transitioned to the current
                            secondary status state.

                          - **EndTime** *(datetime) --*

                            A timestamp that shows when the training job transitioned out of this
                            secondary status state into another secondary status state or when the
                            training job has ended.

                          - **StatusMessage** *(string) --*

                            A detailed description of the progress within a secondary status.

                            Amazon SageMaker provides secondary statuses and status messages that
                            apply to each of them:

                              Starting

                            * Starting the training job.

                            * Launching requested ML instances.

                            * Insufficient capacity error from EC2 while launching instances,
                            retrying!

                            * Launched instance was unhealthy, replacing it!

                            * Preparing the instances for training.

                              Training

                            * Downloading the training image.

                            * Training image download completed. Training in progress.

                            .. warning::

                              Status messages are subject to change. Therefore, we recommend not
                              including them in code that programmatically initiates actions. For
                              examples, don't use status messages in if statements.

                            To have an overview of your training job's progress, view
                            ``TrainingJobStatus`` and ``SecondaryStatus`` in  DescribeTrainingJob ,
                            and ``StatusMessage`` together. For example, at the start of a training
                            job, you might see the following:

                            * ``TrainingJobStatus`` - InProgress

                            * ``SecondaryStatus`` - Training

                            * ``StatusMessage`` - Downloading the training image

                      - **FinalMetricDataList** *(list) --*

                        A list of final metric values that are set when the training job completes.
                        Used only if the training job was configured to use metrics.

                        - *(dict) --*

                          The name, value, and date and time of a metric that was emitted to Amazon
                          CloudWatch.

                          - **MetricName** *(string) --*

                            The name of the metric.

                          - **Value** *(float) --*

                            The value of the metric.

                          - **Timestamp** *(datetime) --*

                            The date and time that the algorithm emitted the metric.

                      - **EnableNetworkIsolation** *(boolean) --*

                        If the ``TrainingJob`` was created with network isolation, the value is set
                        to ``true`` . If network isolation is enabled, nodes can't communicate
                        beyond the VPC they run in.

                      - **EnableInterContainerTrafficEncryption** *(boolean) --*

                        To encrypt all communications between ML compute instances in distributed
                        training, choose ``True`` . Encryption provides greater security for
                        distributed training, but training might take longer. How long it takes
                        depends on the amount of communication between compute instances, especially
                        if you use a deep learning algorithm in distributed training.

                      - **EnableManagedSpotTraining** *(boolean) --*

                        When true, enables managed spot training using Amazon EC2 Spot instances to
                        run training jobs instead of on-demand instances. For more information, see
                        model-managed-spot-training .

                      - **CheckpointConfig** *(dict) --*

                        Contains information about the output location for managed spot training
                        checkpoint data.

                        - **S3Uri** *(string) --*

                          Identifies the S3 path where you want Amazon SageMaker to store
                          checkpoints. For example, ``s3://bucket-name/key-name-prefix`` .

                        - **LocalPath** *(string) --*

                          (Optional) The local directory where checkpoints are written. The default
                          directory is ``/opt/ml/checkpoints/`` .

                      - **TrainingTimeInSeconds** *(integer) --*

                        The training time in seconds.

                      - **BillableTimeInSeconds** *(integer) --*

                        The billable time in seconds.

                      - **DebugHookConfig** *(dict) --*

                        Configuration information for the debug hook parameters, collection
                        configuration, and storage paths.

                        - **LocalPath** *(string) --*

                          Path to local storage location for tensors. Defaults to
                          ``/opt/ml/output/tensors/`` .

                        - **S3OutputPath** *(string) --*

                          Path to Amazon S3 storage location for tensors.

                        - **HookParameters** *(dict) --*

                          Configuration information for the debug hook parameters.

                          - *(string) --*

                            - *(string) --*

                        - **CollectionConfigurations** *(list) --*

                          Configuration information for tensor collections.

                          - *(dict) --*

                            Configuration information for tensor collections.

                            - **CollectionName** *(string) --*

                              The name of the tensor collection.

                            - **CollectionParameters** *(dict) --*

                              Parameter values for the tensor collection. The allowed parameters are
                              ``"name"`` , ``"include_regex"`` , ``"reduction_config"`` ,
                              ``"save_config"`` , ``"tensor_names"`` , and ``"save_histogram"`` .

                              - *(string) --*

                                - *(string) --*

                      - **ExperimentConfig** *(dict) --*

                        Configuration for the experiment.

                        - **ExperimentName** *(string) --*

                          The name of the experiment.

                        - **TrialName** *(string) --*

                          The name of the trial.

                        - **TrialComponentDisplayName** *(string) --*

                          Display name for the trial component.

                      - **DebugRuleConfigurations** *(list) --*

                        Information about the debug rule configuration.

                        - *(dict) --*

                          Configuration information for debugging rules.

                          - **RuleConfigurationName** *(string) --*

                            The name of the rule configuration. It must be unique relative to other
                            rule configuration names.

                          - **LocalPath** *(string) --*

                            Path to local storage location for rules. Defaults to
                            ``/opt/ml/processing/output/rule/`` .

                          - **S3OutputPath** *(string) --*

                            Path to Amazon S3 storage location for rules.

                          - **RuleEvaluatorImage** *(string) --*

                            The Amazon Elastic Container (ECR) Image for the managed rule
                            evaluation.

                          - **InstanceType** *(string) --*

                            The instance type to deploy for a training job.

                          - **VolumeSizeInGB** *(integer) --*

                            The size, in GB, of the ML storage volume attached to the notebook
                            instance.

                          - **RuleParameters** *(dict) --*

                            Runtime configuration for rule container.

                            - *(string) --*

                              - *(string) --*

                      - **TensorBoardOutputConfig** *(dict) --*

                        Configuration of storage locations for TensorBoard output.

                        - **LocalPath** *(string) --*

                          Path to local storage location for tensorBoard output. Defaults to
                          ``/opt/ml/output/tensorboard`` .

                        - **S3OutputPath** *(string) --*

                          Path to Amazon S3 storage location for TensorBoard output.

                      - **DebugRuleEvaluationStatuses** *(list) --*

                        Information about the evaluation status of the rules for the training job.

                        - *(dict) --*

                          Information about the status of the rule evaluation.

                          - **RuleConfigurationName** *(string) --*

                            The name of the rule configuration

                          - **RuleEvaluationJobArn** *(string) --*

                            The Amazon Resource Name (ARN) of the rule evaluation job.

                          - **RuleEvaluationStatus** *(string) --*

                            Status of the rule evaluation.

                          - **StatusDetails** *(string) --*

                            Details from the rule evaluation.

                          - **LastModifiedTime** *(datetime) --*

                            Timestamp when the rule evaluation status was last modified.

                      - **Tags** *(list) --*

                        An array of key-value pairs. For more information, see `Using Cost
                        Allocation Tags
                        <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what>`__
                        in the *AWS Billing and Cost Management User Guide* .

                        - *(dict) --*

                          Describes a tag.

                          - **Key** *(string) --*

                            The tag key.

                          - **Value** *(string) --*

                            The tag value.

                  - **Tags** *(list) --*

                    The list of tags that are associated with the component. You can use  Search API
                    to search on the tags.

                    - *(dict) --*

                      Describes a tag.

                      - **Key** *(string) --*

                        The tag key.

                      - **Value** *(string) --*

                        The tag value.

                  - **Parents** *(list) --*

                    An array of the parents of the component. A parent is a trial the component is
                    associated with and the experiment the trial is part of. A component might not
                    have any parents.

                    - *(dict) --*

                      The trial that a trial component is associated with and the experiment the
                      trial is part of. A component might not be associated with a trial. A
                      component can be associated with multiple trials.

                      - **TrialName** *(string) --*

                        The name of the trial.

                      - **ExperimentName** *(string) --*

                        The name of the experiment.

            - **NextToken** *(string) --*

              If the result of the previous ``Search`` request was truncated, the response includes
              a NextToken. To retrieve the next set of results, use the token in the next request.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def start_monitoring_schedule(self, MonitoringScheduleName: str) -> None:
        """
        Starts a previously stopped monitoring schedule.

        .. note::

          New monitoring schedules are immediately started after creation.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StartMonitoringSchedule>`_

        **Request Syntax**
        ::

          response = client.start_monitoring_schedule(
              MonitoringScheduleName='string'
          )
        :type MonitoringScheduleName: string
        :param MonitoringScheduleName: **[REQUIRED]**

          The name of the schedule to start.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def start_notebook_instance(self, NotebookInstanceName: str) -> None:
        """
        Launches an ML compute instance with the latest version of the libraries and attaches your
        ML storage volume. After configuring the notebook instance, Amazon SageMaker sets the
        notebook instance status to ``InService`` . A notebook instance's status must be
        ``InService`` before you can connect to your Jupyter notebook.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StartNotebookInstance>`_

        **Request Syntax**
        ::

          response = client.start_notebook_instance(
              NotebookInstanceName='string'
          )
        :type NotebookInstanceName: string
        :param NotebookInstanceName: **[REQUIRED]**

          The name of the notebook instance to start.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_auto_ml_job(self, AutoMLJobName: str) -> None:
        """
        A method for forcing the termination of a running job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopAutoMLJob>`_

        **Request Syntax**
        ::

          response = client.stop_auto_ml_job(
              AutoMLJobName='string'
          )
        :type AutoMLJobName: string
        :param AutoMLJobName: **[REQUIRED]**

          The name of the object you are requesting.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_compilation_job(self, CompilationJobName: str) -> None:
        """
        Stops a model compilation job.

        To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal. This gracefully
        shuts the job down. If the job hasn't stopped, it sends the SIGKILL signal.

        When it receives a ``StopCompilationJob`` request, Amazon SageMaker changes the
        CompilationJobSummary$CompilationJobStatus of the job to ``Stopping`` . After Amazon
        SageMaker stops the job, it sets the  CompilationJobSummary$CompilationJobStatus to
        ``Stopped`` .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopCompilationJob>`_

        **Request Syntax**
        ::

          response = client.stop_compilation_job(
              CompilationJobName='string'
          )
        :type CompilationJobName: string
        :param CompilationJobName: **[REQUIRED]**

          The name of the model compilation job to stop.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_hyper_parameter_tuning_job(self, HyperParameterTuningJobName: str) -> None:
        """
        Stops a running hyperparameter tuning job and all running training jobs that the tuning job
        launched.

        All model artifacts output from the training jobs are stored in Amazon Simple Storage
        Service (Amazon S3). All data that the training jobs write to Amazon CloudWatch Logs are
        still available in CloudWatch. After the tuning job moves to the ``Stopped`` state, it
        releases all reserved resources for the tuning job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopHyperParameterTuningJob>`_

        **Request Syntax**
        ::

          response = client.stop_hyper_parameter_tuning_job(
              HyperParameterTuningJobName='string'
          )
        :type HyperParameterTuningJobName: string
        :param HyperParameterTuningJobName: **[REQUIRED]**

          The name of the tuning job to stop.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_labeling_job(self, LabelingJobName: str) -> None:
        """
        Stops a running labeling job. A job that is stopped cannot be restarted. Any results
        obtained before the job is stopped are placed in the Amazon S3 output bucket.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopLabelingJob>`_

        **Request Syntax**
        ::

          response = client.stop_labeling_job(
              LabelingJobName='string'
          )
        :type LabelingJobName: string
        :param LabelingJobName: **[REQUIRED]**

          The name of the labeling job to stop.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_monitoring_schedule(self, MonitoringScheduleName: str) -> None:
        """
        Stops a previously started monitoring schedule.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopMonitoringSchedule>`_

        **Request Syntax**
        ::

          response = client.stop_monitoring_schedule(
              MonitoringScheduleName='string'
          )
        :type MonitoringScheduleName: string
        :param MonitoringScheduleName: **[REQUIRED]**

          The name of the schedule to stop.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_notebook_instance(self, NotebookInstanceName: str) -> None:
        """
        Terminates the ML compute instance. Before terminating the instance, Amazon SageMaker
        disconnects the ML storage volume from it. Amazon SageMaker preserves the ML storage volume.
        Amazon SageMaker stops charging you for the ML compute instance when you call
        ``StopNotebookInstance`` .

        To access data on the ML storage volume for a notebook instance that has been terminated,
        call the ``StartNotebookInstance`` API. ``StartNotebookInstance`` launches another ML
        compute instance, configures it, and attaches the preserved ML storage volume so you can
        continue your work.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopNotebookInstance>`_

        **Request Syntax**
        ::

          response = client.stop_notebook_instance(
              NotebookInstanceName='string'
          )
        :type NotebookInstanceName: string
        :param NotebookInstanceName: **[REQUIRED]**

          The name of the notebook instance to terminate.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_processing_job(self, ProcessingJobName: str) -> None:
        """
        Stops a processing job.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopProcessingJob>`_

        **Request Syntax**
        ::

          response = client.stop_processing_job(
              ProcessingJobName='string'
          )
        :type ProcessingJobName: string
        :param ProcessingJobName: **[REQUIRED]**

          The name of the processing job to stop.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_training_job(self, TrainingJobName: str) -> None:
        """
        Stops a training job. To stop a job, Amazon SageMaker sends the algorithm the ``SIGTERM``
        signal, which delays job termination for 120 seconds. Algorithms might use this 120-second
        window to save the model artifacts, so the results of the training is not lost.

        When it receives a ``StopTrainingJob`` request, Amazon SageMaker changes the status of the
        job to ``Stopping`` . After Amazon SageMaker stops the job, it sets the status to
        ``Stopped`` .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopTrainingJob>`_

        **Request Syntax**
        ::

          response = client.stop_training_job(
              TrainingJobName='string'
          )
        :type TrainingJobName: string
        :param TrainingJobName: **[REQUIRED]**

          The name of the training job to stop.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def stop_transform_job(self, TransformJobName: str) -> None:
        """
        Stops a transform job.

        When Amazon SageMaker receives a ``StopTransformJob`` request, the status of the job changes
        to ``Stopping`` . After Amazon SageMaker stops the job, the status is set to ``Stopped`` .
        When you stop a transform job before it is completed, Amazon SageMaker doesn't store the
        job's output in Amazon S3.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/StopTransformJob>`_

        **Request Syntax**
        ::

          response = client.stop_transform_job(
              TransformJobName='string'
          )
        :type TransformJobName: string
        :param TransformJobName: **[REQUIRED]**

          The name of the transform job to stop.

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_code_repository(
        self, CodeRepositoryName: str, GitConfig: ClientUpdateCodeRepositoryGitConfigTypeDef = None
    ) -> ClientUpdateCodeRepositoryResponseTypeDef:
        """
        Updates the specified Git repository with the specified values.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateCodeRepository>`_

        **Request Syntax**
        ::

          response = client.update_code_repository(
              CodeRepositoryName='string',
              GitConfig={
                  'SecretArn': 'string'
              }
          )
        :type CodeRepositoryName: string
        :param CodeRepositoryName: **[REQUIRED]**

          The name of the Git repository to update.

        :type GitConfig: dict
        :param GitConfig:

          The configuration of the git repository, including the URL and the Amazon Resource Name
          (ARN) of the AWS Secrets Manager secret that contains the credentials used to access the
          repository. The secret must have a staging label of ``AWSCURRENT`` and must be in the
          following format:

           ``{"username": *UserName* , "password": *Password* }``

          - **SecretArn** *(string) --*

            The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the
            credentials used to access the git repository. The secret must have a staging label of
            ``AWSCURRENT`` and must be in the following format:

             ``{"username": *UserName* , "password": *Password* }``

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CodeRepositoryArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **CodeRepositoryArn** *(string) --*

              The ARN of the Git repository.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_domain(
        self,
        DomainId: str,
        DefaultUserSettings: ClientUpdateDomainDefaultUserSettingsTypeDef = None,
    ) -> ClientUpdateDomainResponseTypeDef:
        """
        Updates a domain. Changes will impact all of the people in the domain.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateDomain>`_

        **Request Syntax**
        ::

          response = client.update_domain(
              DomainId='string',
              DefaultUserSettings={
                  'ExecutionRole': 'string',
                  'SecurityGroups': [
                      'string',
                  ],
                  'SharingSettings': {
                      'NotebookOutputOption': 'Allowed'|'Disabled',
                      'S3OutputPath': 'string',
                      'S3KmsKeyId': 'string'
                  },
                  'JupyterServerAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'KernelGatewayAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'TensorBoardAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  }
              }
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type DefaultUserSettings: dict
        :param DefaultUserSettings:

          A collection of settings.

          - **ExecutionRole** *(string) --*

            The execution role for the user.

          - **SecurityGroups** *(list) --*

            The security groups.

            - *(string) --*

          - **SharingSettings** *(dict) --*

            The sharing settings.

            - **NotebookOutputOption** *(string) --*

              The notebook output option.

            - **S3OutputPath** *(string) --*

              The Amazon S3 output path.

            - **S3KmsKeyId** *(string) --*

              The AWS Key Management Service encryption key ID.

          - **JupyterServerAppSettings** *(dict) --*

            The Jupyter server's app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **KernelGatewayAppSettings** *(dict) --*

            The kernel gateway app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **TensorBoardAppSettings** *(dict) --*

            The TensorBoard app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'DomainArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **DomainArn** *(string) --*

              The domain Amazon Resource Name (ARN).
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_endpoint(
        self, EndpointName: str, EndpointConfigName: str
    ) -> ClientUpdateEndpointResponseTypeDef:
        """
        Deploys the new ``EndpointConfig`` specified in the request, switches to using newly created
        endpoint, and then deletes resources provisioned for the endpoint using the previous
        ``EndpointConfig`` (there is no availability loss).

        When Amazon SageMaker receives the request, it sets the endpoint status to ``Updating`` .
        After updating the endpoint, it sets the status to ``InService`` . To check the status of an
        endpoint, use the `DescribeEndpoint
        <https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeEndpoint.html>`__ API.

        .. note::

          You must not delete an ``EndpointConfig`` in use by an endpoint that is live or while the
          ``UpdateEndpoint`` or ``CreateEndpoint`` operations are being performed on the endpoint.
          To update an endpoint, you must create a new ``EndpointConfig`` .

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateEndpoint>`_

        **Request Syntax**
        ::

          response = client.update_endpoint(
              EndpointName='string',
              EndpointConfigName='string'
          )
        :type EndpointName: string
        :param EndpointName: **[REQUIRED]**

          The name of the endpoint whose configuration you want to update.

        :type EndpointConfigName: string
        :param EndpointConfigName: **[REQUIRED]**

          The name of the new endpoint configuration.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **EndpointArn** *(string) --*

              The Amazon Resource Name (ARN) of the endpoint.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_endpoint_weights_and_capacities(
        self,
        EndpointName: str,
        DesiredWeightsAndCapacities: List[
            ClientUpdateEndpointWeightsAndCapacitiesDesiredWeightsAndCapacitiesTypeDef
        ],
    ) -> ClientUpdateEndpointWeightsAndCapacitiesResponseTypeDef:
        """
        Updates variant weight of one or more variants associated with an existing endpoint, or
        capacity of one variant associated with an existing endpoint. When it receives the request,
        Amazon SageMaker sets the endpoint status to ``Updating`` . After updating the endpoint, it
        sets the status to ``InService`` . To check the status of an endpoint, use the
        `DescribeEndpoint
        <https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeEndpoint.html>`__ API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateEndpointWeightsAndCapacities>`_

        **Request Syntax**
        ::

          response = client.update_endpoint_weights_and_capacities(
              EndpointName='string',
              DesiredWeightsAndCapacities=[
                  {
                      'VariantName': 'string',
                      'DesiredWeight': ...,
                      'DesiredInstanceCount': 123
                  },
              ]
          )
        :type EndpointName: string
        :param EndpointName: **[REQUIRED]**

          The name of an existing Amazon SageMaker endpoint.

        :type DesiredWeightsAndCapacities: list
        :param DesiredWeightsAndCapacities: **[REQUIRED]**

          An object that provides new capacity and weight values for a variant.

          - *(dict) --*

            Specifies weight and capacity values for a production variant.

            - **VariantName** *(string) --* **[REQUIRED]**

              The name of the variant to update.

            - **DesiredWeight** *(float) --*

              The variant's weight.

            - **DesiredInstanceCount** *(integer) --*

              The variant's capacity.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **EndpointArn** *(string) --*

              The Amazon Resource Name (ARN) of the updated endpoint.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_experiment(
        self, ExperimentName: str, DisplayName: str = None, Description: str = None
    ) -> ClientUpdateExperimentResponseTypeDef:
        """
        Adds, updates, or removes the description of an experiment. Updates the display name of an
        experiment.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateExperiment>`_

        **Request Syntax**
        ::

          response = client.update_experiment(
              ExperimentName='string',
              DisplayName='string',
              Description='string'
          )
        :type ExperimentName: string
        :param ExperimentName: **[REQUIRED]**

          The name of the experiment to update.

        :type DisplayName: string
        :param DisplayName:

          The name of the experiment as displayed. The name doesn't need to be unique. If
          ``DisplayName`` isn't specified, ``ExperimentName`` is displayed.

        :type Description: string
        :param Description:

          The description of the experiment.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExperimentArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **ExperimentArn** *(string) --*

              The Amazon Resource Name (ARN) of the experiment.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_monitoring_schedule(
        self,
        MonitoringScheduleName: str,
        MonitoringScheduleConfig: ClientUpdateMonitoringScheduleMonitoringScheduleConfigTypeDef,
    ) -> ClientUpdateMonitoringScheduleResponseTypeDef:
        """
        Updates a previously created schedule.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateMonitoringSchedule>`_

        **Request Syntax**
        ::

          response = client.update_monitoring_schedule(
              MonitoringScheduleName='string',
              MonitoringScheduleConfig={
                  'ScheduleConfig': {
                      'ScheduleExpression': 'string'
                  },
                  'MonitoringJobDefinition': {
                      'BaselineConfig': {
                          'ConstraintsResource': {
                              'S3Uri': 'string'
                          },
                          'StatisticsResource': {
                              'S3Uri': 'string'
                          }
                      },
                      'MonitoringInputs': [
                          {
                              'EndpointInput': {
                                  'EndpointName': 'string',
                                  'LocalPath': 'string',
                                  'S3InputMode': 'Pipe'|'File',
                                  'S3DataDistributionType': 'FullyReplicated'|'ShardedByS3Key'
                              }
                          },
                      ],
                      'MonitoringOutputConfig': {
                          'MonitoringOutputs': [
                              {
                                  'S3Output': {
                                      'S3Uri': 'string',
                                      'LocalPath': 'string',
                                      'S3UploadMode': 'Continuous'|'EndOfJob'
                                  }
                              },
                          ],
                          'KmsKeyId': 'string'
                      },
                      'MonitoringResources': {
                          'ClusterConfig': {
                              'InstanceCount': 123,
                              'InstanceType':
                              'ml.t3.medium'|'ml.t3.large'|'ml.t3.xlarge'
                              |'ml.t3.2xlarge'|'ml.m4.xlarge'|'ml.m4.2xlarge'
                              |'ml.m4.4xlarge'|'ml.m4.10xlarge'
                              |'ml.m4.16xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'
                              |'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.p2.xlarge'
                              |'ml.p2.8xlarge'|'ml.p2.16xlarge'
                              |'ml.p3.2xlarge'|'ml.p3.8xlarge'
                              |'ml.p3.16xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'
                              |'ml.c5.4xlarge'|'ml.c5.9xlarge'
                              |'ml.c5.18xlarge'|'ml.m5.large'|'ml.m5.xlarge'
                              |'ml.m5.2xlarge'|'ml.m5.4xlarge'
                              |'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.r5.large'
                              |'ml.r5.xlarge'|'ml.r5.2xlarge'|'ml.r5.4xlarge'
                              |'ml.r5.8xlarge'|'ml.r5.12xlarge'
                              |'ml.r5.16xlarge'|'ml.r5.24xlarge',
                              'VolumeSizeInGB': 123,
                              'VolumeKmsKeyId': 'string'
                          }
                      },
                      'MonitoringAppSpecification': {
                          'ImageUri': 'string',
                          'ContainerEntrypoint': [
                              'string',
                          ],
                          'ContainerArguments': [
                              'string',
                          ],
                          'RecordPreprocessorSourceUri': 'string',
                          'PostAnalyticsProcessorSourceUri': 'string'
                      },
                      'StoppingCondition': {
                          'MaxRuntimeInSeconds': 123
                      },
                      'Environment': {
                          'string': 'string'
                      },
                      'NetworkConfig': {
                          'EnableNetworkIsolation': True|False,
                          'VpcConfig': {
                              'SecurityGroupIds': [
                                  'string',
                              ],
                              'Subnets': [
                                  'string',
                              ]
                          }
                      },
                      'RoleArn': 'string'
                  }
              }
          )
        :type MonitoringScheduleName: string
        :param MonitoringScheduleName: **[REQUIRED]**

          The name of the monitoring schedule. The name must be unique within an AWS Region within
          an AWS account.

        :type MonitoringScheduleConfig: dict
        :param MonitoringScheduleConfig: **[REQUIRED]**

          The configuration object that specifies the monitoring schedule and defines the monitoring
          job.

          - **ScheduleConfig** *(dict) --*

            Configures the monitoring schedule.

            - **ScheduleExpression** *(string) --* **[REQUIRED]**

              A cron expression that describes details about the monitoring schedule.

              Currently the only supported cron expressions are:

              * If you want to set the job to start every hour, please use the following:  ``Hourly:
              cron(0 * ? * * *)``

              * If you want to start the job daily:  ``cron(0 [00-23] ? * * *)``

              For example, the following are valid cron expressions:

              * Daily at noon UTC: ``cron(0 12 ? * * *)``

              * Daily at midnight UTC: ``cron(0 0 ? * * *)``

              To support running every 6, 12 hours, the following are also supported:

               ``cron(0 [00-23]/[01-24] ? * * *)``

              For example, the following are valid cron expressions:

              * Every 12 hours, starting at 5pm UTC: ``cron(0 17/12 ? * * *)``

              * Every two hours starting at midnight: ``cron(0 0/2 ? * * *)``

              .. note::

                * Even though the cron expression is set to start at 5PM UTC, note that there could
                be a delay of 0-20 minutes from the actual requested time to run the execution.

                * We recommend that if you would like a daily schedule, you do not provide this
                parameter. Amazon SageMaker will pick a time for running every day.

          - **MonitoringJobDefinition** *(dict) --* **[REQUIRED]**

            Defines the monitoring job.

            - **BaselineConfig** *(dict) --*

              Baseline configuration used to validate that the data conforms to the specified
              constraints and statistics

              - **ConstraintsResource** *(dict) --*

                The baseline constraint file in Amazon S3 that the current monitoring job should
                validated against.

                - **S3Uri** *(string) --*

                  The Amazon S3 URI for the constraints resource.

              - **StatisticsResource** *(dict) --*

                The baseline statistics file in Amazon S3 that the current monitoring job should be
                validated against.

                - **S3Uri** *(string) --*

                  The Amazon S3 URI for the statistics resource.

            - **MonitoringInputs** *(list) --* **[REQUIRED]**

              The array of inputs for the monitoring job. Currently we support monitoring an Amazon
              SageMaker Endpoint.

              - *(dict) --*

                The inputs for a monitoring job.

                - **EndpointInput** *(dict) --* **[REQUIRED]**

                  The endpoint for a monitoring job.

                  - **EndpointName** *(string) --* **[REQUIRED]**

                    An endpoint in customer's account which has enabled ``DataCaptureConfig``
                    enabled.

                  - **LocalPath** *(string) --* **[REQUIRED]**

                    Path to the filesystem where the endpoint data is available to the container.

                  - **S3InputMode** *(string) --*

                    Whether the ``Pipe`` or ``File`` is used as the input mode for transfering data
                    for the monitoring job. ``Pipe`` mode is recommended for large datasets.
                    ``File`` mode is useful for small files that fit in memory. Defaults to ``File``
                    .

                  - **S3DataDistributionType** *(string) --*

                    Whether input data distributed in Amazon S3 is fully replicated or sharded by an
                    S3 key. Defauts to ``FullyReplicated``

            - **MonitoringOutputConfig** *(dict) --* **[REQUIRED]**

              The array of outputs from the monitoring job to be uploaded to Amazon Simple Storage
              Service (Amazon S3).

              - **MonitoringOutputs** *(list) --* **[REQUIRED]**

                Monitoring outputs for monitoring jobs. This is where the output of the periodic
                monitoring jobs is uploaded.

                - *(dict) --*

                  The output object for a monitoring job.

                  - **S3Output** *(dict) --* **[REQUIRED]**

                    The Amazon S3 storage location where the results of a monitoring job are saved.

                    - **S3Uri** *(string) --* **[REQUIRED]**

                      A URI that identifies the Amazon S3 storage location where Amazon SageMaker
                      saves the results of a monitoring job.

                    - **LocalPath** *(string) --* **[REQUIRED]**

                      The local path to the Amazon S3 storage location where Amazon SageMaker saves
                      the results of a monitoring job. LocalPath is an absolute path for the output
                      data.

                    - **S3UploadMode** *(string) --*

                      Whether to upload the results of the monitoring job continuously or after the
                      job completes.

              - **KmsKeyId** *(string) --*

                The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                the model artifacts at rest using Amazon S3 server-side encryption.

            - **MonitoringResources** *(dict) --* **[REQUIRED]**

              Identifies the resources, ML compute instances, and ML storage volumes to deploy for a
              monitoring job. In distributed processing, you specify more than one instance.

              - **ClusterConfig** *(dict) --* **[REQUIRED]**

                The configuration for the cluster resources used to run the processing job.

                - **InstanceCount** *(integer) --* **[REQUIRED]**

                  The number of ML compute instances to use in the model monitoring job. For
                  distributed processing jobs, specify a value greater than 1. The default value is
                  1.

                - **InstanceType** *(string) --* **[REQUIRED]**

                  The ML compute instance type for the processing job.

                - **VolumeSizeInGB** *(integer) --* **[REQUIRED]**

                  The size of the ML storage volume, in gigabytes, that you want to provision. You
                  must specify sufficient ML storage for your scenario.

                - **VolumeKmsKeyId** *(string) --*

                  The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt
                  data on the storage volume attached to the ML compute instance(s) that run the
                  model monitoring job.

            - **MonitoringAppSpecification** *(dict) --* **[REQUIRED]**

              Configures the monitoring job to run a specified Docker container image.

              - **ImageUri** *(string) --* **[REQUIRED]**

                The container image to be run by the monitoring job.

              - **ContainerEntrypoint** *(list) --*

                Specifies the entrypoint for a container used to run the monitoring job.

                - *(string) --*

              - **ContainerArguments** *(list) --*

                An array of arguments for the container used to run the monitoring job.

                - *(string) --*

              - **RecordPreprocessorSourceUri** *(string) --*

                An Amazon S3 URI to a script that is called per row prior to running analysis. It
                can base64 decode the payload and convert it into a flatted json so that the
                built-in container can use the converted data. Applicable only for the built-in
                (first party) containers.

              - **PostAnalyticsProcessorSourceUri** *(string) --*

                An Amazon S3 URI to a script that is called after analysis has been performed.
                Applicable only for the built-in (first party) containers.

            - **StoppingCondition** *(dict) --*

              Specifies a time limit for how long the monitoring job is allowed to run.

              - **MaxRuntimeInSeconds** *(integer) --* **[REQUIRED]**

                The maximum runtime allowed in seconds.

            - **Environment** *(dict) --*

              Sets the environment variables in the Docker container.

              - *(string) --*

                - *(string) --*

            - **NetworkConfig** *(dict) --*

              Specifies networking options for an monitoring job.

              - **EnableNetworkIsolation** *(boolean) --*

                Whether to allow inbound and outbound network calls to and from the containers used
                for the processing job.

              - **VpcConfig** *(dict) --*

                Specifies a VPC that your training jobs and hosted models have access to. Control
                access to and from your training and model containers by configuring the VPC. For
                more information, see `Protect Endpoints by Using an Amazon Virtual Private Cloud
                <https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html>`__ and `Protect
                Training Jobs by Using an Amazon Virtual Private Cloud
                <https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html>`__ .

                - **SecurityGroupIds** *(list) --* **[REQUIRED]**

                  The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups
                  for the VPC that is specified in the ``Subnets`` field.

                  - *(string) --*

                - **Subnets** *(list) --* **[REQUIRED]**

                  The ID of the subnets in the VPC to which you want to connect your training job or
                  model.

                  .. note::

                    Amazon EC2 P3 accelerated computing instances are not available in the c/d/e
                    availability zones of region us-east-1. If you want to create endpoints with P3
                    instances in VPC mode in region us-east-1, create subnets in a/b/f availability
                    zones instead.

                  - *(string) --*

            - **RoleArn** *(string) --* **[REQUIRED]**

              The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to
              perform tasks on your behalf.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MonitoringScheduleArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **MonitoringScheduleArn** *(string) --*

              The Amazon Resource Name (ARN) of the monitoring schedule.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_notebook_instance(
        self,
        NotebookInstanceName: str,
        InstanceType: Literal[
            "ml.t2.medium",
            "ml.t2.large",
            "ml.t2.xlarge",
            "ml.t2.2xlarge",
            "ml.t3.medium",
            "ml.t3.large",
            "ml.t3.xlarge",
            "ml.t3.2xlarge",
            "ml.m4.xlarge",
            "ml.m4.2xlarge",
            "ml.m4.4xlarge",
            "ml.m4.10xlarge",
            "ml.m4.16xlarge",
            "ml.m5.xlarge",
            "ml.m5.2xlarge",
            "ml.m5.4xlarge",
            "ml.m5.12xlarge",
            "ml.m5.24xlarge",
            "ml.c4.xlarge",
            "ml.c4.2xlarge",
            "ml.c4.4xlarge",
            "ml.c4.8xlarge",
            "ml.c5.xlarge",
            "ml.c5.2xlarge",
            "ml.c5.4xlarge",
            "ml.c5.9xlarge",
            "ml.c5.18xlarge",
            "ml.c5d.xlarge",
            "ml.c5d.2xlarge",
            "ml.c5d.4xlarge",
            "ml.c5d.9xlarge",
            "ml.c5d.18xlarge",
            "ml.p2.xlarge",
            "ml.p2.8xlarge",
            "ml.p2.16xlarge",
            "ml.p3.2xlarge",
            "ml.p3.8xlarge",
            "ml.p3.16xlarge",
        ] = None,
        RoleArn: str = None,
        LifecycleConfigName: str = None,
        DisassociateLifecycleConfig: bool = None,
        VolumeSizeInGB: int = None,
        DefaultCodeRepository: str = None,
        AdditionalCodeRepositories: List[str] = None,
        AcceleratorTypes: List[
            Literal[
                "ml.eia1.medium",
                "ml.eia1.large",
                "ml.eia1.xlarge",
                "ml.eia2.medium",
                "ml.eia2.large",
                "ml.eia2.xlarge",
            ]
        ] = None,
        DisassociateAcceleratorTypes: bool = None,
        DisassociateDefaultCodeRepository: bool = None,
        DisassociateAdditionalCodeRepositories: bool = None,
        RootAccess: Literal["Enabled", "Disabled"] = None,
    ) -> Dict[str, Any]:
        """
        Updates a notebook instance. NotebookInstance updates include upgrading or downgrading the
        ML compute instance used for your notebook instance to accommodate changes in your workload
        requirements.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateNotebookInstance>`_

        **Request Syntax**
        ::

          response = client.update_notebook_instance(
              NotebookInstanceName='string',
              InstanceType=
                  'ml.t2.medium'|'ml.t2.large'|'ml.t2.xlarge'|'ml.t2.2xlarge'|'ml.t3.medium'
                  |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'|'ml.m4.xlarge'|'ml.m4.2xlarge'
                  |'ml.m4.4xlarge'|'ml.m4.10xlarge'|'ml.m4.16xlarge'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                  |'ml.m5.4xlarge'|'ml.m5.12xlarge'|'ml.m5.24xlarge'|'ml.c4.xlarge'|'ml.c4.2xlarge'
                  |'ml.c4.4xlarge'|'ml.c4.8xlarge'|'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                  |'ml.c5.9xlarge'|'ml.c5.18xlarge'|'ml.c5d.xlarge'|'ml.c5d.2xlarge'
                  |'ml.c5d.4xlarge'|'ml.c5d.9xlarge'|'ml.c5d.18xlarge'|'ml.p2.xlarge'
                  |'ml.p2.8xlarge'|'ml.p2.16xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                  |'ml.p3.16xlarge',
              RoleArn='string',
              LifecycleConfigName='string',
              DisassociateLifecycleConfig=True|False,
              VolumeSizeInGB=123,
              DefaultCodeRepository='string',
              AdditionalCodeRepositories=[
                  'string',
              ],
              AcceleratorTypes=[
                  'ml.eia1.medium'|'ml.eia1.large'|'ml.eia1.xlarge'|'ml.eia2.medium'|'ml.eia2.large'
                  |'ml.eia2.xlarge',
              ],
              DisassociateAcceleratorTypes=True|False,
              DisassociateDefaultCodeRepository=True|False,
              DisassociateAdditionalCodeRepositories=True|False,
              RootAccess='Enabled'|'Disabled'
          )
        :type NotebookInstanceName: string
        :param NotebookInstanceName: **[REQUIRED]**

          The name of the notebook instance to update.

        :type InstanceType: string
        :param InstanceType:

          The Amazon ML compute instance type.

        :type RoleArn: string
        :param RoleArn:

          The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker can assume to access
          the notebook instance. For more information, see `Amazon SageMaker Roles
          <https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-roles.html>`__ .

          .. note::

            To be able to pass this role to Amazon SageMaker, the caller of this API must have the
            ``iam:PassRole`` permission.

        :type LifecycleConfigName: string
        :param LifecycleConfigName:

          The name of a lifecycle configuration to associate with the notebook instance. For
          information about lifestyle configurations, see `Step 2.1\\: (Optional) Customize a
          Notebook Instance
          <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

        :type DisassociateLifecycleConfig: boolean
        :param DisassociateLifecycleConfig:

          Set to ``true`` to remove the notebook instance lifecycle configuration currently
          associated with the notebook instance. This operation is idempotent. If you specify a
          lifecycle configuration that is not associated with the notebook instance when you call
          this method, it does not throw an error.

        :type VolumeSizeInGB: integer
        :param VolumeSizeInGB:

          The size, in GB, of the ML storage volume to attach to the notebook instance. The default
          value is 5 GB. ML storage volumes are encrypted, so Amazon SageMaker can't determine the
          amount of available free space on the volume. Because of this, you can increase the volume
          size when you update a notebook instance, but you can't decrease the volume size. If you
          want to decrease the size of the ML storage volume in use, create a new notebook instance
          with the desired size.

        :type DefaultCodeRepository: string
        :param DefaultCodeRepository:

          The Git repository to associate with the notebook instance as its default code repository.
          This can be either the name of a Git repository stored as a resource in your account, or
          the URL of a Git repository in `AWS CodeCommit
          <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in any other
          Git repository. When you open a notebook instance, it opens in the directory that contains
          this repository. For more information, see `Associating Git Repositories with Amazon
          SageMaker Notebook Instances
          <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

        :type AdditionalCodeRepositories: list
        :param AdditionalCodeRepositories:

          An array of up to three Git repositories to associate with the notebook instance. These
          can be either the names of Git repositories stored as resources in your account, or the
          URL of Git repositories in `AWS CodeCommit
          <https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html>`__ or in any other
          Git repository. These repositories are cloned at the same level as the default repository
          of your notebook instance. For more information, see `Associating Git Repositories with
          Amazon SageMaker Notebook Instances
          <https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html>`__ .

          - *(string) --*

        :type AcceleratorTypes: list
        :param AcceleratorTypes:

          A list of the Elastic Inference (EI) instance types to associate with this notebook
          instance. Currently only one EI instance type can be associated with a notebook instance.
          For more information, see `Using Elastic Inference in Amazon SageMaker
          <https://docs.aws.amazon.com/sagemaker/latest/dg/ei.html>`__ .

          - *(string) --*

        :type DisassociateAcceleratorTypes: boolean
        :param DisassociateAcceleratorTypes:

          A list of the Elastic Inference (EI) instance types to remove from this notebook instance.
          This operation is idempotent. If you specify an accelerator type that is not associated
          with the notebook instance when you call this method, it does not throw an error.

        :type DisassociateDefaultCodeRepository: boolean
        :param DisassociateDefaultCodeRepository:

          The name or URL of the default Git repository to remove from this notebook instance. This
          operation is idempotent. If you specify a Git repository that is not associated with the
          notebook instance when you call this method, it does not throw an error.

        :type DisassociateAdditionalCodeRepositories: boolean
        :param DisassociateAdditionalCodeRepositories:

          A list of names or URLs of the default Git repositories to remove from this notebook
          instance. This operation is idempotent. If you specify a Git repository that is not
          associated with the notebook instance when you call this method, it does not throw an
          error.

        :type RootAccess: string
        :param RootAccess:

          Whether root access is enabled or disabled for users of the notebook instance. The default
          value is ``Enabled`` .

          .. note::

            If you set this to ``Disabled`` , users don't have root access on the notebook instance,
            but lifecycle configuration scripts still run with root permissions.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {}
          **Response Structure**

          - *(dict) --*
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_notebook_instance_lifecycle_config(
        self,
        NotebookInstanceLifecycleConfigName: str,
        OnCreate: List[ClientUpdateNotebookInstanceLifecycleConfigOnCreateTypeDef] = None,
        OnStart: List[ClientUpdateNotebookInstanceLifecycleConfigOnStartTypeDef] = None,
    ) -> Dict[str, Any]:
        """
        Updates a notebook instance lifecycle configuration created with the
        CreateNotebookInstanceLifecycleConfig API.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateNotebookInstanceLifecycleConfig>`_

        **Request Syntax**
        ::

          response = client.update_notebook_instance_lifecycle_config(
              NotebookInstanceLifecycleConfigName='string',
              OnCreate=[
                  {
                      'Content': 'string'
                  },
              ],
              OnStart=[
                  {
                      'Content': 'string'
                  },
              ]
          )
        :type NotebookInstanceLifecycleConfigName: string
        :param NotebookInstanceLifecycleConfigName: **[REQUIRED]**

          The name of the lifecycle configuration.

        :type OnCreate: list
        :param OnCreate:

          The shell script that runs only once, when you create a notebook instance. The shell
          script must be a base64-encoded string.

          - *(dict) --*

            Contains the notebook instance lifecycle configuration script.

            Each lifecycle configuration script has a limit of 16384 characters.

            The value of the ``$PATH`` environment variable that is available to both scripts is
            ``/sbin:bin:/usr/sbin:/usr/bin`` .

            View CloudWatch Logs for notebook instance lifecycle configurations in log group
            ``/aws/sagemaker/NotebookInstances`` in log stream
            ``[notebook-instance-name]/[LifecycleConfigHook]`` .

            Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script runs
            for longer than 5 minutes, it fails and the notebook instance is not created or started.

            For information about notebook instance lifestyle configurations, see `Step 2.1\\:
            (Optional) Customize a Notebook Instance
            <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

            - **Content** *(string) --*

              A base64-encoded string that contains a shell script for a notebook instance lifecycle
              configuration.

        :type OnStart: list
        :param OnStart:

          The shell script that runs every time you start a notebook instance, including when you
          create the notebook instance. The shell script must be a base64-encoded string.

          - *(dict) --*

            Contains the notebook instance lifecycle configuration script.

            Each lifecycle configuration script has a limit of 16384 characters.

            The value of the ``$PATH`` environment variable that is available to both scripts is
            ``/sbin:bin:/usr/sbin:/usr/bin`` .

            View CloudWatch Logs for notebook instance lifecycle configurations in log group
            ``/aws/sagemaker/NotebookInstances`` in log stream
            ``[notebook-instance-name]/[LifecycleConfigHook]`` .

            Lifecycle configuration scripts cannot run for longer than 5 minutes. If a script runs
            for longer than 5 minutes, it fails and the notebook instance is not created or started.

            For information about notebook instance lifestyle configurations, see `Step 2.1\\:
            (Optional) Customize a Notebook Instance
            <https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html>`__ .

            - **Content** *(string) --*

              A base64-encoded string that contains a shell script for a notebook instance lifecycle
              configuration.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {}
          **Response Structure**

          - *(dict) --*
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_trial(
        self, TrialName: str, DisplayName: str = None
    ) -> ClientUpdateTrialResponseTypeDef:
        """
        Updates the display name of a trial.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateTrial>`_

        **Request Syntax**
        ::

          response = client.update_trial(
              TrialName='string',
              DisplayName='string'
          )
        :type TrialName: string
        :param TrialName: **[REQUIRED]**

          The name of the trial to update.

        :type DisplayName: string
        :param DisplayName:

          The name of the trial as displayed. The name doesn't need to be unique. If ``DisplayName``
          isn't specified, ``TrialName`` is displayed.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_trial_component(
        self,
        TrialComponentName: str,
        DisplayName: str = None,
        Status: ClientUpdateTrialComponentStatusTypeDef = None,
        StartTime: datetime = None,
        EndTime: datetime = None,
        Parameters: Dict[str, ClientUpdateTrialComponentParametersTypeDef] = None,
        ParametersToRemove: List[str] = None,
        InputArtifacts: Dict[str, ClientUpdateTrialComponentInputArtifactsTypeDef] = None,
        InputArtifactsToRemove: List[str] = None,
        OutputArtifacts: Dict[str, ClientUpdateTrialComponentOutputArtifactsTypeDef] = None,
        OutputArtifactsToRemove: List[str] = None,
    ) -> ClientUpdateTrialComponentResponseTypeDef:
        """
        Updates one or more properties of a trial component.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateTrialComponent>`_

        **Request Syntax**
        ::

          response = client.update_trial_component(
              TrialComponentName='string',
              DisplayName='string',
              Status={
                  'PrimaryStatus': 'InProgress'|'Completed'|'Failed',
                  'Message': 'string'
              },
              StartTime=datetime(2015, 1, 1),
              EndTime=datetime(2015, 1, 1),
              Parameters={
                  'string': {
                      'StringValue': 'string',
                      'NumberValue': 123.0
                  }
              },
              ParametersToRemove=[
                  'string',
              ],
              InputArtifacts={
                  'string': {
                      'MediaType': 'string',
                      'Value': 'string'
                  }
              },
              InputArtifactsToRemove=[
                  'string',
              ],
              OutputArtifacts={
                  'string': {
                      'MediaType': 'string',
                      'Value': 'string'
                  }
              },
              OutputArtifactsToRemove=[
                  'string',
              ]
          )
        :type TrialComponentName: string
        :param TrialComponentName: **[REQUIRED]**

          The name of the component to update.

        :type DisplayName: string
        :param DisplayName:

          The name of the component as displayed. The name doesn't need to be unique. If
          ``DisplayName`` isn't specified, ``TrialComponentName`` is displayed.

        :type Status: dict
        :param Status:

          The new status of the component.

          - **PrimaryStatus** *(string) --*

            The status of the trial component.

          - **Message** *(string) --*

            If the component failed, a message describing why.

        :type StartTime: datetime
        :param StartTime:

          When the component started.

        :type EndTime: datetime
        :param EndTime:

          When the component ended.

        :type Parameters: dict
        :param Parameters:

          Replaces all of the component's hyperparameters with the specified hyperparameters.

          - *(string) --*

            - *(dict) --*

              The value of a hyperparameter. Only one of ``NumberValue`` or ``StringValue`` can be
              specified.

              This object is specified in the  CreateTrialComponent request.

              - **StringValue** *(string) --*

                The string value of a categorical hyperparameter. If you specify a value for this
                parameter, you can't specify the ``NumberValue`` parameter.

              - **NumberValue** *(float) --*

                The numeric value of a numeric hyperparameter. If you specify a value for this
                parameter, you can't specify the ``StringValue`` parameter.

        :type ParametersToRemove: list
        :param ParametersToRemove:

          The hyperparameters to remove from the component.

          - *(string) --*

        :type InputArtifacts: dict
        :param InputArtifacts:

          Replaces all of the component's input artifacts with the specified artifacts.

          - *(string) --*

            - *(dict) --*

              Represents an input or output artifact of a trial component. You specify
              ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and ``OutputArtifacts``
              parameters in the  CreateTrialComponent request.

              Examples of input artifacts are datasets, algorithms, hyperparameters, source code,
              and instance types. Examples of output artifacts are metrics, snapshots, logs, and
              images.

              - **MediaType** *(string) --*

                The media type of the artifact, which indicates the type of data in the artifact
                file. The media type consists of a *type* and a *subtype* concatenated with a slash
                (/) character, for example, text/csv, image/jpeg, and s3/uri. The type specifies the
                category of the media. The subtype specifies the kind of data.

              - **Value** *(string) --* **[REQUIRED]**

                The location of the artifact.

        :type InputArtifactsToRemove: list
        :param InputArtifactsToRemove:

          The input artifacts to remove from the component.

          - *(string) --*

        :type OutputArtifacts: dict
        :param OutputArtifacts:

          Replaces all of the component's output artifacts with the specified artifacts.

          - *(string) --*

            - *(dict) --*

              Represents an input or output artifact of a trial component. You specify
              ``TrialComponentArtifact`` as part of the ``InputArtifacts`` and ``OutputArtifacts``
              parameters in the  CreateTrialComponent request.

              Examples of input artifacts are datasets, algorithms, hyperparameters, source code,
              and instance types. Examples of output artifacts are metrics, snapshots, logs, and
              images.

              - **MediaType** *(string) --*

                The media type of the artifact, which indicates the type of data in the artifact
                file. The media type consists of a *type* and a *subtype* concatenated with a slash
                (/) character, for example, text/csv, image/jpeg, and s3/uri. The type specifies the
                category of the media. The subtype specifies the kind of data.

              - **Value** *(string) --* **[REQUIRED]**

                The location of the artifact.

        :type OutputArtifactsToRemove: list
        :param OutputArtifactsToRemove:

          The output artifacts to remove from the component.

          - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TrialComponentArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **TrialComponentArn** *(string) --*

              The Amazon Resource Name (ARN) of the trial component.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_user_profile(
        self,
        DomainId: str,
        UserProfileName: str,
        UserSettings: ClientUpdateUserProfileUserSettingsTypeDef = None,
    ) -> ClientUpdateUserProfileResponseTypeDef:
        """
        Updates a user profile.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateUserProfile>`_

        **Request Syntax**
        ::

          response = client.update_user_profile(
              DomainId='string',
              UserProfileName='string',
              UserSettings={
                  'ExecutionRole': 'string',
                  'SecurityGroups': [
                      'string',
                  ],
                  'SharingSettings': {
                      'NotebookOutputOption': 'Allowed'|'Disabled',
                      'S3OutputPath': 'string',
                      'S3KmsKeyId': 'string'
                  },
                  'JupyterServerAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'KernelGatewayAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  },
                  'TensorBoardAppSettings': {
                      'DefaultResourceSpec': {
                          'EnvironmentArn': 'string',
                          'InstanceType':
                          'system'|'ml.t3.micro'|'ml.t3.small'|'ml.t3.medium'
                          |'ml.t3.large'|'ml.t3.xlarge'|'ml.t3.2xlarge'
                          |'ml.m5.large'|'ml.m5.xlarge'|'ml.m5.2xlarge'
                          |'ml.m5.4xlarge'|'ml.m5.8xlarge'|'ml.m5.12xlarge'
                          |'ml.m5.16xlarge'|'ml.m5.24xlarge'|'ml.c5.large'
                          |'ml.c5.xlarge'|'ml.c5.2xlarge'|'ml.c5.4xlarge'
                          |'ml.c5.9xlarge'|'ml.c5.12xlarge'|'ml.c5.18xlarge'
                          |'ml.c5.24xlarge'|'ml.p3.2xlarge'|'ml.p3.8xlarge'
                          |'ml.p3.16xlarge'|'ml.g4dn.xlarge'|'ml.g4dn.2xlarge'
                          |'ml.g4dn.4xlarge'|'ml.g4dn.8xlarge'|'ml.g4dn.12xlarge'
                          |'ml.g4dn.16xlarge'
                      }
                  }
              }
          )
        :type DomainId: string
        :param DomainId: **[REQUIRED]**

          The domain ID.

        :type UserProfileName: string
        :param UserProfileName: **[REQUIRED]**

          The user profile name.

        :type UserSettings: dict
        :param UserSettings:

          A collection of settings.

          - **ExecutionRole** *(string) --*

            The execution role for the user.

          - **SecurityGroups** *(list) --*

            The security groups.

            - *(string) --*

          - **SharingSettings** *(dict) --*

            The sharing settings.

            - **NotebookOutputOption** *(string) --*

              The notebook output option.

            - **S3OutputPath** *(string) --*

              The Amazon S3 output path.

            - **S3KmsKeyId** *(string) --*

              The AWS Key Management Service encryption key ID.

          - **JupyterServerAppSettings** *(dict) --*

            The Jupyter server's app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **KernelGatewayAppSettings** *(dict) --*

            The kernel gateway app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

          - **TensorBoardAppSettings** *(dict) --*

            The TensorBoard app settings.

            - **DefaultResourceSpec** *(dict) --*

              The instance type and quantity.

              - **EnvironmentArn** *(string) --*

                The Amazon Resource Name (ARN) of the environment.

              - **InstanceType** *(string) --*

                The instance type.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'UserProfileArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **UserProfileArn** *(string) --*

              The user profile Amazon Resource Name (ARN).
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_workteam(
        self,
        WorkteamName: str,
        MemberDefinitions: List[ClientUpdateWorkteamMemberDefinitionsTypeDef] = None,
        Description: str = None,
        NotificationConfiguration: ClientUpdateWorkteamNotificationConfigurationTypeDef = None,
    ) -> ClientUpdateWorkteamResponseTypeDef:
        """
        Updates an existing work team with new member definitions or description.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/UpdateWorkteam>`_

        **Request Syntax**
        ::

          response = client.update_workteam(
              WorkteamName='string',
              MemberDefinitions=[
                  {
                      'CognitoMemberDefinition': {
                          'UserPool': 'string',
                          'UserGroup': 'string',
                          'ClientId': 'string'
                      }
                  },
              ],
              Description='string',
              NotificationConfiguration={
                  'NotificationTopicArn': 'string'
              }
          )
        :type WorkteamName: string
        :param WorkteamName: **[REQUIRED]**

          The name of the work team to update.

        :type MemberDefinitions: list
        :param MemberDefinitions:

          A list of ``MemberDefinition`` objects that contain the updated work team members.

          - *(dict) --*

            Defines the Amazon Cognito user group that is part of a work team.

            - **CognitoMemberDefinition** *(dict) --*

              The Amazon Cognito user group that is part of the work team.

              - **UserPool** *(string) --* **[REQUIRED]**

                An identifier for a user pool. The user pool must be in the same region as the
                service that you are calling.

              - **UserGroup** *(string) --* **[REQUIRED]**

                An identifier for a user group.

              - **ClientId** *(string) --* **[REQUIRED]**

                An identifier for an application client. You must create the app client ID using
                Amazon Cognito.

        :type Description: string
        :param Description:

          An updated description for the work team.

        :type NotificationConfiguration: dict
        :param NotificationConfiguration:

          Configures SNS topic notifications for available or expiring work items

          - **NotificationTopicArn** *(string) --*

            The ARN for the SNS topic to which notifications should be published.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'Workteam': {
                    'WorkteamName': 'string',
                    'MemberDefinitions': [
                        {
                            'CognitoMemberDefinition': {
                                'UserPool': 'string',
                                'UserGroup': 'string',
                                'ClientId': 'string'
                            }
                        },
                    ],
                    'WorkteamArn': 'string',
                    'ProductListingIds': [
                        'string',
                    ],
                    'Description': 'string',
                    'SubDomain': 'string',
                    'CreateDate': datetime(2015, 1, 1),
                    'LastUpdatedDate': datetime(2015, 1, 1),
                    'NotificationConfiguration': {
                        'NotificationTopicArn': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            - **Workteam** *(dict) --*

              A ``Workteam`` object that describes the updated work team.

              - **WorkteamName** *(string) --*

                The name of the work team.

              - **MemberDefinitions** *(list) --*

                The Amazon Cognito user groups that make up the work team.

                - *(dict) --*

                  Defines the Amazon Cognito user group that is part of a work team.

                  - **CognitoMemberDefinition** *(dict) --*

                    The Amazon Cognito user group that is part of the work team.

                    - **UserPool** *(string) --*

                      An identifier for a user pool. The user pool must be in the same region as the
                      service that you are calling.

                    - **UserGroup** *(string) --*

                      An identifier for a user group.

                    - **ClientId** *(string) --*

                      An identifier for an application client. You must create the app client ID
                      using Amazon Cognito.

              - **WorkteamArn** *(string) --*

                The Amazon Resource Name (ARN) that identifies the work team.

              - **ProductListingIds** *(list) --*

                The Amazon Marketplace identifier for a vendor's work team.

                - *(string) --*

              - **Description** *(string) --*

                A description of the work team.

              - **SubDomain** *(string) --*

                The URI of the labeling job's user interface. Workers open this URI to start
                labeling your data objects.

              - **CreateDate** *(datetime) --*

                The date and time that the work team was created (timestamp).

              - **LastUpdatedDate** *(datetime) --*

                The date and time that the work team was last updated (timestamp).

              - **NotificationConfiguration** *(dict) --*

                Configures SNS notifications of available or expiring work items for work teams.

                - **NotificationTopicArn** *(string) --*

                  The ARN for the SNS topic to which notifications should be published.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_algorithms"]
    ) -> paginator_scope.ListAlgorithmsPaginator:
        """
        Get Paginator for `list_algorithms` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_apps"]
    ) -> paginator_scope.ListAppsPaginator:
        """
        Get Paginator for `list_apps` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_auto_ml_jobs"]
    ) -> paginator_scope.ListAutoMLJobsPaginator:
        """
        Get Paginator for `list_auto_ml_jobs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_candidates_for_auto_ml_job"]
    ) -> paginator_scope.ListCandidatesForAutoMLJobPaginator:
        """
        Get Paginator for `list_candidates_for_auto_ml_job` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_code_repositories"]
    ) -> paginator_scope.ListCodeRepositoriesPaginator:
        """
        Get Paginator for `list_code_repositories` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_compilation_jobs"]
    ) -> paginator_scope.ListCompilationJobsPaginator:
        """
        Get Paginator for `list_compilation_jobs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_domains"]
    ) -> paginator_scope.ListDomainsPaginator:
        """
        Get Paginator for `list_domains` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_endpoint_configs"]
    ) -> paginator_scope.ListEndpointConfigsPaginator:
        """
        Get Paginator for `list_endpoint_configs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_endpoints"]
    ) -> paginator_scope.ListEndpointsPaginator:
        """
        Get Paginator for `list_endpoints` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_experiments"]
    ) -> paginator_scope.ListExperimentsPaginator:
        """
        Get Paginator for `list_experiments` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_flow_definitions"]
    ) -> paginator_scope.ListFlowDefinitionsPaginator:
        """
        Get Paginator for `list_flow_definitions` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_human_task_uis"]
    ) -> paginator_scope.ListHumanTaskUisPaginator:
        """
        Get Paginator for `list_human_task_uis` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_hyper_parameter_tuning_jobs"]
    ) -> paginator_scope.ListHyperParameterTuningJobsPaginator:
        """
        Get Paginator for `list_hyper_parameter_tuning_jobs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_labeling_jobs"]
    ) -> paginator_scope.ListLabelingJobsPaginator:
        """
        Get Paginator for `list_labeling_jobs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_labeling_jobs_for_workteam"]
    ) -> paginator_scope.ListLabelingJobsForWorkteamPaginator:
        """
        Get Paginator for `list_labeling_jobs_for_workteam` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_model_packages"]
    ) -> paginator_scope.ListModelPackagesPaginator:
        """
        Get Paginator for `list_model_packages` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_models"]
    ) -> paginator_scope.ListModelsPaginator:
        """
        Get Paginator for `list_models` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_monitoring_executions"]
    ) -> paginator_scope.ListMonitoringExecutionsPaginator:
        """
        Get Paginator for `list_monitoring_executions` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_monitoring_schedules"]
    ) -> paginator_scope.ListMonitoringSchedulesPaginator:
        """
        Get Paginator for `list_monitoring_schedules` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_notebook_instance_lifecycle_configs"]
    ) -> paginator_scope.ListNotebookInstanceLifecycleConfigsPaginator:
        """
        Get Paginator for `list_notebook_instance_lifecycle_configs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_notebook_instances"]
    ) -> paginator_scope.ListNotebookInstancesPaginator:
        """
        Get Paginator for `list_notebook_instances` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_processing_jobs"]
    ) -> paginator_scope.ListProcessingJobsPaginator:
        """
        Get Paginator for `list_processing_jobs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_subscribed_workteams"]
    ) -> paginator_scope.ListSubscribedWorkteamsPaginator:
        """
        Get Paginator for `list_subscribed_workteams` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_tags"]
    ) -> paginator_scope.ListTagsPaginator:
        """
        Get Paginator for `list_tags` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_training_jobs"]
    ) -> paginator_scope.ListTrainingJobsPaginator:
        """
        Get Paginator for `list_training_jobs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_training_jobs_for_hyper_parameter_tuning_job"]
    ) -> paginator_scope.ListTrainingJobsForHyperParameterTuningJobPaginator:
        """
        Get Paginator for `list_training_jobs_for_hyper_parameter_tuning_job` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_transform_jobs"]
    ) -> paginator_scope.ListTransformJobsPaginator:
        """
        Get Paginator for `list_transform_jobs` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_trial_components"]
    ) -> paginator_scope.ListTrialComponentsPaginator:
        """
        Get Paginator for `list_trial_components` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_trials"]
    ) -> paginator_scope.ListTrialsPaginator:
        """
        Get Paginator for `list_trials` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_user_profiles"]
    ) -> paginator_scope.ListUserProfilesPaginator:
        """
        Get Paginator for `list_user_profiles` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_workteams"]
    ) -> paginator_scope.ListWorkteamsPaginator:
        """
        Get Paginator for `list_workteams` operation.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(self, operation_name: Literal["search"]) -> paginator_scope.SearchPaginator:
        """
        Get Paginator for `search` operation.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(self, operation_name: str) -> Boto3Paginator:
        """
        Create a paginator for an operation.

        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you'd normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator("create_foo")``.

        :raise OperationNotPageableError: Raised if the operation is not
            pageable.  You can use the ``client.can_paginate`` method to
            check if an operation is pageable.

        :rtype: L{botocore.paginate.Paginator}
        :return: A paginator object.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["endpoint_deleted"]
    ) -> waiter_scope.EndpointDeletedWaiter:
        """
        Get Waiter `endpoint_deleted`.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["endpoint_in_service"]
    ) -> waiter_scope.EndpointInServiceWaiter:
        """
        Get Waiter `endpoint_in_service`.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["notebook_instance_deleted"]
    ) -> waiter_scope.NotebookInstanceDeletedWaiter:
        """
        Get Waiter `notebook_instance_deleted`.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["notebook_instance_in_service"]
    ) -> waiter_scope.NotebookInstanceInServiceWaiter:
        """
        Get Waiter `notebook_instance_in_service`.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["notebook_instance_stopped"]
    ) -> waiter_scope.NotebookInstanceStoppedWaiter:
        """
        Get Waiter `notebook_instance_stopped`.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["processing_job_completed_or_stopped"]
    ) -> waiter_scope.ProcessingJobCompletedOrStoppedWaiter:
        """
        Get Waiter `processing_job_completed_or_stopped`.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["training_job_completed_or_stopped"]
    ) -> waiter_scope.TrainingJobCompletedOrStoppedWaiter:
        """
        Get Waiter `training_job_completed_or_stopped`.
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(
        self, waiter_name: Literal["transform_job_completed_or_stopped"]
    ) -> waiter_scope.TransformJobCompletedOrStoppedWaiter:
        """
        Get Waiter `transform_job_completed_or_stopped`.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_waiter(self, waiter_name: str) -> Boto3Waiter:
        """
        Returns an object that can wait for some condition.

        :type waiter_name: str
        :param waiter_name: The name of the waiter to get. See the waiters
            section of the service docs for a list of available waiters.

        :returns: The specified waiter object.
        :rtype: botocore.waiter.Waiter
        """


class Exceptions:
    ClientError: Boto3ClientError
    ConflictException: Boto3ClientError
    ResourceInUse: Boto3ClientError
    ResourceLimitExceeded: Boto3ClientError
    ResourceNotFound: Boto3ClientError
